import { __decorate, __param, __awaiter, __rest } from 'tslib';
import { NgModule, ɵɵdefineInjectable, Injectable, Inject, Component, ɵɵinject, EventEmitter, ChangeDetectorRef, Input, Output, ViewChild, ViewEncapsulation, Pipe, ViewChildren, ChangeDetectionStrategy, Directive, TemplateRef, ViewContainerRef } from '@angular/core';
import { DatePipe, CommonModule } from '@angular/common';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { FormGroup, FormControl, Validators, NG_VALIDATORS, NG_ASYNC_VALIDATORS, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { DeviceDetectorService, DeviceDetectorModule } from 'ngx-device-detector';
import { CKEditorModule } from 'ckeditor4-angular';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatInputModule } from '@angular/material/input';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatSelectModule } from '@angular/material/select';
import { MatRadioModule } from '@angular/material/radio';
import { MatAutocompleteModule, MatAutocompleteTrigger } from '@angular/material/autocomplete';
import { MatIconModule } from '@angular/material/icon';
import { MatMenuModule } from '@angular/material/menu';
import { MatChipsModule } from '@angular/material/chips';
import { MatButtonModule } from '@angular/material/button';
import { MatDialogModule, MatDialogRef, MAT_DIALOG_DATA, MatDialog } from '@angular/material/dialog';
import { MatBottomSheetModule, MatBottomSheet } from '@angular/material/bottom-sheet';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { timeout, startWith, map } from 'rxjs/operators';
import { v4 } from 'uuid';
import $$1 from 'jquery';
import swal from 'sweetalert2';
import md5 from 'md5';
import XLSX from 'xlsx';
import { saveAs } from 'file-saver';
import 'bootstrap';
import * as hash from 'object-hash';
import hash__default from 'object-hash';
import 'jquery-datetimepicker';
import { Subscription } from 'rxjs';
import * as Chart from 'chart.js';
import { ENTER, COMMA } from '@angular/cdk/keycodes';
import { DomSanitizer } from '@angular/platform-browser';
import moment from 'moment';
import 'daterangepicker';

let MaterialModule = class MaterialModule {
};
MaterialModule = __decorate([
    NgModule({
        imports: [
            MatTooltipModule,
            MatFormFieldModule,
            MatInputModule,
            MatSelectModule,
            MatAutocompleteModule,
            MatCheckboxModule,
            MatSlideToggleModule,
            MatRadioModule,
            MatIconModule,
            MatMenuModule,
            MatChipsModule,
            MatButtonModule,
            MatDialogModule,
            MatBottomSheetModule,
            MatProgressSpinnerModule
        ],
        exports: [
            MatTooltipModule,
            MatFormFieldModule,
            MatInputModule,
            MatSelectModule,
            MatAutocompleteModule,
            MatCheckboxModule,
            MatSlideToggleModule,
            MatRadioModule,
            MatIconModule,
            MatMenuModule,
            MatChipsModule,
            MatButtonModule,
            MatDialogModule,
            MatBottomSheetModule,
            MatProgressSpinnerModule
        ]
    })
], MaterialModule);

let ConfigurationService = class ConfigurationService {
    constructor() {
    }
    setConfig(configurationOption) {
        this.option = configurationOption;
    }
    getApiConfiguration() {
        this.option = this.option || {};
        this.option.api = this.option.api || {};
        this.option.api.host = this.option.api.host || location.origin;
        this.option.api.localStorageKey = this.option.api.localStorageKey || 'a9b9b57f-cfea-49d8-988b-9e96f486b7c4';
        this.option.api.tokenHeaderKey = this.option.api.tokenHeaderKey || 'Token';
        return this.option.api;
    }
    getExcelConfiguration() {
        if (this.option && this.option.excel) {
            return this.option.excel;
        }
        return null;
    }
    getSettingConfiguration() {
        if (this.option && this.option.setting) {
            return this.option.setting;
        }
        return null;
    }
    getGridConfiguration() {
        if (this.option && this.option.grid) {
            return this.option.grid;
        }
        return null;
    }
    getTranslateConfiguration() {
        var _a;
        return (_a = this.option) === null || _a === void 0 ? void 0 : _a.translate;
    }
};
ConfigurationService.ɵprov = ɵɵdefineInjectable({ factory: function ConfigurationService_Factory() { return new ConfigurationService(); }, token: ConfigurationService, providedIn: "root" });
ConfigurationService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ConfigurationService);

let TranslateService = class TranslateService {
    constructor(configurationService) {
        var _a, _b;
        this.configurationService = configurationService;
        this.undeclaredLanguage = {};
        this.dictionary = {};
        this.translate = (keyWord, language) => {
            var _a;
            keyWord = keyWord.toString().trim();
            language = language || this.currentLanguage;
            if (!keyWord || !language) {
                return keyWord;
            }
            if (!((_a = this.dictionary[language]) === null || _a === void 0 ? void 0 : _a[keyWord])) {
                if (!this.undeclaredLanguage[keyWord]) {
                    this.undeclaredLanguage[keyWord] = true;
                }
                return keyWord;
            }
            return this.dictionary[language][keyWord];
        };
        this.setDictionary = (language, keyWord, value) => {
            if (!this.dictionary[language]) {
                this.dictionary[language] = {
                    [keyWord]: value
                };
            }
            else {
                this.dictionary[language][keyWord] = value;
            }
        };
        this.setDictionaries = (language, dictionary) => {
            this.dictionary[language] = dictionary;
        };
        this.setDefaultLanguage = (language) => {
            this.currentLanguage = language;
        };
        this.getUndeclaredLanguage = () => this.undeclaredLanguage;
        const translateConfiguration = this.configurationService.getTranslateConfiguration();
        if (translateConfiguration) {
            this.currentLanguage = translateConfiguration.defaultLanguage;
            this.dictionary = ((_b = (_a = translateConfiguration).initializeDictionary) === null || _b === void 0 ? void 0 : _b.call(_a)) || {};
        }
    }
};
TranslateService.ctorParameters = () => [
    { type: ConfigurationService }
];
TranslateService = __decorate([
    Injectable()
], TranslateService);

let DialogConfirmComponent = class DialogConfirmComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    onNoClick() {
        this.dialogRef.close();
    }
};
DialogConfirmComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
DialogConfirmComponent = __decorate([
    Component({
        selector: 'sd-dialog-confirm',
        template: "<h1 mat-dialog-title>\r\n  <mat-icon *ngIf=\"data?.icon\">\r\n    {{data?.icon}}\r\n  </mat-icon>{{data?.title || 'Confirm'}}\r\n</h1>\r\n<div mat-dialog-content>\r\n  <div [innerHtml]=\"data?.message\">\r\n  </div>\r\n  <div *ngIf=\"data?.input\">\r\n    <sd-textarea-control [(model)]=\"value\" [maxlength]=\"data.input?.maxlength\" [placeholder]=\"data.input?.placeholder\">\r\n    </sd-textarea-control>\r\n  </div>\r\n</div>\r\n<div mat-dialog-actions align=\"end\">\r\n  <button *ngIf=\"data?.noTitle\" mat-button (click)=\"onNoClick()\">{{data?.noTitle}}</button>\r\n  <button *ngIf=\"data?.yesTitle\" mat-raised-button [mat-dialog-close]=\"value || 'ACCEPT'\" color=\"primary\"\r\n    cdkFocusInitial>{{data?.yesTitle}}</button>\r\n</div>"
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], DialogConfirmComponent);

let NotifyService = class NotifyService {
    constructor(dialog, translateService) {
        this.dialog = dialog;
        this.translateService = translateService;
        this.notifyId = 'N' + v4();
        this.alert = {
            success: (message) => {
                this.dialog.open(DialogConfirmComponent, {
                    width: '400px',
                    data: {
                        icon: 'done',
                        title: this.translateService.translate('Success'),
                        message: message || 'Done!',
                        yesTitle: this.translateService.translate('Ok'),
                    }
                });
            },
            warning: (message) => {
                this.dialog.open(DialogConfirmComponent, {
                    width: '400px',
                    data: {
                        icon: 'warning',
                        title: this.translateService.translate('Warning'),
                        message: message || 'Something went wrong!',
                        yesTitle: this.translateService.translate('Ok'),
                    }
                });
            },
            error: (message) => {
                this.dialog.open(DialogConfirmComponent, {
                    width: '400px',
                    data: {
                        icon: 'error',
                        title: this.translateService.translate('Error'),
                        message: message || 'Something went wrong!',
                        yesTitle: this.translateService.translate('Ok'),
                    }
                });
            },
            image: (imageUrl, imageWidth, imageHeight, option = {}) => {
                swal.fire({
                    title: option.title,
                    html: option.message,
                    imageUrl,
                    imageWidth,
                    imageHeight,
                });
            }
        };
        this.notify = {
            success: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #4F8A10; background-color: #DFF2BF`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-check"></i> ${message || this.translateService.translate('Success')}</div>`;
                this.showNotify(html, delay);
            },
            warning: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #9F6000; background-color: #FEEFB3`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-exclamation-triangle"></i> ${message || this.translateService.translate('Warning')}</div>`;
                this.showNotify(html, delay);
            },
            error: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #D8000C; background-color: #FFD2D2`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-times"></i> ${message || this.translateService.translate('Error')}</div>`;
                this.showNotify(html, delay);
            }
        };
        this.confirmDelete = () => this.confirm(this.translateService.translate('Delete record(s)'));
        this.confirmApprove = () => this.confirm(this.translateService.translate('Approve record(s)'));
        this.confirmWithInput = (title, option = {}) => {
            var _a, _b;
            const dialogRef = this.dialog.open(DialogConfirmComponent, {
                width: '400px',
                data: {
                    title: title || this.translateService.translate('Confirm'),
                    yesTitle: ((_a = option) === null || _a === void 0 ? void 0 : _a.yesTitle) || this.translateService.translate('Yes'),
                    noTitle: ((_b = option) === null || _b === void 0 ? void 0 : _b.noTitle) || this.translateService.translate('No'),
                    input: {
                        maxlength: 255
                    }
                }
            });
            return new Promise(resolve => {
                dialogRef.afterClosed().subscribe(result => {
                    if (result) {
                        if (result === 'ACCEPT') {
                            resolve('');
                        }
                        else {
                            resolve(result);
                        }
                    }
                });
            });
            // return new Promise(resolve => {
            //   swal.fire({
            //     title,
            //     input: 'textarea',
            //     inputPlaceholder: 'Tối đa 225 ký tự...',
            //     inputAttributes: {
            //       'aria-label': 'Tối đa 225 ký tự'
            //     },
            //     showCancelButton: true,
            //     confirmButtonColor: '#3085d6',
            //     cancelButtonColor: '#adadad',
            //     confirmButtonText: option.yesTitle || this.translateService.translate('Yes'),
            //     cancelButtonText: option.noTitle || this.translateService.translate('No'),
            //     reverseButtons: true,
            //     inputValidator: (value) => {
            //       if (!value || value?.length > 255) {
            //         return 'Vui lòng nhập lý do tối đa 255 ký tự!';
            //       }
            //     },
            //     allowOutsideClick: () => false
            //   }).then((result) => {
            //     if (result.value) {
            //       resolve(result.value);
            //     }
            //   });
            // });
        };
    }
    confirm(message, option = {}) {
        var _a, _b, _c;
        const dialogRef = this.dialog.open(DialogConfirmComponent, {
            width: '400px',
            data: {
                title: ((_a = option) === null || _a === void 0 ? void 0 : _a.title) || this.translateService.translate('Confirm'),
                message,
                yesTitle: ((_b = option) === null || _b === void 0 ? void 0 : _b.yesTitle) || this.translateService.translate('Yes'),
                noTitle: ((_c = option) === null || _c === void 0 ? void 0 : _c.noTitle) || this.translateService.translate('No'),
            }
        });
        return new Promise(resolve => {
            dialogRef.afterClosed().subscribe(result => {
                if (result) {
                    resolve();
                }
            });
        });
    }
    showNotify(html, delay) {
        if ($$1(`#${this.notifyId}`).length === 0) {
            $$1('body').append(html);
            const element = $$1(`#${this.notifyId}`);
            element.slideDown(200);
            setTimeout(() => {
                $$1('body').children(`#${this.notifyId}`).remove();
            }, delay || 5000);
        }
    }
};
NotifyService.ctorParameters = () => [
    { type: MatDialog },
    { type: TranslateService }
];
NotifyService.ɵprov = ɵɵdefineInjectable({ factory: function NotifyService_Factory() { return new NotifyService(ɵɵinject(MatDialog), ɵɵinject(TranslateService)); }, token: NotifyService, providedIn: "root" });
NotifyService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], NotifyService);

let ApiService = class ApiService {
    constructor(httpClient, notifyService, configurationService, translateService) {
        this.httpClient = httpClient;
        this.notifyService = notifyService;
        this.configurationService = configurationService;
        this.translateService = translateService;
        this.uploadId = 'U' + v4();
        this.init = () => {
            const apiConfiguration = this.configurationService.getApiConfiguration();
            this.host = apiConfiguration.host;
            this.tokenHeaderKey = apiConfiguration.tokenHeaderKey;
            this.setCustomHeader = apiConfiguration.setCustomHeader;
            this.beforeRemote = apiConfiguration.beforeRemote;
            this.afterRemote = apiConfiguration.afterRemote;
        };
        this.uploadSingle = (url, option) => {
            return new Promise((resolve, reject) => {
                if ($$1(`#${this.uploadId}`).length) {
                    $$1('body').children(`#${this.uploadId}`).remove();
                }
                $$1('body').append(`<input id="${this.uploadId}" style="display: none" type="file" />`);
                $$1(`#${this.uploadId}`).on('change', (evt) => {
                    try {
                        const target = evt.target;
                        const fileToUpload = target.files.item(0);
                        this.upload(url, fileToUpload, option).then(resolve).catch(reject);
                    }
                    catch (error) {
                        reject(error);
                    }
                });
                $$1(`#${this.uploadId}`).trigger('click');
            });
        };
        this.upload = (url, file, option) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            const { translate } = this.translateService;
            const lastDot = file.name.lastIndexOf('.');
            if (lastDot === -1) {
                const message = this.translateService.translate(`Invalid file extension`);
                this.notifyService.notify.warning(message);
                throw new Error(message);
            }
            const extension = file.name.substring(lastDot + 1);
            if (option) {
                if (((_a = option.extensions) === null || _a === void 0 ? void 0 : _a.length) && !option.extensions.some(e => e.toUpperCase() === extension.toUpperCase())) {
                    const message = `[${file.name}] ${translate('Uploaded file is not match extension')} ${option.extensions.join(', ')}`;
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
                if (option.maxSizeInMb > 0 && option.maxSizeInMb * 1024 * 1024 < file.size) {
                    const message = `[${file.name}] ${translate('Max file size')} ${option.maxSizeInMb} Mbs`;
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
                if (option.validator && option.validator(file.name)) {
                    const message = option.validator(file.name);
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
            }
            const formData = new FormData();
            formData.append('file', file, file.name);
            return yield this.post(url, formData, this.defaultHeader);
        });
        this.setTokenHeaderValue = (tokenHeaderValue) => {
            localStorage.setItem(this.key, JSON.stringify({ tokenHeaderValue }));
        };
        this.getTokenHeaderValue = () => {
            return this.token;
        };
    }
    get key() {
        var _a;
        const apiConfiguration = this.configurationService.getApiConfiguration();
        return ((_a = apiConfiguration) === null || _a === void 0 ? void 0 : _a.localStorageKey) || 'a9b9b57f-cfea-49d8-988b-9e96f486b7c4';
    }
    get token() {
        try {
            const { tokenHeaderValue } = JSON.parse(localStorage.getItem(this.key));
            return tokenHeaderValue;
        }
        catch (err) {
            return '';
        }
    }
    get defaultHeader() {
        let httpHeaders = new HttpHeaders();
        if (this.tokenHeaderKey) {
            httpHeaders = httpHeaders.set(this.tokenHeaderKey, this.token);
        }
        return httpHeaders;
    }
    get headers() {
        if (this.setCustomHeader) {
            return this.setCustomHeader(this.defaultHeader);
        }
        return this.defaultHeader;
    }
    post(url, body, headers) {
        this.init();
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        headers = headers || this.headers;
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'POST',
                headers,
                body
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.post(encodeURI(url), body, {
                observe: 'response',
                headers
            }).pipe(timeout(600000)).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'POST',
                        headers,
                        body,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'POST',
                        headers,
                        body,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse);
            });
        });
    }
    put(url, body, headers) {
        this.init();
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        headers = headers || this.headers;
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'PUT',
                headers,
                body
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.put(encodeURI(url), body, {
                observe: 'response',
                headers
            }).pipe(timeout(600000)).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'PUT',
                        headers,
                        body,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'PUT',
                        headers,
                        body,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse);
            });
        });
    }
    get(url, headers, options) {
        this.init();
        headers = headers || this.headers;
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'GET',
                headers
            });
        }
        return new Promise((resolve, reject) => {
            var _a, _b;
            if (((_a = options) === null || _a === void 0 ? void 0 : _a.responseType) && options.responseType !== 'json') {
                this.httpClient.get(encodeURI(url), { observe: 'body', headers, responseType: (_b = options) === null || _b === void 0 ? void 0 : _b.responseType })
                    .toPromise().then(result => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: null,
                            result
                        });
                    }
                    resolve(result);
                }).catch((httpErrorResponse) => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: httpErrorResponse.status,
                            result: httpErrorResponse.error
                        });
                    }
                    reject(httpErrorResponse.error);
                });
            }
            else {
                this.httpClient.get(encodeURI(url), { observe: 'response', headers }).toPromise().then(result => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: result.status,
                            result: result.body
                        });
                    }
                    if (result.ok) {
                        resolve(result.body);
                    }
                    else {
                        reject(result.body);
                    }
                }).catch((httpErrorResponse) => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: httpErrorResponse.status,
                            result: httpErrorResponse.error
                        });
                    }
                    reject(httpErrorResponse.error);
                });
            }
        });
    }
    delete(url, headers) {
        this.init();
        headers = headers || this.headers;
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'DELETE',
                headers
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.delete(encodeURI(url), { observe: 'response', headers }).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'DELETE',
                        headers,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'DELETE',
                        headers,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse.error);
            });
        });
    }
    get hasTokenHeaderValue() {
        return !!this.token;
    }
    clearToken() {
        localStorage.removeItem(this.key);
    }
    getHost() {
        return this.host;
    }
};
ApiService.ctorParameters = () => [
    { type: HttpClient },
    { type: NotifyService },
    { type: ConfigurationService },
    { type: TranslateService }
];
ApiService.ɵprov = ɵɵdefineInjectable({ factory: function ApiService_Factory() { return new ApiService(ɵɵinject(HttpClient), ɵɵinject(NotifyService), ɵɵinject(ConfigurationService), ɵɵinject(TranslateService)); }, token: ApiService, providedIn: "root" });
ApiService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ApiService);

let UtilityService = class UtilityService {
    constructor(notifyService) {
        this.notifyService = notifyService;
        this.handle = {
            error: (err) => {
                if (typeof (err) === 'string') {
                    this.notifyService.notify.warning(err);
                }
                else if (typeof (err) === 'object') {
                    let message = err.error || err.message || err.ExceptionMessage || err.Message || 'UNKNOWN ERROR';
                    if (typeof (err.json) === 'function') {
                        err = err.json();
                        if (err) {
                            message = err.error || err.message || err.ExceptionMessage || err.Message || 'UNKNOWN ERROR';
                        }
                    }
                    this.notifyService.notify.warning(message);
                }
                else {
                    console.error(err);
                    this.notifyService.notify.warning('UNKNOWN ERROR');
                }
            }
        };
        this.hashMD5 = (key) => md5(key);
        this.arrayToObject = (items, key) => {
            return items.reduce((obj, item) => { obj[item[key]] = item; return obj; }, {});
        };
        this.isUuid = (key) => {
            key = key || '';
            return key.length === 36;
            // const regex = new Regex('[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}');
            // return regex.test(key);
        };
    }
    changeAliasLowerCase(alias) {
        let str = alias || '';
        str = str.toString().toLowerCase();
        str = str.replace(/à|á|ạ|ả|ã|â|ầ|ấ|ậ|ẩ|ẫ|ă|ằ|ắ|ặ|ẳ|ẵ/g, 'a');
        str = str.replace(/è|é|ẹ|ẻ|ẽ|ê|ề|ế|ệ|ể|ễ/g, 'e');
        str = str.replace(/ì|í|ị|ỉ|ĩ/g, 'i');
        str = str.replace(/ò|ó|ọ|ỏ|õ|ô|ồ|ố|ộ|ổ|ỗ|ơ|ờ|ớ|ợ|ở|ỡ/g, 'o');
        str = str.replace(/ù|ú|ụ|ủ|ũ|ư|ừ|ứ|ự|ử|ữ/g, 'u');
        str = str.replace(/ỳ|ý|ỵ|ỷ|ỹ/g, 'y');
        str = str.replace(/đ/g, 'd');
        str = str.replace(/!|@|%|\^|\*|\(|\)|\+|\=|\<|\>|\?|\/|,|\.|\:|\;|\'|\"|\&|\#|\[|\]|~|\$|_|`|-|{|}|\||\\/g, ' ');
        str = str.replace(/ + /g, ' ');
        str = str.trim();
        return str;
    }
};
UtilityService.ctorParameters = () => [
    { type: NotifyService }
];
UtilityService.ɵprov = ɵɵdefineInjectable({ factory: function UtilityService_Factory() { return new UtilityService(ɵɵinject(NotifyService)); }, token: UtilityService, providedIn: "root" });
UtilityService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], UtilityService);

let ExcelService = class ExcelService {
    constructor(configurationService, notifyService) {
        this.configurationService = configurationService;
        this.notifyService = notifyService;
        this.importId = 'I' + v4();
        this.import = () => {
            return new Promise((resolve, reject) => {
                if ($$1(`#${this.importId}`).length) {
                    $$1('body').children(`#${this.importId}`).remove();
                }
                $$1('body').append(`<input id="${this.importId}" style="display: none" type="file" />`);
                $$1(`#${this.importId}`).on('change', (evt) => {
                    try {
                        const target = evt.target;
                        if (target.files.length !== 1) {
                            throw new Error('Cannot use multiple files');
                        }
                        const reader = new FileReader();
                        reader.onload = (e) => {
                            const bstr = e.target.result;
                            const wb = XLSX.read(bstr, { type: 'binary' });
                            const wsname = wb.SheetNames[0];
                            const ws = wb.Sheets[wsname];
                            const lines = (XLSX.utils.sheet_to_json(ws, { header: 1 }));
                            const records = [];
                            const headers = lines[0];
                            lines.splice(0, 1);
                            lines.forEach(line => {
                                const record = {};
                                let hasValue = false;
                                headers.forEach((header, index) => {
                                    record[header] = line[index];
                                    if (line[index] !== undefined && line[index] !== null && line[index].toString()) {
                                        hasValue = true;
                                    }
                                    if (typeof (record[header]) === 'string') {
                                        record[header] = record[header].trim();
                                    }
                                    if (record[header] === '') {
                                        record[header] = null;
                                    }
                                });
                                if (hasValue) {
                                    records.push(record);
                                }
                            });
                            resolve({
                                items: records,
                                file: target.files[0]
                            });
                        };
                        reader.readAsBinaryString(target.files[0]);
                    }
                    catch (error) {
                        reject(error);
                    }
                });
                $$1(`#${this.importId}`).trigger('click');
            });
        };
        this.export = (exportInfo) => {
            /* Worksheet */
            const worksheet = XLSX.utils.json_to_sheet(exportInfo.data, { cellDates: true });
            /* Workbook */
            const workbook = XLSX.utils.book_new();
            /* Add worksheet to workbook */
            XLSX.utils.book_append_sheet(workbook, worksheet, exportInfo.sheetName || 'Default');
            const wbout = XLSX.write(workbook, { bookType: 'xlsx', type: 'binary' });
            const fileName = exportInfo.fileName ? exportInfo.fileName + this.current() : v4() + '.xlsx';
            saveAs(new Blob([this.s2ab(wbout)], { type: 'application/octet-stream' }), fileName);
        };
        this.current = () => {
            const now = new Date();
            const year = now.getFullYear();
            const month = (now.getMonth() + 1).toString().padStart(2, '0');
            const day = now.getDate().toString().padStart(2, '0');
            const hour = now.getHours().toString().padStart(2, '0');
            const minute = now.getMinutes().toString().padStart(2, '0');
            const second = now.getSeconds().toString().padStart(2, '0');
            return `${year}-${month}-${day} ${hour}:${minute}:${second}`;
        };
        this.s2ab = (s) => {
            const buffer = new ArrayBuffer(s.length);
            const view = new Uint8Array(buffer);
            for (let i = 0; i < s.length; ++i) {
                // tslint:disable-next-line: no-bitwise
                view[i] = s.charCodeAt(i) & 0xFF;
            }
            return buffer;
        };
        this.generateExcelTemplate = (excelTemplate) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.generateTemplate(excelTemplate).catch(err => {
                this.notifyService.notify.error(err);
                return {
                    filePath: ''
                };
            });
        });
        this.uploadTemplate = (key, validator) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.uploadTemplate(key, validator);
        });
        this.downloadTemplate = (filePath, fileName) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            yield this.configuration.downloadTemplate(filePath, fileName);
        });
        this.generateExcelDataByTemplate = (filePath, columns, items, fileName) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            const result = yield this.configuration.generateExcelDataByTemplate(filePath, columns, items).catch(err => {
                this.notifyService.notify.error(err);
                return {
                    filePath: ''
                };
            });
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                yield this.configuration.downloadTemplate(result.filePath, fileName || `${v4()}.xlsx`);
            }
        });
        this.getFiles = (key) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.getFiles(key);
        });
        this.remove = (key, name) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.remove(key, name);
        });
    }
    get configuration() {
        return this.configurationService.getExcelConfiguration();
    }
};
ExcelService.ctorParameters = () => [
    { type: ConfigurationService },
    { type: NotifyService }
];
ExcelService.ɵprov = ɵɵdefineInjectable({ factory: function ExcelService_Factory() { return new ExcelService(ɵɵinject(ConfigurationService), ɵɵinject(NotifyService)); }, token: ExcelService, providedIn: "root" });
ExcelService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ExcelService);

let LoadingService = class LoadingService {
    constructor() {
        this.loadingId = 'L' + v4();
        this.progressId = 'P' + v4();
        this.start = (element = 'body') => {
            $$1(element).append(this.loadingNormal);
        };
        this.stop = () => {
            $$1('body').children(`#${this.loadingId}`).remove();
        };
    }
    // Loading
    get loadingNormal() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100vh;width:100vw;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;"><i class="fa fa-5x fa-spinner fa-pulse" style="margin-top:calc(50vh - 2.5rem);margin-left:calc(50vw - 2.5rem)"></i></div>`;
    }
    get loadingSearching() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/searching.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    get loadingRalph() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/ralph.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    get loadingFiveBalls() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/five-balls.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    startProgress(title, current, max) {
        this.max = max;
        let html = `<div id="${this.progressId}" class="modal fade" data-backdrop="static" data-keyboard="false" tabindex="-1" role="dialog" aria-hidden="true" style="padding-top:15%; overflow-y:visible;">
                        <div class="modal-dialog modal-m">
                            <div class="modal-content">
                                <div class="modal-header"><h3 style="margin:0;">${title} (<span id="abcd">${current}</span>/${max})</h3></div>
                            <div class="modal-body">
                                <div class="progress">
                                    <div id="cde" class="progress-bar progress-bar-striped progress-bar-animated" role="progressbar" style="width: ${current / 100}%"></div>
                                </div>
                            </div>
                        </div>
                    </div>`;
        $$1('body').append(html);
        $$1(`#${this.progressId}`).modal('show');
    }
    updateProgress(current) {
        $$1(`#${this.progressId}`).find('#abcd').html(current.toString());
        $$1(`#${this.progressId}`).find('#cde').css('width', `${current * 100 / this.max}%`);
    }
    stopProgress() {
        $$1(`#${this.progressId}`).modal('hide');
        setTimeout(() => {
            $$1(`#${this.progressId}`).remove();
        }, 1000);
    }
};
LoadingService = __decorate([
    Injectable()
], LoadingService);

let InputControlComponent = class InputControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.name = v4();
        this.appearance = 'legacy ';
        this.type = 'text';
        this.step = 0.01;
        this.modelChange = new EventEmitter();
        this.icon = 'fa fa-search';
        // tslint:disable-next-line: no-output-native
        this.click = new EventEmitter();
        this.sdClick = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.sdFocus = new EventEmitter();
        this.keyupEnter = new EventEmitter();
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.onFocus = () => {
            this.sdFocus.emit();
        };
        this.blur = () => {
            $(this.control.nativeElement).trigger('blur');
        };
    }
    set model(value) {
        this._model = value;
        this.ref.detectChanges();
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
        this.sdChange.emit(this._model);
    }
    onKeyupEnter() {
        this.keyupEnter.emit(this._model);
    }
    onClick() {
        this.click.emit(this._model);
        this.sdClick.emit(this._model);
    }
};
InputControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], InputControlComponent.prototype, "appearance", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "placeholder", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "step", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "model", null);
__decorate([
    Output()
], InputControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "maxlength", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "pattern", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "icon", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "validator", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "tooltip", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "click", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdClick", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdFocus", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "keyupEnter", void 0);
__decorate([
    ViewChild('control')
], InputControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], InputControlComponent.prototype, "formModel", void 0);
InputControlComponent = __decorate([
    Component({
        selector: 'sd-input-control',
        template: "<mat-form-field class=\"sd-form\" [ngClass]=\"{'sd-form-with-information':tooltip}\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #formModel=\"ngModel\" [type]=\"type\" [name]=\"name\" #control matInput\r\n    placeholder=\"{{placeholder || label}}\" [ngModel]=\"_model\" (ngModelChange)=\"onChange($event)\"\r\n    (keyup.enter)=\"onKeyupEnter()\" (focus)=\"onFocus()\" [required]=\"required\" [maxlength]=\"maxlength\" [pattern]=\"pattern\"\r\n    [disabled]=\"disabled\" [sdCustomValidator]=\"validator\" autocomplete=\"off\">\r\n  <span class=\"mr-1\" *ngIf=\"maxlength\" matSuffix>{{_model?.length || 0}}/{{maxlength}}</span>\r\n  <i *ngIf=\"click?.observers?.length || sdClick?.observers?.length\" [className]=\"icon\" (click)=\"onClick()\"\r\n    style=\"cursor:pointer\" matSuffix></i>\r\n\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.maxlength\">\r\n    {{'Max length' | sdTranslate}} <strong>{{maxlength}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.pattern\">\r\n    {{'Pattern error' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    <strong>{{formModel?.errors?.customValidator}}</strong>\r\n  </mat-error>\r\n</mat-form-field>\r\n<div *ngIf=\"tooltip\" class=\"sd-information\">\r\n  <i class=\"fa fa-info-circle fa-fw\" [matTooltip]=\"_model | inputTooltipPipe:tooltip\" (click)=\"sdTooltip.toggle()\" #sdTooltip=\"matTooltip\"></i>\r\n</div>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}"]
    })
], InputControlComponent);

const defaultGridOption = {
    type: undefined,
    items: [],
    filter: {
        type: 'inline',
        disabled: false
    },
    sortable: true,
    paginate: {
        pageSize: 50,
        pageCount: 5
    },
    exportable: true,
    commands: [],
    columns: []
};

let HandlerLocal = class HandlerLocal {
    constructor(datePipe) {
        this.datePipe = datePipe;
        this.filter = (localItems, filterInfo) => {
            const items = localItems.filter(item => {
                for (const column of filterInfo.columns) {
                    const filterValue = (filterInfo.rawFilter[column.field] || '').toString().trim().toLowerCase();
                    const columnValue = (item[column.field] || '').toString().trim().toLowerCase();
                    if (filterValue) {
                        if (!columnValue) {
                            return false;
                        }
                        if (column.type === 'string') {
                            if (columnValue.indexOf(filterValue) === -1) {
                                return false;
                            }
                        }
                        else if (column.type === 'values' || column.type === 'radio') {
                            if (columnValue !== filterValue) {
                                return false;
                            }
                        }
                        else if (column.type === 'number') {
                            const fValue = +filterValue.replace('>=', '').replace('<=', '').replace('>', '').replace('<', '');
                            const cValue = +columnValue;
                            if (fValue || fValue === 0) {
                                if (!cValue && cValue !== 0) {
                                    return false;
                                }
                                if (filterValue.indexOf('>=') > -1 && cValue < fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('<=') > -1 && cValue > fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('<') > -1 && cValue >= fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('>') > -1 && cValue <= fValue) {
                                    return false;
                                }
                                else if (cValue !== fValue) {
                                    return false;
                                }
                            }
                        }
                        else if (column.type === 'bool') {
                            if (filterValue === '1' && columnValue !== '1' && columnValue !== 'true') {
                                return false;
                            }
                            else if (filterValue === '0' && columnValue !== '0' && columnValue !== 'false') {
                                return false;
                            }
                        }
                        else if (column.type === 'date' || column.type === 'datetime') {
                            const date = this.datePipe.transform(filterValue, 'yyyy/MM/dd');
                            const fromDate = new Date(date);
                            const toDate = new Date(date);
                            toDate.setDate(toDate.getDate() + 1);
                            if (new Date(columnValue).getTime() < fromDate.getTime() || new Date(columnValue).getTime() >= toDate.getTime()) {
                                return false;
                            }
                        }
                    }
                }
                return true;
            });
            // Sort
            if (filterInfo.orderBy && filterInfo.orderDirection) {
                const column = filterInfo.columns.find(e => e.field === filterInfo.orderBy);
                if (column) {
                    const { type, field } = column;
                    items.sort((current, next) => {
                        if (type === 'number') {
                            return (current[field] || 0) - (next[field] || 0);
                        }
                        if (type === 'date' || type === 'datetime' || type === 'time') {
                            const d1 = new Date(current[field] || '').getTime();
                            const d2 = new Date(current[field] || '').getTime();
                            return d1 - d2;
                        }
                        return (current[field] || '') - (next[field] || '');
                    });
                    if (filterInfo.orderDirection === 'DESC') {
                        items.reverse();
                    }
                }
            }
            return {
                items,
                total: items.length
            };
        };
    }
};
HandlerLocal.ctorParameters = () => [
    { type: DatePipe }
];
HandlerLocal.ɵprov = ɵɵdefineInjectable({ factory: function HandlerLocal_Factory() { return new HandlerLocal(ɵɵinject(DatePipe)); }, token: HandlerLocal, providedIn: "root" });
HandlerLocal = __decorate([
    Injectable({
        providedIn: 'root'
    })
], HandlerLocal);

let HandlerDotnet = class HandlerDotnet {
    constructor() {
        this.mapRequest = (filterInfo) => {
            const result = {
                whereClause: '1>0',
                pageSize: filterInfo.pageSize,
                pageNumber: filterInfo.pageNumber,
                orderBy: filterInfo.orderBy,
                orderDirection: filterInfo.orderDirection,
                filter: {}
            };
            if (filterInfo.customFilter) {
                // Nếu custom filter là string
                if (typeof (filterInfo.customFilter) === 'string') {
                    result.whereClause += ` AND ${filterInfo.customFilter}`;
                }
                else if (typeof (filterInfo.customFilter) === 'function') {
                    result.whereClause += ` AND ${filterInfo.customFilter()}`;
                }
            }
            const executeColumnNoChildren = (column) => {
                if (!filterInfo.rawFilter[column.field]) {
                    return;
                }
                result.filter[column.field] = filterInfo.rawFilter[column.field];
                if (column.type === 'string') {
                    const filterValue = filterInfo.rawFilter[column.field].toString();
                    // Kiểm tra có phải Guid ko?
                    if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                        return;
                    }
                    if (this.isGuid(filterInfo.rawFilter[column.field])) {
                        result.whereClause += ` AND ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                    }
                    else if (filterValue.startsWith('!=')) {
                        result.whereClause += ` AND ${column.field} != "${filterValue.substring(2, filterValue.length)}"`;
                    }
                    else if (filterValue.startsWith('=')) {
                        result.whereClause += ` AND ${column.field} = "${filterValue.substring(1, filterValue.length)}"`;
                    }
                    else if (filterValue.startsWith('%')) {
                        result.whereClause += ` AND ${column.field}.EndsWith("${filterValue.substring(1, filterValue.length)}")`;
                    }
                    else if (filterValue.endsWith('%')) {
                        result.whereClause += ` AND ${column.field}.StartsWith("${filterValue.substring(0, filterValue.length - 1)}")`;
                    }
                    else {
                        result.whereClause += ` AND ${column.field}.Contains("${filterValue}")`;
                    }
                }
                else if (column.type === 'number') {
                    const value = +(filterInfo.rawFilter[column.field].replace('>=', '').replace('<=', '').replace('>', '').replace('<', '').trim());
                    if (filterInfo.rawFilter[column.field].indexOf('>=') > -1) {
                        result.whereClause += ` AND ${column.field} >= ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('<=') > -1) {
                        result.whereClause += ` AND ${column.field} <= ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('>') > -1) {
                        result.whereClause += ` AND ${column.field} > ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('<') > -1) {
                        result.whereClause += ` AND ${column.field} < ${value}`;
                    }
                    else {
                        result.whereClause += ` AND ${column.field} = ${value}`;
                    }
                }
                else if (column.type === 'bool') {
                    if (filterInfo.rawFilter[column.field] === '0' || filterInfo.rawFilter[column.field] === '1') {
                        result.whereClause += ` AND ${column.field} = ${filterInfo.rawFilter[column.field] === '1' ? 'true' : 'false'}`;
                    }
                }
                else if (column.type === 'values') {
                    if (filterInfo.rawFilter[column.field]) {
                        // Kiểm tra có phải Guid ko?
                        if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                            return;
                        }
                        if (this.isGuid(filterInfo.rawFilter[column.field])) {
                            result.whereClause += ` AND ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                        }
                        else {
                            result.whereClause += ` AND ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                        }
                    }
                }
                else if (column.type === 'radio') {
                    if (filterInfo.rawFilter[column.field]) {
                        result.whereClause += ` AND ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                    }
                }
                else if (column.type === 'date' || column.type === 'datetime') {
                    // "DateTime(yyyy,mm,dd,HH,mm,ss)"
                    // generate fromDate, toDate
                    let date = new Date(filterInfo.rawFilter[column.field]);
                    // From Date
                    date = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0);
                    result.whereClause += ` AND ${column.field} >= DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                    // To Date
                    date.setDate(date.getDate() + 1);
                    result.whereClause += ` AND ${column.field} < DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                }
            };
            const executeColumnChildren = (columnChildren) => {
                let flag = false;
                for (const column of columnChildren.children) {
                    if (filterInfo.rawFilter[column.field]) {
                        executeColumnNoChildren(column);
                        flag = true;
                    }
                }
                if (flag) {
                    return;
                }
                if (!filterInfo.rawFilter[columnChildren.field]) {
                    return;
                }
                result.filter[columnChildren.field] = filterInfo.rawFilter[columnChildren.field];
                let whereClause = '';
                for (const column of columnChildren.children) {
                    if (column.type === 'string') {
                        const filterValue = filterInfo.rawFilter[column.field].toString();
                        // Kiểm tra có phải Guid ko?
                        if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                            return;
                        }
                        if (this.isGuid(filterInfo.rawFilter[column.field])) {
                            whereClause += ` OR ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                        }
                        else if (filterValue.startsWith('!=')) {
                            whereClause += ` OR ${column.field} != "${filterValue.substring(2, filterValue.length)}"`;
                        }
                        else if (filterValue.startsWith('=')) {
                            whereClause += ` OR ${column.field} = "${filterValue.substring(1, filterValue.length)}"`;
                        }
                        else if (filterValue.startsWith('%')) {
                            whereClause += ` OR ${column.field}.EndsWith("${filterValue.substring(1, filterValue.length)}")`;
                        }
                        else if (filterValue.endsWith('%')) {
                            whereClause += ` OR ${column.field}.StartsWith("${filterValue.substring(0, filterValue.length - 1)}")`;
                        }
                        else {
                            whereClause += ` OR ${column.field}.Contains("${filterValue}")`;
                        }
                    }
                    else if (column.type === 'number') {
                        const value = +(filterInfo.rawFilter[column.field].replace('>=', '').replace('<=', '').replace('>', '').replace('<', '').trim());
                        if (!Number.isNaN(value)) {
                            if (filterInfo.rawFilter[column.field].indexOf('>=') > -1) {
                                whereClause += ` OR ${column.field} >= ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('<=') > -1) {
                                whereClause += ` OR ${column.field} <= ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('>') > -1) {
                                whereClause += ` OR ${column.field} > ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('<') > -1) {
                                whereClause += ` OR ${column.field} < ${value}`;
                            }
                            else {
                                whereClause += ` OR ${column.field} = ${value}`;
                            }
                        }
                    }
                    else if (column.type === 'bool') {
                        if (filterInfo.rawFilter[column.field] === '0' || filterInfo.rawFilter[column.field] === '1') {
                            whereClause += ` OR ${column.field} = ${filterInfo.rawFilter[column.field] === '1' ? 'true' : 'false'}`;
                        }
                    }
                    else if (column.type === 'values') {
                        if (filterInfo.rawFilter[column.field]) {
                            // Kiểm tra có phải Guid ko?
                            if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                                return;
                            }
                            if (this.isGuid(filterInfo.rawFilter[column.field])) {
                                whereClause += ` OR ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                            }
                            else {
                                whereClause += ` OR ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                            }
                        }
                    }
                    else if (column.type === 'radio') {
                        if (filterInfo.rawFilter[column.field]) {
                            whereClause += ` OR ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                        }
                    }
                    else if (column.type === 'date' || column.type === 'datetime') {
                        // "DateTime(yyyy,mm,dd,HH,mm,ss)"
                        // generate fromDate, toDate
                        let date = new Date(filterInfo.rawFilter[column.field]);
                        // From Date
                        date = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0);
                        whereClause += ` OR ${column.field} >= DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                        // To Date
                        date.setDate(date.getDate() + 1);
                        whereClause += ` OR ${column.field} < DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                    }
                }
                if (whereClause.trim().startsWith('OR')) {
                    whereClause = whereClause.trim().substr(2);
                    result.whereClause += ` AND(${whereClause})`;
                }
            };
            filterInfo.columns.forEach(column => {
                if (column.type !== 'children') {
                    executeColumnNoChildren(column);
                }
                else {
                    executeColumnChildren(column);
                }
            });
            return result;
        };
        this.mapResponse = (res) => {
            const { items, total } = res;
            return {
                items,
                total
            };
        };
        this.isGuid = (key) => {
            return key.length === 36;
            // const regex = new Regex('[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}');
            // return regex.test(key);
        };
    }
};
HandlerDotnet.ɵprov = ɵɵdefineInjectable({ factory: function HandlerDotnet_Factory() { return new HandlerDotnet(); }, token: HandlerDotnet, providedIn: "root" });
HandlerDotnet = __decorate([
    Injectable({
        providedIn: 'root'
    })
], HandlerDotnet);

let EditorHandlerPipe = class EditorHandlerPipe {
    transform(value, item, gridOption) {
        const visible = (column) => {
            if (column.type === 'children') {
                return false;
            }
            let isDisabled = false;
            // Kiểm tra xem có bị disabled hay không?
            if (column.editor) {
                isDisabled = typeof (column.editor.disabled) === 'function' ? column.editor.disabled(item) : column.editor.disabled;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            if (typeof (gridOption.editor) === 'object') {
                if (typeof (gridOption.editor.disabled) === 'function') {
                    isDisabled = gridOption.editor.disabled(item);
                }
                else {
                    isDisabled = gridOption.editor.disabled;
                }
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Hiển thị editor nếu dòng đó:
            // Đang được edit: editingStatus
            return item.editingStatus
                // Được thiết lập alwayDisplay
                || (column.editor && column.editor.alwayDisplay)
                // Editable có thuộc tính type inline
                || (gridOption.editor && typeof (gridOption.editor) === 'object' && gridOption.editor.type === 'inline');
        };
        item.editorHandler = item.editorHandler || {};
        for (const column of gridOption.columns) {
            item.editorHandler.disabled = false;
            item.editorHandler[column.field] = {};
            if (typeof (gridOption.editor) === 'object') {
                if (typeof (gridOption.editor.disabled) === 'function') {
                    item.editorHandler.disabled = gridOption.editor.disabled(item);
                }
                else {
                    item.editorHandler.disabled = gridOption.editor.disabled;
                }
            }
            else {
                item.editorHandler.disabled = false;
            }
            if (item.editorHandler.disabled) {
                item.editorHandler[column.field].visible = false;
            }
            else {
                item.editorHandler[column.field].visible = visible(column);
            }
        }
        return true;
    }
};
EditorHandlerPipe = __decorate([
    Pipe({
        name: 'editorHandler'
    })
], EditorHandlerPipe);

let GridImportExcelComponent = class GridImportExcelComponent {
    constructor() { }
    set columns(gridColumns) {
        const columns = [];
        gridColumns.forEach(column => {
            var _a;
            if (column.ignoreImport) {
                return;
            }
            if (column.type === 'string' || column.type === 'color') {
                columns.push({
                    type: 'string',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'number') {
                columns.push({
                    type: 'number',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'bool') {
                columns.push({
                    type: 'bool',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'date') {
                columns.push({
                    type: 'date',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'datetime' || column.type === 'time') {
                columns.push({
                    type: 'datetime',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'values') {
                columns.push({
                    type: 'values',
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    values: column.values.map(e => e.value),
                });
            }
            else if (column.type === 'radio') {
                columns.push({
                    type: 'radio',
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    values: column.values.map(e => e[column.valueField])
                });
            }
            if (column.type === 'children' && ((_a = column.children) === null || _a === void 0 ? void 0 : _a.length)) {
                column.children.forEach(childColumn => {
                    if (childColumn.ignoreImport) {
                        return;
                    }
                    if (childColumn.type === 'string' || childColumn.type === 'color') {
                        columns.push({
                            type: 'string',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'number') {
                        columns.push({
                            type: 'number',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'bool') {
                        columns.push({
                            type: 'bool',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'date') {
                        columns.push({
                            type: 'date',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'datetime' || childColumn.type === 'time') {
                        columns.push({
                            type: 'datetime',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'values') {
                        columns.push({
                            type: 'values',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width,
                            values: childColumn.values.map(e => e.value),
                        });
                    }
                    else if (childColumn.type === 'radio') {
                        columns.push({
                            type: 'radio',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width,
                            values: childColumn.values.map(e => e[childColumn.valueField])
                        });
                    }
                });
            }
        });
        this.option = {
            key: `GridImport${this.key}`,
            columns,
            onAccept: this.accept
        };
    }
    open() {
        if (this.control) {
            this.control.open();
        }
    }
};
__decorate([
    Input()
], GridImportExcelComponent.prototype, "key", void 0);
__decorate([
    Input()
], GridImportExcelComponent.prototype, "accept", void 0);
__decorate([
    Input()
], GridImportExcelComponent.prototype, "columns", null);
__decorate([
    ViewChild('control')
], GridImportExcelComponent.prototype, "control", void 0);
GridImportExcelComponent = __decorate([
    Component({
        selector: 'sd-grid-import-excel',
        template: "<sd-upload-excel-control *ngIf=\"key && option\" [option]=\"option\" #control></sd-upload-excel-control>",
        styles: [""]
    })
], GridImportExcelComponent);

let GridPopupExportExcelComponent = class GridPopupExportExcelComponent {
    constructor(ref, loadingService, excelService, notifyService, translateService) {
        this.ref = ref;
        this.loadingService = loadingService;
        this.excelService = excelService;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.prefix = 'Popup Export Excel';
        this.key = '';
        this.columns = [];
        this.extendColumns = [];
        this.excelConfigs = [];
        this.exportByTemplate = new EventEmitter();
        this.initDefaultTemplate = () => __awaiter(this, void 0, void 0, function* () {
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                description: childColumn.description,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        description: column.description,
                        width: column.width
                    });
                }
            }
            return yield this.excelService.generateExcelTemplate({
                columns: excelColumns
            });
        });
        this.generateTemplate = () => __awaiter(this, void 0, void 0, function* () {
            var _a;
            this.loadingService.start();
            const result = yield this.initDefaultTemplate().finally(this.loadingService.stop);
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                this.excelService.downloadTemplate(result.filePath, `${this.fullKey}.xlsx`);
            }
        });
        this.onExportByTemplate = (excelConfig) => {
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                description: childColumn.description,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        description: column.description,
                        width: column.width
                    });
                }
            }
            this.exportByTemplate.emit({
                excelConfig,
                excelColumns
            });
            this.ref.detectChanges();
        };
        this.uploadTemplate = () => __awaiter(this, void 0, void 0, function* () {
            const excelConfig = yield this.excelService.uploadTemplate(this.fullKey, this.validator);
            this.excelConfigs.push({
                name: excelConfig.name,
                fullPath: excelConfig.fullPath,
                removable: true
            });
            this.ref.detectChanges();
        });
        this.downloadTemplate = (excelConfig) => {
            this.excelService.downloadTemplate(excelConfig.fullPath, excelConfig.name);
        };
        this.removeTemplate = (excelConfig) => {
            this.notifyService.confirm(this.translateService.translate('Remove template')).then(() => __awaiter(this, void 0, void 0, function* () {
                this.loadingService.start();
                yield this.excelService.remove(this.fullKey, excelConfig.name).finally(this.loadingService.stop);
                const idx = this.excelConfigs.indexOf(excelConfig);
                this.excelConfigs.splice(idx, 1);
                this.ref.detectChanges();
            }));
        };
        this.exportDefault = () => __awaiter(this, void 0, void 0, function* () {
            this.loadingService.start();
            const result = yield this.initDefaultTemplate().finally(this.loadingService.stop);
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        width: column.width
                    });
                }
            }
            this.exportByTemplate.emit({
                excelConfig: {
                    fullPath: result.filePath,
                    name: `[${this.fullKey}] Default.xlsx`
                },
                excelColumns
            });
            this.ref.detectChanges();
        });
    }
    get fullKey() {
        if (!this.key) {
            return '';
        }
        return hash({
            prefix: this.prefix,
            key: this.key
        });
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
    }
    open() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.fullKey) {
                yield this.exportDefault();
                return;
            }
            yield this.loadConfiguration();
            this.modal.open();
            this.ref.detectChanges();
        });
    }
    loadConfiguration() {
        return __awaiter(this, void 0, void 0, function* () {
            this.excelConfigs = [];
            this.excelConfigs = yield this.excelService.getFiles(this.fullKey);
        });
    }
};
GridPopupExportExcelComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: LoadingService },
    { type: ExcelService },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridPopupExportExcelComponent.prototype, "modal", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "key", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "extendColumns", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "validator", void 0);
__decorate([
    Output()
], GridPopupExportExcelComponent.prototype, "exportByTemplate", void 0);
GridPopupExportExcelComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-export-excel',
        template: "<sd-modal-control width=\"sm\" [title]=\"'Export excel' | sdTranslate\" #modal>\r\n  <sd-modal-body>\r\n    <!-- <div class=\"mt-2\">\r\n      <button class=\"btn btn-success btn-sm mr-2\" (click)=\"exportDefault()\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>\r\n        {{'Export' | sdTranslate}}\r\n      </button>\r\n      <span>{{'Default Template' | sdTranslate}}</span>\r\n    </div> -->\r\n    <div *ngFor=\"let excelConfig of excelConfigs\" class=\"mt-2\">\r\n      <button class=\"btn btn-success btn-sm mr-2\" (click)=\"onExportByTemplate(excelConfig)\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>\r\n        {{'Export' | sdTranslate}}\r\n      </button>\r\n      <button *ngIf=\"excelConfig.removable\" class=\"btn btn-danger btn-sm mr-2\" (click)=\"removeTemplate(excelConfig)\">\r\n        <i class=\"fa fa-trash fa-fw mr-1\"></i>\r\n        {{'Delete template' | sdTranslate}}\r\n      </button>\r\n      <span>{{excelConfig.name}}</span>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <div class=\"mr-auto\">\r\n      <button type=\"button\" class=\"btn btn-success btn-sm mr-2\" (click)=\"generateTemplate()\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>{{'Generate template' | sdTranslate}}</button>\r\n      <button type=\"button\" class=\"btn btn-warning btn-sm mr-2\" (click)=\"uploadTemplate()\">\r\n        <i class=\"fa fa-plus fa-fw mr-1\"></i>{{'Add template' | sdTranslate}}</button>\r\n    </div>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}"]
    })
], GridPopupExportExcelComponent);

let GridControlComponent = class GridControlComponent {
    constructor(ref, deviceService, handlerLocal, handlerDotnet, utilityService, translateService, configurationService, datePipe, loadingService, apiService, excelService, notifyService, editorVisiblePipe) {
        var _a;
        this.ref = ref;
        this.handlerLocal = handlerLocal;
        this.handlerDotnet = handlerDotnet;
        this.utilityService = utilityService;
        this.translateService = translateService;
        this.configurationService = configurationService;
        this.datePipe = datePipe;
        this.loadingService = loadingService;
        this.apiService = apiService;
        this.excelService = excelService;
        this.notifyService = notifyService;
        this.editorVisiblePipe = editorVisiblePipe;
        this.isMobileOrTablet = false;
        this.displayKey = 'SDCUSTOM';
        this.localItems = [];
        this.items = [];
        this.filter = {};
        this.externalFilter = {};
        this.currentPage = 1;
        this.hiddenPaginate = false;
        this.showInlineFilter = true;
        this.quickFilters = [];
        // Paginate
        this.pages = [1];
        this.pageCount = 5;
        this.totalPage = 1;
        // Loading
        this.isLoading = false;
        this.viewItems = [];
        this.fixedColumns = [];
        this.normalColumns = [];
        this.columns = [];
        this.isCheckedAll = false;
        this.selectedItems = [];
        this.selectedItem = null;
        this.rowHandler = {
            click: (item) => {
                this.selectedItem = item;
                if (this.gridOption.onClickRow) {
                    this.gridOption.onClickRow(item);
                }
            },
            dblClick: (item) => {
                this.selectedItem = item;
                if (this.gridOption.onDblClickRow) {
                    this.gridOption.onDblClickRow(item);
                }
            }
        };
        this.setOption = (option) => {
            var _a, _b, _c, _d;
            delete this.gridOption;
            const gridConfiguration = this.configurationService.getGridConfiguration();
            if (!((_a = option.filter) === null || _a === void 0 ? void 0 : _a.type) && ((_c = (_b = gridConfiguration) === null || _b === void 0 ? void 0 : _b.filter) === null || _c === void 0 ? void 0 : _c.type)) {
                if (!option.filter) {
                    option.filter = {
                        type: gridConfiguration.filter.type
                    };
                }
                else {
                    option.filter.type = gridConfiguration.filter.type;
                }
            }
            this.gridOption = Object.assign(Object.assign({}, defaultGridOption), option);
            switch (this.gridOption.type) {
                case 'local':
                    this.handler = this.handlerLocal;
                    break;
                case 'dotnet':
                    this.handler = this.handlerDotnet;
                    break;
                case 'custom':
                    this.handler = this.gridOption.handlerCustom || ((_d = gridConfiguration) === null || _d === void 0 ? void 0 : _d.handlerCustom);
                    if (!this.handler) {
                        this.notifyService.notify.warning(`Handler custom was not found`);
                        return;
                    }
                    break;
            }
            // Loại bỏ những command bị ẩn
            this.gridOption.commands = this.gridOption.commands.filter(command => {
                const hidden = command.hidden;
                if (hidden !== undefined) {
                    if (typeof (hidden) === 'boolean') {
                        return !hidden;
                    }
                    else if (typeof (hidden) === 'function') {
                        return !hidden();
                    }
                }
                else {
                    return true;
                }
            });
            this.sdGridConfig.setOption({
                key: option.key,
                pageSize: this.gridOption.paginate.pageSize,
                columns: this.gridOption.columns
            });
            this.initExternalFilter();
            this.resize();
            this.detectChanges();
        };
        this.reload = (gridItems) => __awaiter(this, void 0, void 0, function* () {
            var _b, _c, _d;
            if (this.isLoading) {
                return;
            }
            this.isLoading = true;
            try {
                if (this.gridOption.type !== 'local') {
                    const handler = this.handler;
                    const filter = handler.mapRequest(this.getFilterInfo(this.currentPage, this.gridOption.paginate.pageSize));
                    if (this.gridOption.method === 'GET') {
                        const queryString = Object.keys(filter).map(key => key + '=' + filter[key]).join('&');
                        const url = this.gridOption.url.includes('?') ? `${this.gridOption.url}&${queryString}` : `${this.gridOption.url}?${queryString}`;
                        const response = yield this.apiService.get(url);
                        const { items, total } = handler.mapResponse(response);
                        this.items = items;
                        this.total = total;
                    }
                    else {
                        const response = yield this.apiService.post(this.gridOption.url, filter);
                        const { items, total } = handler.mapResponse(response);
                        this.items = items;
                        this.total = total;
                    }
                }
                else {
                    const handler = this.handler;
                    if (typeof (this.gridOption.items) === 'function') {
                        if (Array.isArray(gridItems)) {
                            this.localItems = gridItems;
                        }
                        else {
                            const results = this.gridOption.items();
                            if (results instanceof Promise) {
                                this.localItems = yield results;
                            }
                            else {
                                this.localItems = results;
                            }
                        }
                    }
                    else {
                        this.gridOption.items = gridItems || this.gridOption.items;
                        this.localItems = this.gridOption.items;
                    }
                    const response = handler.filter(this.localItems, {
                        customFilter: this.gridOption.filter.customFilter,
                        rawFilter: this.filter,
                        columns: this.gridOption.columns,
                        rawExternalFilter: this.externalFilter,
                        externalFilters: (_b = this.gridOption.filter) === null || _b === void 0 ? void 0 : _b.externalFilters,
                        orderBy: this.orderBy,
                        orderDirection: this.orderDirection,
                        pageNumber: this.currentPage,
                        pageSize: this.gridOption.paginate.pageSize
                    });
                    this.items = response.items;
                    this.total = response.total;
                }
                this.items.forEach(item => item.originItem = Object.assign({}, item));
                if (this.gridOption.onReloadCompleted) {
                    this.gridOption.onReloadCompleted(this.items);
                }
                this.generatePaginate();
                this.generateViewItems();
                this.generateEditorHandlers();
                this.generateSumarize();
                this.isLoading = false;
                $$1(this.gridBody.nativeElement).scrollTop(0);
                if (this.currentPage > 1 && !((_c = this.viewItems) === null || _c === void 0 ? void 0 : _c.length)) {
                    if (this.gridOption.type === 'local') {
                        if ((_d = this.localItems) === null || _d === void 0 ? void 0 : _d.length) {
                            this.selectPage(1);
                            return;
                        }
                    }
                    else {
                        if (this.total > 0) {
                            this.selectPage(1);
                            return;
                        }
                    }
                }
                this.detectChanges();
            }
            catch (error) {
                this.utilityService.handle.error(error);
                this.isLoading = false;
            }
        });
        this.clearFilter = () => {
            this.filter = {};
            this.externalFilter = {};
            this.initFilter();
            this.initExternalFilter();
            if (this.sdGridPopupFilter) {
                this.sdGridPopupFilter.filter = this.filter;
                this.sdGridPopupFilter.externalFilter = this.externalFilter;
            }
        };
        this.onClearFilter = () => {
            this.clearFilter();
            this.reload();
        };
        this.expandOrCollapse = (gridItem) => __awaiter(this, void 0, void 0, function* () {
            var _e, _f;
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation } = gridItem, item = __rest(gridItem, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation"]);
            if (!this.gridOption.subInformation) {
                return;
            }
            if ((_e = gridItem.subInformation) === null || _e === void 0 ? void 0 : _e.isOpened) {
                gridItem.subInformation.isOpened = false;
                return;
            }
            if (this.gridOption.subInformation.lazyLoading && !((_f = gridItem.subInformation) === null || _f === void 0 ? void 0 : _f.isLoaded)) {
                gridItem.subInformation.isLoading = true;
                try {
                    gridItem.subInformation.subItems = yield this.gridOption.subInformation.onLoad(item);
                    if (!Array.isArray(gridItem.subInformation.subItems)) {
                        this.notifyService.alert.warning(`Data is not an array`);
                        gridItem.subInformation.subItems = [];
                    }
                    gridItem.subInformation.isLoading = false;
                    gridItem.subInformation.isLoaded = true;
                    gridItem.subInformation.isOpened = true;
                    this.ref.detectChanges();
                }
                catch (err) {
                    this.utilityService.handle.error(err);
                    gridItem.subInformation.isLoading = false;
                    this.ref.detectChanges();
                }
                return;
            }
            if (this.gridOption.subInformation.lazyLoading === false && !gridItem.subInformation.isLoaded) {
                gridItem.subInformation.subItems = gridItem[this.gridOption.subInformation.field];
                if (!Array.isArray(gridItem.subInformation.subItems)) {
                    this.notifyService.alert.warning(`Data is not an array`);
                    gridItem.subInformation.subItems = [];
                }
                gridItem.subInformation.isLoaded = true;
                gridItem.subInformation.isOpened = true;
                return;
            }
            gridItem.subInformation.isOpened = true;
            this.ref.detectChanges();
        });
        //#region Editable
        this.onCreate = () => {
            var _a, _b, _c;
            const { editor } = this.gridOption;
            if (!editor) {
                return;
            }
            if (!((_a = editor) === null || _a === void 0 ? void 0 : _a.addable)) {
                return;
            }
            const item = {
                editingStatus: 'create',
                blinker: {},
                subInformation: {}
            };
            // Gán giá trị mặc định
            this.gridOption.columns.forEach(column => {
                if (column.type === 'values') {
                    item[column.field] = '';
                }
                else if (column.type === 'bool') {
                    item[column.field] = true;
                }
                else if (column.type === 'number') {
                    item[column.field] = 0;
                }
            });
            (_c = (_b = editor).onAdd) === null || _c === void 0 ? void 0 : _c.call(_b, item);
            // Đưa item lên dòng đầu tiên nếu type khác popup
            if (editor.type !== 'popup') {
                if (this.gridOption.type === 'local') {
                    this.items.splice(0, 0, item);
                }
                this.viewItems.splice(0, 0, item);
            }
            this.onUpdate(item);
        };
        this.onUpdate = (item) => {
            const { editor } = this.gridOption;
            item.editingStatus = item.editingStatus || 'update';
            item.temporary = Object.assign({}, item);
            this.generateEditorHanlder(item);
            if (editor.type === 'popup') {
                this.sdGridPopupEditor.open(item);
            }
        };
        this.onSave = (item) => __awaiter(this, void 0, void 0, function* () {
            const { editor } = this.gridOption;
            try {
                item.editorHandler.saving = true;
                if (editor.validate) {
                    const result = editor.validate(item);
                    if (result instanceof Promise) {
                        const message = yield result;
                        if (message) {
                            throw message;
                        }
                    }
                    else {
                        if (result) {
                            throw result;
                        }
                    }
                }
                if (editor.onSave) {
                    const result = editor.onSave(item);
                    if (result instanceof Promise) {
                        yield result;
                    }
                }
                if (item.editingStatus === 'create' && editor.type === 'popup') {
                    if (this.gridOption.type === 'local') {
                        this.items.splice(0, 0, item);
                    }
                    this.viewItems.splice(0, 0, item);
                }
                item.editingStatus = undefined;
                this.generateEditorHanlder(item);
            }
            catch (err) {
                this.notifyService.notify.warning(err);
            }
            finally {
                item.editorHandler.saving = false;
                this.ref.detectChanges();
            }
        });
        this.onCancel = (item) => {
            const { editor } = this.gridOption;
            if (item.editingStatus === 'create') {
                if (editor.type !== 'popup') {
                    if (this.gridOption.type === 'local') {
                        this.items.splice(0, 1);
                    }
                    this.viewItems.splice(0, 1);
                }
            }
            else {
                Object.assign(item, item.temporary);
                item.editingStatus = undefined;
                this.generateEditorHanlder(item);
                this.ref.detectChanges();
            }
        };
        this.initExternalFilter = () => {
            var _a, _b;
            if ((_b = (_a = this.gridOption.filter) === null || _a === void 0 ? void 0 : _a.externalFilters) === null || _b === void 0 ? void 0 : _b.length) {
                this.gridOption.filter.externalFilters.forEach(externalFilter => {
                    var _a, _b, _c, _d, _e, _f, _g, _h;
                    if (externalFilter.type === 'string') {
                        if (externalFilter.default) {
                            this.externalFilter[externalFilter.field] = (_a = externalFilter.default, (_a !== null && _a !== void 0 ? _a : ''));
                        }
                        return;
                    }
                    if (externalFilter.type === 'number') {
                        if (externalFilter.default) {
                            this.externalFilter[externalFilter.field] = (_b = externalFilter.default, (_b !== null && _b !== void 0 ? _b : undefined));
                        }
                        return;
                    }
                    if (externalFilter.type === 'daterange') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_c = externalFilter.defaultFrom, (_c !== null && _c !== void 0 ? _c : undefined)),
                            to: (_d = externalFilter.defaultTo, (_d !== null && _d !== void 0 ? _d : undefined))
                        };
                        return;
                    }
                    if (externalFilter.type === 'numberrange') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_e = externalFilter.defaultFrom, (_e !== null && _e !== void 0 ? _e : undefined)),
                            to: (_f = externalFilter.defaultTo, (_f !== null && _f !== void 0 ? _f : undefined))
                        };
                        return;
                    }
                    if (externalFilter.type === 'daterangefull') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_g = externalFilter.defaultFrom, (_g !== null && _g !== void 0 ? _g : undefined)),
                            to: (_h = externalFilter.defaultTo, (_h !== null && _h !== void 0 ? _h : undefined))
                        };
                        return;
                    }
                });
            }
        };
        //#endregion
        this.onSearch = (searchValue, item, column) => {
            item[column.field] = searchValue;
        };
        this.onFilterConfigurationLoaded = (param) => {
            var _a;
            this.quickFilters = param.quickFilters || [];
            this.selectedQuickFilter = param.selectedQuickFilter || '';
            if (this.selectedQuickFilter) {
                const quickFilter = this.quickFilters.find(e => e.code === this.selectedQuickFilter);
                if (quickFilter) {
                    const f1 = JSON.stringify(quickFilter.filter);
                    const f2 = JSON.stringify(quickFilter.externalFilter);
                    this.filter = JSON.parse(f1);
                    this.externalFilter = JSON.parse(f2);
                }
            }
            if (this.showInlineFilter !== param.showInlineFilter) {
                this.showInlineFilter = (_a = param.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true));
                this.resize();
            }
        };
        this.onSelectQuickFilter = (event) => {
            var _a, _b, _c;
            const quickFilter = this.quickFilters.find(e => e.code === event.value);
            if ((_a = quickFilter) === null || _a === void 0 ? void 0 : _a.code) {
                const f1 = JSON.stringify(quickFilter.filter);
                const f2 = JSON.stringify(quickFilter.externalFilter);
                this.selectedQuickFilter = (_b = quickFilter) === null || _b === void 0 ? void 0 : _b.code;
                this.filter = JSON.parse(f1);
                this.externalFilter = JSON.parse(f2);
                this.updateFilter();
            }
            else {
                this.selectedQuickFilter = '';
                this.onClearFilter();
            }
            (_c = this.sdGridPopupFilter) === null || _c === void 0 ? void 0 : _c.updateConfiguration(this.selectedQuickFilter);
        };
        this.getExportItems = () => __awaiter(this, void 0, void 0, function* () {
            var _g;
            if (this.isLoading) {
                return;
            }
            const pageNumber = 1;
            const pageSize = 10000;
            this.isLoading = true;
            try {
                if (this.gridOption.type !== 'local') {
                    const handler = this.handler;
                    const filter = handler.mapRequest(this.getFilterInfo(pageNumber, pageSize));
                    if (this.gridOption.method === 'GET') {
                        const queryString = Object.keys(filter).map(key => key + '=' + filter[key]).join('&');
                        const url = this.gridOption.url.includes('?') ? `${this.gridOption.url}&${queryString}` : `${this.gridOption.url}?${queryString}`;
                        const response = yield this.apiService.get(url);
                        return handler.mapResponse(response).items;
                    }
                    else {
                        const response = yield this.apiService.post(this.gridOption.url, filter);
                        return handler.mapResponse(response).items;
                    }
                }
                else {
                    let localItems = [];
                    const handler = this.handler;
                    if (typeof (this.gridOption.items) === 'function') {
                        const results = this.gridOption.items();
                        if (results instanceof Promise) {
                            localItems = yield results;
                        }
                        else {
                            localItems = results;
                        }
                    }
                    else {
                        localItems = this.gridOption.items;
                    }
                    const response = handler.filter(localItems, {
                        customFilter: this.gridOption.filter.customFilter,
                        rawFilter: this.filter,
                        columns: this.gridOption.columns,
                        rawExternalFilter: this.externalFilter,
                        externalFilters: (_g = this.gridOption.filter) === null || _g === void 0 ? void 0 : _g.externalFilters,
                        orderBy: this.orderBy,
                        orderDirection: this.orderDirection,
                        pageNumber,
                        pageSize
                    });
                    return response.items;
                }
            }
            catch (error) {
                this.utilityService.handle.error(error);
            }
            finally {
                this.isLoading = false;
                this.ref.detectChanges();
            }
        });
        this.getFilterInfo = (pageNumber, pageSize) => {
            var _a;
            for (const key of Object.keys(this.filter)) {
                if (typeof (this.filter[key]) === 'string') {
                    this.filter[key] = this.filter[key].trim();
                }
            }
            for (const key of Object.keys(this.externalFilter)) {
                if (typeof (this.externalFilter[key]) === 'string') {
                    this.externalFilter[key] = this.externalFilter[key].trim();
                }
            }
            return {
                customFilter: this.gridOption.filter.customFilter,
                rawFilter: this.filter,
                columns: this.gridOption.columns,
                rawExternalFilter: this.externalFilter,
                externalFilters: (_a = this.gridOption.filter) === null || _a === void 0 ? void 0 : _a.externalFilters,
                orderBy: this.orderBy,
                orderDirection: this.orderDirection,
                pageNumber,
                pageSize
            };
        };
        this.onExportByTemplate = (params) => __awaiter(this, void 0, void 0, function* () {
            var _h, _j;
            this.loadingService.start();
            let exportItems = yield this.getExportItems().finally(this.loadingService.stop);
            if ((_h = this.gridOption.export) === null || _h === void 0 ? void 0 : _h.mapping) {
                exportItems = this.gridOption.export.mapping(exportItems, params.excelConfig.name);
            }
            const columns = [...this.gridOption.columns, ...(((_j = this.gridOption.export) === null || _j === void 0 ? void 0 : _j.columns) || [])];
            const items = exportItems.map(item => {
                const obj = {};
                const handle = (column) => {
                    if (column.type === 'children') {
                        column.children.forEach(handle);
                    }
                    else if (column.transform) {
                        obj[column.field] = column.transform(item[column.field], item);
                    }
                    else if (item[column.field] === undefined || item[column.field] === null || item[column.field] === '') {
                        obj[column.field] = '';
                    }
                    else if (column.type === 'string' || column.type === 'number' || column.type === 'color') {
                        // Nếu cell là string hoặc number thì gán bằng chính nó
                        obj[column.field] = item[column.field];
                    }
                    else if (column.type === 'bool') {
                        // Nếu là bool thì gán bằng giá trị trueValue và falseValue (nếu có), mặc định là TRUE/FALSE
                        if (item[column.field]) {
                            obj[column.field] = column.trueValue || 'True';
                        }
                        else {
                            obj[column.field] = column.falseValue || 'False';
                        }
                    }
                    else if (column.type === 'date') {
                        // Nếu là date thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'dd/MM/yyyy');
                    }
                    else if (column.type === 'datetime') {
                        // Nếu là datetime thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'dd/MM/yyyy HH:mm:ss');
                    }
                    else if (column.type === 'time') {
                        // Nếu là time thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'HH:mm:ss');
                    }
                    else if (column.type === 'values') {
                        // Nếu là values thì lấy giá trị của value được chọn
                        const data = column.values.find(e => e.value === item[column.field]);
                        if (data) {
                            obj[column.field] = data.text;
                        }
                        else {
                            obj[column.field] = item[column.field];
                        }
                    }
                    else if (column.type === 'radio') {
                        const data = column.values.find(e => e[column.valueField] === item[column.field]);
                        if (data) {
                            obj[column.field] = data[column.displayField];
                        }
                        else {
                            obj[column.field] = item[column.field];
                        }
                    }
                };
                columns.forEach(handle);
                return obj;
            });
            this.excelService.generateExcelDataByTemplate(params.excelConfig.fullPath, params.excelColumns, items, params.excelConfig.name);
        });
        this.onEditorChange = () => {
            this.ref.detectChanges();
        };
        this.onSelectPageSize = () => {
            this.reload();
        };
        this.noDataImage = (_a = this.configurationService.getGridConfiguration()) === null || _a === void 0 ? void 0 : _a.noDataImage;
        this.isMobileOrTablet = !deviceService.isDesktop();
        // this.ref.detach();
        // setInterval(() => {
        //   this.ref.markForCheck();
        // }, 1000);
        // ref.detach();
    }
    set option(value) {
        this.setOption(value);
    }
    ngAfterViewInit() {
        this.fixedHeadersSubcription = this.fixedHeaders.changes.subscribe(() => {
            const fixedHeaders = this.fixedHeaders.toArray();
            if (fixedHeaders.length > 0) {
                let left = $$1(fixedHeaders[0].nativeElement).outerWidth(true);
                for (let i = 1; i < fixedHeaders.length; i++) {
                    $$1(fixedHeaders[i].nativeElement).css({ left });
                    left += $$1(fixedHeaders[i].nativeElement).outerWidth(true);
                }
            }
        });
        this.fixedBodiesSubcription = this.fixedBodies.changes.subscribe(() => {
            const fixedBodies = this.fixedBodies.toArray();
            if (fixedBodies.length > 0) {
                const fixedPerRow = this.fixedBodies.length / this.viewItems.length;
                let left = $$1(fixedBodies[0].nativeElement).outerWidth(true);
                for (let i = 1; i < fixedBodies.length; i++) {
                    if (i % fixedPerRow === 0) {
                        left = 0;
                    }
                    $$1(fixedBodies[i].nativeElement).css({ left });
                    left += $$1(fixedBodies[i].nativeElement).outerWidth(true);
                }
            }
        });
    }
    ngOnDestroy() {
        var _a, _b;
        (_a = this.fixedHeadersSubcription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        (_b = this.fixedBodiesSubcription) === null || _b === void 0 ? void 0 : _b.unsubscribe();
    }
    reloadItem(data) {
        Object.keys(data).forEach(id => {
            const item = this.items.find(e => !!e.id && e.id === id);
            if (item) {
                this.gridOption.columns.forEach(column => {
                    if (item[column.field] !== undefined && data[id][column.field] !== undefined && item[column.field] !== data[id][column.field]) {
                        this.blink(item, column.field);
                    }
                });
                Object.assign(item, data[id]);
                this.generateEditorHanlder(item);
                this.stopBlink();
            }
        });
    }
    blink(item, field) {
        item.blinker = item.blinker || {};
        item.blinker[field] = true;
    }
    stopBlink() {
        setTimeout(() => {
            this.viewItems.forEach(item => {
                item.blinker = {};
            });
        }, 1500);
    }
    detectChanges() {
        this.ref.detectChanges();
        this.ref.markForCheck();
    }
    generateViewItems() {
        this.currentPage = this.currentPage || 1;
        delete this.viewItems;
        if (this.gridOption.type === 'local') {
            this.viewItems = this.items.filter((item, index) => {
                return index >= (this.currentPage - 1) * this.gridOption.paginate.pageSize
                    && index < this.currentPage * this.gridOption.paginate.pageSize;
            });
        }
        else {
            this.viewItems = this.items;
        }
        this.viewItems.forEach(item => {
            item.blinker = item.blinker || {};
            item.subInformation = item.subInformation || {};
        });
    }
    get editedItems() {
        return this.items.filter(item => {
            if (!item.originItem) {
                return true;
            }
            if (Object.keys(item.originItem).some(key => item.originItem[key] !== item[key])) {
                return true;
            }
            return false;
        }).map(item => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = item, result = __rest(item, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return result;
        });
    }
    selectPage(selectedPage) {
        if (this.isLoading) {
            return;
        }
        const page = +selectedPage || 1;
        if (this.currentPage !== page && page > 0 && page <= this.totalPage) {
            this.currentPage = page;
            if (this.gridOption.type === 'local') {
                this.reload(this.localItems);
            }
            else {
                this.reload();
            }
        }
    }
    updateFilter(param) {
        var _a, _b;
        if ((_a = param) === null || _a === void 0 ? void 0 : _a.filter) {
            this.filter = param.filter;
        }
        if ((_b = param) === null || _b === void 0 ? void 0 : _b.externalFilter) {
            this.externalFilter = param.externalFilter;
        }
        if (this.gridOption.type === 'local') {
            this.reload(this.localItems);
        }
        else {
            this.reload();
        }
    }
    generatePaginate() {
        const { pageSize } = this.gridOption.paginate;
        if (this.gridOption.type === 'local') {
            this.total = this.items.length;
        }
        this.pages = [];
        this.totalPage = Math.trunc(this.total / pageSize) + (this.total % pageSize === 0 ? 0 : 1);
        if (this.totalPage <= this.pageCount) {
            for (let i = 1; i <= this.totalPage; i++) {
                this.pages.push(i);
            }
        }
        else {
            if (this.currentPage < 3) {
                this.pages = [1, 2, 3, 4, 5];
            }
            else if (this.currentPage > this.totalPage - 2) {
                this.pages = [this.totalPage - 4, this.totalPage - 3, this.totalPage - 2, this.totalPage - 1, this.totalPage];
            }
            else {
                this.pages = [this.currentPage - 2, this.currentPage - 1, this.currentPage, this.currentPage + 1, this.currentPage + 2];
            }
        }
        this.hiddenPaginate = this.currentPage === 1 && this.total <= pageSize;
    }
    generateSumarize() {
        var _a;
        if (((_a = this.items) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            const from = +this.gridOption.paginate.pageSize * (+this.currentPage - 1) + 1;
            const to = from + this.viewItems.length - 1;
            this.sumarize = `${from} - ${to} / ${this.total}`;
        }
        else {
            this.sumarize = this.translateService.translate('EMPTY');
        }
    }
    getItems() {
        return this.items;
    }
    //#region Checkable
    setSelectedItems() {
        this.selectedItems = this.items.filter(item => item.isChecked)
            .map(item => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = item, result = __rest(item, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return result;
        });
    }
    check(item, isCheckbox) {
        var _a, _b;
        if (!this.gridOption.checkable) {
            return;
        }
        if (!isCheckbox) {
            item.isChecked = !item.isChecked;
        }
        this.isCheckedAll = this.items.length === this.items.filter(e => e.isChecked).length;
        (_b = (_a = this.gridOption).onCheck) === null || _b === void 0 ? void 0 : _b.call(_a, this.items.filter(e => e.isChecked), item);
        this.setSelectedItems();
    }
    checkAll(isCheckedAll) {
        this.isCheckedAll = isCheckedAll;
        this.items.forEach(item => item.isChecked = this.isCheckedAll);
        if (this.gridOption.onCheck) {
            this.gridOption.onCheck(this.items.filter(item => item.isChecked));
        }
        this.setSelectedItems();
    }
    //#endregion
    //#region Sort
    sort(column) {
        var _a, _b;
        const sortable = (_a = this.gridOption.sortable, (_a !== null && _a !== void 0 ? _a : true));
        const columnSortable = (_b = column.sortable, (_b !== null && _b !== void 0 ? _b : true));
        if (!sortable || !columnSortable) {
            return;
        }
        if (this.orderBy === column.field) {
            this.orderDirection = this.orderDirection === 'ASC' ? 'DESC' : 'ASC';
        }
        else {
            this.orderBy = column.field;
            this.orderDirection = 'ASC';
        }
        if (this.gridOption.type === 'local') {
            this.reload(this.localItems);
        }
        else {
            this.reload();
        }
    }
    //#endregion
    // #region Resize Grid
    resize() {
        this.detectChanges();
        if (this.gridOption.height) {
            this.gridBody.nativeElement.style.height = this.gridOption.height;
        }
        else {
            this.gridBody.nativeElement.style.height = `${window.innerHeight - 300}px`;
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 0);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 200);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 500);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 1000);
        }
    }
    setHeight(height) {
        this.gridOption.height = height;
        this.resize();
    }
    // #endregion
    //#region Import, Export, Config
    loadConfig(configResult) {
        this.gridOption.paginate.pageSize = configResult.pageSize;
        this.gridOption.columns = configResult.columns;
        this.fixedColumns = configResult.fixedColumns;
        this.normalColumns = configResult.normalColumns;
        this.columns = [...this.fixedColumns, ...this.normalColumns];
        this.currentPage = 1;
        this.initFilter();
        this.initDictionaryColumnValues();
        this.reload();
    }
    initFilter() {
        this.gridOption.columns.forEach(column => {
            var _a;
            // Gán giá trị filter mặc định cho từng cột
            this.filter[column.field] = (_a = this.filter[column.field], (_a !== null && _a !== void 0 ? _a : ''));
        });
    }
    initDictionaryColumnValues() {
        this.gridOption.columns.forEach(column => {
            if (column.type === 'values') {
                column.dictionary = {};
                if (column.values) {
                    column.values.forEach(e => {
                        column.dictionary[e.value.toString()] = {
                            text: e.text,
                            icon: e.icon,
                            color: e.color,
                            backgroundColor: e.backgroundColor
                        };
                    });
                }
            }
            if (column.type === 'children') {
                column.children.forEach(childColumn => {
                    if (childColumn.type === 'values') {
                        childColumn.dictionary = {};
                        if (childColumn.values) {
                            childColumn.values.forEach(e => {
                                childColumn.dictionary[e.value.toString()] = {
                                    text: e.text,
                                    icon: e.icon,
                                    color: e.color,
                                    backgroundColor: e.backgroundColor
                                };
                            });
                        }
                    }
                });
            }
        });
    }
    //#endregion
    generateEditorHandlers() {
        this.viewItems.forEach(item => {
            this.generateEditorHanlder(item);
        });
    }
    generateEditorHanlder(item) {
        // item.editorHandler = item.editorHandler || {};
        this.editorVisiblePipe.transform(null, item, this.gridOption);
    }
    trackById(index, item) {
        return item.id;
    }
    get isFiltering() {
        return Object.values(this.filter).some(value => !!value);
    }
    onFilterPopup() {
        const f1 = JSON.stringify(this.filter);
        const f2 = JSON.stringify(this.externalFilter);
        const filter = JSON.parse(f1);
        const externalFilter = JSON.parse(f2);
        this.sdGridPopupFilter.open(this.fixedColumns, this.normalColumns, filter, externalFilter, this.gridOption.filter.externalFilters);
    }
    get invalidItems() {
        return this.items.filter(e => { var _a; return (_a = e.editorHandler) === null || _a === void 0 ? void 0 : _a.errorMessage; }).map(e => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = e, item = __rest(e, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return {
                item,
                message: e.editorHandler.errorMessage
            };
        });
    }
    get gridItems() {
        return this.items.map(e => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = e, item = __rest(e, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return item;
        });
    }
};
GridControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: HandlerLocal },
    { type: HandlerDotnet },
    { type: UtilityService },
    { type: TranslateService },
    { type: ConfigurationService },
    { type: DatePipe },
    { type: LoadingService },
    { type: ApiService },
    { type: ExcelService },
    { type: NotifyService },
    { type: EditorHandlerPipe }
];
__decorate([
    ViewChildren('fixedHeader')
], GridControlComponent.prototype, "fixedHeaders", void 0);
__decorate([
    ViewChildren('fixedBody')
], GridControlComponent.prototype, "fixedBodies", void 0);
__decorate([
    ViewChild('fixedGridContainer')
], GridControlComponent.prototype, "fixedGridContainer", void 0);
__decorate([
    ViewChild('gridFixedBody')
], GridControlComponent.prototype, "gridFixedBody", void 0);
__decorate([
    ViewChild('gridContainer')
], GridControlComponent.prototype, "gridContainer", void 0);
__decorate([
    ViewChild('gridHeader')
], GridControlComponent.prototype, "gridHeader", void 0);
__decorate([
    ViewChild('gridBody')
], GridControlComponent.prototype, "gridBody", void 0);
__decorate([
    ViewChild('sdGridConfig', { static: true })
], GridControlComponent.prototype, "sdGridConfig", void 0);
__decorate([
    ViewChild('sdGridPopupEditor')
], GridControlComponent.prototype, "sdGridPopupEditor", void 0);
__decorate([
    ViewChild('sdGridPopupFilter')
], GridControlComponent.prototype, "sdGridPopupFilter", void 0);
__decorate([
    ViewChild(GridImportExcelComponent)
], GridControlComponent.prototype, "sdGridImportExcel", void 0);
__decorate([
    ViewChild(GridPopupExportExcelComponent)
], GridControlComponent.prototype, "sdGridPopupExportExcel", void 0);
__decorate([
    Input()
], GridControlComponent.prototype, "option", null);
GridControlComponent = __decorate([
    Component({
        selector: 'sd-grid-control',
        template: "<div class=\"clearfix\"></div>\r\n<mat-form-field class=\"sd-form\" *ngIf=\"quickFilters?.length\" appearance=\"outline\" style=\"width: 200px;\">\r\n  <mat-select [(ngModel)]=\"selectedQuickFilter\" (selectionChange)=\"onSelectQuickFilter($event)\">\r\n    <mat-option value=\"\">{{'Quick filter' | sdTranslate}}</mat-option>\r\n    <mat-option *ngFor=\"let quickFilter of quickFilters\" [value]=\"quickFilter?.code\">\r\n      <span>{{quickFilter?.code}}</span>\r\n    </mat-option>\r\n  </mat-select>\r\n</mat-form-field>\r\n<sd-grid-desktop-inline-filter [externalFilters]=\"gridOption?.filter?.externalFilters\" [columns]=\"gridOption?.columns\"\r\n  [showInlineFilter]=\"showInlineFilter\" [filter]=\"filter\" [externalFilter]=\"externalFilter\" (sdChange)=\"updateFilter()\">\r\n</sd-grid-desktop-inline-filter>\r\n<div *ngIf=\"!isMobileOrTablet; else elseMobileOrTablet\" class=\"sd-box sd-box-primary\">\r\n  <div class=\"sd-box-body p-0\">\r\n    <div class=\"row mx-0\">\r\n      <div [ngClass]=\"{'c-loading': isLoading}\" class=\"table-responsive\" #gridBody style=\"position: relative;\">\r\n        <i [ngClass]=\"{'d-none': !isLoading}\" class=\"fa fa-5x fa-spinner fa-pulse c-loading-icon\"></i>\r\n        <table [ngClass]=\"{'c-loading-margin': isLoading}\" *ngIf=\"gridOption\"\r\n          class=\"table table-hover table-striped table-bordered c-table\" style=\"border:0!important;\">\r\n          <thead class=\"thead-light\">\r\n            <tr>\r\n              <th class=\"position-sticky c-sticky-all align-middle p-0\" style=\"width:4px; min-width: 4px;\" #fixedHeader>\r\n              </th>\r\n              <th class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\" #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.subInformation\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:30px;min-width: 30px;line-height: 3rem\" #fixedHeader>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.subInformation\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.checkable\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:50px;min-width:50px;\" #fixedHeader>\r\n                <label class=\"custom-control custom-checkbox\">\r\n                  <input type=\"checkbox\" class=\"custom-control-input\" [(ngModel)]=\"isCheckedAll\"\r\n                    (change)=\"checkAll(isCheckedAll)\">\r\n                  <span class=\"custom-control-label\"></span>\r\n                </label>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.checkable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.commands?.length\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                [ngStyle]=\"{'width':gridOption.commands.length*30 + 'px', 'min-width': gridOption.commands.length*30 + 'px'}\"\r\n                #fixedHeader>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.commands?.length\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption.editor?.addable || gridOption.editor?.editable\"\r\n                class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:60px;min-width: 60px;line-height: 1.5\" #fixedHeader>\r\n                <div *ngIf=\"gridOption.editor.addable\" class=\"align-middle text-center\">\r\n                  <button type=\"button\" class=\"c-btn-icon\" (click)=\"onCreate()\">\r\n                    <i class=\"fa fa-plus\"></i>\r\n                  </button>\r\n                </div>\r\n              </th>\r\n              <th *ngIf=\"gridOption.editor\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.numberable\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:50px;min-width:50px;\" #fixedHeader>\r\n                #\r\n              </th>\r\n              <th *ngIf=\"gridOption?.numberable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <ng-template ngFor let-column [ngForOf]=\"fixedColumns\">\r\n                <th class=\"position-sticky align-middle cursor-pointer c-cell c-sticky-all\" #fixedHeader\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                  <span [title]=\"column.title\" class=\"c-header-title\"\r\n                    [ngStyle]=\"{'width':column.width && column.width !== 'auto' ? column.width : '400px'}\"\r\n                    (click)=\"sort(column)\">\r\n                    {{column.title}}\r\n                    <i *ngIf=\"column.type !== 'children' && gridOption.sortable !== false && column.sortable !== false && orderBy !== column.field\"\r\n                      class=\"fa fa-sort fa-fw\"></i>\r\n                    <i *ngIf=\"orderBy == column.field && orderDirection == 'ASC'\" class=\"fa fa-sort-asc fa-fw\"></i>\r\n                    <i *ngIf=\"orderBy == column.field && orderDirection == 'DESC'\" class=\"fa fa-sort-desc fa-fw\"></i>\r\n                  </span>\r\n                  <ng-container\r\n                    *ngIf=\"(showInlineFilter || gridOption?.filter?.type === 'inline') && !column?.preventFilter && !gridOption?.filter?.disabled\">\r\n                    <input\r\n                      *ngIf=\"column.type === 'string' || column.type === 'number' || column.type === 'color' || column.type === 'children'\"\r\n                      type=\"text\" class=\"form-control form-control-xs\" [(ngModel)]=\"filter[column.field]\"\r\n                      (keyup.enter)=\"updateFilter()\">\r\n                    <select *ngIf=\"column.type === 'bool'\" class=\"form-control form-control-xs\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option value=\"1\">{{column.trueValue || 'True'}}</option>\r\n                      <option value=\"0\">{{column.falseValue || 'False'}}</option>\r\n                    </select>\r\n                    <sd-grid-autocomplete-control *ngIf=\"column.type === 'values' && column?.editor?.autocomplete\"\r\n                      [items]=\"column.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\"\r\n                      (sdChange)=\"updateFilter()\">\r\n                    </sd-grid-autocomplete-control>\r\n                    <select class=\"form-control form-control-xs\"\r\n                      *ngIf=\"column.type == 'values' && !column?.editor?.autocomplete\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}</option>\r\n                    </select>\r\n                    <select class=\"form-control form-control-xs\" *ngIf=\"column.type == 'radio'\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option *ngFor=\"let data of column.values\" [value]=\"data[column.valueField]\">\r\n                        {{data[column.displayField]}}</option>\r\n                    </select>\r\n                    <sd-grid-date-picker-control\r\n                      *ngIf=\"column.type === 'date' || column.type === 'datetime' || column.type === 'time'\"\r\n                      [(model)]=\"filter[column.field]\" (sdChange)=\"updateFilter()\" type=\"date\">\r\n                    </sd-grid-date-picker-control>\r\n                  </ng-container>\r\n                </th>\r\n                <th class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\" #fixedHeader></th>\r\n              </ng-template>\r\n              <th *ngFor=\"let column of normalColumns\"\r\n                class=\"position-sticky align-middle cursor-pointer border-top-0 border-bottom-0 c-cell c-sticky-top\"\r\n                [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                <span [title]=\"column.title\" class=\"c-header-title\"\r\n                  [ngStyle]=\"{'width':column.width && column.width !== 'auto' ? column.width : '400px'}\"\r\n                  (click)=\"sort(column)\">\r\n                  {{column.title}}\r\n                  <i *ngIf=\"column.type !== 'children' && gridOption.sortable !== false && column.sortable !== false && orderBy !== column.field\"\r\n                    class=\"fa fa-sort fa-fw\"></i>\r\n                  <i *ngIf=\"orderBy == column.field && orderDirection == 'ASC'\" class=\"fa fa-sort-asc fa-fw\"></i>\r\n                  <i *ngIf=\"orderBy == column.field && orderDirection == 'DESC'\" class=\"fa fa-sort-desc fa-fw\"></i>\r\n                </span>\r\n                <ng-container\r\n                  *ngIf=\"(showInlineFilter || gridOption?.filter?.type === 'inline') && !column?.preventFilter && !gridOption?.filter?.disabled\">\r\n                  <input\r\n                    *ngIf=\"column.type === 'string' || column.type === 'number' || column.type === 'color' || column.type === 'children'\"\r\n                    type=\"text\" class=\"form-control form-control-xs\" [(ngModel)]=\"filter[column.field]\"\r\n                    (keyup.enter)=\"updateFilter()\">\r\n                  <select *ngIf=\"column.type === 'bool'\" class=\"form-control form-control-xs\"\r\n                    [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option value=\"1\">{{column.trueValue || 'TRUE'}}</option>\r\n                    <option value=\"0\">{{column.falseValue || 'FALSE'}}</option>\r\n                  </select>\r\n                  <sd-grid-autocomplete-control *ngIf=\"column.type === 'values' && column?.editor?.autocomplete\"\r\n                    [items]=\"column.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\"\r\n                    (sdChange)=\"updateFilter()\">\r\n                  </sd-grid-autocomplete-control>\r\n                  <select class=\"form-control form-control-xs\"\r\n                    *ngIf=\"column.type == 'values' && !column?.editor?.autocomplete\" [(ngModel)]=\"filter[column.field]\"\r\n                    (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}</option>\r\n                  </select>\r\n                  <select class=\"form-control form-control-xs\" *ngIf=\"column.type == 'radio'\"\r\n                    [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option *ngFor=\"let data of column.values\" [value]=\"data[column.valueField]\">\r\n                      {{data[column.displayField]}}</option>\r\n                  </select>\r\n                  <sd-grid-date-picker-control\r\n                    *ngIf=\"column.type === 'date' || column.type === 'datetime' || column.type === 'time'\"\r\n                    [(model)]=\"filter[column.field]\" (sdChange)=\"updateFilter()\" type=\"date\">\r\n                  </sd-grid-date-picker-control>\r\n                </ng-container>\r\n              </th>\r\n            </tr>\r\n          </thead>\r\n          <tbody>\r\n            <ng-container *ngFor=\"let item of viewItems; index as idx; trackBy: trackById\">\r\n              <tr>\r\n                <td class=\"position-sticky c-sticky-left p-0\"\r\n                  [ngClass]=\"{'c-error': (item.editingStatus && item.editorHandler?.errorMessage), 'c-selected': !(item.editingStatus && item.editorHandler?.errorMessage) && selectedItem === item}\"\r\n                  style=\"width:4px;min-width: 4px;left:0\" matTooltipPosition=\"after\"\r\n                  [matTooltip]=\"item.editingStatus ? item.editorHandler?.errorMessage:''\" #fixedBody>\r\n                </td>\r\n                <td class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\" #fixedBody></td>\r\n                <td *ngIf=\"gridOption.subInformation\" class=\"position-sticky text-center align-middle p-0 c-sticky-left\"\r\n                  style=\"width:30px;min-width: 30px;line-height: 3rem\" #fixedBody>\r\n                  <button *ngIf=\"!item.editingStatus\" (click)=\"expandOrCollapse(item)\" type=\"button\" class=\"c-btn-icon\">\r\n                    <i *ngIf=\"item.subInformation?.isLoading\" class=\"fa fa-spinner fa-spin\"></i>\r\n                    <i *ngIf=\"!item.subInformation?.isLoading\" class=\"fa\"\r\n                      [ngClass]=\"{'fa-caret-right': !item.subInformation?.isOpened, 'fa-caret-down': item.subInformation?.isOpened}\"></i>\r\n                  </button>\r\n                </td>\r\n                <td *ngIf=\"gridOption.subInformation\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.checkable\" class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"align-middle text-center\" style=\"width:50px;min-width: 50px;\">\r\n                    <label class=\"custom-control custom-checkbox\">\r\n                      <input type=\"checkbox\" class=\"custom-control-input\" [(ngModel)]=\"item.isChecked\"\r\n                        (change)=\"check(item, true)\">\r\n                      <span class=\"custom-control-label\"></span>\r\n                    </label>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.checkable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.commands?.length\" class=\"position-sticky c-sticky-left align-middle p-0\"\r\n                  #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"d-flex align-middle text-center justify-content-center\"\r\n                    [ngStyle]=\"{'width':gridOption.commands.length*30 + 'px', 'min-width': gridOption.commands.length*30 + 'px'}\">\r\n                    <ng-container *ngFor=\"let command of gridOption.commands\">\r\n                      <section *ngIf=\"!(item | commandHiddenByItem:command.hiddenByItem | async)\">\r\n                        <button *ngIf=\"!command.children?.length; else elseCommandChildren\"\r\n                          (click)=\"command.click(item)\" type=\"button\" class=\"c-btn-icon\"\r\n                          [matTooltip]=\"command.title | commandTitle:item\"\r\n                          [disabled]=\"command.disabled | commandDisabled:item\">\r\n                          <i class=\"{{command.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n                        </button>\r\n                        <ng-template #elseCommandChildren>\r\n                          <ng-container\r\n                            *ngIf=\"command.children | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                            <div *ngIf=\"filteredColumnCommands?.length\">\r\n                              <button [matMenuTriggerFor]=\"menu\" type=\"button\" class=\"c-btn-icon\"\r\n                                [matTooltip]=\"command.title\" [disabled]=\"command.disabled | commandDisabled:item\">\r\n                                <i class=\"{{command.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n                              </button>\r\n                              <mat-menu #menu=\"matMenu\">\r\n                                <button mat-menu-item *ngFor=\"let childCommand of filteredColumnCommands\"\r\n                                  [disabled]=\"childCommand.disabled | commandDisabled:item\"\r\n                                  (click)=\"childCommand.click(item)\">\r\n                                  <i class=\"{{childCommand.icon | commandIcon:item}}\"></i>\r\n                                  <span> {{childCommand.title | commandTitle:item}}</span>\r\n                                </button>\r\n                              </mat-menu>\r\n                            </div>\r\n                          </ng-container>\r\n                        </ng-template>\r\n                      </section>\r\n                    </ng-container>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.commands?.length\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.editor?.addable || gridOption.editor?.editable\"\r\n                  class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div class=\"align-middle text-center\" style=\"width:60px;min-width: 60px;line-height: 1.5\">\r\n                    <button type=\"button\"\r\n                      *ngIf=\"!item.editingStatus && gridOption.editor?.type !== 'inline' && gridOption.editor?.editable\"\r\n                      type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Edit\" (click)=\"onUpdate(item)\"\r\n                      [disabled]=\"item.editorHandler?.disabled\">\r\n                      <i class=\"fa fa-pencil text-primary\" aria-hidden=\"true\"></i>\r\n                    </button>\r\n                    <button type=\"button\" *ngIf=\"item.editingStatus && gridOption.editor?.type !== 'inline'\"\r\n                      type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Save\" (click)=\"onSave(item)\"\r\n                      [disabled]=\"item.editorHandler?.errorMessage\">\r\n                      <i class=\"fa fa-fw text-success\"\r\n                        [ngClass]=\"{'fa-floppy-o': !item.editorHandler?.saving, 'fa-spinner': item.editorHandler?.saving, 'fa-spin': item.editorHandler?.saving}\"\r\n                        aria-hidden=\"true\"></i>\r\n                    </button>\r\n                    <button type=\"button\" *ngIf=\"item.editingStatus\" type=\"button\" class=\"c-btn-icon\" placement=\"top\"\r\n                      matTooltip=\"Cancel\" (click)=\"onCancel(item)\">\r\n                      <i class=\"fa fa-fw fa-times text-danger\" aria-hidden=\"true\"></i>\r\n                    </button>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.editor\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.numberable\" class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"align-middle text-center\" style=\"width:50px;min-width: 50px;\">\r\n                    {{gridOption.paginate?.pageSize * (currentPage - 1) + idx + 1}}\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.numberable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <ng-template ngFor let-column [ngForOf]=\"fixedColumns\">\r\n                  <td class=\"position-sticky align-middle c-cell c-sticky-left\"\r\n                    [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number' && column.type !== 'children', 'text-right': column.type === 'number'}\"\r\n                    [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\"\r\n                    (click)=\"rowHandler.click(item)\" #fixedBody>\r\n                    <ng-container *ngIf=\"column.type !== 'children';else elseColumnChildren\">\r\n                      <div *ngIf=\"item[column.field] | editorHandler:item:gridOption\" class=\"align-middle\"\r\n                        (dblclick)=\"rowHandler.dblClick(item)\">\r\n                        <div\r\n                          *ngIf=\"item.editorHandler[column.field].visible && gridOption.editor?.validate && !(item[column.field] | editorValidate:item:gridOption.editor.validate | async)\">\r\n                        </div>\r\n                        <ng-container *ngIf=\"item.editorHandler[column.field].visible;else columnView\">\r\n                          <sd-grid-desktop-column-edit [column]=\"column\" [item]=\"item\" (sdChange)=\"onEditorChange()\"></sd-grid-desktop-column-edit>\r\n                        </ng-container>\r\n                        <ng-template #columnView>\r\n                          <sd-grid-desktop-column-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-view>\r\n                        </ng-template>\r\n                      </div>\r\n                    </ng-container>\r\n                    <ng-template #elseColumnChildren>\r\n                      <sd-grid-desktop-column-children-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-children-view>\r\n                    </ng-template>\r\n                  </td>\r\n                  <td class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\" #fixedBody></td>\r\n                </ng-template>\r\n                <td *ngFor=\"let column of normalColumns\" class=\"align-middle c-cell\" (click)=\"rowHandler.click(item)\"\r\n                  [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number' && column.type !== 'children', 'text-right': column.type === 'number'}\"\r\n                  (dblclick)=\"rowHandler.dblClick(item)\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '', 'min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                  <ng-container *ngIf=\"column.type !== 'children';else elseColumnChildren\">\r\n                    <div *ngIf=\"item[column.field] | editorHandler:item:gridOption\" class=\"align-middle\"\r\n                      (dblclick)=\"rowHandler.dblClick(item)\">\r\n                      <div\r\n                        *ngIf=\"item.editorHandler[column.field].visible && gridOption.editor?.validate && !(item[column.field] | editorValidate:item:gridOption.editor.validate | async)\">\r\n                      </div>\r\n                      <ng-container *ngIf=\"item.editorHandler[column.field].visible;else columnView\">\r\n                        <sd-grid-desktop-column-edit [column]=\"column\" [item]=\"item\" (sdChange)=\"onEditorChange()\"></sd-grid-desktop-column-edit>\r\n                      </ng-container>\r\n                      <ng-template #columnView>\r\n                        <sd-grid-desktop-column-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-view>\r\n                      </ng-template>\r\n                    </div>\r\n                  </ng-container>\r\n                  <ng-template #elseColumnChildren>\r\n                    <sd-grid-desktop-column-children-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-children-view>\r\n                  </ng-template>\r\n                </td>\r\n              </tr>\r\n              <tr *ngIf=\"gridOption?.subInformation && item?.subInformation?.isOpened\" class=\"c-no-hover\">\r\n                <td class=\"position-sticky c-sticky-left p-0\" style=\"width:4px;min-width: 4px;left:0\">\r\n                </td>\r\n                <td class=\"p-3\" colspan=\"100\">\r\n                  <sd-grid-sub-information [subItems]=\"item?.subInformation?.subItems\"\r\n                    [columns]=\"gridOption?.subInformation?.columns\"></sd-grid-sub-information>\r\n                </td>\r\n              </tr>\r\n            </ng-container>\r\n            <tr *ngIf=\"!viewItems?.length && !isLoading && noDataImage\">\r\n              <td class=\"c-empty\" colspan=\"100\">\r\n                <img [src]=\"noDataImage\">\r\n              </td>\r\n            </tr>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"!gridOption.hideFooter\" class=\"sd-box-footer clearfix\">\r\n    <sd-button *ngIf=\"sdGridPopupFilter\" class=\"mr-1\" [title]=\"'Filter' | sdTranslate\" icon=\"filter_list\" size=\"sm\" (action)=\"onFilterPopup()\"></sd-button>\r\n    <sd-button *ngIf=\"!gridOption?.hideReload\" class=\"mr-1\" [title]=\"'Reload' | sdTranslate\" icon=\"refresh\" size=\"sm\" (action)=\"reload()\"></sd-button>\r\n    <sd-button *ngIf=\"gridOption.onImportExcel\" class=\"mr-1\" [title]=\"'Import' | sdTranslate\" icon=\"publish\" size=\"sm\" (action)=\"sdGridImportExcel.open()\"></sd-button>\r\n    <sd-button *ngIf=\"sdGridPopupExportExcel\" class=\"mr-1\" [title]=\"'Export' | sdTranslate\" icon=\"get_app\" size=\"sm\" (action)=\"sdGridPopupExportExcel.open()\"></sd-button>\r\n    <sd-button *ngIf=\"gridOption.key\" class=\"mr-1\" [title]=\"'Configure' | sdTranslate\" icon=\"settings\" size=\"sm\" (action)=\"sdGridConfig.open()\"></sd-button>\r\n    <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n      <ul class=\"pagination pagination-primary m-0\">\r\n        <li class=\"page-item disabled\">\r\n          <span> {{sumarize}} </span>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage > 1\" class=\"page-item\" (click)=\"selectPage(1)\">\r\n          <a class=\"page-link\">\r\n            {{'First' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage > 1\" class=\"page-item\" (click)=\"selectPage(currentPage-1)\">\r\n          <a class=\"page-link\">\r\n            {{'Previous' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <ng-container *ngIf=\"!hiddenPaginate\">\r\n          <li class=\"page-item\" [ngClass]=\"{'active':page === currentPage}\" *ngFor=\"let page of pages\"\r\n            (click)=\"selectPage(page)\">\r\n            <a class=\"page-link\">{{page}}</a>\r\n          </li>\r\n        </ng-container>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage < totalPage\" class=\"page-item\" (click)=\"selectPage(currentPage+1)\">\r\n          <a class=\"page-link\">\r\n            {{'Next' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage < totalPage\" class=\"page-item\" (click)=\"selectPage(totalPage)\">\r\n          <a class=\"page-link\">\r\n            {{'Last' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n  </div>\r\n</div>\r\n<ng-template #elseMobileOrTablet>\r\n  <div class=\"sd-box c-mobile-box\">\r\n    <div class=\"sd-box-body c-mobile-body\" [ngClass]=\"{'c-loading': isLoading}\" #gridBody>\r\n      <i [ngClass]=\"{'d-none': !isLoading}\" class=\"fa fa-4x fa-spinner fa-pulse c-loading-icon\"></i>\r\n      <ng-container *ngFor=\"let item of viewItems\">\r\n        <div class=\"c-mobile-item\" [ngClass]=\"{'c-mobile-item-selected':item.isChecked}\">\r\n          <ng-container *ngFor=\"let column of columns | filterMobile:item\">\r\n            <div *ngIf=\"column.type !== 'children'\" class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n              <div class=\"col-5\">\r\n                <span class=\"c-mobile-title\">\r\n                  <!-- <i class=\"fa fa-circle fa-fw\" style=\"font-size: 10px;\"></i> -->\r\n                  {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n                </span>\r\n              </div>\r\n              <div class=\"col-7\">\r\n                <ng-container *ngIf=\"column.type === 'string'\">\r\n                  <span *ngIf=\"!column.htmlTemplate; else elseUseTemplate\"\r\n                    [className]=\"item[column.field] | cellClassName:item:column\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                    <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                      (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n                    <ng-container *ngIf=\"!column.click\">\r\n                      {{item[column.field]}}</ng-container>\r\n                  </span>\r\n                  <ng-template #elseUseTemplate>\r\n                    <span class=\"c-mobile-value\"\r\n                      [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n                  </ng-template>\r\n                  <ng-container\r\n                    *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                    <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\"\r\n                      type=\"button\" class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n                      <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\"\r\n                        style=\"font-size: 14px;\"></i>\r\n                    </button>\r\n                  </ng-container>\r\n                </ng-container>\r\n                <span *ngIf=\"column.type === 'number'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'datetime'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'date'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'time'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'HH:mm'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'HH:mm'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'bool'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\"\r\n                  (click)=\"column.click && column.click(item[column.field], item)\">\r\n                  <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n                  <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                    class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n                <ng-container *ngIf=\"column.type === 'values'\">\r\n                  <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n                    <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                      [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                      {{dic.text}}\r\n                    </span>\r\n                    <ng-template #elseNoStatus>\r\n                      <span class=\"c-mobile-value\">\r\n                        {{dic.text}}\r\n                      </span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <ng-template #elseNotInDic>\r\n                    <span class=\"c-mobile-value\">\r\n                      {{item[column.field]}}\r\n                    </span>\r\n                  </ng-template>\r\n                </ng-container>\r\n                <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n                <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n                  [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n                  (click)=\"column.click && column.click(item[column.field], item)\">\r\n              </div>\r\n            </div>\r\n            <ng-container *ngIf=\"column.type === 'children' && column.children?.length\">\r\n              <div class=\"row c-mobile-row\" *ngFor=\"let childColumn of column.children | filterMobile:item\"\r\n                (click)=\"check(item)\">\r\n                <div class=\"col-5\">\r\n                  <span class=\"c-mobile-title\">\r\n                    <!-- <i class=\"fa fa-circle fa-fw\" style=\"font-size: 10px;\"></i> -->\r\n                    {{childColumn.title}}:\r\n                  </span>\r\n                </div>\r\n                <div class=\"col-7\">\r\n                  <ng-container *ngIf=\"childColumn.type === 'string'\">\r\n                    <span *ngIf=\"!childColumn.htmlTemplate; else elseUseTemplate\"\r\n                      [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                      [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"><a\r\n                        *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                        (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</a>\r\n                      <ng-container *ngIf=\"!childColumn.click\">\r\n                        {{item[childColumn.field]}}</ng-container>\r\n                    </span>\r\n                    <ng-template #elseUseTemplate>\r\n                      <span class=\"c-mobile-value\"\r\n                        [innerHTML]=\"(item[childColumn.field] | columnHtmlTemplate:item:childColumn.htmlTemplate) | safeHtml\"></span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <span *ngIf=\"childColumn.type === 'number'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'date'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'time'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'HH:mm'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'HH:mm'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'bool'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n                    (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n                    <span *ngIf=\"item[childColumn.field]\"\r\n                      class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                    <span *ngIf=\"!item[childColumn.field]\"\r\n                      class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'color'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n                    (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\"><input\r\n                      disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n                      [(ngModel)]=\"item[childColumn.field]\"></span>\r\n                  <ng-container *ngIf=\"childColumn.type === 'values'\">\r\n                    <ng-container *ngIf=\"childColumn?.dictionary[item[childColumn.field]] as dic; else elseNotInDic\">\r\n                      <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                        [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                        {{dic.text}}\r\n                      </span>\r\n                      <ng-template #elseNoStatus>\r\n                        <span class=\"c-mobile-value\">\r\n                          {{dic.text}}\r\n                        </span>\r\n                      </ng-template>\r\n                    </ng-container>\r\n                    <ng-template #elseNotInDic>\r\n                      <span class=\"c-mobile-value\">\r\n                        {{item[childColumn.field]}}\r\n                      </span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <span *ngIf=\"childColumn.type === 'radio'\" class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n                  <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                    [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\" style=\"margin: 5px 0\"\r\n                    (click)=\"column.click && column.click(item[column.field], item)\">\r\n                </div>\r\n              </div>\r\n            </ng-container>\r\n          </ng-container>\r\n          <div class=\"p-2\" *ngIf=\"gridOption?.subInformation && item?.subInformation?.isOpened\">\r\n            <sd-grid-sub-information [subItems]=\"item?.subInformation?.subItems\"\r\n              [columns]=\"gridOption?.subInformation?.columns\"></sd-grid-sub-information>\r\n          </div>\r\n          <div class=\"c-mobile-command\">\r\n            <div>\r\n              <i *ngIf=\"gridOption?.subInformation && item.subInformation?.isLoading\"\r\n                class=\"fa fa-spinner fa-spin ml-1 c-mobile-action\" (click)=\"expandOrCollapse(item)\"></i>\r\n              <i *ngIf=\"gridOption?.subInformation && !item.subInformation?.isLoading\" class=\"fa ml-1 c-mobile-action\"\r\n                [ngClass]=\"{'fa-plus': !item.subInformation?.isOpened, 'fa-minus': item.subInformation?.isOpened}\"\r\n                (click)=\"expandOrCollapse(item)\"></i>\r\n            </div>\r\n            <ng-container *ngIf=\"gridOption.commands | mobileCommandFilter:item | async; $implicit as filteredCommands\">\r\n              <div *ngIf=\"filteredCommands.length\">\r\n                <i [matMenuTriggerFor]=\"menu\" class=\"fa fa-navicon fa-fw c-mobile-action\"></i>\r\n                <mat-menu #menu=\"matMenu\">\r\n                  <button *ngFor=\"let command of filteredCommands\" mat-menu-item (click)=\"command.click(item)\"\r\n                    [disabled]=\"command.disabled | commandDisabled:item\">\r\n                    <i class=\"{{command.icon | commandIcon:item}}\"></i>\r\n                    <span> {{command.title | commandTitle:item}}</span>\r\n                  </button>\r\n                </mat-menu>\r\n              </div>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n    <div *ngIf=\"!gridOption.hideFooter\" class=\"sd-box-footer clearfix\">\r\n      <button *ngIf=\"sdGridPopupFilter\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"onFilterPopup()\">\r\n        <i class=\"fa fa-filter fa-fw sd-text-info c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"!gridOption?.hideReload\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"reload()\">\r\n        <i class=\"fa fa-refresh fa-fw sd-text-info c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"gridOption.onImportExcel\" type=\"button\" class=\"c-btn-icon c-m-3\"\r\n        (click)=\"sdGridImportExcel.open()\">\r\n        <i class=\"fa fa-upload fa-fw sd-text-success c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"sdGridPopupExportExcel\" [disabled]=\"!viewItems?.length\" type=\"button\" class=\"c-btn-icon c-m-3\"\r\n        (click)=\"sdGridPopupExportExcel.open()\">\r\n        <i class=\"fa fa-download fa-fw sd-text-success c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"gridOption.key\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"sdGridConfig.open()\">\r\n        <i class=\"fa fa-cogs fa-fw sd-text-primary c-mobile-action\"></i>\r\n      </button>\r\n      <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n        <div class=\"40px\">\r\n          <select class=\"form-control form-control-xs\" [(ngModel)]=\"gridOption.paginate.pageSize\"\r\n            (change)=\"onSelectPageSize()\">\r\n            <option value=\"10\">10</option>\r\n            <option value=\"25\">25</option>\r\n            <option value=\"50\">50</option>\r\n            <option value=\"100\">100</option>\r\n          </select>\r\n        </div>\r\n        <ul class=\"pagination pagination-primary m-0\">\r\n          <!-- <li class=\"page-item disabled\">\r\n            <span> {{sumarize}} </span>\r\n          </li> -->\r\n          <li class=\"page-item\" [ngClass]=\"{'disabled':currentPage === 1}\" (click)=\"selectPage(currentPage-1)\">\r\n            <a class=\"page-link\">\r\n              <i class=\"fa fa-angle-left\"></i>\r\n            </a>\r\n          </li>\r\n          <li class=\"page-item active\">\r\n            <a class=\"page-link\">{{currentPage}}</a>\r\n          </li>\r\n          <li class=\"page-item\" [ngClass]=\"{'disabled':currentPage === totalPage}\" (click)=\"selectPage(currentPage+1)\">\r\n            <a class=\"page-link\">\r\n              <i class=\"fa fa-angle-right\"></i>\r\n            </a>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n<!-- Modal Configure Grid -->\r\n<sd-grid-config (sdChange)=\"loadConfig($event)\" #sdGridConfig></sd-grid-config>\r\n<sd-grid-popup-editor (save)=\"onSave($event)\" #sdGridPopupEditor></sd-grid-popup-editor>\r\n<!-- Import Excel -->\r\n<sd-grid-import-excel *ngIf=\"gridOption?.onImportExcel\" [key]=\"gridOption?.key\" [columns]=\"gridOption?.columns\"\r\n  [accept]=\"gridOption?.onImportExcel\" #sdGridImportExcel></sd-grid-import-excel>\r\n<sd-grid-popup-export-excel *ngIf=\"gridOption.exportable\" [key]=\"gridOption?.key\" [columns]=\"gridOption?.columns\"\r\n  [extendColumns]=\"gridOption?.export?.columns\" [validator]=\"gridOption?.export?.validator\"\r\n  (exportByTemplate)=\"onExportByTemplate($event)\" #sdGridPopupExportExcel>\r\n</sd-grid-popup-export-excel>\r\n<sd-grid-popup-filter\r\n  *ngIf=\"!gridOption?.filter?.disabled && (isMobileOrTablet || gridOption?.filter?.type === 'popup' || gridOption?.filter?.externalFilters?.length)\"\r\n  [key]=\"gridOption?.key\" (accept)=\"updateFilter($event)\" [filterType]=\"gridOption?.filter?.type\"\r\n  (clear)=\"onClearFilter()\" #sdGridPopupFilter (loadInlineFilter)=\"onFilterConfigurationLoaded($event)\">\r\n</sd-grid-popup-filter>",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-text-primary{color:#c82c37!important}.sd-text-secondary{color:#919191!important}.sd-text-info{color:#00bcd4!important}.sd-text-success{color:#4caf50!important}.sd-text-warning{color:#ff9800!important}.sd-text-danger{color:#f44336!important}.sd-t48m{font-size:48px;font-weight:Medium;line-height:56px}.sd-t48r{font-size:48px;font-weight:Regular;line-height:56px}.sd-t32m{font-size:32px;font-weight:Medium;line-height:40px}.sd-t32r{font-size:32px;font-weight:Regular;line-height:40px}.sd-t24m{font-size:24px;font-weight:Medium;line-height:32px}.sd-t24r{font-size:24px;font-weight:Regular;line-height:32px}.sd-t20m{font-size:20px;font-weight:Medium;line-height:28px}.sd-t20r{font-size:20px;font-weight:Regular;line-height:28px}.sd-t16m{font-size:16px;font-weight:Medium;line-height:24px}.sd-t16r{font-size:16px;font-weight:Regular;line-height:24px}.sd-t14m{font-size:14px;font-weight:Medium;line-height:20px}.sd-t14r{font-size:14px;font-weight:Regular;line-height:20px}.sd-t12m{font-size:12px;font-weight:Medium;line-height:16px}.sd-t12r{font-size:12px;font-weight:Regular;line-height:16px}.sd-t10m{font-size:10px;font-weight:Medium;line-height:12px}.sd-t10r{font-size:10px;font-weight:Regular;line-height:12px}", ".pagination>li>a{border:0;border-radius:24px!important;transition:.3s;padding:0 9px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>span{border:0;border-radius:24px!important;transition:.3s;padding:0 8px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>a:focus,.pagination>li>a:hover,.pagination>li>span:focus,.pagination>li>span:hover{z-index:3;color:#23527c;background-color:#eee;border-color:#ddd}.pagination>.active>a,.pagination>.active>a:focus,.pagination>.active>a:hover,.pagination>.active>span,.pagination>.active>span:focus,.pagination>.active>span:hover{background-color:#c82c37;border-color:#c82c37;color:#fff;box-shadow:0 4px 5px 0 rgba(156,39,176,.14),0 1px 10px 0 rgba(156,39,176,.12),0 2px 4px -1px rgba(156,39,176,.2)}.pagination.pagination-info>.active>a,.pagination.pagination-info>.active>a:focus,.pagination.pagination-info>.active>a:hover,.pagination.pagination-info>.active>span,.pagination.pagination-info>.active>span:focus,.pagination.pagination-info>.active>span:hover{background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 4px 5px 0 rgba(0,188,212,.14),0 1px 10px 0 rgba(0,188,212,.12),0 2px 4px -1px rgba(0,188,212,.2)}.pagination.pagination-success>.active>a,.pagination.pagination-success>.active>a:focus,.pagination.pagination-success>.active>a:hover,.pagination.pagination-success>.active>span,.pagination.pagination-success>.active>span:focus,.pagination.pagination-success>.active>span:hover{background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.pagination.pagination-warning>.active>a,.pagination.pagination-warning>.active>a:focus,.pagination.pagination-warning>.active>a:hover,.pagination.pagination-warning>.active>span,.pagination.pagination-warning>.active>span:focus,.pagination.pagination-warning>.active>span:hover{background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.pagination.pagination-danger>.active>a,.pagination.pagination-danger>.active>a:focus,.pagination.pagination-danger>.active>a:hover,.pagination.pagination-danger>.active>span,.pagination.pagination-danger>.active>span:focus,.pagination.pagination-danger>.active>span:hover{background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}", "@charset \"UTF-8\";html{scroll-behavior:smooth;font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:transparent}.c-fs14{font-size:14px}.c-fs15{font-size:15px}.c-fs16{font-size:16px}.c-fs21{font-size:21px}/*!\n * Bootstrap v4.5.0 (https://getbootstrap.com/)\n * Copyright 2011-2020 The Bootstrap Authors\n * Copyright 2011-2020 Twitter, Inc.\n * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)\n */:root{--blue:#007bff;--indigo:#6610f2;--purple:#6f42c1;--pink:#e83e8c;--red:#dc3545;--orange:#fd7e14;--yellow:#ffc107;--green:#28a745;--teal:#20c997;--cyan:#17a2b8;--white:#fff;--gray:#6c757d;--gray-dark:#343a40;--primary:#c82c37;--secondary:#919191;--success:#4caf50;--info:#00bcd4;--warning:#ff9800;--danger:#f44336;--light:#f8f9fa;--dark:#343a40;--breakpoint-xs:0;--breakpoint-sm:576px;--breakpoint-md:768px;--breakpoint-lg:992px;--breakpoint-xl:1200px;--font-family-sans-serif:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";--font-family-monospace:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace}*,::after,::before{box-sizing:border-box}article,aside,figcaption,figure,footer,header,hgroup,main,nav,section{display:block}body{margin:0;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-size:1rem;font-weight:400;line-height:1.5;color:#212529;text-align:left;background-color:#fff}[tabindex=\"-1\"]:focus:not(:focus-visible){outline:0!important}h1,h2,h3,h4,h5,h6{margin-top:0}dl,ol,p,ul{margin-top:0;margin-bottom:1rem}abbr[data-original-title],abbr[title]{text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;cursor:help;border-bottom:0;-webkit-text-decoration-skip-ink:none;text-decoration-skip-ink:none}address{margin-bottom:1rem;font-style:normal;line-height:inherit}ol ol,ol ul,ul ol,ul ul{margin-bottom:0}dt{font-weight:700}dd{margin-bottom:.5rem;margin-left:0}blockquote,figure{margin:0 0 1rem}b,strong{font-weight:bolder}sub,sup{position:relative;font-size:75%;line-height:0;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}a{color:#344468;text-decoration:none;background-color:transparent}a:hover{color:#c82c37;text-decoration:underline}a:not([href]),a:not([href]):hover{color:inherit;text-decoration:none}code,kbd,pre,samp{font-family:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace;font-size:1em}pre{margin-top:0;margin-bottom:1rem;overflow:auto;-ms-overflow-style:scrollbar}img{vertical-align:middle;border-style:none}svg{overflow:hidden;vertical-align:middle}table{border-collapse:collapse}caption{padding-top:.75rem;padding-bottom:.75rem;color:#6c757d;text-align:left;caption-side:bottom}th{text-align:inherit}label{display:inline-block;margin-bottom:.5rem}button{border-radius:0}button:focus{outline:dotted 1px;outline:-webkit-focus-ring-color auto 5px}button,input,optgroup,select,textarea{margin:0;font-family:inherit;font-size:inherit;line-height:inherit}button,input{overflow:visible}button,select{text-transform:none}[role=button],[type=button]:not(:disabled),[type=reset]:not(:disabled),[type=submit]:not(:disabled),button:not(:disabled){cursor:pointer}select{word-wrap:normal}[type=button],[type=reset],[type=submit],button{-webkit-appearance:button}[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner,button::-moz-focus-inner{padding:0;border-style:none}input[type=checkbox],input[type=radio]{box-sizing:border-box;padding:0}textarea{overflow:auto;resize:vertical}fieldset{min-width:0;padding:0;margin:0;border:0}legend{display:block;width:100%;max-width:100%;padding:0;margin-bottom:.5rem;font-size:1.5rem;line-height:inherit;color:inherit;white-space:normal}progress{vertical-align:baseline}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{outline-offset:-2px;-webkit-appearance:none}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{font:inherit;-webkit-appearance:button}output{display:inline-block}summary{display:list-item;cursor:pointer}template{display:none}[hidden]{display:none!important}.h1,.h2,.h3,.h4,.h5,.h6,h1,h2,h3,h4,h5,h6{margin-bottom:.5px;font-weight:500;line-height:1.2}.h1,h1{font-size:3rem}.h2,h2{font-size:2rem}.h3,h3{font-size:1.75rem}.h4,.h5,h4,h5{font-size:1.25rem}.h6,h6{font-size:1rem}.lead{font-size:1.25rem;font-weight:300}.display-1{font-size:6rem;font-weight:300;line-height:1.2}.display-2{font-size:5.5rem;font-weight:300;line-height:1.2}.display-3{font-size:4.5rem;font-weight:300;line-height:1.2}.display-4{font-size:3.5rem;font-weight:300;line-height:1.2}hr{box-sizing:content-box;height:0;overflow:visible;margin-top:1px;margin-bottom:1px;border:0;border-top:1px solid rgba(0,0,0,.1)}.small,small{font-size:80%;font-weight:400}.mark,mark{padding:.2em;background-color:#fcf8e3}.list-inline,.list-unstyled{padding-left:0;list-style:none}.list-inline-item{display:inline-block}.list-inline-item:not(:last-child){margin-right:.5rem}.initialism{font-size:90%;text-transform:uppercase}.blockquote{margin-bottom:1px;font-size:1.25rem}.blockquote-footer{display:block;font-size:80%;color:#6c757d}.blockquote-footer::before{content:\"\u2014\u00A0\"}.img-fluid{max-width:100%;height:auto}.img-thumbnail{padding:.25rem;background-color:#fff;border:1px solid #dee2e6;border-radius:8px;max-width:100%;height:auto}.figure{display:inline-block}.figure-img{margin-bottom:.5px;line-height:1}.figure-caption{font-size:90%;color:#6c757d}code{font-size:87.5%;color:#e83e8c;word-wrap:break-word}a>code{color:inherit}kbd{padding:.2rem .4rem;font-size:87.5%;color:#fff;background-color:#212529;border-radius:.2rem}kbd kbd{padding:0;font-size:100%;font-weight:700}pre{display:block;font-size:87.5%;color:#212529}pre code{font-size:inherit;color:inherit;word-break:normal}.pre-scrollable{max-height:340px;overflow-y:scroll}.container{width:100%;padding-right:16px;padding-left:16px;margin-right:auto;margin-left:auto}@media (min-width:576px){.container{max-width:540px}}@media (min-width:768px){.container{max-width:720px}}@media (min-width:992px){.container{max-width:960px}}@media (min-width:1200px){.container{max-width:1264px}}.container-fluid,.container-lg,.container-md,.container-sm,.container-xl{width:100%;padding-right:16px;padding-left:16px;margin-right:auto;margin-left:auto}@media (min-width:576px){.container,.container-sm{max-width:540px}}@media (min-width:768px){.container,.container-md,.container-sm{max-width:720px}}@media (min-width:992px){.container,.container-lg,.container-md,.container-sm{max-width:960px}}@media (min-width:1200px){.container,.container-lg,.container-md,.container-sm,.container-xl{max-width:1264px}}.row{display:flex;flex-wrap:wrap;margin-right:-16px;margin-left:-16px}.no-gutters{margin-right:0;margin-left:0}.no-gutters>.col,.no-gutters>[class*=col-]{padding-right:0;padding-left:0}.col,.col-1,.col-10,.col-11,.col-12,.col-2,.col-3,.col-4,.col-5,.col-6,.col-7,.col-8,.col-9,.col-auto,.col-lg,.col-lg-1,.col-lg-10,.col-lg-11,.col-lg-12,.col-lg-2,.col-lg-3,.col-lg-4,.col-lg-5,.col-lg-6,.col-lg-7,.col-lg-8,.col-lg-9,.col-lg-auto,.col-md,.col-md-1,.col-md-10,.col-md-11,.col-md-12,.col-md-2,.col-md-3,.col-md-4,.col-md-5,.col-md-6,.col-md-7,.col-md-8,.col-md-9,.col-md-auto,.col-sm,.col-sm-1,.col-sm-10,.col-sm-11,.col-sm-12,.col-sm-2,.col-sm-3,.col-sm-4,.col-sm-5,.col-sm-6,.col-sm-7,.col-sm-8,.col-sm-9,.col-sm-auto,.col-xl,.col-xl-1,.col-xl-10,.col-xl-11,.col-xl-12,.col-xl-2,.col-xl-3,.col-xl-4,.col-xl-5,.col-xl-6,.col-xl-7,.col-xl-8,.col-xl-9,.col-xl-auto{position:relative;width:100%;padding-right:16px;padding-left:16px}.col{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-1>*{flex:0 0 100%;max-width:100%}.row-cols-2>*{flex:0 0 50%;max-width:50%}.row-cols-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-4>*{flex:0 0 25%;max-width:25%}.row-cols-5>*{flex:0 0 20%;max-width:20%}.row-cols-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-auto{flex:0 0 auto;width:auto;max-width:100%}.col-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-3{flex:0 0 25%;max-width:25%}.col-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-6{flex:0 0 50%;max-width:50%}.col-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-9{flex:0 0 75%;max-width:75%}.col-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-12{flex:0 0 100%;max-width:100%}.order-first{order:-1}.order-last{order:13}.order-0{order:0}.order-1{order:1}.order-2{order:2}.order-3{order:3}.order-4{order:4}.order-5{order:5}.order-6{order:6}.order-7{order:7}.order-8{order:8}.order-9{order:9}.order-10{order:10}.order-11{order:11}.order-12{order:12}.offset-1{margin-left:8.3333333333%}.offset-2{margin-left:16.6666666667%}.offset-3{margin-left:25%}.offset-4{margin-left:33.3333333333%}.offset-5{margin-left:41.6666666667%}.offset-6{margin-left:50%}.offset-7{margin-left:58.3333333333%}.offset-8{margin-left:66.6666666667%}.offset-9{margin-left:75%}.offset-10{margin-left:83.3333333333%}.offset-11{margin-left:91.6666666667%}@media (min-width:576px){.col-sm{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-sm-1>*{flex:0 0 100%;max-width:100%}.row-cols-sm-2>*{flex:0 0 50%;max-width:50%}.row-cols-sm-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-sm-4>*{flex:0 0 25%;max-width:25%}.row-cols-sm-5>*{flex:0 0 20%;max-width:20%}.row-cols-sm-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-sm-auto{flex:0 0 auto;width:auto;max-width:100%}.col-sm-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-sm-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-sm-3{flex:0 0 25%;max-width:25%}.col-sm-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-sm-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-sm-6{flex:0 0 50%;max-width:50%}.col-sm-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-sm-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-sm-9{flex:0 0 75%;max-width:75%}.col-sm-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-sm-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-sm-12{flex:0 0 100%;max-width:100%}.order-sm-first{order:-1}.order-sm-last{order:13}.order-sm-0{order:0}.order-sm-1{order:1}.order-sm-2{order:2}.order-sm-3{order:3}.order-sm-4{order:4}.order-sm-5{order:5}.order-sm-6{order:6}.order-sm-7{order:7}.order-sm-8{order:8}.order-sm-9{order:9}.order-sm-10{order:10}.order-sm-11{order:11}.order-sm-12{order:12}.offset-sm-0{margin-left:0}.offset-sm-1{margin-left:8.3333333333%}.offset-sm-2{margin-left:16.6666666667%}.offset-sm-3{margin-left:25%}.offset-sm-4{margin-left:33.3333333333%}.offset-sm-5{margin-left:41.6666666667%}.offset-sm-6{margin-left:50%}.offset-sm-7{margin-left:58.3333333333%}.offset-sm-8{margin-left:66.6666666667%}.offset-sm-9{margin-left:75%}.offset-sm-10{margin-left:83.3333333333%}.offset-sm-11{margin-left:91.6666666667%}}@media (min-width:768px){.col-md{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-md-1>*{flex:0 0 100%;max-width:100%}.row-cols-md-2>*{flex:0 0 50%;max-width:50%}.row-cols-md-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-md-4>*{flex:0 0 25%;max-width:25%}.row-cols-md-5>*{flex:0 0 20%;max-width:20%}.row-cols-md-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-md-auto{flex:0 0 auto;width:auto;max-width:100%}.col-md-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-md-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-md-3{flex:0 0 25%;max-width:25%}.col-md-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-md-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-md-6{flex:0 0 50%;max-width:50%}.col-md-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-md-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-md-9{flex:0 0 75%;max-width:75%}.col-md-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-md-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-md-12{flex:0 0 100%;max-width:100%}.order-md-first{order:-1}.order-md-last{order:13}.order-md-0{order:0}.order-md-1{order:1}.order-md-2{order:2}.order-md-3{order:3}.order-md-4{order:4}.order-md-5{order:5}.order-md-6{order:6}.order-md-7{order:7}.order-md-8{order:8}.order-md-9{order:9}.order-md-10{order:10}.order-md-11{order:11}.order-md-12{order:12}.offset-md-0{margin-left:0}.offset-md-1{margin-left:8.3333333333%}.offset-md-2{margin-left:16.6666666667%}.offset-md-3{margin-left:25%}.offset-md-4{margin-left:33.3333333333%}.offset-md-5{margin-left:41.6666666667%}.offset-md-6{margin-left:50%}.offset-md-7{margin-left:58.3333333333%}.offset-md-8{margin-left:66.6666666667%}.offset-md-9{margin-left:75%}.offset-md-10{margin-left:83.3333333333%}.offset-md-11{margin-left:91.6666666667%}}@media (min-width:992px){.col-lg{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-lg-1>*{flex:0 0 100%;max-width:100%}.row-cols-lg-2>*{flex:0 0 50%;max-width:50%}.row-cols-lg-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-lg-4>*{flex:0 0 25%;max-width:25%}.row-cols-lg-5>*{flex:0 0 20%;max-width:20%}.row-cols-lg-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-lg-auto{flex:0 0 auto;width:auto;max-width:100%}.col-lg-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-lg-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-lg-3{flex:0 0 25%;max-width:25%}.col-lg-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-lg-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-lg-6{flex:0 0 50%;max-width:50%}.col-lg-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-lg-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-lg-9{flex:0 0 75%;max-width:75%}.col-lg-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-lg-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-lg-12{flex:0 0 100%;max-width:100%}.order-lg-first{order:-1}.order-lg-last{order:13}.order-lg-0{order:0}.order-lg-1{order:1}.order-lg-2{order:2}.order-lg-3{order:3}.order-lg-4{order:4}.order-lg-5{order:5}.order-lg-6{order:6}.order-lg-7{order:7}.order-lg-8{order:8}.order-lg-9{order:9}.order-lg-10{order:10}.order-lg-11{order:11}.order-lg-12{order:12}.offset-lg-0{margin-left:0}.offset-lg-1{margin-left:8.3333333333%}.offset-lg-2{margin-left:16.6666666667%}.offset-lg-3{margin-left:25%}.offset-lg-4{margin-left:33.3333333333%}.offset-lg-5{margin-left:41.6666666667%}.offset-lg-6{margin-left:50%}.offset-lg-7{margin-left:58.3333333333%}.offset-lg-8{margin-left:66.6666666667%}.offset-lg-9{margin-left:75%}.offset-lg-10{margin-left:83.3333333333%}.offset-lg-11{margin-left:91.6666666667%}}@media (min-width:1200px){.col-xl{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-xl-1>*{flex:0 0 100%;max-width:100%}.row-cols-xl-2>*{flex:0 0 50%;max-width:50%}.row-cols-xl-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-xl-4>*{flex:0 0 25%;max-width:25%}.row-cols-xl-5>*{flex:0 0 20%;max-width:20%}.row-cols-xl-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-xl-auto{flex:0 0 auto;width:auto;max-width:100%}.col-xl-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-xl-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-xl-3{flex:0 0 25%;max-width:25%}.col-xl-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-xl-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-xl-6{flex:0 0 50%;max-width:50%}.col-xl-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-xl-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-xl-9{flex:0 0 75%;max-width:75%}.col-xl-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-xl-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-xl-12{flex:0 0 100%;max-width:100%}.order-xl-first{order:-1}.order-xl-last{order:13}.order-xl-0{order:0}.order-xl-1{order:1}.order-xl-2{order:2}.order-xl-3{order:3}.order-xl-4{order:4}.order-xl-5{order:5}.order-xl-6{order:6}.order-xl-7{order:7}.order-xl-8{order:8}.order-xl-9{order:9}.order-xl-10{order:10}.order-xl-11{order:11}.order-xl-12{order:12}.offset-xl-0{margin-left:0}.offset-xl-1{margin-left:8.3333333333%}.offset-xl-2{margin-left:16.6666666667%}.offset-xl-3{margin-left:25%}.offset-xl-4{margin-left:33.3333333333%}.offset-xl-5{margin-left:41.6666666667%}.offset-xl-6{margin-left:50%}.offset-xl-7{margin-left:58.3333333333%}.offset-xl-8{margin-left:66.6666666667%}.offset-xl-9{margin-left:75%}.offset-xl-10{margin-left:83.3333333333%}.offset-xl-11{margin-left:91.6666666667%}}.table{width:100%;margin-bottom:1px;color:#212529}.table td,.table th{padding:.75rem;vertical-align:top;border-top:1px solid #f2f3f4}.table thead th{vertical-align:bottom;border-bottom:2px solid #f2f3f4}.table tbody+tbody{border-top:2px solid #f2f3f4}.table-sm td,.table-sm th{padding:.3rem}.table-bordered,.table-bordered td,.table-bordered th{border:1px solid #f2f3f4}.table-bordered thead td,.table-bordered thead th{border-bottom-width:2px}.table-borderless tbody+tbody,.table-borderless td,.table-borderless th,.table-borderless thead th{border:0}.table-striped tbody tr:nth-of-type(odd){background-color:rgba(0,0,0,.05)}.table-hover tbody tr:hover{color:#212529;background-color:rgba(0,0,0,.075)}.table-primary,.table-primary>td,.table-primary>th{background-color:#f0c4c7}.table-primary tbody+tbody,.table-primary td,.table-primary th,.table-primary thead th{border-color:#e29197}.table-hover .table-primary:hover,.table-hover .table-primary:hover>td,.table-hover .table-primary:hover>th{background-color:#ebb0b4}.table-secondary,.table-secondary>td,.table-secondary>th{background-color:#e0e0e0}.table-secondary tbody+tbody,.table-secondary td,.table-secondary th,.table-secondary thead th{border-color:#c6c6c6}.table-hover .table-secondary:hover,.table-hover .table-secondary:hover>td,.table-hover .table-secondary:hover>th{background-color:#d3d3d3}.table-success,.table-success>td,.table-success>th{background-color:#cde9ce}.table-success tbody+tbody,.table-success td,.table-success th,.table-success thead th{border-color:#a2d5a4}.table-hover .table-success:hover,.table-hover .table-success:hover>td,.table-hover .table-success:hover>th{background-color:#bbe1bd}.table-info,.table-info>td,.table-info>th{background-color:#b8ecf3}.table-info tbody+tbody,.table-info td,.table-info th,.table-info thead th{border-color:#7adce9}.table-hover .table-info:hover,.table-hover .table-info:hover>td,.table-hover .table-info:hover>th{background-color:#a2e6ef}.table-warning,.table-warning>td,.table-warning>th{background-color:#ffe2b8}.table-warning tbody+tbody,.table-warning td,.table-warning th,.table-warning thead th{border-color:#ffc97a}.table-hover .table-warning:hover,.table-hover .table-warning:hover>td,.table-hover .table-warning:hover>th{background-color:#ffd89f}.table-danger,.table-danger>td,.table-danger>th{background-color:#fccac7}.table-danger tbody+tbody,.table-danger td,.table-danger th,.table-danger thead th{border-color:#f99d96}.table-hover .table-danger:hover,.table-hover .table-danger:hover>td,.table-hover .table-danger:hover>th{background-color:#fbb3af}.table-light,.table-light>td,.table-light>th{background-color:#fdfdfe}.table-light tbody+tbody,.table-light td,.table-light th,.table-light thead th{border-color:#fbfcfc}.table-hover .table-light:hover,.table-hover .table-light:hover>td,.table-hover .table-light:hover>th{background-color:#ececf6}.table-dark,.table-dark>td,.table-dark>th{background-color:#c6c8ca}.table-dark tbody+tbody,.table-dark td,.table-dark th,.table-dark thead th{border-color:#95999c}.table-hover .table-dark:hover,.table-hover .table-dark:hover>td,.table-hover .table-dark:hover>th{background-color:#b9bbbe}.table-active,.table-active>td,.table-active>th,.table-hover .table-active:hover,.table-hover .table-active:hover>td,.table-hover .table-active:hover>th{background-color:rgba(0,0,0,.075)}.table .thead-dark th{color:#fff;background-color:#343a40;border-color:#454d55}.table .thead-light th{color:#495057;background-color:#e9ecef;border-color:#f2f3f4}.table-dark{color:#fff;background-color:#343a40}.table-dark td,.table-dark th,.table-dark thead th{border-color:#454d55}.table-dark.table-bordered{border:0}.table-dark.table-striped tbody tr:nth-of-type(odd){background-color:rgba(255,255,255,.05)}.table-dark.table-hover tbody tr:hover{color:#fff;background-color:rgba(255,255,255,.075)}@media (max-width:575.98px){.table-responsive-sm{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-sm>.table-bordered{border:0}}@media (max-width:767.98px){.table-responsive-md{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-md>.table-bordered{border:0}}@media (max-width:991.98px){.table-responsive-lg{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-lg>.table-bordered{border:0}}@media (max-width:1199.98px){.table-responsive-xl{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-xl>.table-bordered{border:0}}.table-responsive{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive>.table-bordered{border:0}.form-control{display:block;width:100%;height:56px;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;background-color:#fff;background-clip:padding-box;border:1px solid #e6e7e9;border-radius:8px;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.form-control{transition:none}}.form-control::-ms-expand{background-color:transparent;border:0}.form-control:-moz-focusring{color:transparent;text-shadow:0 0 0 #344468}.form-control:focus{color:#344468;background-color:#fff;border-color:rgba(47,107,255,.1);outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.form-control::-webkit-input-placeholder{color:#6c757d;opacity:1}.form-control::-moz-placeholder{color:#6c757d;opacity:1}.form-control::-ms-input-placeholder{color:#6c757d;opacity:1}.form-control::placeholder{color:#6c757d;opacity:1}.form-control:disabled,.form-control[readonly]{background-color:#e9ecef;opacity:1}input[type=date].form-control,input[type=datetime-local].form-control,input[type=month].form-control,input[type=time].form-control{-webkit-appearance:none;-moz-appearance:none;appearance:none}select.form-control:focus::-ms-value{color:#344468;background-color:#fff}.form-control-file,.form-control-range{display:block;width:100%}.col-form-label{padding-top:calc(.375rem + 1px);padding-bottom:calc(.375rem + 1px);margin-bottom:0;font-size:inherit;line-height:1.5}.col-form-label-lg{padding-top:calc(.5rem + 1px);padding-bottom:calc(.5rem + 1px);font-size:1.25rem;line-height:1.5}.col-form-label-sm{padding-top:calc(.25rem + 1px);padding-bottom:calc(.25rem + 1px);font-size:.875rem;line-height:1.5}.form-control-plaintext{display:block;width:100%;padding:.375rem 0;margin-bottom:0;font-size:1rem;line-height:1.5;color:#212529;background-color:transparent;border:solid transparent;border-width:1px 0}.form-control-plaintext.form-control-lg,.form-control-plaintext.form-control-sm{padding-right:0;padding-left:0}.form-control-sm{height:calc(1.5em + .5rem + 2px);padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.form-control-lg{height:calc(1.5em + 1rem + 2px);padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}select.form-control[multiple],select.form-control[size],textarea.form-control{height:auto}.form-group{margin-bottom:1rem}.form-text{display:block;margin-top:.25rem}.form-row{display:flex;flex-wrap:wrap;margin-right:-5px;margin-left:-5px}.form-row>.col,.form-row>[class*=col-]{padding-right:5px;padding-left:5px}.form-check{position:relative;display:block;padding-left:1.25rem}.form-check-input{position:absolute;margin-top:.3rem;margin-left:-1.25rem}.form-check-input:disabled~.form-check-label,.form-check-input[disabled]~.form-check-label{color:#6c757d}.form-check-label{margin-bottom:0}.form-check-inline{display:inline-flex;align-items:center;padding-left:0;margin-right:.75rem}.form-check-inline .form-check-input{position:static;margin-top:0;margin-right:.3125rem;margin-left:0}.valid-feedback{display:none;width:100%;margin-top:.25rem;font-size:80%;color:#4caf50}.valid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;line-height:1.5;color:#fff;background-color:rgba(76,175,80,.9);border-radius:8px}.is-valid~.valid-feedback,.is-valid~.valid-tooltip,.was-validated :valid~.valid-feedback,.was-validated :valid~.valid-tooltip{display:block}.form-control.is-valid,.was-validated .form-control:valid{border-color:#4caf50;padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%234caf50' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.form-control.is-valid:focus,.was-validated .form-control:valid:focus{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.was-validated textarea.form-control:valid,textarea.form-control.is-valid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.custom-select.is-valid,.was-validated .custom-select:valid{border-color:#4caf50;padding-right:calc(.75em + 2.3125rem);background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat,url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%234caf50' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e\") center right 1.75rem/calc(.75em + .375rem) calc(.75em + .375rem) no-repeat #fff}.custom-select.is-valid:focus,.was-validated .custom-select:valid:focus{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.form-check-input.is-valid~.form-check-label,.was-validated .form-check-input:valid~.form-check-label{color:#4caf50}.form-check-input.is-valid~.valid-feedback,.form-check-input.is-valid~.valid-tooltip,.was-validated .form-check-input:valid~.valid-feedback,.was-validated .form-check-input:valid~.valid-tooltip{display:block}.custom-control-input.is-valid~.custom-control-label,.was-validated .custom-control-input:valid~.custom-control-label{color:#4caf50}.custom-control-input.is-valid~.custom-control-label::before,.was-validated .custom-control-input:valid~.custom-control-label::before{border-color:#4caf50}.custom-control-input.is-valid:checked~.custom-control-label::before,.was-validated .custom-control-input:valid:checked~.custom-control-label::before{border-color:#6ec071;background-color:#6ec071}.custom-control-input.is-valid:focus~.custom-control-label::before,.was-validated .custom-control-input:valid:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.custom-control-input.is-valid:focus:not(:checked)~.custom-control-label::before,.was-validated .custom-control-input:valid:focus:not(:checked)~.custom-control-label::before{border-color:#4caf50}.custom-file-input.is-valid~.custom-file-label,.was-validated .custom-file-input:valid~.custom-file-label{border-color:#4caf50}.custom-file-input.is-valid:focus~.custom-file-label,.was-validated .custom-file-input:valid:focus~.custom-file-label{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.invalid-feedback{display:none;width:100%;margin-top:.25rem;font-size:80%;color:#f44336}.invalid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;line-height:1.5;color:#fff;background-color:rgba(244,67,54,.9);border-radius:8px}.is-invalid~.invalid-feedback,.is-invalid~.invalid-tooltip,.was-validated :invalid~.invalid-feedback,.was-validated :invalid~.invalid-tooltip{display:block}.form-control.is-invalid,.was-validated .form-control:invalid{border-color:#f44336;padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none' stroke='%23f44336' viewBox='0 0 12 12'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23f44336' stroke='none'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.form-control.is-invalid:focus,.was-validated .form-control:invalid:focus{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.was-validated textarea.form-control:invalid,textarea.form-control.is-invalid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.custom-select.is-invalid,.was-validated .custom-select:invalid{border-color:#f44336;padding-right:calc(.75em + 2.3125rem);background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat,url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none' stroke='%23f44336' viewBox='0 0 12 12'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23f44336' stroke='none'/%3e%3c/svg%3e\") center right 1.75rem/calc(.75em + .375rem) calc(.75em + .375rem) no-repeat #fff}.custom-select.is-invalid:focus,.was-validated .custom-select:invalid:focus{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.form-check-input.is-invalid~.form-check-label,.was-validated .form-check-input:invalid~.form-check-label{color:#f44336}.form-check-input.is-invalid~.invalid-feedback,.form-check-input.is-invalid~.invalid-tooltip,.was-validated .form-check-input:invalid~.invalid-feedback,.was-validated .form-check-input:invalid~.invalid-tooltip{display:block}.custom-control-input.is-invalid~.custom-control-label,.was-validated .custom-control-input:invalid~.custom-control-label{color:#f44336}.custom-control-input.is-invalid~.custom-control-label::before,.was-validated .custom-control-input:invalid~.custom-control-label::before{border-color:#f44336}.custom-control-input.is-invalid:checked~.custom-control-label::before,.was-validated .custom-control-input:invalid:checked~.custom-control-label::before{border-color:#f77066;background-color:#f77066}.custom-control-input.is-invalid:focus~.custom-control-label::before,.was-validated .custom-control-input:invalid:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.custom-control-input.is-invalid:focus:not(:checked)~.custom-control-label::before,.was-validated .custom-control-input:invalid:focus:not(:checked)~.custom-control-label::before{border-color:#f44336}.custom-file-input.is-invalid~.custom-file-label,.was-validated .custom-file-input:invalid~.custom-file-label{border-color:#f44336}.custom-file-input.is-invalid:focus~.custom-file-label,.was-validated .custom-file-input:invalid:focus~.custom-file-label{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.form-inline{display:flex;flex-flow:row wrap;align-items:center}.form-inline .form-check{width:100%}@media (min-width:576px){.form-inline label{display:flex;align-items:center;justify-content:center;margin-bottom:0}.form-inline .form-group{display:flex;flex:0 0 auto;flex-flow:row wrap;align-items:center;margin-bottom:0}.form-inline .form-control{display:inline-block;width:auto;vertical-align:middle}.form-inline .form-control-plaintext{display:inline-block}.form-inline .custom-select,.form-inline .input-group{width:auto}.form-inline .form-check{display:flex;align-items:center;justify-content:center;width:auto;padding-left:0}.form-inline .form-check-input{position:relative;flex-shrink:0;margin-top:0;margin-right:.25rem;margin-left:0}.form-inline .custom-control{align-items:center;justify-content:center}.form-inline .custom-control-label{margin-bottom:0}}.btn{display:inline-block;font-weight:400;color:#212529;text-align:center;vertical-align:middle;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-color:transparent;border:1px solid transparent;padding:12px .75rem;font-size:1rem;line-height:1.4;border-radius:8px;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.btn{transition:none}}.btn:hover{color:#212529;text-decoration:none}.btn.focus,.btn:focus{outline:0!important;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.btn.disabled,.btn:disabled{opacity:.65}.btn:not(:disabled):not(.disabled){cursor:pointer}a.btn.disabled,fieldset:disabled a.btn{pointer-events:none}.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-primary:hover{color:#fff;background-color:#a9252e;border-color:#9e232c}.btn-primary.focus,.btn-primary:focus{color:#fff;background-color:#a9252e;border-color:#9e232c;box-shadow:0 0 0 .2rem rgba(208,76,85,.5)}.btn-primary.disabled,.btn-primary:disabled{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-primary:not(:disabled):not(.disabled).active,.btn-primary:not(:disabled):not(.disabled):active,.show>.btn-primary.dropdown-toggle{color:#fff;background-color:#9e232c;border-color:#942129}.btn-primary:not(:disabled):not(.disabled).active:focus,.btn-primary:not(:disabled):not(.disabled):active:focus,.show>.btn-primary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(208,76,85,.5)}.btn-secondary{color:#fff;background-color:#919191;border-color:#919191}.btn-secondary:hover{color:#fff;background-color:#7e7e7e;border-color:#787878}.btn-secondary.focus,.btn-secondary:focus{color:#fff;background-color:#7e7e7e;border-color:#787878;box-shadow:0 0 0 .2rem rgba(162,162,162,.5)}.btn-secondary.disabled,.btn-secondary:disabled{color:#fff;background-color:#919191;border-color:#919191}.btn-secondary:not(:disabled):not(.disabled).active,.btn-secondary:not(:disabled):not(.disabled):active,.show>.btn-secondary.dropdown-toggle{color:#fff;background-color:#787878;border-color:#717171}.btn-secondary:not(:disabled):not(.disabled).active:focus,.btn-secondary:not(:disabled):not(.disabled):active:focus,.show>.btn-secondary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(162,162,162,.5)}.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-success:hover{color:#fff;background-color:#409444;border-color:#3d8b40}.btn-success.focus,.btn-success:focus{color:#fff;background-color:#409444;border-color:#3d8b40;box-shadow:0 0 0 .2rem rgba(103,187,106,.5)}.btn-success.disabled,.btn-success:disabled{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-success:not(:disabled):not(.disabled).active,.btn-success:not(:disabled):not(.disabled):active,.show>.btn-success.dropdown-toggle{color:#fff;background-color:#3d8b40;border-color:#39833c}.btn-success:not(:disabled):not(.disabled).active:focus,.btn-success:not(:disabled):not(.disabled):active:focus,.show>.btn-success.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(103,187,106,.5)}.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-info:hover{color:#fff;background-color:#009aae;border-color:#008fa1}.btn-info.focus,.btn-info:focus{color:#fff;background-color:#009aae;border-color:#008fa1;box-shadow:0 0 0 .2rem rgba(38,198,218,.5)}.btn-info.disabled,.btn-info:disabled{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-info:not(:disabled):not(.disabled).active,.btn-info:not(:disabled):not(.disabled):active,.show>.btn-info.dropdown-toggle{color:#fff;background-color:#008fa1;border-color:#008394}.btn-info:not(:disabled):not(.disabled).active:focus,.btn-info:not(:disabled):not(.disabled):active:focus,.show>.btn-info.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(38,198,218,.5)}.btn-warning{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-warning:hover{color:#fff;background-color:#d98100;border-color:#cc7a00}.btn-warning.focus,.btn-warning:focus{color:#fff;background-color:#d98100;border-color:#cc7a00;box-shadow:0 0 0 .2rem rgba(222,135,6,.5)}.btn-warning.disabled,.btn-warning:disabled{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-warning:not(:disabled):not(.disabled).active,.btn-warning:not(:disabled):not(.disabled):active,.show>.btn-warning.dropdown-toggle{color:#fff;background-color:#cc7a00;border-color:#bf7200}.btn-warning:not(:disabled):not(.disabled).active:focus,.btn-warning:not(:disabled):not(.disabled):active:focus,.show>.btn-warning.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(222,135,6,.5)}.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336}.btn-danger:hover{color:#fff;background-color:#f22112;border-color:#ea1c0d}.btn-danger.focus,.btn-danger:focus{color:#fff;background-color:#f22112;border-color:#ea1c0d;box-shadow:0 0 0 .2rem rgba(246,95,84,.5)}.btn-danger.disabled,.btn-danger:disabled{color:#fff;background-color:#f44336;border-color:#f44336}.btn-danger:not(:disabled):not(.disabled).active,.btn-danger:not(:disabled):not(.disabled):active,.show>.btn-danger.dropdown-toggle{color:#fff;background-color:#ea1c0d;border-color:#de1b0c}.btn-danger:not(:disabled):not(.disabled).active:focus,.btn-danger:not(:disabled):not(.disabled):active:focus,.show>.btn-danger.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(246,95,84,.5)}.btn-light{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-light:hover{color:#212529;background-color:#e2e6ea;border-color:#dae0e5}.btn-light.focus,.btn-light:focus{color:#212529;background-color:#e2e6ea;border-color:#dae0e5;box-shadow:0 0 0 .2rem rgba(216,217,219,.5)}.btn-light.disabled,.btn-light:disabled{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-light:not(:disabled):not(.disabled).active,.btn-light:not(:disabled):not(.disabled):active,.show>.btn-light.dropdown-toggle{color:#212529;background-color:#dae0e5;border-color:#d3d9df}.btn-light:not(:disabled):not(.disabled).active:focus,.btn-light:not(:disabled):not(.disabled):active:focus,.show>.btn-light.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(216,217,219,.5)}.btn-dark{color:#fff;background-color:#343a40;border-color:#343a40}.btn-dark:hover{color:#fff;background-color:#23272b;border-color:#1d2124}.btn-dark.focus,.btn-dark:focus{color:#fff;background-color:#23272b;border-color:#1d2124;box-shadow:0 0 0 .2rem rgba(82,88,93,.5)}.btn-dark.disabled,.btn-dark:disabled{color:#fff;background-color:#343a40;border-color:#343a40}.btn-dark:not(:disabled):not(.disabled).active,.btn-dark:not(:disabled):not(.disabled):active,.show>.btn-dark.dropdown-toggle{color:#fff;background-color:#1d2124;border-color:#171a1d}.btn-dark:not(:disabled):not(.disabled).active:focus,.btn-dark:not(:disabled):not(.disabled):active:focus,.show>.btn-dark.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(82,88,93,.5)}.btn-outline-primary{color:#c82c37;border-color:#c82c37}.btn-outline-primary:hover{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-outline-primary.focus,.btn-outline-primary:focus{box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.btn-outline-primary.disabled,.btn-outline-primary:disabled{color:#c82c37;background-color:transparent}.btn-outline-primary:not(:disabled):not(.disabled).active,.btn-outline-primary:not(:disabled):not(.disabled):active,.show>.btn-outline-primary.dropdown-toggle{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-outline-primary:not(:disabled):not(.disabled).active:focus,.btn-outline-primary:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-primary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.btn-outline-secondary{color:#919191;border-color:#919191}.btn-outline-secondary:hover{color:#fff;background-color:#919191;border-color:#919191}.btn-outline-secondary.focus,.btn-outline-secondary:focus{box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.btn-outline-secondary.disabled,.btn-outline-secondary:disabled{color:#919191;background-color:transparent}.btn-outline-secondary:not(:disabled):not(.disabled).active,.btn-outline-secondary:not(:disabled):not(.disabled):active,.show>.btn-outline-secondary.dropdown-toggle{color:#fff;background-color:#919191;border-color:#919191}.btn-outline-secondary:not(:disabled):not(.disabled).active:focus,.btn-outline-secondary:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-secondary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.btn-outline-success{color:#4caf50;border-color:#4caf50}.btn-outline-success:hover{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-outline-success.focus,.btn-outline-success:focus{box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.btn-outline-success.disabled,.btn-outline-success:disabled{color:#4caf50;background-color:transparent}.btn-outline-success:not(:disabled):not(.disabled).active,.btn-outline-success:not(:disabled):not(.disabled):active,.show>.btn-outline-success.dropdown-toggle{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-outline-success:not(:disabled):not(.disabled).active:focus,.btn-outline-success:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-success.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.btn-outline-info{color:#00bcd4;border-color:#00bcd4}.btn-outline-info:hover{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-outline-info.focus,.btn-outline-info:focus{box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.btn-outline-info.disabled,.btn-outline-info:disabled{color:#00bcd4;background-color:transparent}.btn-outline-info:not(:disabled):not(.disabled).active,.btn-outline-info:not(:disabled):not(.disabled):active,.show>.btn-outline-info.dropdown-toggle{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-outline-info:not(:disabled):not(.disabled).active:focus,.btn-outline-info:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-info.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.btn-outline-warning{color:#ff9800;border-color:#ff9800}.btn-outline-warning:hover{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-outline-warning.focus,.btn-outline-warning:focus{box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.btn-outline-warning.disabled,.btn-outline-warning:disabled{color:#ff9800;background-color:transparent}.btn-outline-warning:not(:disabled):not(.disabled).active,.btn-outline-warning:not(:disabled):not(.disabled):active,.show>.btn-outline-warning.dropdown-toggle{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-outline-warning:not(:disabled):not(.disabled).active:focus,.btn-outline-warning:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-warning.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.btn-outline-danger{color:#f44336;border-color:#f44336}.btn-outline-danger:hover{color:#fff;background-color:#f44336;border-color:#f44336}.btn-outline-danger.focus,.btn-outline-danger:focus{box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.btn-outline-danger.disabled,.btn-outline-danger:disabled{color:#f44336;background-color:transparent}.btn-outline-danger:not(:disabled):not(.disabled).active,.btn-outline-danger:not(:disabled):not(.disabled):active,.show>.btn-outline-danger.dropdown-toggle{color:#fff;background-color:#f44336;border-color:#f44336}.btn-outline-danger:not(:disabled):not(.disabled).active:focus,.btn-outline-danger:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-danger.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.btn-outline-light{color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light:hover{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light.focus,.btn-outline-light:focus{box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.btn-outline-light.disabled,.btn-outline-light:disabled{color:#f8f9fa;background-color:transparent}.btn-outline-light:not(:disabled):not(.disabled).active,.btn-outline-light:not(:disabled):not(.disabled):active,.show>.btn-outline-light.dropdown-toggle{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light:not(:disabled):not(.disabled).active:focus,.btn-outline-light:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-light.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.btn-outline-dark{color:#343a40;border-color:#343a40}.btn-outline-dark:hover{color:#fff;background-color:#343a40;border-color:#343a40}.btn-outline-dark.focus,.btn-outline-dark:focus{box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.btn-outline-dark.disabled,.btn-outline-dark:disabled{color:#343a40;background-color:transparent}.btn-outline-dark:not(:disabled):not(.disabled).active,.btn-outline-dark:not(:disabled):not(.disabled):active,.show>.btn-outline-dark.dropdown-toggle{color:#fff;background-color:#343a40;border-color:#343a40}.btn-outline-dark:not(:disabled):not(.disabled).active:focus,.btn-outline-dark:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-dark.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.btn-link{font-weight:400;color:#344468;text-decoration:none}.btn-link:hover{color:#c82c37;text-decoration:underline}.btn-link.focus,.btn-link:focus{text-decoration:underline}.btn-link.disabled,.btn-link:disabled{color:#6c757d;pointer-events:none}.btn-group-lg>.btn,.btn-lg{padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}.btn-group-sm>.btn,.btn-sm{padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.btn-block{display:block;width:100%}.btn-block+.btn-block{margin-top:.5rem}input[type=button].btn-block,input[type=reset].btn-block,input[type=submit].btn-block{width:100%}.fade{transition:opacity .15s linear}@media (prefers-reduced-motion:reduce){.fade{transition:none}}.fade:not(.show){opacity:0}.collapse:not(.show){display:none}.collapsing{position:relative;height:0;overflow:hidden;transition:height .35s}.dropdown,.dropleft,.dropright,.dropup{position:relative}.dropdown-toggle{white-space:nowrap}.dropdown-toggle::after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}.dropdown-toggle:empty::after{margin-left:0}.dropdown-menu{position:absolute;top:100%;left:0;z-index:1000;display:none;float:left;min-width:10rem;padding:.5rem 0;margin:.125rem 0 0;font-size:1rem;color:#212529;text-align:left;list-style:none;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.15);border-radius:8px}.dropdown-menu-left{right:auto;left:0}.dropdown-menu-right{right:0;left:auto}@media (min-width:576px){.dropdown-menu-sm-left{right:auto;left:0}.dropdown-menu-sm-right{right:0;left:auto}}@media (min-width:768px){.dropdown-menu-md-left{right:auto;left:0}.dropdown-menu-md-right{right:0;left:auto}}@media (min-width:992px){.dropdown-menu-lg-left{right:auto;left:0}.dropdown-menu-lg-right{right:0;left:auto}}@media (min-width:1200px){.dropdown-menu-xl-left{right:auto;left:0}.dropdown-menu-xl-right{right:0;left:auto}}.dropup .dropdown-menu{top:auto;bottom:100%;margin-top:0;margin-bottom:.125rem}.dropup .dropdown-toggle::after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}.dropup .dropdown-toggle:empty::after{margin-left:0}.dropright .dropdown-menu{top:0;right:auto;left:100%;margin-top:0;margin-left:.125rem}.dropright .dropdown-toggle::after{display:inline-block;margin-left:.255em;content:\"\";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid;vertical-align:0}.dropright .dropdown-toggle:empty::after{margin-left:0}.dropleft .dropdown-menu{top:0;right:100%;left:auto;margin-top:0;margin-right:.125rem}.dropleft .dropdown-toggle::after{margin-left:.255em;vertical-align:.255em;content:\"\";display:none}.dropleft .dropdown-toggle::before{display:inline-block;margin-right:.255em;content:\"\";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent;vertical-align:0}.dropleft .dropdown-toggle:empty::after{margin-left:0}.dropdown-menu[x-placement^=bottom],.dropdown-menu[x-placement^=left],.dropdown-menu[x-placement^=right],.dropdown-menu[x-placement^=top]{right:auto;bottom:auto}.dropdown-divider{height:0;margin:.5px 0;overflow:hidden;border-top:1px solid #e9ecef}.dropdown-item{display:block;width:100%;padding:.25rem 1.5rem;clear:both;font-weight:400;color:#212529;text-align:inherit;white-space:nowrap;background-color:transparent;border:0}.dropdown-item:focus,.dropdown-item:hover{color:#16181b;text-decoration:none;background-color:#f8f9fa}.dropdown-item.active,.dropdown-item:active{color:#fff;text-decoration:none;background-color:#c82c37}.dropdown-item.disabled,.dropdown-item:disabled{color:#6c757d;pointer-events:none;background-color:transparent}.dropdown-menu.show{display:block}.dropdown-header{display:block;padding:.5rem 1.5rem;margin-bottom:0;font-size:.875rem;color:#6c757d;white-space:nowrap}.dropdown-item-text{display:block;padding:.25rem 1.5rem;color:#212529}.btn-group,.btn-group-vertical{position:relative;display:inline-flex;vertical-align:middle}.btn-group-vertical>.btn,.btn-group>.btn{position:relative;flex:1 1 auto}.btn-group-vertical>.btn.active,.btn-group-vertical>.btn:active,.btn-group-vertical>.btn:focus,.btn-group-vertical>.btn:hover,.btn-group>.btn.active,.btn-group>.btn:active,.btn-group>.btn:focus,.btn-group>.btn:hover{z-index:1}.btn-toolbar{display:flex;flex-wrap:wrap;justify-content:flex-start}.btn-toolbar .input-group{width:auto}.btn-group>.btn-group:not(:first-child),.btn-group>.btn:not(:first-child){margin-left:-1px}.btn-group>.btn-group:not(:last-child)>.btn,.btn-group>.btn:not(:last-child):not(.dropdown-toggle){border-top-right-radius:0;border-bottom-right-radius:0}.btn-group>.btn-group:not(:first-child)>.btn,.btn-group>.btn:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.dropdown-toggle-split{padding-right:.5625rem;padding-left:.5625rem}.dropdown-toggle-split::after,.dropright .dropdown-toggle-split::after,.dropup .dropdown-toggle-split::after{margin-left:0}.dropleft .dropdown-toggle-split::before{margin-right:0}.btn-group-sm>.btn+.dropdown-toggle-split,.btn-sm+.dropdown-toggle-split{padding-right:.375rem;padding-left:.375rem}.btn-group-lg>.btn+.dropdown-toggle-split,.btn-lg+.dropdown-toggle-split{padding-right:.75rem;padding-left:.75rem}.btn-group-vertical{flex-direction:column;align-items:flex-start;justify-content:center}.btn-group-vertical>.btn,.btn-group-vertical>.btn-group{width:100%}.btn-group-vertical>.btn-group:not(:first-child),.btn-group-vertical>.btn:not(:first-child){margin-top:-1px}.btn-group-vertical>.btn-group:not(:last-child)>.btn,.btn-group-vertical>.btn:not(:last-child):not(.dropdown-toggle){border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn-group:not(:first-child)>.btn,.btn-group-vertical>.btn:not(:first-child){border-top-left-radius:0;border-top-right-radius:0}.btn-group-toggle>.btn,.btn-group-toggle>.btn-group>.btn{margin-bottom:0}.btn-group-toggle>.btn input[type=checkbox],.btn-group-toggle>.btn input[type=radio],.btn-group-toggle>.btn-group>.btn input[type=checkbox],.btn-group-toggle>.btn-group>.btn input[type=radio]{position:absolute;clip:rect(0,0,0,0);pointer-events:none}.input-group{position:relative;display:flex;flex-wrap:wrap;align-items:stretch;width:100%}.input-group>.custom-file,.input-group>.custom-select,.input-group>.form-control,.input-group>.form-control-plaintext{position:relative;flex:1 1 auto;width:1%;min-width:0;margin-bottom:0}.input-group>.custom-file+.custom-file,.input-group>.custom-file+.custom-select,.input-group>.custom-file+.form-control,.input-group>.custom-select+.custom-file,.input-group>.custom-select+.custom-select,.input-group>.custom-select+.form-control,.input-group>.form-control+.custom-file,.input-group>.form-control+.custom-select,.input-group>.form-control+.form-control,.input-group>.form-control-plaintext+.custom-file,.input-group>.form-control-plaintext+.custom-select,.input-group>.form-control-plaintext+.form-control{margin-left:-1px}.input-group>.custom-file .custom-file-input:focus~.custom-file-label,.input-group>.custom-select:focus,.input-group>.form-control:focus{z-index:3}.input-group>.custom-file .custom-file-input:focus{z-index:4}.input-group>.custom-select:not(:last-child),.input-group>.form-control:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.custom-select:not(:first-child),.input-group>.form-control:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.input-group>.custom-file{display:flex;align-items:center}.input-group>.custom-file:not(:last-child) .custom-file-label,.input-group>.custom-file:not(:last-child) .custom-file-label::after{border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.custom-file:not(:first-child) .custom-file-label{border-top-left-radius:0;border-bottom-left-radius:0}.input-group-append,.input-group-prepend{display:flex}.input-group-append .btn,.input-group-prepend .btn{position:relative;z-index:2}.input-group-append .btn:focus,.input-group-prepend .btn:focus{z-index:3}.input-group-append .btn+.btn,.input-group-append .btn+.input-group-text,.input-group-append .input-group-text+.btn,.input-group-append .input-group-text+.input-group-text,.input-group-prepend .btn+.btn,.input-group-prepend .btn+.input-group-text,.input-group-prepend .input-group-text+.btn,.input-group-prepend .input-group-text+.input-group-text{margin-left:-1px}.input-group-prepend{margin-right:-1px}.input-group-append{margin-left:-1px}.input-group-text{display:flex;align-items:center;padding:.375rem .75rem;margin-bottom:0;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;text-align:center;white-space:nowrap;background-color:#e9ecef;border:1px solid #e6e7e9;border-radius:8px}.input-group-text input[type=checkbox],.input-group-text input[type=radio]{margin-top:0}.input-group-lg>.custom-select,.input-group-lg>.form-control:not(textarea){height:calc(1.5em + 1rem + 2px)}.input-group-lg>.custom-select,.input-group-lg>.form-control,.input-group-lg>.input-group-append>.btn,.input-group-lg>.input-group-append>.input-group-text,.input-group-lg>.input-group-prepend>.btn,.input-group-lg>.input-group-prepend>.input-group-text{padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}.input-group-sm>.custom-select,.input-group-sm>.form-control:not(textarea){height:calc(1.5em + .5rem + 2px)}.input-group-sm>.custom-select,.input-group-sm>.form-control,.input-group-sm>.input-group-append>.btn,.input-group-sm>.input-group-append>.input-group-text,.input-group-sm>.input-group-prepend>.btn,.input-group-sm>.input-group-prepend>.input-group-text{padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.input-group-lg>.custom-select,.input-group-sm>.custom-select{padding-right:1.75rem}.input-group>.input-group-append:last-child>.btn:not(:last-child):not(.dropdown-toggle),.input-group>.input-group-append:last-child>.input-group-text:not(:last-child),.input-group>.input-group-append:not(:last-child)>.btn,.input-group>.input-group-append:not(:last-child)>.input-group-text,.input-group>.input-group-prepend>.btn,.input-group>.input-group-prepend>.input-group-text{border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.input-group-append>.btn,.input-group>.input-group-append>.input-group-text,.input-group>.input-group-prepend:first-child>.btn:not(:first-child),.input-group>.input-group-prepend:first-child>.input-group-text:not(:first-child),.input-group>.input-group-prepend:not(:first-child)>.btn,.input-group>.input-group-prepend:not(:first-child)>.input-group-text{border-top-left-radius:0;border-bottom-left-radius:0}.custom-control{position:relative;display:block;min-height:1.5rem;padding-left:1.5rem}.custom-control-inline{display:inline-flex;margin-right:1rem}.custom-control-input{position:absolute;left:0;z-index:-1;width:1rem;height:1.25rem;opacity:0}.custom-control-input:checked~.custom-control-label::before{color:#fff;border-color:#c82c37;background-color:#c82c37}.custom-control-input:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-control-input:focus:not(:checked)~.custom-control-label::before{border-color:rgba(47,107,255,.1)}.custom-control-input:not(:disabled):active~.custom-control-label::before{color:#fff;background-color:#efb7bb;border-color:#efb7bb}.custom-control-input:disabled~.custom-control-label,.custom-control-input[disabled]~.custom-control-label{color:#6c757d}.custom-control-input:disabled~.custom-control-label::before,.custom-control-input[disabled]~.custom-control-label::before{background-color:#e9ecef}.custom-control-label{position:relative;margin-bottom:0;vertical-align:top}.custom-control-label::before{position:absolute;top:.25rem;left:-1.5rem;display:block;width:1rem;height:1rem;pointer-events:none;content:\"\";background-color:#fff;border:1px solid #adb5bd}.custom-control-label::after{position:absolute;top:.25rem;left:-1.5rem;display:block;width:1rem;height:1rem;content:\"\";background:50%/50% 50% no-repeat}.custom-checkbox .custom-control-label::before{border-radius:8px}.custom-checkbox .custom-control-input:checked~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%23fff' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26l2.974 2.99L8 2.193z'/%3e%3c/svg%3e\")}.custom-checkbox .custom-control-input:indeterminate~.custom-control-label::before{border-color:#c82c37;background-color:#c82c37}.custom-checkbox .custom-control-input:indeterminate~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='4' viewBox='0 0 4 4'%3e%3cpath stroke='%23fff' d='M0 2h4'/%3e%3c/svg%3e\")}.custom-checkbox .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-checkbox .custom-control-input:disabled:indeterminate~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-radio .custom-control-label::before{border-radius:50%}.custom-radio .custom-control-input:checked~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='%23fff'/%3e%3c/svg%3e\")}.custom-radio .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-switch{padding-left:2.25rem}.custom-switch .custom-control-label::before{left:-2.25rem;width:1.75rem;pointer-events:all;border-radius:.5rem}.custom-switch .custom-control-label::after{top:calc(.25rem + 2px);left:calc(-2.25rem + 2px);width:calc(1rem - 4px);height:calc(1rem - 4px);background-color:#adb5bd;border-radius:.5rem;transition:transform .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.collapsing,.custom-switch .custom-control-label::after{transition:none}}.custom-switch .custom-control-input:checked~.custom-control-label::after{background-color:#fff;transform:translateX(.75rem)}.custom-switch .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-select{display:inline-block;width:100%;height:56px;padding:.375rem 1.75rem .375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;vertical-align:middle;background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat #fff;border:1px solid #e6e7e9;border-radius:8px;-webkit-appearance:none;-moz-appearance:none;appearance:none}.custom-select:focus{border-color:rgba(47,107,255,.1);outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-select:focus::-ms-value{color:#344468;background-color:#fff}.custom-select[multiple],.custom-select[size]:not([size=\"1\"]){height:auto;padding-right:.75rem;background-image:none}.custom-select:disabled{color:#6c757d;background-color:#e9ecef}.custom-select::-ms-expand{display:none}.custom-select:-moz-focusring{color:transparent;text-shadow:0 0 0 #344468}.custom-select-sm{height:calc(1.5em + .5rem + 2px);padding-top:.25rem;padding-bottom:.25rem;padding-left:.5rem;font-size:.875rem}.custom-select-lg{height:calc(1.5em + 1rem + 2px);padding-top:.5rem;padding-bottom:.5rem;padding-left:1rem;font-size:1.25rem}.custom-file{position:relative;display:inline-block;width:100%;height:56px;margin-bottom:0}.custom-file-input{position:relative;z-index:2;width:100%;height:56px;margin:0;opacity:0}.custom-file-input:focus~.custom-file-label{border-color:rgba(47,107,255,.1);box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-file-input:disabled~.custom-file-label,.custom-file-input[disabled]~.custom-file-label{background-color:#e9ecef}.custom-file-input:lang(en)~.custom-file-label::after{content:\"Browse\"}.custom-file-input~.custom-file-label[data-browse]::after{content:attr(data-browse)}.custom-file-label{position:absolute;top:0;right:0;left:0;z-index:1;height:56px;padding:.375rem .75rem;font-weight:400;line-height:1.5;color:#344468;background-color:#fff;border:1px solid #e6e7e9;border-radius:8px}.custom-file-label::after{position:absolute;top:0;right:0;bottom:0;z-index:3;display:block;height:calc(1.5em + .75rem);padding:.375rem .75rem;line-height:1.5;color:#344468;content:\"Browse\";background-color:#e9ecef;border-left:inherit;border-radius:0 8px 8px 0}.custom-range{width:100%;height:1.4rem;padding:0;background-color:transparent;-webkit-appearance:none;-moz-appearance:none;appearance:none}.custom-range:focus{outline:0}.custom-range:focus::-webkit-slider-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range:focus::-moz-range-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range:focus::-ms-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range::-moz-focus-outer{border:0}.custom-range::-webkit-slider-thumb{width:1rem;height:1rem;margin-top:-.25rem;background-color:#c82c37;border:0;border-radius:1rem;-webkit-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-webkit-appearance:none;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-webkit-slider-thumb{-webkit-transition:none;transition:none}}.custom-range::-webkit-slider-thumb:active{background-color:#efb7bb}.custom-range::-webkit-slider-runnable-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:#dee2e6;border-color:transparent;border-radius:1rem}.custom-range::-moz-range-thumb{width:1rem;height:1rem;background-color:#c82c37;border:0;border-radius:1rem;-moz-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-moz-appearance:none;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-moz-range-thumb{-moz-transition:none;transition:none}}.custom-range::-moz-range-thumb:active{background-color:#efb7bb}.custom-range::-moz-range-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:#dee2e6;border-color:transparent;border-radius:1rem}.custom-range::-ms-thumb{width:1rem;height:1rem;margin-top:0;margin-right:.2rem;margin-left:.2rem;background-color:#c82c37;border:0;border-radius:1rem;-ms-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-ms-thumb{-ms-transition:none;transition:none}}.custom-range::-ms-thumb:active{background-color:#efb7bb}.custom-range::-ms-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:transparent;border-color:transparent;border-width:.5rem}.custom-range::-ms-fill-lower{background-color:#dee2e6;border-radius:1rem}.custom-range::-ms-fill-upper{margin-right:15px;background-color:#dee2e6;border-radius:1rem}.custom-range:disabled::-webkit-slider-thumb{background-color:#adb5bd}.custom-range:disabled::-webkit-slider-runnable-track{cursor:default}.custom-range:disabled::-moz-range-thumb{background-color:#adb5bd}.custom-range:disabled::-moz-range-track{cursor:default}.custom-range:disabled::-ms-thumb{background-color:#adb5bd}.custom-control-label::before,.custom-file-label,.custom-select{transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.custom-control-label::before,.custom-file-label,.custom-select{transition:none}}.nav{display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}.nav-link{display:block;padding:.5rem 1rem}.nav-link:focus,.nav-link:hover{text-decoration:none}.nav-link.disabled{color:#6c757d;pointer-events:none;cursor:default}.nav-tabs{border-bottom:1px solid #dee2e6}.nav-tabs .nav-item{margin-bottom:-1px}.nav-tabs .nav-link{border:1px solid transparent;border-top-left-radius:8px;border-top-right-radius:8px}.nav-tabs .nav-link:focus,.nav-tabs .nav-link:hover{border-color:#e9ecef #e9ecef #dee2e6}.nav-tabs .nav-link.disabled{color:#6c757d;background-color:transparent;border-color:transparent}.nav-tabs .nav-item.show .nav-link,.nav-tabs .nav-link.active{color:#495057;background-color:#fff;border-color:#dee2e6 #dee2e6 #fff}.nav-tabs .dropdown-menu{margin-top:-1px;border-top-left-radius:0;border-top-right-radius:0}.nav-pills .nav-link{border-radius:8px}.nav-pills .nav-link.active,.nav-pills .show>.nav-link{color:#fff;background-color:#c82c37}.nav-fill .nav-item{flex:1 1 auto;text-align:center}.nav-justified .nav-item{flex-basis:0;flex-grow:1;text-align:center}.tab-content>.tab-pane{display:none}.tab-content>.active{display:block}.navbar{position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:.5px 1px}.navbar .container,.navbar .container-fluid,.navbar .container-lg,.navbar .container-md,.navbar .container-sm,.navbar .container-xl{display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between}.navbar-brand{display:inline-block;padding-top:.3125rem;padding-bottom:.3125rem;margin-right:1px;font-size:1.25rem;line-height:inherit;white-space:nowrap}.navbar-brand:focus,.navbar-brand:hover{text-decoration:none}.navbar-nav{display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}.navbar-nav .nav-link{padding-right:0;padding-left:0}.navbar-nav .dropdown-menu{position:static;float:none}.navbar-text{display:inline-block;padding-top:.5rem;padding-bottom:.5rem}.navbar-collapse{flex-basis:100%;flex-grow:1;align-items:center}.navbar-toggler{padding:.25rem .75rem;font-size:1.25rem;line-height:1;background-color:transparent;border:1px solid transparent;border-radius:8px}.navbar-toggler:focus,.navbar-toggler:hover{text-decoration:none}.navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;content:\"\";background:center center/100% 100% no-repeat}@media (max-width:575.98px){.navbar-expand-sm>.container,.navbar-expand-sm>.container-fluid,.navbar-expand-sm>.container-lg,.navbar-expand-sm>.container-md,.navbar-expand-sm>.container-sm,.navbar-expand-sm>.container-xl{padding-right:0;padding-left:0}}@media (min-width:576px){.navbar-expand-sm{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-sm .navbar-nav{flex-direction:row}.navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-sm .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-sm>.container,.navbar-expand-sm>.container-fluid,.navbar-expand-sm>.container-lg,.navbar-expand-sm>.container-md,.navbar-expand-sm>.container-sm,.navbar-expand-sm>.container-xl{flex-wrap:nowrap}.navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-sm .navbar-toggler{display:none}}@media (max-width:767.98px){.navbar-expand-md>.container,.navbar-expand-md>.container-fluid,.navbar-expand-md>.container-lg,.navbar-expand-md>.container-md,.navbar-expand-md>.container-sm,.navbar-expand-md>.container-xl{padding-right:0;padding-left:0}}@media (min-width:768px){.navbar-expand-md{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-md .navbar-nav{flex-direction:row}.navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-md .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-md>.container,.navbar-expand-md>.container-fluid,.navbar-expand-md>.container-lg,.navbar-expand-md>.container-md,.navbar-expand-md>.container-sm,.navbar-expand-md>.container-xl{flex-wrap:nowrap}.navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-md .navbar-toggler{display:none}}@media (max-width:991.98px){.navbar-expand-lg>.container,.navbar-expand-lg>.container-fluid,.navbar-expand-lg>.container-lg,.navbar-expand-lg>.container-md,.navbar-expand-lg>.container-sm,.navbar-expand-lg>.container-xl{padding-right:0;padding-left:0}}@media (min-width:992px){.navbar-expand-lg{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-lg .navbar-nav{flex-direction:row}.navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-lg .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-lg>.container,.navbar-expand-lg>.container-fluid,.navbar-expand-lg>.container-lg,.navbar-expand-lg>.container-md,.navbar-expand-lg>.container-sm,.navbar-expand-lg>.container-xl{flex-wrap:nowrap}.navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-lg .navbar-toggler{display:none}}@media (max-width:1199.98px){.navbar-expand-xl>.container,.navbar-expand-xl>.container-fluid,.navbar-expand-xl>.container-lg,.navbar-expand-xl>.container-md,.navbar-expand-xl>.container-sm,.navbar-expand-xl>.container-xl{padding-right:0;padding-left:0}}@media (min-width:1200px){.navbar-expand-xl{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-xl .navbar-nav{flex-direction:row}.navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-xl .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-xl>.container,.navbar-expand-xl>.container-fluid,.navbar-expand-xl>.container-lg,.navbar-expand-xl>.container-md,.navbar-expand-xl>.container-sm,.navbar-expand-xl>.container-xl{flex-wrap:nowrap}.navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-xl .navbar-toggler{display:none}}.navbar-expand{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand .navbar-nav{flex-direction:row}.navbar-expand .navbar-nav .dropdown-menu{position:absolute}.navbar-expand .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand>.container,.navbar-expand>.container-fluid,.navbar-expand>.container-lg,.navbar-expand>.container-md,.navbar-expand>.container-sm,.navbar-expand>.container-xl{padding-right:0;padding-left:0;flex-wrap:nowrap}.navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand .navbar-toggler{display:none}.navbar-light .navbar-brand,.navbar-light .navbar-brand:focus,.navbar-light .navbar-brand:hover{color:rgba(0,0,0,.9)}.navbar-light .navbar-nav .nav-link{color:rgba(0,0,0,.5)}.navbar-light .navbar-nav .nav-link:focus,.navbar-light .navbar-nav .nav-link:hover{color:rgba(0,0,0,.7)}.navbar-light .navbar-nav .nav-link.disabled{color:rgba(0,0,0,.3)}.navbar-light .navbar-nav .active>.nav-link,.navbar-light .navbar-nav .nav-link.active,.navbar-light .navbar-nav .nav-link.show,.navbar-light .navbar-nav .show>.nav-link{color:rgba(0,0,0,.9)}.navbar-light .navbar-toggler{color:rgba(0,0,0,.5);border-color:rgba(0,0,0,.1)}.navbar-light .navbar-toggler-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='30' height='30' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%280, 0, 0, 0.5%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.navbar-light .navbar-text{color:rgba(0,0,0,.5)}.navbar-light .navbar-text a,.navbar-light .navbar-text a:focus,.navbar-light .navbar-text a:hover{color:rgba(0,0,0,.9)}.navbar-dark .navbar-brand,.navbar-dark .navbar-brand:focus,.navbar-dark .navbar-brand:hover{color:#fff}.navbar-dark .navbar-nav .nav-link{color:rgba(255,255,255,.5)}.navbar-dark .navbar-nav .nav-link:focus,.navbar-dark .navbar-nav .nav-link:hover{color:rgba(255,255,255,.75)}.navbar-dark .navbar-nav .nav-link.disabled{color:rgba(255,255,255,.25)}.navbar-dark .navbar-nav .active>.nav-link,.navbar-dark .navbar-nav .nav-link.active,.navbar-dark .navbar-nav .nav-link.show,.navbar-dark .navbar-nav .show>.nav-link{color:#fff}.navbar-dark .navbar-toggler{color:rgba(255,255,255,.5);border-color:rgba(255,255,255,.1)}.navbar-dark .navbar-toggler-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='30' height='30' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.5%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.navbar-dark .navbar-text{color:rgba(255,255,255,.5)}.navbar-dark .navbar-text a,.navbar-dark .navbar-text a:focus,.navbar-dark .navbar-text a:hover{color:#fff}.card{position:relative;display:flex;flex-direction:column;min-width:0;word-wrap:break-word;background-color:#fff;background-clip:border-box;border:1px solid rgba(0,0,0,.125);border-radius:8px}.card>hr{margin-right:0;margin-left:0}.card>.list-group{border-top:inherit;border-bottom:inherit}.card>.list-group:first-child{border-top-width:0;border-top-left-radius:7px;border-top-right-radius:7px}.card>.list-group:last-child{border-bottom-width:0;border-bottom-right-radius:7px;border-bottom-left-radius:7px}.card-body{flex:1 1 auto;min-height:1px;padding:1.25rem}.card-title{margin-bottom:.75rem}.card-subtitle{margin-top:-.375rem;margin-bottom:0}.card-text:last-child{margin-bottom:0}.card-link:hover{text-decoration:none}.card-link+.card-link{margin-left:1.25rem}.card-header{padding:.75rem 1.25rem;margin-bottom:0;background-color:rgba(0,0,0,.03);border-bottom:1px solid rgba(0,0,0,.125)}.card-header:first-child{border-radius:7px 7px 0 0}.card-header+.list-group .list-group-item:first-child{border-top:0}.card-footer{padding:.75rem 1.25rem;background-color:rgba(0,0,0,.03);border-top:1px solid rgba(0,0,0,.125)}.card-footer:last-child{border-radius:0 0 7px 7px}.card-header-tabs{margin-right:-.625rem;margin-bottom:-.75rem;margin-left:-.625rem;border-bottom:0}.card-header-pills{margin-right:-.625rem;margin-left:-.625rem}.card-img-overlay{position:absolute;top:0;right:0;bottom:0;left:0;padding:1.25rem}.card-img,.card-img-bottom,.card-img-top{flex-shrink:0;width:100%}.card-img,.card-img-top{border-top-left-radius:7px;border-top-right-radius:7px}.card-img,.card-img-bottom{border-bottom-right-radius:7px;border-bottom-left-radius:7px}.card-deck .card{margin-bottom:16px}@media (min-width:576px){.card-deck{display:flex;flex-flow:row wrap;margin-right:-16px;margin-left:-16px}.card-deck .card{flex:1 0 0%;margin-right:16px;margin-bottom:0;margin-left:16px}}.card-group>.card{margin-bottom:16px}@media (min-width:576px){.card-group{display:flex;flex-flow:row wrap}.card-group>.card{flex:1 0 0%;margin-bottom:0}.card-group>.card+.card{margin-left:0;border-left:0}.card-group>.card:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.card-group>.card:not(:last-child) .card-header,.card-group>.card:not(:last-child) .card-img-top{border-top-right-radius:0}.card-group>.card:not(:last-child) .card-footer,.card-group>.card:not(:last-child) .card-img-bottom{border-bottom-right-radius:0}.card-group>.card:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.card-group>.card:not(:first-child) .card-header,.card-group>.card:not(:first-child) .card-img-top{border-top-left-radius:0}.card-group>.card:not(:first-child) .card-footer,.card-group>.card:not(:first-child) .card-img-bottom{border-bottom-left-radius:0}.card-columns{-moz-column-count:3;column-count:3;-moz-column-gap:1.25rem;column-gap:1.25rem;orphans:1;widows:1}.card-columns .card{display:inline-block;width:100%}}.card-columns .card{margin-bottom:.75rem}.accordion>.card{overflow:hidden}.accordion>.card:not(:last-of-type){border-bottom:0;border-bottom-right-radius:0;border-bottom-left-radius:0}.accordion>.card:not(:first-of-type){border-top-left-radius:0;border-top-right-radius:0}.accordion>.card>.card-header{border-radius:0;margin-bottom:-1px}.breadcrumb{display:flex;flex-wrap:wrap;padding:.75rem 1rem;margin-bottom:1rem;list-style:none;background-color:#e9ecef;border-radius:8px}.breadcrumb-item{display:flex}.breadcrumb-item+.breadcrumb-item{padding-left:.5rem}.breadcrumb-item+.breadcrumb-item::before{display:inline-block;padding-right:.5rem;color:#6c757d;content:\"/\"}.breadcrumb-item+.breadcrumb-item:hover::before{text-decoration:none}.breadcrumb-item.active{color:#6c757d}.pagination{display:flex;padding-left:0;list-style:none;border-radius:8px}.page-link{position:relative;display:block;padding:.5rem .75rem;margin-left:-1px;line-height:1.25;color:#344468;background-color:#fff;border:1px solid #dee2e6}.page-link:hover{z-index:2;color:#c82c37;text-decoration:none;background-color:#e9ecef;border-color:#dee2e6}.page-link:focus{z-index:3;outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.page-item:first-child .page-link{margin-left:0;border-top-left-radius:8px;border-bottom-left-radius:8px}.page-item:last-child .page-link{border-top-right-radius:8px;border-bottom-right-radius:8px}.page-item.active .page-link{z-index:3;color:#fff;background-color:#c82c37;border-color:#c82c37}.page-item.disabled .page-link{color:#6c757d;pointer-events:none;cursor:auto;background-color:#fff;border-color:#dee2e6}.pagination-lg .page-link{padding:.75rem 1.5rem;font-size:1.25rem;line-height:1.5}.pagination-lg .page-item:first-child .page-link{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}.pagination-lg .page-item:last-child .page-link{border-top-right-radius:.3rem;border-bottom-right-radius:.3rem}.pagination-sm .page-link{padding:.25rem .5rem;font-size:.875rem;line-height:1.5}.pagination-sm .page-item:first-child .page-link{border-top-left-radius:.2rem;border-bottom-left-radius:.2rem}.pagination-sm .page-item:last-child .page-link{border-top-right-radius:.2rem;border-bottom-right-radius:.2rem}.badge{display:inline-block;padding:.25em .4em;font-size:75%;font-weight:700;line-height:1;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:8px;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.badge{transition:none}}a.badge:focus,a.badge:hover{text-decoration:none}.badge:empty{display:none}.btn .badge{position:relative;top:-1px}.badge-pill{padding-right:.6em;padding-left:.6em;border-radius:10rem}.badge-primary{color:#fff;background-color:#c82c37}a.badge-primary:focus,a.badge-primary:hover{color:#fff;background-color:#9e232c}a.badge-primary.focus,a.badge-primary:focus{outline:0;box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.badge-secondary{color:#fff;background-color:#919191}a.badge-secondary:focus,a.badge-secondary:hover{color:#fff;background-color:#787878}a.badge-secondary.focus,a.badge-secondary:focus{outline:0;box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.badge-success{color:#fff;background-color:#4caf50}a.badge-success:focus,a.badge-success:hover{color:#fff;background-color:#3d8b40}a.badge-success.focus,a.badge-success:focus{outline:0;box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.badge-info{color:#fff;background-color:#00bcd4}a.badge-info:focus,a.badge-info:hover{color:#fff;background-color:#008fa1}a.badge-info.focus,a.badge-info:focus{outline:0;box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.badge-warning{color:#212529;background-color:#ff9800}a.badge-warning:focus,a.badge-warning:hover{color:#212529;background-color:#cc7a00}a.badge-warning.focus,a.badge-warning:focus{outline:0;box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.badge-danger{color:#fff;background-color:#f44336}a.badge-danger:focus,a.badge-danger:hover{color:#fff;background-color:#ea1c0d}a.badge-danger.focus,a.badge-danger:focus{outline:0;box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.badge-light{color:#212529;background-color:#f8f9fa}a.badge-light:focus,a.badge-light:hover{color:#212529;background-color:#dae0e5}a.badge-light.focus,a.badge-light:focus{outline:0;box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.badge-dark{color:#fff;background-color:#343a40}a.badge-dark:focus,a.badge-dark:hover{color:#fff;background-color:#1d2124}a.badge-dark.focus,a.badge-dark:focus{outline:0;box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.jumbotron{padding:2rem 1rem;margin-bottom:2rem;background-color:#e9ecef;border-radius:.3rem}@media (min-width:576px){.jumbotron{padding:4rem 2rem}}.jumbotron-fluid{padding-right:0;padding-left:0;border-radius:0}.alert{position:relative;padding:.75rem 1.25rem;margin-bottom:1rem;border:1px solid transparent;border-radius:8px}.alert-heading{color:inherit}.alert-link{font-weight:700}.alert-dismissible{padding-right:4rem}.alert-dismissible .close{position:absolute;top:0;right:0;padding:.75rem 1.25rem;color:inherit}.alert-primary{color:#68171d;background-color:#f4d5d7;border-color:#f0c4c7}.alert-primary hr{border-top-color:#ebb0b4}.alert-primary .alert-link{color:#3e0e11}.alert-secondary{color:#4b4b4b;background-color:#e9e9e9;border-color:#e0e0e0}.alert-secondary hr{border-top-color:#d3d3d3}.alert-secondary .alert-link{color:#323232}.alert-success{color:#285b2a;background-color:#dbefdc;border-color:#cde9ce}.alert-success hr{border-top-color:#bbe1bd}.alert-success .alert-link{color:#18381a}.alert-info{color:#00626e;background-color:#ccf2f6;border-color:#b8ecf3}.alert-info hr{border-top-color:#a2e6ef}.alert-info .alert-link{color:#00353b}.alert-warning{color:#854f00;background-color:#ffeacc;border-color:#ffe2b8}.alert-warning hr{border-top-color:#ffd89f}.alert-warning .alert-link{color:#523100}.alert-danger{color:#7f231c;background-color:#fdd9d7;border-color:#fccac7}.alert-danger hr{border-top-color:#fbb3af}.alert-danger .alert-link{color:#551713}.alert-light{color:#818182;background-color:#fefefe;border-color:#fdfdfe}.alert-light hr{border-top-color:#ececf6}.alert-light .alert-link{color:#686868}.alert-dark{color:#1b1e21;background-color:#d6d8d9;border-color:#c6c8ca}.alert-dark hr{border-top-color:#b9bbbe}.alert-dark .alert-link{color:#040505}@-webkit-keyframes progress-bar-stripes{from{background-position:1rem 0}to{background-position:0 0}}@keyframes progress-bar-stripes{from{background-position:1rem 0}to{background-position:0 0}}.progress{display:flex;height:1rem;overflow:hidden;line-height:0;font-size:.75rem;background-color:#e9ecef;border-radius:8px}.progress-bar{display:flex;flex-direction:column;justify-content:center;overflow:hidden;color:#fff;text-align:center;white-space:nowrap;background-color:#c82c37;transition:width .6s}.progress-bar-striped{background-image:linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);background-size:1rem 1rem}.progress-bar-animated{-webkit-animation:1s linear infinite progress-bar-stripes;animation:1s linear infinite progress-bar-stripes}.media{display:flex;align-items:flex-start}.media-body{flex:1}.list-group{display:flex;flex-direction:column;padding-left:0;margin-bottom:0;border-radius:8px}.list-group-item-action{width:100%;color:#495057;text-align:inherit}.list-group-item-action:focus,.list-group-item-action:hover{z-index:1;color:#495057;text-decoration:none;background-color:#f8f9fa}.list-group-item-action:active{color:#212529;background-color:#e9ecef}.list-group-item{position:relative;display:block;padding:.75rem 1.25rem;background-color:#fff;border:1px solid rgba(0,0,0,.125)}.list-group-item:first-child{border-top-left-radius:inherit;border-top-right-radius:inherit}.list-group-item:last-child{border-bottom-right-radius:inherit;border-bottom-left-radius:inherit}.list-group-item.disabled,.list-group-item:disabled{color:#6c757d;pointer-events:none;background-color:#fff}.list-group-item.active{z-index:2;color:#fff;background-color:#c82c37;border-color:#c82c37}.list-group-item+.list-group-item{border-top-width:0}.list-group-item+.list-group-item.active{margin-top:-1px;border-top-width:1px}.list-group-horizontal{flex-direction:row}.list-group-horizontal>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal>.list-group-item.active{margin-top:0}.list-group-horizontal>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}@media (min-width:576px){.list-group-horizontal-sm{flex-direction:row}.list-group-horizontal-sm>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-sm>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-sm>.list-group-item.active{margin-top:0}.list-group-horizontal-sm>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-sm>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:768px){.list-group-horizontal-md{flex-direction:row}.list-group-horizontal-md>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-md>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-md>.list-group-item.active{margin-top:0}.list-group-horizontal-md>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-md>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:992px){.list-group-horizontal-lg{flex-direction:row}.list-group-horizontal-lg>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-lg>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-lg>.list-group-item.active{margin-top:0}.list-group-horizontal-lg>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-lg>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:1200px){.list-group-horizontal-xl{flex-direction:row}.list-group-horizontal-xl>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-xl>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-xl>.list-group-item.active{margin-top:0}.list-group-horizontal-xl>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-xl>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}.list-group-flush{border-radius:0}.list-group-flush>.list-group-item{border-width:0 0 1px}.list-group-flush>.list-group-item:last-child{border-bottom-width:0}.list-group-item-primary{color:#68171d;background-color:#f0c4c7}.list-group-item-primary.list-group-item-action:focus,.list-group-item-primary.list-group-item-action:hover{color:#68171d;background-color:#ebb0b4}.list-group-item-primary.list-group-item-action.active{color:#fff;background-color:#68171d;border-color:#68171d}.list-group-item-secondary{color:#4b4b4b;background-color:#e0e0e0}.list-group-item-secondary.list-group-item-action:focus,.list-group-item-secondary.list-group-item-action:hover{color:#4b4b4b;background-color:#d3d3d3}.list-group-item-secondary.list-group-item-action.active{color:#fff;background-color:#4b4b4b;border-color:#4b4b4b}.list-group-item-success{color:#285b2a;background-color:#cde9ce}.list-group-item-success.list-group-item-action:focus,.list-group-item-success.list-group-item-action:hover{color:#285b2a;background-color:#bbe1bd}.list-group-item-success.list-group-item-action.active{color:#fff;background-color:#285b2a;border-color:#285b2a}.list-group-item-info{color:#00626e;background-color:#b8ecf3}.list-group-item-info.list-group-item-action:focus,.list-group-item-info.list-group-item-action:hover{color:#00626e;background-color:#a2e6ef}.list-group-item-info.list-group-item-action.active{color:#fff;background-color:#00626e;border-color:#00626e}.list-group-item-warning{color:#854f00;background-color:#ffe2b8}.list-group-item-warning.list-group-item-action:focus,.list-group-item-warning.list-group-item-action:hover{color:#854f00;background-color:#ffd89f}.list-group-item-warning.list-group-item-action.active{color:#fff;background-color:#854f00;border-color:#854f00}.list-group-item-danger{color:#7f231c;background-color:#fccac7}.list-group-item-danger.list-group-item-action:focus,.list-group-item-danger.list-group-item-action:hover{color:#7f231c;background-color:#fbb3af}.list-group-item-danger.list-group-item-action.active{color:#fff;background-color:#7f231c;border-color:#7f231c}.list-group-item-light{color:#818182;background-color:#fdfdfe}.list-group-item-light.list-group-item-action:focus,.list-group-item-light.list-group-item-action:hover{color:#818182;background-color:#ececf6}.list-group-item-light.list-group-item-action.active{color:#fff;background-color:#818182;border-color:#818182}.list-group-item-dark{color:#1b1e21;background-color:#c6c8ca}.list-group-item-dark.list-group-item-action:focus,.list-group-item-dark.list-group-item-action:hover{color:#1b1e21;background-color:#b9bbbe}.list-group-item-dark.list-group-item-action.active{color:#fff;background-color:#1b1e21;border-color:#1b1e21}.close{float:right;font-size:1.5rem;font-weight:700;line-height:1;color:#000;text-shadow:0 1px 0 #fff;opacity:.5}.close:hover{color:#000;text-decoration:none}.close:not(:disabled):not(.disabled):focus,.close:not(:disabled):not(.disabled):hover{opacity:.75}button.close{padding:0;background-color:transparent;border:0}a.close.disabled{pointer-events:none}.toast{max-width:350px;overflow:hidden;font-size:.875rem;background-color:rgba(255,255,255,.85);background-clip:padding-box;border:1px solid rgba(0,0,0,.1);box-shadow:0 .25rem .75rem rgba(0,0,0,.1);-webkit-backdrop-filter:blur(10px);backdrop-filter:blur(10px);opacity:0;border-radius:.25rem}.toast:not(:last-child){margin-bottom:.75rem}.toast.showing{opacity:1}.toast.show{display:block;opacity:1}.toast.hide{display:none}.toast-header{display:flex;align-items:center;padding:.25rem .75rem;color:#6c757d;background-color:rgba(255,255,255,.85);background-clip:padding-box;border-bottom:1px solid rgba(0,0,0,.05)}.toast-body{padding:.75rem}.modal-open{overflow:hidden}.modal-open .modal{overflow-x:hidden;overflow-y:auto}.modal{position:fixed;top:0;left:0;z-index:1050;display:none;width:100%;height:100%;overflow:hidden;outline:0}.modal-dialog{position:relative;width:auto;margin:.5rem;pointer-events:none}.modal.fade .modal-dialog{transition:transform .3s ease-out;transform:translate(0,-50px)}@media (prefers-reduced-motion:reduce){.progress-bar{transition:none}.progress-bar-animated{-webkit-animation:none;animation:none}.modal.fade .modal-dialog{transition:none}}.modal.show .modal-dialog{transform:none}.modal.modal-static .modal-dialog{transform:scale(1.02)}.modal-dialog-scrollable{display:flex;max-height:calc(100% - 1rem)}.modal-dialog-scrollable .modal-content{max-height:calc(100vh - 1rem);overflow:hidden}.modal-dialog-scrollable .modal-footer,.modal-dialog-scrollable .modal-header{flex-shrink:0}.modal-dialog-scrollable .modal-body{overflow-y:auto}.modal-dialog-centered{display:flex;align-items:center;min-height:calc(100% - 1rem)}.modal-dialog-centered::before{display:block;height:calc(100vh - 1rem);height:-webkit-min-content;height:-moz-min-content;height:min-content;content:\"\"}.modal-dialog-centered.modal-dialog-scrollable{flex-direction:column;justify-content:center;height:100%}.modal-dialog-centered.modal-dialog-scrollable .modal-content{max-height:none}.modal-dialog-centered.modal-dialog-scrollable::before{content:none}.modal-content{position:relative;display:flex;flex-direction:column;width:100%;pointer-events:auto;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.2);border-radius:.3rem;outline:0}.modal-backdrop{position:fixed;top:0;left:0;z-index:1040;width:100vw;height:100vh;background-color:#000}.modal-backdrop.fade{opacity:0}.modal-backdrop.show{opacity:.5}.modal-header{display:flex;align-items:flex-start;justify-content:space-between;padding:1rem;border-bottom:1px solid #f2f3f4;border-top-left-radius:calc(.3rem - 1px);border-top-right-radius:calc(.3rem - 1px)}.modal-header .close{padding:1rem;margin:-1rem -1rem -1rem auto}.modal-title{margin-bottom:0;line-height:1.5}.modal-body{position:relative;flex:1 1 auto;padding:1rem}.modal-footer{display:flex;flex-wrap:wrap;align-items:center;justify-content:flex-end;padding:.75rem;border-top:1px solid #f2f3f4;border-bottom-right-radius:calc(.3rem - 1px);border-bottom-left-radius:calc(.3rem - 1px)}.modal-footer>*{margin:.25rem}.modal-scrollbar-measure{position:absolute;top:-9999px;width:50px;height:50px;overflow:scroll}@media (min-width:576px){.modal-dialog{max-width:500px;margin:1.75rem auto}.modal-dialog-scrollable{max-height:calc(100% - 3.5rem)}.modal-dialog-scrollable .modal-content{max-height:calc(100vh - 3.5rem)}.modal-dialog-centered{min-height:calc(100% - 3.5rem)}.modal-dialog-centered::before{height:calc(100vh - 3.5rem);height:-webkit-min-content;height:-moz-min-content;height:min-content}.modal-sm{max-width:300px}}@media (min-width:992px){.modal-lg,.modal-xl{max-width:800px}}@media (min-width:1200px){.modal-xl{max-width:1140px}}.tooltip{position:absolute;z-index:1070;display:block;margin:0;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-style:normal;font-weight:400;line-height:1.5;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;white-space:normal;line-break:auto;font-size:.875rem;word-wrap:break-word;opacity:0}.tooltip.show{opacity:.9}.tooltip .arrow{position:absolute;display:block;width:.8rem;height:.4rem}.tooltip .arrow::before{position:absolute;content:\"\";border-color:transparent;border-style:solid}.bs-tooltip-auto[x-placement^=top],.bs-tooltip-top{padding:.4rem 0}.bs-tooltip-auto[x-placement^=top] .arrow,.bs-tooltip-top .arrow{bottom:0}.bs-tooltip-auto[x-placement^=top] .arrow::before,.bs-tooltip-top .arrow::before{top:0;border-width:.4rem .4rem 0;border-top-color:#000}.bs-tooltip-auto[x-placement^=right],.bs-tooltip-right{padding:0 .4rem}.bs-tooltip-auto[x-placement^=right] .arrow,.bs-tooltip-right .arrow{left:0;width:.4rem;height:.8rem}.bs-tooltip-auto[x-placement^=right] .arrow::before,.bs-tooltip-right .arrow::before{right:0;border-width:.4rem .4rem .4rem 0;border-right-color:#000}.bs-tooltip-auto[x-placement^=bottom],.bs-tooltip-bottom{padding:.4rem 0}.bs-tooltip-auto[x-placement^=bottom] .arrow,.bs-tooltip-bottom .arrow{top:0}.bs-tooltip-auto[x-placement^=bottom] .arrow::before,.bs-tooltip-bottom .arrow::before{bottom:0;border-width:0 .4rem .4rem;border-bottom-color:#000}.bs-tooltip-auto[x-placement^=left],.bs-tooltip-left{padding:0 .4rem}.bs-tooltip-auto[x-placement^=left] .arrow,.bs-tooltip-left .arrow{right:0;width:.4rem;height:.8rem}.bs-tooltip-auto[x-placement^=left] .arrow::before,.bs-tooltip-left .arrow::before{left:0;border-width:.4rem 0 .4rem .4rem;border-left-color:#000}.tooltip-inner{max-width:200px;padding:.25rem .5rem;color:#fff;text-align:center;background-color:#000;border-radius:8px}.popover{position:absolute;top:0;left:0;z-index:1060;display:block;max-width:276px;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-style:normal;font-weight:400;line-height:1.5;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;white-space:normal;line-break:auto;font-size:.875rem;word-wrap:break-word;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.2);border-radius:.3rem}.popover .arrow{position:absolute;display:block;width:1rem;height:.5rem;margin:0 .3rem}.popover .arrow::after,.popover .arrow::before{position:absolute;display:block;content:\"\";border-color:transparent;border-style:solid}.bs-popover-auto[x-placement^=top],.bs-popover-top{margin-bottom:.5rem}.bs-popover-auto[x-placement^=top]>.arrow,.bs-popover-top>.arrow{bottom:calc(-.5rem - 1px)}.bs-popover-auto[x-placement^=top]>.arrow::before,.bs-popover-top>.arrow::before{bottom:0;border-width:.5rem .5rem 0;border-top-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=top]>.arrow::after,.bs-popover-top>.arrow::after{bottom:1px;border-width:.5rem .5rem 0;border-top-color:#fff}.bs-popover-auto[x-placement^=right],.bs-popover-right{margin-left:.5rem}.bs-popover-auto[x-placement^=right]>.arrow,.bs-popover-right>.arrow{left:calc(-.5rem - 1px);width:.5rem;height:1rem;margin:.3rem 0}.bs-popover-auto[x-placement^=right]>.arrow::before,.bs-popover-right>.arrow::before{left:0;border-width:.5rem .5rem .5rem 0;border-right-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=right]>.arrow::after,.bs-popover-right>.arrow::after{left:1px;border-width:.5rem .5rem .5rem 0;border-right-color:#fff}.bs-popover-auto[x-placement^=bottom],.bs-popover-bottom{margin-top:.5rem}.bs-popover-auto[x-placement^=bottom]>.arrow,.bs-popover-bottom>.arrow{top:calc(-.5rem - 1px)}.bs-popover-auto[x-placement^=bottom]>.arrow::before,.bs-popover-bottom>.arrow::before{top:0;border-width:0 .5rem .5rem;border-bottom-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=bottom]>.arrow::after,.bs-popover-bottom>.arrow::after{top:1px;border-width:0 .5rem .5rem;border-bottom-color:#fff}.bs-popover-auto[x-placement^=bottom] .popover-header::before,.bs-popover-bottom .popover-header::before{position:absolute;top:0;left:50%;display:block;width:1rem;margin-left:-.5rem;content:\"\";border-bottom:1px solid #f7f7f7}.bs-popover-auto[x-placement^=left],.bs-popover-left{margin-right:.5rem}.bs-popover-auto[x-placement^=left]>.arrow,.bs-popover-left>.arrow{right:calc(-.5rem - 1px);width:.5rem;height:1rem;margin:.3rem 0}.bs-popover-auto[x-placement^=left]>.arrow::before,.bs-popover-left>.arrow::before{right:0;border-width:.5rem 0 .5rem .5rem;border-left-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=left]>.arrow::after,.bs-popover-left>.arrow::after{right:1px;border-width:.5rem 0 .5rem .5rem;border-left-color:#fff}.popover-header{padding:.5rem .75rem;margin-bottom:0;font-size:1rem;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;border-top-left-radius:calc(.3rem - 1px);border-top-right-radius:calc(.3rem - 1px)}.popover-header:empty{display:none}.popover-body{padding:.5rem .75rem;color:#212529}.carousel{position:relative}.carousel.pointer-event{touch-action:pan-y}.carousel-inner{position:relative;width:100%;overflow:hidden}.carousel-inner::after{display:block;clear:both;content:\"\"}.carousel-item{position:relative;display:none;float:left;width:100%;margin-right:-100%;-webkit-backface-visibility:hidden;backface-visibility:hidden;transition:transform .6s ease-in-out}.carousel-item-next,.carousel-item-prev,.carousel-item.active{display:block}.active.carousel-item-right,.carousel-item-next:not(.carousel-item-left){transform:translateX(100%)}.active.carousel-item-left,.carousel-item-prev:not(.carousel-item-right){transform:translateX(-100%)}.carousel-fade .carousel-item{opacity:0;transition-property:opacity;transform:none}.carousel-fade .carousel-item-next.carousel-item-left,.carousel-fade .carousel-item-prev.carousel-item-right,.carousel-fade .carousel-item.active{z-index:1;opacity:1}.carousel-fade .active.carousel-item-left,.carousel-fade .active.carousel-item-right{z-index:0;opacity:0;transition:opacity .6s}@media (prefers-reduced-motion:reduce){.carousel-fade .active.carousel-item-left,.carousel-fade .active.carousel-item-right,.carousel-item{transition:none}}.carousel-control-next,.carousel-control-prev{position:absolute;top:0;bottom:0;z-index:1;display:flex;align-items:center;justify-content:center;width:15%;color:#fff;text-align:center;opacity:.5;transition:opacity .15s}.carousel-control-next:focus,.carousel-control-next:hover,.carousel-control-prev:focus,.carousel-control-prev:hover{color:#fff;text-decoration:none;outline:0;opacity:.9}.carousel-control-prev{left:0}.carousel-control-next{right:0}.carousel-control-next-icon,.carousel-control-prev-icon{display:inline-block;width:20px;height:20px;background:50%/100% 100% no-repeat}.carousel-control-prev-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath d='M5.25 0l-4 4 4 4 1.5-1.5L4.25 4l2.5-2.5L5.25 0z'/%3e%3c/svg%3e\")}.carousel-control-next-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath d='M2.75 0l-1.5 1.5L3.75 4l-2.5 2.5L2.75 8l4-4-4-4z'/%3e%3c/svg%3e\")}.carousel-indicators{position:absolute;right:0;bottom:0;left:0;z-index:15;display:flex;justify-content:center;padding-left:0;margin-right:15%;margin-left:15%;list-style:none}.carousel-indicators li{box-sizing:content-box;flex:0 1 auto;width:30px;height:3px;margin-right:3px;margin-left:3px;text-indent:-999px;cursor:pointer;background-color:#fff;background-clip:padding-box;border-top:10px solid transparent;border-bottom:10px solid transparent;opacity:.5;transition:opacity .6s}@media (prefers-reduced-motion:reduce){.carousel-control-next,.carousel-control-prev,.carousel-indicators li{transition:none}}.carousel-indicators .active{opacity:1}.carousel-caption{position:absolute;right:15%;bottom:20px;left:15%;z-index:10;padding-top:20px;padding-bottom:20px;color:#fff;text-align:center}@-webkit-keyframes spinner-border{to{transform:rotate(360deg)}}@keyframes spinner-border{to{transform:rotate(360deg)}}.spinner-border{display:inline-block;width:2rem;height:2rem;vertical-align:text-bottom;border:.25em solid currentColor;border-right-color:transparent;border-radius:50%;-webkit-animation:.75s linear infinite spinner-border;animation:.75s linear infinite spinner-border}.spinner-border-sm{width:1rem;height:1rem;border-width:.2em}@-webkit-keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}@keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}.spinner-grow{display:inline-block;width:2rem;height:2rem;vertical-align:text-bottom;background-color:currentColor;border-radius:50%;opacity:0;-webkit-animation:.75s linear infinite spinner-grow;animation:.75s linear infinite spinner-grow}.spinner-grow-sm{width:1rem;height:1rem}.align-baseline{vertical-align:baseline!important}.align-top{vertical-align:top!important}.align-middle{vertical-align:middle!important}.align-bottom{vertical-align:bottom!important}.align-text-bottom{vertical-align:text-bottom!important}.align-text-top{vertical-align:text-top!important}.bg-primary{background-color:#c82c37!important}a.bg-primary:focus,a.bg-primary:hover,button.bg-primary:focus,button.bg-primary:hover{background-color:#9e232c!important}.bg-secondary{background-color:#919191!important}a.bg-secondary:focus,a.bg-secondary:hover,button.bg-secondary:focus,button.bg-secondary:hover{background-color:#787878!important}.bg-success{background-color:#4caf50!important}a.bg-success:focus,a.bg-success:hover,button.bg-success:focus,button.bg-success:hover{background-color:#3d8b40!important}.bg-info{background-color:#00bcd4!important}a.bg-info:focus,a.bg-info:hover,button.bg-info:focus,button.bg-info:hover{background-color:#008fa1!important}.bg-warning{background-color:#ff9800!important}a.bg-warning:focus,a.bg-warning:hover,button.bg-warning:focus,button.bg-warning:hover{background-color:#cc7a00!important}.bg-danger{background-color:#f44336!important}a.bg-danger:focus,a.bg-danger:hover,button.bg-danger:focus,button.bg-danger:hover{background-color:#ea1c0d!important}.bg-light{background-color:#f8f9fa!important}a.bg-light:focus,a.bg-light:hover,button.bg-light:focus,button.bg-light:hover{background-color:#dae0e5!important}.bg-dark{background-color:#343a40!important}a.bg-dark:focus,a.bg-dark:hover,button.bg-dark:focus,button.bg-dark:hover{background-color:#1d2124!important}.bg-white{background-color:#fff!important}.bg-transparent{background-color:transparent!important}.border{border:1px solid #f2f3f4!important}.border-top{border-top:1px solid #f2f3f4!important}.border-right{border-right:1px solid #f2f3f4!important}.border-bottom{border-bottom:1px solid #f2f3f4!important}.border-left{border-left:1px solid #f2f3f4!important}.border-0{border:0!important}.border-top-0{border-top:0!important}.border-right-0{border-right:0!important}.border-bottom-0{border-bottom:0!important}.border-left-0{border-left:0!important}.border-primary{border-color:#c82c37!important}.border-secondary{border-color:#919191!important}.border-success{border-color:#4caf50!important}.border-info{border-color:#00bcd4!important}.border-warning{border-color:#ff9800!important}.border-danger{border-color:#f44336!important}.border-light{border-color:#f8f9fa!important}.border-dark{border-color:#343a40!important}.border-white{border-color:#fff!important}.rounded-sm{border-radius:.2rem!important}.rounded{border-radius:8px!important}.rounded-top{border-top-left-radius:8px!important;border-top-right-radius:8px!important}.rounded-right{border-top-right-radius:8px!important;border-bottom-right-radius:8px!important}.rounded-bottom{border-bottom-right-radius:8px!important;border-bottom-left-radius:8px!important}.rounded-left{border-top-left-radius:8px!important;border-bottom-left-radius:8px!important}.rounded-lg{border-radius:.3rem!important}.rounded-circle{border-radius:50%!important}.rounded-pill{border-radius:50rem!important}.rounded-0{border-radius:0!important}.clearfix::after{display:block;clear:both;content:\"\"}.d-none{display:none!important}.d-inline{display:inline!important}.d-inline-block{display:inline-block!important}.d-block{display:block!important}.d-table{display:table!important}.d-table-row{display:table-row!important}.d-table-cell{display:table-cell!important}.d-flex{display:flex!important}.d-inline-flex{display:inline-flex!important}@media (min-width:576px){.d-sm-none{display:none!important}.d-sm-inline{display:inline!important}.d-sm-inline-block{display:inline-block!important}.d-sm-block{display:block!important}.d-sm-table{display:table!important}.d-sm-table-row{display:table-row!important}.d-sm-table-cell{display:table-cell!important}.d-sm-flex{display:flex!important}.d-sm-inline-flex{display:inline-flex!important}}@media (min-width:768px){.d-md-none{display:none!important}.d-md-inline{display:inline!important}.d-md-inline-block{display:inline-block!important}.d-md-block{display:block!important}.d-md-table{display:table!important}.d-md-table-row{display:table-row!important}.d-md-table-cell{display:table-cell!important}.d-md-flex{display:flex!important}.d-md-inline-flex{display:inline-flex!important}}@media (min-width:992px){.d-lg-none{display:none!important}.d-lg-inline{display:inline!important}.d-lg-inline-block{display:inline-block!important}.d-lg-block{display:block!important}.d-lg-table{display:table!important}.d-lg-table-row{display:table-row!important}.d-lg-table-cell{display:table-cell!important}.d-lg-flex{display:flex!important}.d-lg-inline-flex{display:inline-flex!important}}@media (min-width:1200px){.d-xl-none{display:none!important}.d-xl-inline{display:inline!important}.d-xl-inline-block{display:inline-block!important}.d-xl-block{display:block!important}.d-xl-table{display:table!important}.d-xl-table-row{display:table-row!important}.d-xl-table-cell{display:table-cell!important}.d-xl-flex{display:flex!important}.d-xl-inline-flex{display:inline-flex!important}}@media print{.d-print-none{display:none!important}.d-print-inline{display:inline!important}.d-print-inline-block{display:inline-block!important}.d-print-block{display:block!important}.d-print-table{display:table!important}.d-print-table-row{display:table-row!important}.d-print-table-cell{display:table-cell!important}.d-print-flex{display:flex!important}.d-print-inline-flex{display:inline-flex!important}}.embed-responsive{position:relative;display:block;width:100%;padding:0;overflow:hidden}.embed-responsive::before{display:block;content:\"\"}.embed-responsive .embed-responsive-item,.embed-responsive embed,.embed-responsive iframe,.embed-responsive object,.embed-responsive video{position:absolute;top:0;bottom:0;left:0;width:100%;height:100%;border:0}.embed-responsive-21by9::before{padding-top:42.8571428571%}.embed-responsive-16by9::before{padding-top:56.25%}.embed-responsive-4by3::before{padding-top:75%}.embed-responsive-1by1::before{padding-top:100%}.flex-row{flex-direction:row!important}.flex-column{flex-direction:column!important}.flex-row-reverse{flex-direction:row-reverse!important}.flex-column-reverse{flex-direction:column-reverse!important}.flex-wrap{flex-wrap:wrap!important}.flex-nowrap{flex-wrap:nowrap!important}.flex-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-fill{flex:1 1 auto!important}.flex-grow-0{flex-grow:0!important}.flex-grow-1{flex-grow:1!important}.flex-shrink-0{flex-shrink:0!important}.flex-shrink-1{flex-shrink:1!important}.justify-content-start{justify-content:flex-start!important}.justify-content-end{justify-content:flex-end!important}.justify-content-center{justify-content:center!important}.justify-content-between{justify-content:space-between!important}.justify-content-around{justify-content:space-around!important}.align-items-start{align-items:flex-start!important}.align-items-end{align-items:flex-end!important}.align-items-center{align-items:center!important}.align-items-baseline{align-items:baseline!important}.align-items-stretch{align-items:stretch!important}.align-content-start{align-content:flex-start!important}.align-content-end{align-content:flex-end!important}.align-content-center{align-content:center!important}.align-content-between{align-content:space-between!important}.align-content-around{align-content:space-around!important}.align-content-stretch{align-content:stretch!important}.align-self-auto{align-self:auto!important}.align-self-start{align-self:flex-start!important}.align-self-end{align-self:flex-end!important}.align-self-center{align-self:center!important}.align-self-baseline{align-self:baseline!important}.align-self-stretch{align-self:stretch!important}.float-left{float:left!important}.float-right{float:right!important}.float-none{float:none!important}.user-select-all{-webkit-user-select:all!important;-moz-user-select:all!important;-ms-user-select:all!important;user-select:all!important}.user-select-auto{-webkit-user-select:auto!important;-moz-user-select:auto!important;-ms-user-select:auto!important;user-select:auto!important}.user-select-none{-webkit-user-select:none!important;-moz-user-select:none!important;-ms-user-select:none!important;user-select:none!important}.overflow-auto{overflow:auto!important}.overflow-hidden{overflow:hidden!important}.position-static{position:static!important}.position-relative{position:relative!important}.position-absolute{position:absolute!important}.position-fixed{position:fixed!important}.position-sticky{position:-webkit-sticky!important;position:sticky!important}.fixed-top{position:fixed;top:0;right:0;left:0;z-index:1030}.fixed-bottom{position:fixed;right:0;bottom:0;left:0;z-index:1030}@supports ((position:-webkit-sticky) or (position:sticky)){.sticky-top{position:-webkit-sticky;position:sticky;top:0;z-index:1020}}.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);white-space:nowrap;border:0}.sr-only-focusable:active,.sr-only-focusable:focus{position:static;width:auto;height:auto;overflow:visible;clip:auto;white-space:normal}.shadow-sm{box-shadow:0 .125rem .25rem rgba(0,0,0,.075)!important}.shadow{box-shadow:0 .5rem 1rem rgba(0,0,0,.15)!important}.shadow-lg{box-shadow:0 1rem 3rem rgba(0,0,0,.175)!important}.shadow-none{box-shadow:none!important}.w-25{width:25%!important}.w-50{width:50%!important}.w-75{width:75%!important}.w-100{width:100%!important}.w-auto{width:auto!important}.h-25{height:25%!important}.h-50{height:50%!important}.h-75{height:75%!important}.h-100{height:100%!important}.h-auto{height:auto!important}.mw-100{max-width:100%!important}.mh-100{max-height:100%!important}.min-vw-100{min-width:100vw!important}.min-vh-100{min-height:100vh!important}.vw-100{width:100vw!important}.vh-100{height:100vh!important}.m-0{margin:0!important}.mt-0,.my-0{margin-top:0!important}.mr-0,.mx-0{margin-right:0!important}.mb-0,.my-0{margin-bottom:0!important}.ml-0,.mx-0{margin-left:0!important}.m-1{margin:1px!important}.mt-1,.my-1{margin-top:1px!important}.mr-1,.mx-1{margin-right:1px!important}.mb-1,.my-1{margin-bottom:1px!important}.ml-1,.mx-1{margin-left:1px!important}.m-2{margin:2px!important}.mt-2,.my-2{margin-top:2px!important}.mr-2,.mx-2{margin-right:2px!important}.mb-2,.my-2{margin-bottom:2px!important}.ml-2,.mx-2{margin-left:2px!important}.m-3{margin:3px!important}.mt-3,.my-3{margin-top:3px!important}.mr-3,.mx-3{margin-right:3px!important}.mb-3,.my-3{margin-bottom:3px!important}.ml-3,.mx-3{margin-left:3px!important}.m-4{margin:4px!important}.mt-4,.my-4{margin-top:4px!important}.mr-4,.mx-4{margin-right:4px!important}.mb-4,.my-4{margin-bottom:4px!important}.ml-4,.mx-4{margin-left:4px!important}.m-5{margin:5px!important}.mt-5,.my-5{margin-top:5px!important}.mr-5,.mx-5{margin-right:5px!important}.mb-5,.my-5{margin-bottom:5px!important}.ml-5,.mx-5{margin-left:5px!important}.m-6{margin:6px!important}.mt-6,.my-6{margin-top:6px!important}.mr-6,.mx-6{margin-right:6px!important}.mb-6,.my-6{margin-bottom:6px!important}.ml-6,.mx-6{margin-left:6px!important}.m-7{margin:7px!important}.mt-7,.my-7{margin-top:7px!important}.mr-7,.mx-7{margin-right:7px!important}.mb-7,.my-7{margin-bottom:7px!important}.ml-7,.mx-7{margin-left:7px!important}.m-8{margin:8px!important}.mt-8,.my-8{margin-top:8px!important}.mr-8,.mx-8{margin-right:8px!important}.mb-8,.my-8{margin-bottom:8px!important}.ml-8,.mx-8{margin-left:8px!important}.m-9{margin:9px!important}.mt-9,.my-9{margin-top:9px!important}.mr-9,.mx-9{margin-right:9px!important}.mb-9,.my-9{margin-bottom:9px!important}.ml-9,.mx-9{margin-left:9px!important}.m-10{margin:10px!important}.mt-10,.my-10{margin-top:10px!important}.mr-10,.mx-10{margin-right:10px!important}.mb-10,.my-10{margin-bottom:10px!important}.ml-10,.mx-10{margin-left:10px!important}.m-11{margin:11px!important}.mt-11,.my-11{margin-top:11px!important}.mr-11,.mx-11{margin-right:11px!important}.mb-11,.my-11{margin-bottom:11px!important}.ml-11,.mx-11{margin-left:11px!important}.m-12{margin:12px!important}.mt-12,.my-12{margin-top:12px!important}.mr-12,.mx-12{margin-right:12px!important}.mb-12,.my-12{margin-bottom:12px!important}.ml-12,.mx-12{margin-left:12px!important}.m-13{margin:13px!important}.mt-13,.my-13{margin-top:13px!important}.mr-13,.mx-13{margin-right:13px!important}.mb-13,.my-13{margin-bottom:13px!important}.ml-13,.mx-13{margin-left:13px!important}.m-14{margin:14px!important}.mt-14,.my-14{margin-top:14px!important}.mr-14,.mx-14{margin-right:14px!important}.mb-14,.my-14{margin-bottom:14px!important}.ml-14,.mx-14{margin-left:14px!important}.m-15{margin:15px!important}.mt-15,.my-15{margin-top:15px!important}.mr-15,.mx-15{margin-right:15px!important}.mb-15,.my-15{margin-bottom:15px!important}.ml-15,.mx-15{margin-left:15px!important}.m-16{margin:16px!important}.mt-16,.my-16{margin-top:16px!important}.mr-16,.mx-16{margin-right:16px!important}.mb-16,.my-16{margin-bottom:16px!important}.ml-16,.mx-16{margin-left:16px!important}.m-18{margin:18px!important}.mt-18,.my-18{margin-top:18px!important}.mr-18,.mx-18{margin-right:18px!important}.mb-18,.my-18{margin-bottom:18px!important}.ml-18,.mx-18{margin-left:18px!important}.m-20{margin:20px!important}.mt-20,.my-20{margin-top:20px!important}.mr-20,.mx-20{margin-right:20px!important}.mb-20,.my-20{margin-bottom:20px!important}.ml-20,.mx-20{margin-left:20px!important}.m-21{margin:21px!important}.mt-21,.my-21{margin-top:21px!important}.mr-21,.mx-21{margin-right:21px!important}.mb-21,.my-21{margin-bottom:21px!important}.ml-21,.mx-21{margin-left:21px!important}.m-23{margin:23px!important}.mt-23,.my-23{margin-top:23px!important}.mr-23,.mx-23{margin-right:23px!important}.mb-23,.my-23{margin-bottom:23px!important}.ml-23,.mx-23{margin-left:23px!important}.m-24{margin:24px!important}.mt-24,.my-24{margin-top:24px!important}.mr-24,.mx-24{margin-right:24px!important}.mb-24,.my-24{margin-bottom:24px!important}.ml-24,.mx-24{margin-left:24px!important}.m-26{margin:26px!important}.mt-26,.my-26{margin-top:26px!important}.mr-26,.mx-26{margin-right:26px!important}.mb-26,.my-26{margin-bottom:26px!important}.ml-26,.mx-26{margin-left:26px!important}.m-28{margin:28px!important}.mt-28,.my-28{margin-top:28px!important}.mr-28,.mx-28{margin-right:28px!important}.mb-28,.my-28{margin-bottom:28px!important}.ml-28,.mx-28{margin-left:28px!important}.m-29{margin:29px!important}.mt-29,.my-29{margin-top:29px!important}.mr-29,.mx-29{margin-right:29px!important}.mb-29,.my-29{margin-bottom:29px!important}.ml-29,.mx-29{margin-left:29px!important}.m-30{margin:30px!important}.mt-30,.my-30{margin-top:30px!important}.mr-30,.mx-30{margin-right:30px!important}.mb-30,.my-30{margin-bottom:30px!important}.ml-30,.mx-30{margin-left:30px!important}.m-32{margin:32px!important}.mt-32,.my-32{margin-top:32px!important}.mr-32,.mx-32{margin-right:32px!important}.mb-32,.my-32{margin-bottom:32px!important}.ml-32,.mx-32{margin-left:32px!important}.m-38{margin:38px!important}.mt-38,.my-38{margin-top:38px!important}.mr-38,.mx-38{margin-right:38px!important}.mb-38,.my-38{margin-bottom:38px!important}.ml-38,.mx-38{margin-left:38px!important}.m-40{margin:40px!important}.mt-40,.my-40{margin-top:40px!important}.mr-40,.mx-40{margin-right:40px!important}.mb-40,.my-40{margin-bottom:40px!important}.ml-40,.mx-40{margin-left:40px!important}.m-42{margin:42px!important}.mt-42,.my-42{margin-top:42px!important}.mr-42,.mx-42{margin-right:42px!important}.mb-42,.my-42{margin-bottom:42px!important}.ml-42,.mx-42{margin-left:42px!important}.m-48{margin:48px!important}.mt-48,.my-48{margin-top:48px!important}.mr-48,.mx-48{margin-right:48px!important}.mb-48,.my-48{margin-bottom:48px!important}.ml-48,.mx-48{margin-left:48px!important}.m-50{margin:50px!important}.mt-50,.my-50{margin-top:50px!important}.mr-50,.mx-50{margin-right:50px!important}.mb-50,.my-50{margin-bottom:50px!important}.ml-50,.mx-50{margin-left:50px!important}.m-56{margin:56px!important}.mt-56,.my-56{margin-top:56px!important}.mr-56,.mx-56{margin-right:56px!important}.mb-56,.my-56{margin-bottom:56px!important}.ml-56,.mx-56{margin-left:56px!important}.m-58{margin:58px!important}.mt-58,.my-58{margin-top:58px!important}.mr-58,.mx-58{margin-right:58px!important}.mb-58,.my-58{margin-bottom:58px!important}.ml-58,.mx-58{margin-left:58px!important}.m-60{margin:60px!important}.mt-60,.my-60{margin-top:60px!important}.mr-60,.mx-60{margin-right:60px!important}.mb-60,.my-60{margin-bottom:60px!important}.ml-60,.mx-60{margin-left:60px!important}.m-64{margin:64px!important}.mt-64,.my-64{margin-top:64px!important}.mr-64,.mx-64{margin-right:64px!important}.mb-64,.my-64{margin-bottom:64px!important}.ml-64,.mx-64{margin-left:64px!important}.p-0{padding:0!important}.pt-0,.py-0{padding-top:0!important}.pr-0,.px-0{padding-right:0!important}.pb-0,.py-0{padding-bottom:0!important}.pl-0,.px-0{padding-left:0!important}.p-1{padding:1px!important}.pt-1,.py-1{padding-top:1px!important}.pr-1,.px-1{padding-right:1px!important}.pb-1,.py-1{padding-bottom:1px!important}.pl-1,.px-1{padding-left:1px!important}.p-2{padding:2px!important}.pt-2,.py-2{padding-top:2px!important}.pr-2,.px-2{padding-right:2px!important}.pb-2,.py-2{padding-bottom:2px!important}.pl-2,.px-2{padding-left:2px!important}.p-3{padding:3px!important}.pt-3,.py-3{padding-top:3px!important}.pr-3,.px-3{padding-right:3px!important}.pb-3,.py-3{padding-bottom:3px!important}.pl-3,.px-3{padding-left:3px!important}.p-4{padding:4px!important}.pt-4,.py-4{padding-top:4px!important}.pr-4,.px-4{padding-right:4px!important}.pb-4,.py-4{padding-bottom:4px!important}.pl-4,.px-4{padding-left:4px!important}.p-5{padding:5px!important}.pt-5,.py-5{padding-top:5px!important}.pr-5,.px-5{padding-right:5px!important}.pb-5,.py-5{padding-bottom:5px!important}.pl-5,.px-5{padding-left:5px!important}.p-6{padding:6px!important}.pt-6,.py-6{padding-top:6px!important}.pr-6,.px-6{padding-right:6px!important}.pb-6,.py-6{padding-bottom:6px!important}.pl-6,.px-6{padding-left:6px!important}.p-7{padding:7px!important}.pt-7,.py-7{padding-top:7px!important}.pr-7,.px-7{padding-right:7px!important}.pb-7,.py-7{padding-bottom:7px!important}.pl-7,.px-7{padding-left:7px!important}.p-8{padding:8px!important}.pt-8,.py-8{padding-top:8px!important}.pr-8,.px-8{padding-right:8px!important}.pb-8,.py-8{padding-bottom:8px!important}.pl-8,.px-8{padding-left:8px!important}.p-9{padding:9px!important}.pt-9,.py-9{padding-top:9px!important}.pr-9,.px-9{padding-right:9px!important}.pb-9,.py-9{padding-bottom:9px!important}.pl-9,.px-9{padding-left:9px!important}.p-10{padding:10px!important}.pt-10,.py-10{padding-top:10px!important}.pr-10,.px-10{padding-right:10px!important}.pb-10,.py-10{padding-bottom:10px!important}.pl-10,.px-10{padding-left:10px!important}.p-11{padding:11px!important}.pt-11,.py-11{padding-top:11px!important}.pr-11,.px-11{padding-right:11px!important}.pb-11,.py-11{padding-bottom:11px!important}.pl-11,.px-11{padding-left:11px!important}.p-12{padding:12px!important}.pt-12,.py-12{padding-top:12px!important}.pr-12,.px-12{padding-right:12px!important}.pb-12,.py-12{padding-bottom:12px!important}.pl-12,.px-12{padding-left:12px!important}.p-13{padding:13px!important}.pt-13,.py-13{padding-top:13px!important}.pr-13,.px-13{padding-right:13px!important}.pb-13,.py-13{padding-bottom:13px!important}.pl-13,.px-13{padding-left:13px!important}.p-14{padding:14px!important}.pt-14,.py-14{padding-top:14px!important}.pr-14,.px-14{padding-right:14px!important}.pb-14,.py-14{padding-bottom:14px!important}.pl-14,.px-14{padding-left:14px!important}.p-15{padding:15px!important}.pt-15,.py-15{padding-top:15px!important}.pr-15,.px-15{padding-right:15px!important}.pb-15,.py-15{padding-bottom:15px!important}.pl-15,.px-15{padding-left:15px!important}.p-16{padding:16px!important}.pt-16,.py-16{padding-top:16px!important}.pr-16,.px-16{padding-right:16px!important}.pb-16,.py-16{padding-bottom:16px!important}.pl-16,.px-16{padding-left:16px!important}.p-18{padding:18px!important}.pt-18,.py-18{padding-top:18px!important}.pr-18,.px-18{padding-right:18px!important}.pb-18,.py-18{padding-bottom:18px!important}.pl-18,.px-18{padding-left:18px!important}.p-20{padding:20px!important}.pt-20,.py-20{padding-top:20px!important}.pr-20,.px-20{padding-right:20px!important}.pb-20,.py-20{padding-bottom:20px!important}.pl-20,.px-20{padding-left:20px!important}.p-21{padding:21px!important}.pt-21,.py-21{padding-top:21px!important}.pr-21,.px-21{padding-right:21px!important}.pb-21,.py-21{padding-bottom:21px!important}.pl-21,.px-21{padding-left:21px!important}.p-23{padding:23px!important}.pt-23,.py-23{padding-top:23px!important}.pr-23,.px-23{padding-right:23px!important}.pb-23,.py-23{padding-bottom:23px!important}.pl-23,.px-23{padding-left:23px!important}.p-24{padding:24px!important}.pt-24,.py-24{padding-top:24px!important}.pr-24,.px-24{padding-right:24px!important}.pb-24,.py-24{padding-bottom:24px!important}.pl-24,.px-24{padding-left:24px!important}.p-26{padding:26px!important}.pt-26,.py-26{padding-top:26px!important}.pr-26,.px-26{padding-right:26px!important}.pb-26,.py-26{padding-bottom:26px!important}.pl-26,.px-26{padding-left:26px!important}.p-28{padding:28px!important}.pt-28,.py-28{padding-top:28px!important}.pr-28,.px-28{padding-right:28px!important}.pb-28,.py-28{padding-bottom:28px!important}.pl-28,.px-28{padding-left:28px!important}.p-29{padding:29px!important}.pt-29,.py-29{padding-top:29px!important}.pr-29,.px-29{padding-right:29px!important}.pb-29,.py-29{padding-bottom:29px!important}.pl-29,.px-29{padding-left:29px!important}.p-30{padding:30px!important}.pt-30,.py-30{padding-top:30px!important}.pr-30,.px-30{padding-right:30px!important}.pb-30,.py-30{padding-bottom:30px!important}.pl-30,.px-30{padding-left:30px!important}.p-32{padding:32px!important}.pt-32,.py-32{padding-top:32px!important}.pr-32,.px-32{padding-right:32px!important}.pb-32,.py-32{padding-bottom:32px!important}.pl-32,.px-32{padding-left:32px!important}.p-38{padding:38px!important}.pt-38,.py-38{padding-top:38px!important}.pr-38,.px-38{padding-right:38px!important}.pb-38,.py-38{padding-bottom:38px!important}.pl-38,.px-38{padding-left:38px!important}.p-40{padding:40px!important}.pt-40,.py-40{padding-top:40px!important}.pr-40,.px-40{padding-right:40px!important}.pb-40,.py-40{padding-bottom:40px!important}.pl-40,.px-40{padding-left:40px!important}.p-42{padding:42px!important}.pt-42,.py-42{padding-top:42px!important}.pr-42,.px-42{padding-right:42px!important}.pb-42,.py-42{padding-bottom:42px!important}.pl-42,.px-42{padding-left:42px!important}.p-48{padding:48px!important}.pt-48,.py-48{padding-top:48px!important}.pr-48,.px-48{padding-right:48px!important}.pb-48,.py-48{padding-bottom:48px!important}.pl-48,.px-48{padding-left:48px!important}.p-50{padding:50px!important}.pt-50,.py-50{padding-top:50px!important}.pr-50,.px-50{padding-right:50px!important}.pb-50,.py-50{padding-bottom:50px!important}.pl-50,.px-50{padding-left:50px!important}.p-56{padding:56px!important}.pt-56,.py-56{padding-top:56px!important}.pr-56,.px-56{padding-right:56px!important}.pb-56,.py-56{padding-bottom:56px!important}.pl-56,.px-56{padding-left:56px!important}.p-58{padding:58px!important}.pt-58,.py-58{padding-top:58px!important}.pr-58,.px-58{padding-right:58px!important}.pb-58,.py-58{padding-bottom:58px!important}.pl-58,.px-58{padding-left:58px!important}.p-60{padding:60px!important}.pt-60,.py-60{padding-top:60px!important}.pr-60,.px-60{padding-right:60px!important}.pb-60,.py-60{padding-bottom:60px!important}.pl-60,.px-60{padding-left:60px!important}.p-64{padding:64px!important}.pt-64,.py-64{padding-top:64px!important}.pr-64,.px-64{padding-right:64px!important}.pb-64,.py-64{padding-bottom:64px!important}.pl-64,.px-64{padding-left:64px!important}.m-n1{margin:-1px!important}.mt-n1,.my-n1{margin-top:-1px!important}.mr-n1,.mx-n1{margin-right:-1px!important}.mb-n1,.my-n1{margin-bottom:-1px!important}.ml-n1,.mx-n1{margin-left:-1px!important}.m-n2{margin:-2px!important}.mt-n2,.my-n2{margin-top:-2px!important}.mr-n2,.mx-n2{margin-right:-2px!important}.mb-n2,.my-n2{margin-bottom:-2px!important}.ml-n2,.mx-n2{margin-left:-2px!important}.m-n3{margin:-3px!important}.mt-n3,.my-n3{margin-top:-3px!important}.mr-n3,.mx-n3{margin-right:-3px!important}.mb-n3,.my-n3{margin-bottom:-3px!important}.ml-n3,.mx-n3{margin-left:-3px!important}.m-n4{margin:-4px!important}.mt-n4,.my-n4{margin-top:-4px!important}.mr-n4,.mx-n4{margin-right:-4px!important}.mb-n4,.my-n4{margin-bottom:-4px!important}.ml-n4,.mx-n4{margin-left:-4px!important}.m-n5{margin:-5px!important}.mt-n5,.my-n5{margin-top:-5px!important}.mr-n5,.mx-n5{margin-right:-5px!important}.mb-n5,.my-n5{margin-bottom:-5px!important}.ml-n5,.mx-n5{margin-left:-5px!important}.m-n6{margin:-6px!important}.mt-n6,.my-n6{margin-top:-6px!important}.mr-n6,.mx-n6{margin-right:-6px!important}.mb-n6,.my-n6{margin-bottom:-6px!important}.ml-n6,.mx-n6{margin-left:-6px!important}.m-n7{margin:-7px!important}.mt-n7,.my-n7{margin-top:-7px!important}.mr-n7,.mx-n7{margin-right:-7px!important}.mb-n7,.my-n7{margin-bottom:-7px!important}.ml-n7,.mx-n7{margin-left:-7px!important}.m-n8{margin:-8px!important}.mt-n8,.my-n8{margin-top:-8px!important}.mr-n8,.mx-n8{margin-right:-8px!important}.mb-n8,.my-n8{margin-bottom:-8px!important}.ml-n8,.mx-n8{margin-left:-8px!important}.m-n9{margin:-9px!important}.mt-n9,.my-n9{margin-top:-9px!important}.mr-n9,.mx-n9{margin-right:-9px!important}.mb-n9,.my-n9{margin-bottom:-9px!important}.ml-n9,.mx-n9{margin-left:-9px!important}.m-n10{margin:-10px!important}.mt-n10,.my-n10{margin-top:-10px!important}.mr-n10,.mx-n10{margin-right:-10px!important}.mb-n10,.my-n10{margin-bottom:-10px!important}.ml-n10,.mx-n10{margin-left:-10px!important}.m-n11{margin:-11px!important}.mt-n11,.my-n11{margin-top:-11px!important}.mr-n11,.mx-n11{margin-right:-11px!important}.mb-n11,.my-n11{margin-bottom:-11px!important}.ml-n11,.mx-n11{margin-left:-11px!important}.m-n12{margin:-12px!important}.mt-n12,.my-n12{margin-top:-12px!important}.mr-n12,.mx-n12{margin-right:-12px!important}.mb-n12,.my-n12{margin-bottom:-12px!important}.ml-n12,.mx-n12{margin-left:-12px!important}.m-n13{margin:-13px!important}.mt-n13,.my-n13{margin-top:-13px!important}.mr-n13,.mx-n13{margin-right:-13px!important}.mb-n13,.my-n13{margin-bottom:-13px!important}.ml-n13,.mx-n13{margin-left:-13px!important}.m-n14{margin:-14px!important}.mt-n14,.my-n14{margin-top:-14px!important}.mr-n14,.mx-n14{margin-right:-14px!important}.mb-n14,.my-n14{margin-bottom:-14px!important}.ml-n14,.mx-n14{margin-left:-14px!important}.m-n15{margin:-15px!important}.mt-n15,.my-n15{margin-top:-15px!important}.mr-n15,.mx-n15{margin-right:-15px!important}.mb-n15,.my-n15{margin-bottom:-15px!important}.ml-n15,.mx-n15{margin-left:-15px!important}.m-n16{margin:-16px!important}.mt-n16,.my-n16{margin-top:-16px!important}.mr-n16,.mx-n16{margin-right:-16px!important}.mb-n16,.my-n16{margin-bottom:-16px!important}.ml-n16,.mx-n16{margin-left:-16px!important}.m-n18{margin:-18px!important}.mt-n18,.my-n18{margin-top:-18px!important}.mr-n18,.mx-n18{margin-right:-18px!important}.mb-n18,.my-n18{margin-bottom:-18px!important}.ml-n18,.mx-n18{margin-left:-18px!important}.m-n20{margin:-20px!important}.mt-n20,.my-n20{margin-top:-20px!important}.mr-n20,.mx-n20{margin-right:-20px!important}.mb-n20,.my-n20{margin-bottom:-20px!important}.ml-n20,.mx-n20{margin-left:-20px!important}.m-n21{margin:-21px!important}.mt-n21,.my-n21{margin-top:-21px!important}.mr-n21,.mx-n21{margin-right:-21px!important}.mb-n21,.my-n21{margin-bottom:-21px!important}.ml-n21,.mx-n21{margin-left:-21px!important}.m-n23{margin:-23px!important}.mt-n23,.my-n23{margin-top:-23px!important}.mr-n23,.mx-n23{margin-right:-23px!important}.mb-n23,.my-n23{margin-bottom:-23px!important}.ml-n23,.mx-n23{margin-left:-23px!important}.m-n24{margin:-24px!important}.mt-n24,.my-n24{margin-top:-24px!important}.mr-n24,.mx-n24{margin-right:-24px!important}.mb-n24,.my-n24{margin-bottom:-24px!important}.ml-n24,.mx-n24{margin-left:-24px!important}.m-n26{margin:-26px!important}.mt-n26,.my-n26{margin-top:-26px!important}.mr-n26,.mx-n26{margin-right:-26px!important}.mb-n26,.my-n26{margin-bottom:-26px!important}.ml-n26,.mx-n26{margin-left:-26px!important}.m-n28{margin:-28px!important}.mt-n28,.my-n28{margin-top:-28px!important}.mr-n28,.mx-n28{margin-right:-28px!important}.mb-n28,.my-n28{margin-bottom:-28px!important}.ml-n28,.mx-n28{margin-left:-28px!important}.m-n29{margin:-29px!important}.mt-n29,.my-n29{margin-top:-29px!important}.mr-n29,.mx-n29{margin-right:-29px!important}.mb-n29,.my-n29{margin-bottom:-29px!important}.ml-n29,.mx-n29{margin-left:-29px!important}.m-n30{margin:-30px!important}.mt-n30,.my-n30{margin-top:-30px!important}.mr-n30,.mx-n30{margin-right:-30px!important}.mb-n30,.my-n30{margin-bottom:-30px!important}.ml-n30,.mx-n30{margin-left:-30px!important}.m-n32{margin:-32px!important}.mt-n32,.my-n32{margin-top:-32px!important}.mr-n32,.mx-n32{margin-right:-32px!important}.mb-n32,.my-n32{margin-bottom:-32px!important}.ml-n32,.mx-n32{margin-left:-32px!important}.m-n38{margin:-38px!important}.mt-n38,.my-n38{margin-top:-38px!important}.mr-n38,.mx-n38{margin-right:-38px!important}.mb-n38,.my-n38{margin-bottom:-38px!important}.ml-n38,.mx-n38{margin-left:-38px!important}.m-n40{margin:-40px!important}.mt-n40,.my-n40{margin-top:-40px!important}.mr-n40,.mx-n40{margin-right:-40px!important}.mb-n40,.my-n40{margin-bottom:-40px!important}.ml-n40,.mx-n40{margin-left:-40px!important}.m-n42{margin:-42px!important}.mt-n42,.my-n42{margin-top:-42px!important}.mr-n42,.mx-n42{margin-right:-42px!important}.mb-n42,.my-n42{margin-bottom:-42px!important}.ml-n42,.mx-n42{margin-left:-42px!important}.m-n48{margin:-48px!important}.mt-n48,.my-n48{margin-top:-48px!important}.mr-n48,.mx-n48{margin-right:-48px!important}.mb-n48,.my-n48{margin-bottom:-48px!important}.ml-n48,.mx-n48{margin-left:-48px!important}.m-n50{margin:-50px!important}.mt-n50,.my-n50{margin-top:-50px!important}.mr-n50,.mx-n50{margin-right:-50px!important}.mb-n50,.my-n50{margin-bottom:-50px!important}.ml-n50,.mx-n50{margin-left:-50px!important}.m-n56{margin:-56px!important}.mt-n56,.my-n56{margin-top:-56px!important}.mr-n56,.mx-n56{margin-right:-56px!important}.mb-n56,.my-n56{margin-bottom:-56px!important}.ml-n56,.mx-n56{margin-left:-56px!important}.m-n58{margin:-58px!important}.mt-n58,.my-n58{margin-top:-58px!important}.mr-n58,.mx-n58{margin-right:-58px!important}.mb-n58,.my-n58{margin-bottom:-58px!important}.ml-n58,.mx-n58{margin-left:-58px!important}.m-n60{margin:-60px!important}.mt-n60,.my-n60{margin-top:-60px!important}.mr-n60,.mx-n60{margin-right:-60px!important}.mb-n60,.my-n60{margin-bottom:-60px!important}.ml-n60,.mx-n60{margin-left:-60px!important}.m-n64{margin:-64px!important}.mt-n64,.my-n64{margin-top:-64px!important}.mr-n64,.mx-n64{margin-right:-64px!important}.mb-n64,.my-n64{margin-bottom:-64px!important}.ml-n64,.mx-n64{margin-left:-64px!important}.m-auto{margin:auto!important}.mt-auto,.my-auto{margin-top:auto!important}.mr-auto,.mx-auto{margin-right:auto!important}.mb-auto,.my-auto{margin-bottom:auto!important}.ml-auto,.mx-auto{margin-left:auto!important}.stretched-link::after{position:absolute;top:0;right:0;bottom:0;left:0;z-index:1;pointer-events:auto;content:\"\";background-color:rgba(0,0,0,0)}.text-monospace{font-family:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace!important}.text-justify{text-align:justify!important}.text-wrap{white-space:normal!important}.text-nowrap{white-space:nowrap!important}.text-truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.text-left{text-align:left!important}.text-right{text-align:right!important}.text-center{text-align:center!important}@media (min-width:576px){.flex-sm-row{flex-direction:row!important}.flex-sm-column{flex-direction:column!important}.flex-sm-row-reverse{flex-direction:row-reverse!important}.flex-sm-column-reverse{flex-direction:column-reverse!important}.flex-sm-wrap{flex-wrap:wrap!important}.flex-sm-nowrap{flex-wrap:nowrap!important}.flex-sm-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-sm-fill{flex:1 1 auto!important}.flex-sm-grow-0{flex-grow:0!important}.flex-sm-grow-1{flex-grow:1!important}.flex-sm-shrink-0{flex-shrink:0!important}.flex-sm-shrink-1{flex-shrink:1!important}.justify-content-sm-start{justify-content:flex-start!important}.justify-content-sm-end{justify-content:flex-end!important}.justify-content-sm-center{justify-content:center!important}.justify-content-sm-between{justify-content:space-between!important}.justify-content-sm-around{justify-content:space-around!important}.align-items-sm-start{align-items:flex-start!important}.align-items-sm-end{align-items:flex-end!important}.align-items-sm-center{align-items:center!important}.align-items-sm-baseline{align-items:baseline!important}.align-items-sm-stretch{align-items:stretch!important}.align-content-sm-start{align-content:flex-start!important}.align-content-sm-end{align-content:flex-end!important}.align-content-sm-center{align-content:center!important}.align-content-sm-between{align-content:space-between!important}.align-content-sm-around{align-content:space-around!important}.align-content-sm-stretch{align-content:stretch!important}.align-self-sm-auto{align-self:auto!important}.align-self-sm-start{align-self:flex-start!important}.align-self-sm-end{align-self:flex-end!important}.align-self-sm-center{align-self:center!important}.align-self-sm-baseline{align-self:baseline!important}.align-self-sm-stretch{align-self:stretch!important}.float-sm-left{float:left!important}.float-sm-right{float:right!important}.float-sm-none{float:none!important}.m-sm-0{margin:0!important}.mt-sm-0,.my-sm-0{margin-top:0!important}.mr-sm-0,.mx-sm-0{margin-right:0!important}.mb-sm-0,.my-sm-0{margin-bottom:0!important}.ml-sm-0,.mx-sm-0{margin-left:0!important}.m-sm-1{margin:1px!important}.mt-sm-1,.my-sm-1{margin-top:1px!important}.mr-sm-1,.mx-sm-1{margin-right:1px!important}.mb-sm-1,.my-sm-1{margin-bottom:1px!important}.ml-sm-1,.mx-sm-1{margin-left:1px!important}.m-sm-2{margin:2px!important}.mt-sm-2,.my-sm-2{margin-top:2px!important}.mr-sm-2,.mx-sm-2{margin-right:2px!important}.mb-sm-2,.my-sm-2{margin-bottom:2px!important}.ml-sm-2,.mx-sm-2{margin-left:2px!important}.m-sm-3{margin:3px!important}.mt-sm-3,.my-sm-3{margin-top:3px!important}.mr-sm-3,.mx-sm-3{margin-right:3px!important}.mb-sm-3,.my-sm-3{margin-bottom:3px!important}.ml-sm-3,.mx-sm-3{margin-left:3px!important}.m-sm-4{margin:4px!important}.mt-sm-4,.my-sm-4{margin-top:4px!important}.mr-sm-4,.mx-sm-4{margin-right:4px!important}.mb-sm-4,.my-sm-4{margin-bottom:4px!important}.ml-sm-4,.mx-sm-4{margin-left:4px!important}.m-sm-5{margin:5px!important}.mt-sm-5,.my-sm-5{margin-top:5px!important}.mr-sm-5,.mx-sm-5{margin-right:5px!important}.mb-sm-5,.my-sm-5{margin-bottom:5px!important}.ml-sm-5,.mx-sm-5{margin-left:5px!important}.m-sm-6{margin:6px!important}.mt-sm-6,.my-sm-6{margin-top:6px!important}.mr-sm-6,.mx-sm-6{margin-right:6px!important}.mb-sm-6,.my-sm-6{margin-bottom:6px!important}.ml-sm-6,.mx-sm-6{margin-left:6px!important}.m-sm-7{margin:7px!important}.mt-sm-7,.my-sm-7{margin-top:7px!important}.mr-sm-7,.mx-sm-7{margin-right:7px!important}.mb-sm-7,.my-sm-7{margin-bottom:7px!important}.ml-sm-7,.mx-sm-7{margin-left:7px!important}.m-sm-8{margin:8px!important}.mt-sm-8,.my-sm-8{margin-top:8px!important}.mr-sm-8,.mx-sm-8{margin-right:8px!important}.mb-sm-8,.my-sm-8{margin-bottom:8px!important}.ml-sm-8,.mx-sm-8{margin-left:8px!important}.m-sm-9{margin:9px!important}.mt-sm-9,.my-sm-9{margin-top:9px!important}.mr-sm-9,.mx-sm-9{margin-right:9px!important}.mb-sm-9,.my-sm-9{margin-bottom:9px!important}.ml-sm-9,.mx-sm-9{margin-left:9px!important}.m-sm-10{margin:10px!important}.mt-sm-10,.my-sm-10{margin-top:10px!important}.mr-sm-10,.mx-sm-10{margin-right:10px!important}.mb-sm-10,.my-sm-10{margin-bottom:10px!important}.ml-sm-10,.mx-sm-10{margin-left:10px!important}.m-sm-11{margin:11px!important}.mt-sm-11,.my-sm-11{margin-top:11px!important}.mr-sm-11,.mx-sm-11{margin-right:11px!important}.mb-sm-11,.my-sm-11{margin-bottom:11px!important}.ml-sm-11,.mx-sm-11{margin-left:11px!important}.m-sm-12{margin:12px!important}.mt-sm-12,.my-sm-12{margin-top:12px!important}.mr-sm-12,.mx-sm-12{margin-right:12px!important}.mb-sm-12,.my-sm-12{margin-bottom:12px!important}.ml-sm-12,.mx-sm-12{margin-left:12px!important}.m-sm-13{margin:13px!important}.mt-sm-13,.my-sm-13{margin-top:13px!important}.mr-sm-13,.mx-sm-13{margin-right:13px!important}.mb-sm-13,.my-sm-13{margin-bottom:13px!important}.ml-sm-13,.mx-sm-13{margin-left:13px!important}.m-sm-14{margin:14px!important}.mt-sm-14,.my-sm-14{margin-top:14px!important}.mr-sm-14,.mx-sm-14{margin-right:14px!important}.mb-sm-14,.my-sm-14{margin-bottom:14px!important}.ml-sm-14,.mx-sm-14{margin-left:14px!important}.m-sm-15{margin:15px!important}.mt-sm-15,.my-sm-15{margin-top:15px!important}.mr-sm-15,.mx-sm-15{margin-right:15px!important}.mb-sm-15,.my-sm-15{margin-bottom:15px!important}.ml-sm-15,.mx-sm-15{margin-left:15px!important}.m-sm-16{margin:16px!important}.mt-sm-16,.my-sm-16{margin-top:16px!important}.mr-sm-16,.mx-sm-16{margin-right:16px!important}.mb-sm-16,.my-sm-16{margin-bottom:16px!important}.ml-sm-16,.mx-sm-16{margin-left:16px!important}.m-sm-18{margin:18px!important}.mt-sm-18,.my-sm-18{margin-top:18px!important}.mr-sm-18,.mx-sm-18{margin-right:18px!important}.mb-sm-18,.my-sm-18{margin-bottom:18px!important}.ml-sm-18,.mx-sm-18{margin-left:18px!important}.m-sm-20{margin:20px!important}.mt-sm-20,.my-sm-20{margin-top:20px!important}.mr-sm-20,.mx-sm-20{margin-right:20px!important}.mb-sm-20,.my-sm-20{margin-bottom:20px!important}.ml-sm-20,.mx-sm-20{margin-left:20px!important}.m-sm-21{margin:21px!important}.mt-sm-21,.my-sm-21{margin-top:21px!important}.mr-sm-21,.mx-sm-21{margin-right:21px!important}.mb-sm-21,.my-sm-21{margin-bottom:21px!important}.ml-sm-21,.mx-sm-21{margin-left:21px!important}.m-sm-23{margin:23px!important}.mt-sm-23,.my-sm-23{margin-top:23px!important}.mr-sm-23,.mx-sm-23{margin-right:23px!important}.mb-sm-23,.my-sm-23{margin-bottom:23px!important}.ml-sm-23,.mx-sm-23{margin-left:23px!important}.m-sm-24{margin:24px!important}.mt-sm-24,.my-sm-24{margin-top:24px!important}.mr-sm-24,.mx-sm-24{margin-right:24px!important}.mb-sm-24,.my-sm-24{margin-bottom:24px!important}.ml-sm-24,.mx-sm-24{margin-left:24px!important}.m-sm-26{margin:26px!important}.mt-sm-26,.my-sm-26{margin-top:26px!important}.mr-sm-26,.mx-sm-26{margin-right:26px!important}.mb-sm-26,.my-sm-26{margin-bottom:26px!important}.ml-sm-26,.mx-sm-26{margin-left:26px!important}.m-sm-28{margin:28px!important}.mt-sm-28,.my-sm-28{margin-top:28px!important}.mr-sm-28,.mx-sm-28{margin-right:28px!important}.mb-sm-28,.my-sm-28{margin-bottom:28px!important}.ml-sm-28,.mx-sm-28{margin-left:28px!important}.m-sm-29{margin:29px!important}.mt-sm-29,.my-sm-29{margin-top:29px!important}.mr-sm-29,.mx-sm-29{margin-right:29px!important}.mb-sm-29,.my-sm-29{margin-bottom:29px!important}.ml-sm-29,.mx-sm-29{margin-left:29px!important}.m-sm-30{margin:30px!important}.mt-sm-30,.my-sm-30{margin-top:30px!important}.mr-sm-30,.mx-sm-30{margin-right:30px!important}.mb-sm-30,.my-sm-30{margin-bottom:30px!important}.ml-sm-30,.mx-sm-30{margin-left:30px!important}.m-sm-32{margin:32px!important}.mt-sm-32,.my-sm-32{margin-top:32px!important}.mr-sm-32,.mx-sm-32{margin-right:32px!important}.mb-sm-32,.my-sm-32{margin-bottom:32px!important}.ml-sm-32,.mx-sm-32{margin-left:32px!important}.m-sm-38{margin:38px!important}.mt-sm-38,.my-sm-38{margin-top:38px!important}.mr-sm-38,.mx-sm-38{margin-right:38px!important}.mb-sm-38,.my-sm-38{margin-bottom:38px!important}.ml-sm-38,.mx-sm-38{margin-left:38px!important}.m-sm-40{margin:40px!important}.mt-sm-40,.my-sm-40{margin-top:40px!important}.mr-sm-40,.mx-sm-40{margin-right:40px!important}.mb-sm-40,.my-sm-40{margin-bottom:40px!important}.ml-sm-40,.mx-sm-40{margin-left:40px!important}.m-sm-42{margin:42px!important}.mt-sm-42,.my-sm-42{margin-top:42px!important}.mr-sm-42,.mx-sm-42{margin-right:42px!important}.mb-sm-42,.my-sm-42{margin-bottom:42px!important}.ml-sm-42,.mx-sm-42{margin-left:42px!important}.m-sm-48{margin:48px!important}.mt-sm-48,.my-sm-48{margin-top:48px!important}.mr-sm-48,.mx-sm-48{margin-right:48px!important}.mb-sm-48,.my-sm-48{margin-bottom:48px!important}.ml-sm-48,.mx-sm-48{margin-left:48px!important}.m-sm-50{margin:50px!important}.mt-sm-50,.my-sm-50{margin-top:50px!important}.mr-sm-50,.mx-sm-50{margin-right:50px!important}.mb-sm-50,.my-sm-50{margin-bottom:50px!important}.ml-sm-50,.mx-sm-50{margin-left:50px!important}.m-sm-56{margin:56px!important}.mt-sm-56,.my-sm-56{margin-top:56px!important}.mr-sm-56,.mx-sm-56{margin-right:56px!important}.mb-sm-56,.my-sm-56{margin-bottom:56px!important}.ml-sm-56,.mx-sm-56{margin-left:56px!important}.m-sm-58{margin:58px!important}.mt-sm-58,.my-sm-58{margin-top:58px!important}.mr-sm-58,.mx-sm-58{margin-right:58px!important}.mb-sm-58,.my-sm-58{margin-bottom:58px!important}.ml-sm-58,.mx-sm-58{margin-left:58px!important}.m-sm-60{margin:60px!important}.mt-sm-60,.my-sm-60{margin-top:60px!important}.mr-sm-60,.mx-sm-60{margin-right:60px!important}.mb-sm-60,.my-sm-60{margin-bottom:60px!important}.ml-sm-60,.mx-sm-60{margin-left:60px!important}.m-sm-64{margin:64px!important}.mt-sm-64,.my-sm-64{margin-top:64px!important}.mr-sm-64,.mx-sm-64{margin-right:64px!important}.mb-sm-64,.my-sm-64{margin-bottom:64px!important}.ml-sm-64,.mx-sm-64{margin-left:64px!important}.p-sm-0{padding:0!important}.pt-sm-0,.py-sm-0{padding-top:0!important}.pr-sm-0,.px-sm-0{padding-right:0!important}.pb-sm-0,.py-sm-0{padding-bottom:0!important}.pl-sm-0,.px-sm-0{padding-left:0!important}.p-sm-1{padding:1px!important}.pt-sm-1,.py-sm-1{padding-top:1px!important}.pr-sm-1,.px-sm-1{padding-right:1px!important}.pb-sm-1,.py-sm-1{padding-bottom:1px!important}.pl-sm-1,.px-sm-1{padding-left:1px!important}.p-sm-2{padding:2px!important}.pt-sm-2,.py-sm-2{padding-top:2px!important}.pr-sm-2,.px-sm-2{padding-right:2px!important}.pb-sm-2,.py-sm-2{padding-bottom:2px!important}.pl-sm-2,.px-sm-2{padding-left:2px!important}.p-sm-3{padding:3px!important}.pt-sm-3,.py-sm-3{padding-top:3px!important}.pr-sm-3,.px-sm-3{padding-right:3px!important}.pb-sm-3,.py-sm-3{padding-bottom:3px!important}.pl-sm-3,.px-sm-3{padding-left:3px!important}.p-sm-4{padding:4px!important}.pt-sm-4,.py-sm-4{padding-top:4px!important}.pr-sm-4,.px-sm-4{padding-right:4px!important}.pb-sm-4,.py-sm-4{padding-bottom:4px!important}.pl-sm-4,.px-sm-4{padding-left:4px!important}.p-sm-5{padding:5px!important}.pt-sm-5,.py-sm-5{padding-top:5px!important}.pr-sm-5,.px-sm-5{padding-right:5px!important}.pb-sm-5,.py-sm-5{padding-bottom:5px!important}.pl-sm-5,.px-sm-5{padding-left:5px!important}.p-sm-6{padding:6px!important}.pt-sm-6,.py-sm-6{padding-top:6px!important}.pr-sm-6,.px-sm-6{padding-right:6px!important}.pb-sm-6,.py-sm-6{padding-bottom:6px!important}.pl-sm-6,.px-sm-6{padding-left:6px!important}.p-sm-7{padding:7px!important}.pt-sm-7,.py-sm-7{padding-top:7px!important}.pr-sm-7,.px-sm-7{padding-right:7px!important}.pb-sm-7,.py-sm-7{padding-bottom:7px!important}.pl-sm-7,.px-sm-7{padding-left:7px!important}.p-sm-8{padding:8px!important}.pt-sm-8,.py-sm-8{padding-top:8px!important}.pr-sm-8,.px-sm-8{padding-right:8px!important}.pb-sm-8,.py-sm-8{padding-bottom:8px!important}.pl-sm-8,.px-sm-8{padding-left:8px!important}.p-sm-9{padding:9px!important}.pt-sm-9,.py-sm-9{padding-top:9px!important}.pr-sm-9,.px-sm-9{padding-right:9px!important}.pb-sm-9,.py-sm-9{padding-bottom:9px!important}.pl-sm-9,.px-sm-9{padding-left:9px!important}.p-sm-10{padding:10px!important}.pt-sm-10,.py-sm-10{padding-top:10px!important}.pr-sm-10,.px-sm-10{padding-right:10px!important}.pb-sm-10,.py-sm-10{padding-bottom:10px!important}.pl-sm-10,.px-sm-10{padding-left:10px!important}.p-sm-11{padding:11px!important}.pt-sm-11,.py-sm-11{padding-top:11px!important}.pr-sm-11,.px-sm-11{padding-right:11px!important}.pb-sm-11,.py-sm-11{padding-bottom:11px!important}.pl-sm-11,.px-sm-11{padding-left:11px!important}.p-sm-12{padding:12px!important}.pt-sm-12,.py-sm-12{padding-top:12px!important}.pr-sm-12,.px-sm-12{padding-right:12px!important}.pb-sm-12,.py-sm-12{padding-bottom:12px!important}.pl-sm-12,.px-sm-12{padding-left:12px!important}.p-sm-13{padding:13px!important}.pt-sm-13,.py-sm-13{padding-top:13px!important}.pr-sm-13,.px-sm-13{padding-right:13px!important}.pb-sm-13,.py-sm-13{padding-bottom:13px!important}.pl-sm-13,.px-sm-13{padding-left:13px!important}.p-sm-14{padding:14px!important}.pt-sm-14,.py-sm-14{padding-top:14px!important}.pr-sm-14,.px-sm-14{padding-right:14px!important}.pb-sm-14,.py-sm-14{padding-bottom:14px!important}.pl-sm-14,.px-sm-14{padding-left:14px!important}.p-sm-15{padding:15px!important}.pt-sm-15,.py-sm-15{padding-top:15px!important}.pr-sm-15,.px-sm-15{padding-right:15px!important}.pb-sm-15,.py-sm-15{padding-bottom:15px!important}.pl-sm-15,.px-sm-15{padding-left:15px!important}.p-sm-16{padding:16px!important}.pt-sm-16,.py-sm-16{padding-top:16px!important}.pr-sm-16,.px-sm-16{padding-right:16px!important}.pb-sm-16,.py-sm-16{padding-bottom:16px!important}.pl-sm-16,.px-sm-16{padding-left:16px!important}.p-sm-18{padding:18px!important}.pt-sm-18,.py-sm-18{padding-top:18px!important}.pr-sm-18,.px-sm-18{padding-right:18px!important}.pb-sm-18,.py-sm-18{padding-bottom:18px!important}.pl-sm-18,.px-sm-18{padding-left:18px!important}.p-sm-20{padding:20px!important}.pt-sm-20,.py-sm-20{padding-top:20px!important}.pr-sm-20,.px-sm-20{padding-right:20px!important}.pb-sm-20,.py-sm-20{padding-bottom:20px!important}.pl-sm-20,.px-sm-20{padding-left:20px!important}.p-sm-21{padding:21px!important}.pt-sm-21,.py-sm-21{padding-top:21px!important}.pr-sm-21,.px-sm-21{padding-right:21px!important}.pb-sm-21,.py-sm-21{padding-bottom:21px!important}.pl-sm-21,.px-sm-21{padding-left:21px!important}.p-sm-23{padding:23px!important}.pt-sm-23,.py-sm-23{padding-top:23px!important}.pr-sm-23,.px-sm-23{padding-right:23px!important}.pb-sm-23,.py-sm-23{padding-bottom:23px!important}.pl-sm-23,.px-sm-23{padding-left:23px!important}.p-sm-24{padding:24px!important}.pt-sm-24,.py-sm-24{padding-top:24px!important}.pr-sm-24,.px-sm-24{padding-right:24px!important}.pb-sm-24,.py-sm-24{padding-bottom:24px!important}.pl-sm-24,.px-sm-24{padding-left:24px!important}.p-sm-26{padding:26px!important}.pt-sm-26,.py-sm-26{padding-top:26px!important}.pr-sm-26,.px-sm-26{padding-right:26px!important}.pb-sm-26,.py-sm-26{padding-bottom:26px!important}.pl-sm-26,.px-sm-26{padding-left:26px!important}.p-sm-28{padding:28px!important}.pt-sm-28,.py-sm-28{padding-top:28px!important}.pr-sm-28,.px-sm-28{padding-right:28px!important}.pb-sm-28,.py-sm-28{padding-bottom:28px!important}.pl-sm-28,.px-sm-28{padding-left:28px!important}.p-sm-29{padding:29px!important}.pt-sm-29,.py-sm-29{padding-top:29px!important}.pr-sm-29,.px-sm-29{padding-right:29px!important}.pb-sm-29,.py-sm-29{padding-bottom:29px!important}.pl-sm-29,.px-sm-29{padding-left:29px!important}.p-sm-30{padding:30px!important}.pt-sm-30,.py-sm-30{padding-top:30px!important}.pr-sm-30,.px-sm-30{padding-right:30px!important}.pb-sm-30,.py-sm-30{padding-bottom:30px!important}.pl-sm-30,.px-sm-30{padding-left:30px!important}.p-sm-32{padding:32px!important}.pt-sm-32,.py-sm-32{padding-top:32px!important}.pr-sm-32,.px-sm-32{padding-right:32px!important}.pb-sm-32,.py-sm-32{padding-bottom:32px!important}.pl-sm-32,.px-sm-32{padding-left:32px!important}.p-sm-38{padding:38px!important}.pt-sm-38,.py-sm-38{padding-top:38px!important}.pr-sm-38,.px-sm-38{padding-right:38px!important}.pb-sm-38,.py-sm-38{padding-bottom:38px!important}.pl-sm-38,.px-sm-38{padding-left:38px!important}.p-sm-40{padding:40px!important}.pt-sm-40,.py-sm-40{padding-top:40px!important}.pr-sm-40,.px-sm-40{padding-right:40px!important}.pb-sm-40,.py-sm-40{padding-bottom:40px!important}.pl-sm-40,.px-sm-40{padding-left:40px!important}.p-sm-42{padding:42px!important}.pt-sm-42,.py-sm-42{padding-top:42px!important}.pr-sm-42,.px-sm-42{padding-right:42px!important}.pb-sm-42,.py-sm-42{padding-bottom:42px!important}.pl-sm-42,.px-sm-42{padding-left:42px!important}.p-sm-48{padding:48px!important}.pt-sm-48,.py-sm-48{padding-top:48px!important}.pr-sm-48,.px-sm-48{padding-right:48px!important}.pb-sm-48,.py-sm-48{padding-bottom:48px!important}.pl-sm-48,.px-sm-48{padding-left:48px!important}.p-sm-50{padding:50px!important}.pt-sm-50,.py-sm-50{padding-top:50px!important}.pr-sm-50,.px-sm-50{padding-right:50px!important}.pb-sm-50,.py-sm-50{padding-bottom:50px!important}.pl-sm-50,.px-sm-50{padding-left:50px!important}.p-sm-56{padding:56px!important}.pt-sm-56,.py-sm-56{padding-top:56px!important}.pr-sm-56,.px-sm-56{padding-right:56px!important}.pb-sm-56,.py-sm-56{padding-bottom:56px!important}.pl-sm-56,.px-sm-56{padding-left:56px!important}.p-sm-58{padding:58px!important}.pt-sm-58,.py-sm-58{padding-top:58px!important}.pr-sm-58,.px-sm-58{padding-right:58px!important}.pb-sm-58,.py-sm-58{padding-bottom:58px!important}.pl-sm-58,.px-sm-58{padding-left:58px!important}.p-sm-60{padding:60px!important}.pt-sm-60,.py-sm-60{padding-top:60px!important}.pr-sm-60,.px-sm-60{padding-right:60px!important}.pb-sm-60,.py-sm-60{padding-bottom:60px!important}.pl-sm-60,.px-sm-60{padding-left:60px!important}.p-sm-64{padding:64px!important}.pt-sm-64,.py-sm-64{padding-top:64px!important}.pr-sm-64,.px-sm-64{padding-right:64px!important}.pb-sm-64,.py-sm-64{padding-bottom:64px!important}.pl-sm-64,.px-sm-64{padding-left:64px!important}.m-sm-n1{margin:-1px!important}.mt-sm-n1,.my-sm-n1{margin-top:-1px!important}.mr-sm-n1,.mx-sm-n1{margin-right:-1px!important}.mb-sm-n1,.my-sm-n1{margin-bottom:-1px!important}.ml-sm-n1,.mx-sm-n1{margin-left:-1px!important}.m-sm-n2{margin:-2px!important}.mt-sm-n2,.my-sm-n2{margin-top:-2px!important}.mr-sm-n2,.mx-sm-n2{margin-right:-2px!important}.mb-sm-n2,.my-sm-n2{margin-bottom:-2px!important}.ml-sm-n2,.mx-sm-n2{margin-left:-2px!important}.m-sm-n3{margin:-3px!important}.mt-sm-n3,.my-sm-n3{margin-top:-3px!important}.mr-sm-n3,.mx-sm-n3{margin-right:-3px!important}.mb-sm-n3,.my-sm-n3{margin-bottom:-3px!important}.ml-sm-n3,.mx-sm-n3{margin-left:-3px!important}.m-sm-n4{margin:-4px!important}.mt-sm-n4,.my-sm-n4{margin-top:-4px!important}.mr-sm-n4,.mx-sm-n4{margin-right:-4px!important}.mb-sm-n4,.my-sm-n4{margin-bottom:-4px!important}.ml-sm-n4,.mx-sm-n4{margin-left:-4px!important}.m-sm-n5{margin:-5px!important}.mt-sm-n5,.my-sm-n5{margin-top:-5px!important}.mr-sm-n5,.mx-sm-n5{margin-right:-5px!important}.mb-sm-n5,.my-sm-n5{margin-bottom:-5px!important}.ml-sm-n5,.mx-sm-n5{margin-left:-5px!important}.m-sm-n6{margin:-6px!important}.mt-sm-n6,.my-sm-n6{margin-top:-6px!important}.mr-sm-n6,.mx-sm-n6{margin-right:-6px!important}.mb-sm-n6,.my-sm-n6{margin-bottom:-6px!important}.ml-sm-n6,.mx-sm-n6{margin-left:-6px!important}.m-sm-n7{margin:-7px!important}.mt-sm-n7,.my-sm-n7{margin-top:-7px!important}.mr-sm-n7,.mx-sm-n7{margin-right:-7px!important}.mb-sm-n7,.my-sm-n7{margin-bottom:-7px!important}.ml-sm-n7,.mx-sm-n7{margin-left:-7px!important}.m-sm-n8{margin:-8px!important}.mt-sm-n8,.my-sm-n8{margin-top:-8px!important}.mr-sm-n8,.mx-sm-n8{margin-right:-8px!important}.mb-sm-n8,.my-sm-n8{margin-bottom:-8px!important}.ml-sm-n8,.mx-sm-n8{margin-left:-8px!important}.m-sm-n9{margin:-9px!important}.mt-sm-n9,.my-sm-n9{margin-top:-9px!important}.mr-sm-n9,.mx-sm-n9{margin-right:-9px!important}.mb-sm-n9,.my-sm-n9{margin-bottom:-9px!important}.ml-sm-n9,.mx-sm-n9{margin-left:-9px!important}.m-sm-n10{margin:-10px!important}.mt-sm-n10,.my-sm-n10{margin-top:-10px!important}.mr-sm-n10,.mx-sm-n10{margin-right:-10px!important}.mb-sm-n10,.my-sm-n10{margin-bottom:-10px!important}.ml-sm-n10,.mx-sm-n10{margin-left:-10px!important}.m-sm-n11{margin:-11px!important}.mt-sm-n11,.my-sm-n11{margin-top:-11px!important}.mr-sm-n11,.mx-sm-n11{margin-right:-11px!important}.mb-sm-n11,.my-sm-n11{margin-bottom:-11px!important}.ml-sm-n11,.mx-sm-n11{margin-left:-11px!important}.m-sm-n12{margin:-12px!important}.mt-sm-n12,.my-sm-n12{margin-top:-12px!important}.mr-sm-n12,.mx-sm-n12{margin-right:-12px!important}.mb-sm-n12,.my-sm-n12{margin-bottom:-12px!important}.ml-sm-n12,.mx-sm-n12{margin-left:-12px!important}.m-sm-n13{margin:-13px!important}.mt-sm-n13,.my-sm-n13{margin-top:-13px!important}.mr-sm-n13,.mx-sm-n13{margin-right:-13px!important}.mb-sm-n13,.my-sm-n13{margin-bottom:-13px!important}.ml-sm-n13,.mx-sm-n13{margin-left:-13px!important}.m-sm-n14{margin:-14px!important}.mt-sm-n14,.my-sm-n14{margin-top:-14px!important}.mr-sm-n14,.mx-sm-n14{margin-right:-14px!important}.mb-sm-n14,.my-sm-n14{margin-bottom:-14px!important}.ml-sm-n14,.mx-sm-n14{margin-left:-14px!important}.m-sm-n15{margin:-15px!important}.mt-sm-n15,.my-sm-n15{margin-top:-15px!important}.mr-sm-n15,.mx-sm-n15{margin-right:-15px!important}.mb-sm-n15,.my-sm-n15{margin-bottom:-15px!important}.ml-sm-n15,.mx-sm-n15{margin-left:-15px!important}.m-sm-n16{margin:-16px!important}.mt-sm-n16,.my-sm-n16{margin-top:-16px!important}.mr-sm-n16,.mx-sm-n16{margin-right:-16px!important}.mb-sm-n16,.my-sm-n16{margin-bottom:-16px!important}.ml-sm-n16,.mx-sm-n16{margin-left:-16px!important}.m-sm-n18{margin:-18px!important}.mt-sm-n18,.my-sm-n18{margin-top:-18px!important}.mr-sm-n18,.mx-sm-n18{margin-right:-18px!important}.mb-sm-n18,.my-sm-n18{margin-bottom:-18px!important}.ml-sm-n18,.mx-sm-n18{margin-left:-18px!important}.m-sm-n20{margin:-20px!important}.mt-sm-n20,.my-sm-n20{margin-top:-20px!important}.mr-sm-n20,.mx-sm-n20{margin-right:-20px!important}.mb-sm-n20,.my-sm-n20{margin-bottom:-20px!important}.ml-sm-n20,.mx-sm-n20{margin-left:-20px!important}.m-sm-n21{margin:-21px!important}.mt-sm-n21,.my-sm-n21{margin-top:-21px!important}.mr-sm-n21,.mx-sm-n21{margin-right:-21px!important}.mb-sm-n21,.my-sm-n21{margin-bottom:-21px!important}.ml-sm-n21,.mx-sm-n21{margin-left:-21px!important}.m-sm-n23{margin:-23px!important}.mt-sm-n23,.my-sm-n23{margin-top:-23px!important}.mr-sm-n23,.mx-sm-n23{margin-right:-23px!important}.mb-sm-n23,.my-sm-n23{margin-bottom:-23px!important}.ml-sm-n23,.mx-sm-n23{margin-left:-23px!important}.m-sm-n24{margin:-24px!important}.mt-sm-n24,.my-sm-n24{margin-top:-24px!important}.mr-sm-n24,.mx-sm-n24{margin-right:-24px!important}.mb-sm-n24,.my-sm-n24{margin-bottom:-24px!important}.ml-sm-n24,.mx-sm-n24{margin-left:-24px!important}.m-sm-n26{margin:-26px!important}.mt-sm-n26,.my-sm-n26{margin-top:-26px!important}.mr-sm-n26,.mx-sm-n26{margin-right:-26px!important}.mb-sm-n26,.my-sm-n26{margin-bottom:-26px!important}.ml-sm-n26,.mx-sm-n26{margin-left:-26px!important}.m-sm-n28{margin:-28px!important}.mt-sm-n28,.my-sm-n28{margin-top:-28px!important}.mr-sm-n28,.mx-sm-n28{margin-right:-28px!important}.mb-sm-n28,.my-sm-n28{margin-bottom:-28px!important}.ml-sm-n28,.mx-sm-n28{margin-left:-28px!important}.m-sm-n29{margin:-29px!important}.mt-sm-n29,.my-sm-n29{margin-top:-29px!important}.mr-sm-n29,.mx-sm-n29{margin-right:-29px!important}.mb-sm-n29,.my-sm-n29{margin-bottom:-29px!important}.ml-sm-n29,.mx-sm-n29{margin-left:-29px!important}.m-sm-n30{margin:-30px!important}.mt-sm-n30,.my-sm-n30{margin-top:-30px!important}.mr-sm-n30,.mx-sm-n30{margin-right:-30px!important}.mb-sm-n30,.my-sm-n30{margin-bottom:-30px!important}.ml-sm-n30,.mx-sm-n30{margin-left:-30px!important}.m-sm-n32{margin:-32px!important}.mt-sm-n32,.my-sm-n32{margin-top:-32px!important}.mr-sm-n32,.mx-sm-n32{margin-right:-32px!important}.mb-sm-n32,.my-sm-n32{margin-bottom:-32px!important}.ml-sm-n32,.mx-sm-n32{margin-left:-32px!important}.m-sm-n38{margin:-38px!important}.mt-sm-n38,.my-sm-n38{margin-top:-38px!important}.mr-sm-n38,.mx-sm-n38{margin-right:-38px!important}.mb-sm-n38,.my-sm-n38{margin-bottom:-38px!important}.ml-sm-n38,.mx-sm-n38{margin-left:-38px!important}.m-sm-n40{margin:-40px!important}.mt-sm-n40,.my-sm-n40{margin-top:-40px!important}.mr-sm-n40,.mx-sm-n40{margin-right:-40px!important}.mb-sm-n40,.my-sm-n40{margin-bottom:-40px!important}.ml-sm-n40,.mx-sm-n40{margin-left:-40px!important}.m-sm-n42{margin:-42px!important}.mt-sm-n42,.my-sm-n42{margin-top:-42px!important}.mr-sm-n42,.mx-sm-n42{margin-right:-42px!important}.mb-sm-n42,.my-sm-n42{margin-bottom:-42px!important}.ml-sm-n42,.mx-sm-n42{margin-left:-42px!important}.m-sm-n48{margin:-48px!important}.mt-sm-n48,.my-sm-n48{margin-top:-48px!important}.mr-sm-n48,.mx-sm-n48{margin-right:-48px!important}.mb-sm-n48,.my-sm-n48{margin-bottom:-48px!important}.ml-sm-n48,.mx-sm-n48{margin-left:-48px!important}.m-sm-n50{margin:-50px!important}.mt-sm-n50,.my-sm-n50{margin-top:-50px!important}.mr-sm-n50,.mx-sm-n50{margin-right:-50px!important}.mb-sm-n50,.my-sm-n50{margin-bottom:-50px!important}.ml-sm-n50,.mx-sm-n50{margin-left:-50px!important}.m-sm-n56{margin:-56px!important}.mt-sm-n56,.my-sm-n56{margin-top:-56px!important}.mr-sm-n56,.mx-sm-n56{margin-right:-56px!important}.mb-sm-n56,.my-sm-n56{margin-bottom:-56px!important}.ml-sm-n56,.mx-sm-n56{margin-left:-56px!important}.m-sm-n58{margin:-58px!important}.mt-sm-n58,.my-sm-n58{margin-top:-58px!important}.mr-sm-n58,.mx-sm-n58{margin-right:-58px!important}.mb-sm-n58,.my-sm-n58{margin-bottom:-58px!important}.ml-sm-n58,.mx-sm-n58{margin-left:-58px!important}.m-sm-n60{margin:-60px!important}.mt-sm-n60,.my-sm-n60{margin-top:-60px!important}.mr-sm-n60,.mx-sm-n60{margin-right:-60px!important}.mb-sm-n60,.my-sm-n60{margin-bottom:-60px!important}.ml-sm-n60,.mx-sm-n60{margin-left:-60px!important}.m-sm-n64{margin:-64px!important}.mt-sm-n64,.my-sm-n64{margin-top:-64px!important}.mr-sm-n64,.mx-sm-n64{margin-right:-64px!important}.mb-sm-n64,.my-sm-n64{margin-bottom:-64px!important}.ml-sm-n64,.mx-sm-n64{margin-left:-64px!important}.m-sm-auto{margin:auto!important}.mt-sm-auto,.my-sm-auto{margin-top:auto!important}.mr-sm-auto,.mx-sm-auto{margin-right:auto!important}.mb-sm-auto,.my-sm-auto{margin-bottom:auto!important}.ml-sm-auto,.mx-sm-auto{margin-left:auto!important}.text-sm-left{text-align:left!important}.text-sm-right{text-align:right!important}.text-sm-center{text-align:center!important}}@media (min-width:768px){.flex-md-row{flex-direction:row!important}.flex-md-column{flex-direction:column!important}.flex-md-row-reverse{flex-direction:row-reverse!important}.flex-md-column-reverse{flex-direction:column-reverse!important}.flex-md-wrap{flex-wrap:wrap!important}.flex-md-nowrap{flex-wrap:nowrap!important}.flex-md-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-md-fill{flex:1 1 auto!important}.flex-md-grow-0{flex-grow:0!important}.flex-md-grow-1{flex-grow:1!important}.flex-md-shrink-0{flex-shrink:0!important}.flex-md-shrink-1{flex-shrink:1!important}.justify-content-md-start{justify-content:flex-start!important}.justify-content-md-end{justify-content:flex-end!important}.justify-content-md-center{justify-content:center!important}.justify-content-md-between{justify-content:space-between!important}.justify-content-md-around{justify-content:space-around!important}.align-items-md-start{align-items:flex-start!important}.align-items-md-end{align-items:flex-end!important}.align-items-md-center{align-items:center!important}.align-items-md-baseline{align-items:baseline!important}.align-items-md-stretch{align-items:stretch!important}.align-content-md-start{align-content:flex-start!important}.align-content-md-end{align-content:flex-end!important}.align-content-md-center{align-content:center!important}.align-content-md-between{align-content:space-between!important}.align-content-md-around{align-content:space-around!important}.align-content-md-stretch{align-content:stretch!important}.align-self-md-auto{align-self:auto!important}.align-self-md-start{align-self:flex-start!important}.align-self-md-end{align-self:flex-end!important}.align-self-md-center{align-self:center!important}.align-self-md-baseline{align-self:baseline!important}.align-self-md-stretch{align-self:stretch!important}.float-md-left{float:left!important}.float-md-right{float:right!important}.float-md-none{float:none!important}.m-md-0{margin:0!important}.mt-md-0,.my-md-0{margin-top:0!important}.mr-md-0,.mx-md-0{margin-right:0!important}.mb-md-0,.my-md-0{margin-bottom:0!important}.ml-md-0,.mx-md-0{margin-left:0!important}.m-md-1{margin:1px!important}.mt-md-1,.my-md-1{margin-top:1px!important}.mr-md-1,.mx-md-1{margin-right:1px!important}.mb-md-1,.my-md-1{margin-bottom:1px!important}.ml-md-1,.mx-md-1{margin-left:1px!important}.m-md-2{margin:2px!important}.mt-md-2,.my-md-2{margin-top:2px!important}.mr-md-2,.mx-md-2{margin-right:2px!important}.mb-md-2,.my-md-2{margin-bottom:2px!important}.ml-md-2,.mx-md-2{margin-left:2px!important}.m-md-3{margin:3px!important}.mt-md-3,.my-md-3{margin-top:3px!important}.mr-md-3,.mx-md-3{margin-right:3px!important}.mb-md-3,.my-md-3{margin-bottom:3px!important}.ml-md-3,.mx-md-3{margin-left:3px!important}.m-md-4{margin:4px!important}.mt-md-4,.my-md-4{margin-top:4px!important}.mr-md-4,.mx-md-4{margin-right:4px!important}.mb-md-4,.my-md-4{margin-bottom:4px!important}.ml-md-4,.mx-md-4{margin-left:4px!important}.m-md-5{margin:5px!important}.mt-md-5,.my-md-5{margin-top:5px!important}.mr-md-5,.mx-md-5{margin-right:5px!important}.mb-md-5,.my-md-5{margin-bottom:5px!important}.ml-md-5,.mx-md-5{margin-left:5px!important}.m-md-6{margin:6px!important}.mt-md-6,.my-md-6{margin-top:6px!important}.mr-md-6,.mx-md-6{margin-right:6px!important}.mb-md-6,.my-md-6{margin-bottom:6px!important}.ml-md-6,.mx-md-6{margin-left:6px!important}.m-md-7{margin:7px!important}.mt-md-7,.my-md-7{margin-top:7px!important}.mr-md-7,.mx-md-7{margin-right:7px!important}.mb-md-7,.my-md-7{margin-bottom:7px!important}.ml-md-7,.mx-md-7{margin-left:7px!important}.m-md-8{margin:8px!important}.mt-md-8,.my-md-8{margin-top:8px!important}.mr-md-8,.mx-md-8{margin-right:8px!important}.mb-md-8,.my-md-8{margin-bottom:8px!important}.ml-md-8,.mx-md-8{margin-left:8px!important}.m-md-9{margin:9px!important}.mt-md-9,.my-md-9{margin-top:9px!important}.mr-md-9,.mx-md-9{margin-right:9px!important}.mb-md-9,.my-md-9{margin-bottom:9px!important}.ml-md-9,.mx-md-9{margin-left:9px!important}.m-md-10{margin:10px!important}.mt-md-10,.my-md-10{margin-top:10px!important}.mr-md-10,.mx-md-10{margin-right:10px!important}.mb-md-10,.my-md-10{margin-bottom:10px!important}.ml-md-10,.mx-md-10{margin-left:10px!important}.m-md-11{margin:11px!important}.mt-md-11,.my-md-11{margin-top:11px!important}.mr-md-11,.mx-md-11{margin-right:11px!important}.mb-md-11,.my-md-11{margin-bottom:11px!important}.ml-md-11,.mx-md-11{margin-left:11px!important}.m-md-12{margin:12px!important}.mt-md-12,.my-md-12{margin-top:12px!important}.mr-md-12,.mx-md-12{margin-right:12px!important}.mb-md-12,.my-md-12{margin-bottom:12px!important}.ml-md-12,.mx-md-12{margin-left:12px!important}.m-md-13{margin:13px!important}.mt-md-13,.my-md-13{margin-top:13px!important}.mr-md-13,.mx-md-13{margin-right:13px!important}.mb-md-13,.my-md-13{margin-bottom:13px!important}.ml-md-13,.mx-md-13{margin-left:13px!important}.m-md-14{margin:14px!important}.mt-md-14,.my-md-14{margin-top:14px!important}.mr-md-14,.mx-md-14{margin-right:14px!important}.mb-md-14,.my-md-14{margin-bottom:14px!important}.ml-md-14,.mx-md-14{margin-left:14px!important}.m-md-15{margin:15px!important}.mt-md-15,.my-md-15{margin-top:15px!important}.mr-md-15,.mx-md-15{margin-right:15px!important}.mb-md-15,.my-md-15{margin-bottom:15px!important}.ml-md-15,.mx-md-15{margin-left:15px!important}.m-md-16{margin:16px!important}.mt-md-16,.my-md-16{margin-top:16px!important}.mr-md-16,.mx-md-16{margin-right:16px!important}.mb-md-16,.my-md-16{margin-bottom:16px!important}.ml-md-16,.mx-md-16{margin-left:16px!important}.m-md-18{margin:18px!important}.mt-md-18,.my-md-18{margin-top:18px!important}.mr-md-18,.mx-md-18{margin-right:18px!important}.mb-md-18,.my-md-18{margin-bottom:18px!important}.ml-md-18,.mx-md-18{margin-left:18px!important}.m-md-20{margin:20px!important}.mt-md-20,.my-md-20{margin-top:20px!important}.mr-md-20,.mx-md-20{margin-right:20px!important}.mb-md-20,.my-md-20{margin-bottom:20px!important}.ml-md-20,.mx-md-20{margin-left:20px!important}.m-md-21{margin:21px!important}.mt-md-21,.my-md-21{margin-top:21px!important}.mr-md-21,.mx-md-21{margin-right:21px!important}.mb-md-21,.my-md-21{margin-bottom:21px!important}.ml-md-21,.mx-md-21{margin-left:21px!important}.m-md-23{margin:23px!important}.mt-md-23,.my-md-23{margin-top:23px!important}.mr-md-23,.mx-md-23{margin-right:23px!important}.mb-md-23,.my-md-23{margin-bottom:23px!important}.ml-md-23,.mx-md-23{margin-left:23px!important}.m-md-24{margin:24px!important}.mt-md-24,.my-md-24{margin-top:24px!important}.mr-md-24,.mx-md-24{margin-right:24px!important}.mb-md-24,.my-md-24{margin-bottom:24px!important}.ml-md-24,.mx-md-24{margin-left:24px!important}.m-md-26{margin:26px!important}.mt-md-26,.my-md-26{margin-top:26px!important}.mr-md-26,.mx-md-26{margin-right:26px!important}.mb-md-26,.my-md-26{margin-bottom:26px!important}.ml-md-26,.mx-md-26{margin-left:26px!important}.m-md-28{margin:28px!important}.mt-md-28,.my-md-28{margin-top:28px!important}.mr-md-28,.mx-md-28{margin-right:28px!important}.mb-md-28,.my-md-28{margin-bottom:28px!important}.ml-md-28,.mx-md-28{margin-left:28px!important}.m-md-29{margin:29px!important}.mt-md-29,.my-md-29{margin-top:29px!important}.mr-md-29,.mx-md-29{margin-right:29px!important}.mb-md-29,.my-md-29{margin-bottom:29px!important}.ml-md-29,.mx-md-29{margin-left:29px!important}.m-md-30{margin:30px!important}.mt-md-30,.my-md-30{margin-top:30px!important}.mr-md-30,.mx-md-30{margin-right:30px!important}.mb-md-30,.my-md-30{margin-bottom:30px!important}.ml-md-30,.mx-md-30{margin-left:30px!important}.m-md-32{margin:32px!important}.mt-md-32,.my-md-32{margin-top:32px!important}.mr-md-32,.mx-md-32{margin-right:32px!important}.mb-md-32,.my-md-32{margin-bottom:32px!important}.ml-md-32,.mx-md-32{margin-left:32px!important}.m-md-38{margin:38px!important}.mt-md-38,.my-md-38{margin-top:38px!important}.mr-md-38,.mx-md-38{margin-right:38px!important}.mb-md-38,.my-md-38{margin-bottom:38px!important}.ml-md-38,.mx-md-38{margin-left:38px!important}.m-md-40{margin:40px!important}.mt-md-40,.my-md-40{margin-top:40px!important}.mr-md-40,.mx-md-40{margin-right:40px!important}.mb-md-40,.my-md-40{margin-bottom:40px!important}.ml-md-40,.mx-md-40{margin-left:40px!important}.m-md-42{margin:42px!important}.mt-md-42,.my-md-42{margin-top:42px!important}.mr-md-42,.mx-md-42{margin-right:42px!important}.mb-md-42,.my-md-42{margin-bottom:42px!important}.ml-md-42,.mx-md-42{margin-left:42px!important}.m-md-48{margin:48px!important}.mt-md-48,.my-md-48{margin-top:48px!important}.mr-md-48,.mx-md-48{margin-right:48px!important}.mb-md-48,.my-md-48{margin-bottom:48px!important}.ml-md-48,.mx-md-48{margin-left:48px!important}.m-md-50{margin:50px!important}.mt-md-50,.my-md-50{margin-top:50px!important}.mr-md-50,.mx-md-50{margin-right:50px!important}.mb-md-50,.my-md-50{margin-bottom:50px!important}.ml-md-50,.mx-md-50{margin-left:50px!important}.m-md-56{margin:56px!important}.mt-md-56,.my-md-56{margin-top:56px!important}.mr-md-56,.mx-md-56{margin-right:56px!important}.mb-md-56,.my-md-56{margin-bottom:56px!important}.ml-md-56,.mx-md-56{margin-left:56px!important}.m-md-58{margin:58px!important}.mt-md-58,.my-md-58{margin-top:58px!important}.mr-md-58,.mx-md-58{margin-right:58px!important}.mb-md-58,.my-md-58{margin-bottom:58px!important}.ml-md-58,.mx-md-58{margin-left:58px!important}.m-md-60{margin:60px!important}.mt-md-60,.my-md-60{margin-top:60px!important}.mr-md-60,.mx-md-60{margin-right:60px!important}.mb-md-60,.my-md-60{margin-bottom:60px!important}.ml-md-60,.mx-md-60{margin-left:60px!important}.m-md-64{margin:64px!important}.mt-md-64,.my-md-64{margin-top:64px!important}.mr-md-64,.mx-md-64{margin-right:64px!important}.mb-md-64,.my-md-64{margin-bottom:64px!important}.ml-md-64,.mx-md-64{margin-left:64px!important}.p-md-0{padding:0!important}.pt-md-0,.py-md-0{padding-top:0!important}.pr-md-0,.px-md-0{padding-right:0!important}.pb-md-0,.py-md-0{padding-bottom:0!important}.pl-md-0,.px-md-0{padding-left:0!important}.p-md-1{padding:1px!important}.pt-md-1,.py-md-1{padding-top:1px!important}.pr-md-1,.px-md-1{padding-right:1px!important}.pb-md-1,.py-md-1{padding-bottom:1px!important}.pl-md-1,.px-md-1{padding-left:1px!important}.p-md-2{padding:2px!important}.pt-md-2,.py-md-2{padding-top:2px!important}.pr-md-2,.px-md-2{padding-right:2px!important}.pb-md-2,.py-md-2{padding-bottom:2px!important}.pl-md-2,.px-md-2{padding-left:2px!important}.p-md-3{padding:3px!important}.pt-md-3,.py-md-3{padding-top:3px!important}.pr-md-3,.px-md-3{padding-right:3px!important}.pb-md-3,.py-md-3{padding-bottom:3px!important}.pl-md-3,.px-md-3{padding-left:3px!important}.p-md-4{padding:4px!important}.pt-md-4,.py-md-4{padding-top:4px!important}.pr-md-4,.px-md-4{padding-right:4px!important}.pb-md-4,.py-md-4{padding-bottom:4px!important}.pl-md-4,.px-md-4{padding-left:4px!important}.p-md-5{padding:5px!important}.pt-md-5,.py-md-5{padding-top:5px!important}.pr-md-5,.px-md-5{padding-right:5px!important}.pb-md-5,.py-md-5{padding-bottom:5px!important}.pl-md-5,.px-md-5{padding-left:5px!important}.p-md-6{padding:6px!important}.pt-md-6,.py-md-6{padding-top:6px!important}.pr-md-6,.px-md-6{padding-right:6px!important}.pb-md-6,.py-md-6{padding-bottom:6px!important}.pl-md-6,.px-md-6{padding-left:6px!important}.p-md-7{padding:7px!important}.pt-md-7,.py-md-7{padding-top:7px!important}.pr-md-7,.px-md-7{padding-right:7px!important}.pb-md-7,.py-md-7{padding-bottom:7px!important}.pl-md-7,.px-md-7{padding-left:7px!important}.p-md-8{padding:8px!important}.pt-md-8,.py-md-8{padding-top:8px!important}.pr-md-8,.px-md-8{padding-right:8px!important}.pb-md-8,.py-md-8{padding-bottom:8px!important}.pl-md-8,.px-md-8{padding-left:8px!important}.p-md-9{padding:9px!important}.pt-md-9,.py-md-9{padding-top:9px!important}.pr-md-9,.px-md-9{padding-right:9px!important}.pb-md-9,.py-md-9{padding-bottom:9px!important}.pl-md-9,.px-md-9{padding-left:9px!important}.p-md-10{padding:10px!important}.pt-md-10,.py-md-10{padding-top:10px!important}.pr-md-10,.px-md-10{padding-right:10px!important}.pb-md-10,.py-md-10{padding-bottom:10px!important}.pl-md-10,.px-md-10{padding-left:10px!important}.p-md-11{padding:11px!important}.pt-md-11,.py-md-11{padding-top:11px!important}.pr-md-11,.px-md-11{padding-right:11px!important}.pb-md-11,.py-md-11{padding-bottom:11px!important}.pl-md-11,.px-md-11{padding-left:11px!important}.p-md-12{padding:12px!important}.pt-md-12,.py-md-12{padding-top:12px!important}.pr-md-12,.px-md-12{padding-right:12px!important}.pb-md-12,.py-md-12{padding-bottom:12px!important}.pl-md-12,.px-md-12{padding-left:12px!important}.p-md-13{padding:13px!important}.pt-md-13,.py-md-13{padding-top:13px!important}.pr-md-13,.px-md-13{padding-right:13px!important}.pb-md-13,.py-md-13{padding-bottom:13px!important}.pl-md-13,.px-md-13{padding-left:13px!important}.p-md-14{padding:14px!important}.pt-md-14,.py-md-14{padding-top:14px!important}.pr-md-14,.px-md-14{padding-right:14px!important}.pb-md-14,.py-md-14{padding-bottom:14px!important}.pl-md-14,.px-md-14{padding-left:14px!important}.p-md-15{padding:15px!important}.pt-md-15,.py-md-15{padding-top:15px!important}.pr-md-15,.px-md-15{padding-right:15px!important}.pb-md-15,.py-md-15{padding-bottom:15px!important}.pl-md-15,.px-md-15{padding-left:15px!important}.p-md-16{padding:16px!important}.pt-md-16,.py-md-16{padding-top:16px!important}.pr-md-16,.px-md-16{padding-right:16px!important}.pb-md-16,.py-md-16{padding-bottom:16px!important}.pl-md-16,.px-md-16{padding-left:16px!important}.p-md-18{padding:18px!important}.pt-md-18,.py-md-18{padding-top:18px!important}.pr-md-18,.px-md-18{padding-right:18px!important}.pb-md-18,.py-md-18{padding-bottom:18px!important}.pl-md-18,.px-md-18{padding-left:18px!important}.p-md-20{padding:20px!important}.pt-md-20,.py-md-20{padding-top:20px!important}.pr-md-20,.px-md-20{padding-right:20px!important}.pb-md-20,.py-md-20{padding-bottom:20px!important}.pl-md-20,.px-md-20{padding-left:20px!important}.p-md-21{padding:21px!important}.pt-md-21,.py-md-21{padding-top:21px!important}.pr-md-21,.px-md-21{padding-right:21px!important}.pb-md-21,.py-md-21{padding-bottom:21px!important}.pl-md-21,.px-md-21{padding-left:21px!important}.p-md-23{padding:23px!important}.pt-md-23,.py-md-23{padding-top:23px!important}.pr-md-23,.px-md-23{padding-right:23px!important}.pb-md-23,.py-md-23{padding-bottom:23px!important}.pl-md-23,.px-md-23{padding-left:23px!important}.p-md-24{padding:24px!important}.pt-md-24,.py-md-24{padding-top:24px!important}.pr-md-24,.px-md-24{padding-right:24px!important}.pb-md-24,.py-md-24{padding-bottom:24px!important}.pl-md-24,.px-md-24{padding-left:24px!important}.p-md-26{padding:26px!important}.pt-md-26,.py-md-26{padding-top:26px!important}.pr-md-26,.px-md-26{padding-right:26px!important}.pb-md-26,.py-md-26{padding-bottom:26px!important}.pl-md-26,.px-md-26{padding-left:26px!important}.p-md-28{padding:28px!important}.pt-md-28,.py-md-28{padding-top:28px!important}.pr-md-28,.px-md-28{padding-right:28px!important}.pb-md-28,.py-md-28{padding-bottom:28px!important}.pl-md-28,.px-md-28{padding-left:28px!important}.p-md-29{padding:29px!important}.pt-md-29,.py-md-29{padding-top:29px!important}.pr-md-29,.px-md-29{padding-right:29px!important}.pb-md-29,.py-md-29{padding-bottom:29px!important}.pl-md-29,.px-md-29{padding-left:29px!important}.p-md-30{padding:30px!important}.pt-md-30,.py-md-30{padding-top:30px!important}.pr-md-30,.px-md-30{padding-right:30px!important}.pb-md-30,.py-md-30{padding-bottom:30px!important}.pl-md-30,.px-md-30{padding-left:30px!important}.p-md-32{padding:32px!important}.pt-md-32,.py-md-32{padding-top:32px!important}.pr-md-32,.px-md-32{padding-right:32px!important}.pb-md-32,.py-md-32{padding-bottom:32px!important}.pl-md-32,.px-md-32{padding-left:32px!important}.p-md-38{padding:38px!important}.pt-md-38,.py-md-38{padding-top:38px!important}.pr-md-38,.px-md-38{padding-right:38px!important}.pb-md-38,.py-md-38{padding-bottom:38px!important}.pl-md-38,.px-md-38{padding-left:38px!important}.p-md-40{padding:40px!important}.pt-md-40,.py-md-40{padding-top:40px!important}.pr-md-40,.px-md-40{padding-right:40px!important}.pb-md-40,.py-md-40{padding-bottom:40px!important}.pl-md-40,.px-md-40{padding-left:40px!important}.p-md-42{padding:42px!important}.pt-md-42,.py-md-42{padding-top:42px!important}.pr-md-42,.px-md-42{padding-right:42px!important}.pb-md-42,.py-md-42{padding-bottom:42px!important}.pl-md-42,.px-md-42{padding-left:42px!important}.p-md-48{padding:48px!important}.pt-md-48,.py-md-48{padding-top:48px!important}.pr-md-48,.px-md-48{padding-right:48px!important}.pb-md-48,.py-md-48{padding-bottom:48px!important}.pl-md-48,.px-md-48{padding-left:48px!important}.p-md-50{padding:50px!important}.pt-md-50,.py-md-50{padding-top:50px!important}.pr-md-50,.px-md-50{padding-right:50px!important}.pb-md-50,.py-md-50{padding-bottom:50px!important}.pl-md-50,.px-md-50{padding-left:50px!important}.p-md-56{padding:56px!important}.pt-md-56,.py-md-56{padding-top:56px!important}.pr-md-56,.px-md-56{padding-right:56px!important}.pb-md-56,.py-md-56{padding-bottom:56px!important}.pl-md-56,.px-md-56{padding-left:56px!important}.p-md-58{padding:58px!important}.pt-md-58,.py-md-58{padding-top:58px!important}.pr-md-58,.px-md-58{padding-right:58px!important}.pb-md-58,.py-md-58{padding-bottom:58px!important}.pl-md-58,.px-md-58{padding-left:58px!important}.p-md-60{padding:60px!important}.pt-md-60,.py-md-60{padding-top:60px!important}.pr-md-60,.px-md-60{padding-right:60px!important}.pb-md-60,.py-md-60{padding-bottom:60px!important}.pl-md-60,.px-md-60{padding-left:60px!important}.p-md-64{padding:64px!important}.pt-md-64,.py-md-64{padding-top:64px!important}.pr-md-64,.px-md-64{padding-right:64px!important}.pb-md-64,.py-md-64{padding-bottom:64px!important}.pl-md-64,.px-md-64{padding-left:64px!important}.m-md-n1{margin:-1px!important}.mt-md-n1,.my-md-n1{margin-top:-1px!important}.mr-md-n1,.mx-md-n1{margin-right:-1px!important}.mb-md-n1,.my-md-n1{margin-bottom:-1px!important}.ml-md-n1,.mx-md-n1{margin-left:-1px!important}.m-md-n2{margin:-2px!important}.mt-md-n2,.my-md-n2{margin-top:-2px!important}.mr-md-n2,.mx-md-n2{margin-right:-2px!important}.mb-md-n2,.my-md-n2{margin-bottom:-2px!important}.ml-md-n2,.mx-md-n2{margin-left:-2px!important}.m-md-n3{margin:-3px!important}.mt-md-n3,.my-md-n3{margin-top:-3px!important}.mr-md-n3,.mx-md-n3{margin-right:-3px!important}.mb-md-n3,.my-md-n3{margin-bottom:-3px!important}.ml-md-n3,.mx-md-n3{margin-left:-3px!important}.m-md-n4{margin:-4px!important}.mt-md-n4,.my-md-n4{margin-top:-4px!important}.mr-md-n4,.mx-md-n4{margin-right:-4px!important}.mb-md-n4,.my-md-n4{margin-bottom:-4px!important}.ml-md-n4,.mx-md-n4{margin-left:-4px!important}.m-md-n5{margin:-5px!important}.mt-md-n5,.my-md-n5{margin-top:-5px!important}.mr-md-n5,.mx-md-n5{margin-right:-5px!important}.mb-md-n5,.my-md-n5{margin-bottom:-5px!important}.ml-md-n5,.mx-md-n5{margin-left:-5px!important}.m-md-n6{margin:-6px!important}.mt-md-n6,.my-md-n6{margin-top:-6px!important}.mr-md-n6,.mx-md-n6{margin-right:-6px!important}.mb-md-n6,.my-md-n6{margin-bottom:-6px!important}.ml-md-n6,.mx-md-n6{margin-left:-6px!important}.m-md-n7{margin:-7px!important}.mt-md-n7,.my-md-n7{margin-top:-7px!important}.mr-md-n7,.mx-md-n7{margin-right:-7px!important}.mb-md-n7,.my-md-n7{margin-bottom:-7px!important}.ml-md-n7,.mx-md-n7{margin-left:-7px!important}.m-md-n8{margin:-8px!important}.mt-md-n8,.my-md-n8{margin-top:-8px!important}.mr-md-n8,.mx-md-n8{margin-right:-8px!important}.mb-md-n8,.my-md-n8{margin-bottom:-8px!important}.ml-md-n8,.mx-md-n8{margin-left:-8px!important}.m-md-n9{margin:-9px!important}.mt-md-n9,.my-md-n9{margin-top:-9px!important}.mr-md-n9,.mx-md-n9{margin-right:-9px!important}.mb-md-n9,.my-md-n9{margin-bottom:-9px!important}.ml-md-n9,.mx-md-n9{margin-left:-9px!important}.m-md-n10{margin:-10px!important}.mt-md-n10,.my-md-n10{margin-top:-10px!important}.mr-md-n10,.mx-md-n10{margin-right:-10px!important}.mb-md-n10,.my-md-n10{margin-bottom:-10px!important}.ml-md-n10,.mx-md-n10{margin-left:-10px!important}.m-md-n11{margin:-11px!important}.mt-md-n11,.my-md-n11{margin-top:-11px!important}.mr-md-n11,.mx-md-n11{margin-right:-11px!important}.mb-md-n11,.my-md-n11{margin-bottom:-11px!important}.ml-md-n11,.mx-md-n11{margin-left:-11px!important}.m-md-n12{margin:-12px!important}.mt-md-n12,.my-md-n12{margin-top:-12px!important}.mr-md-n12,.mx-md-n12{margin-right:-12px!important}.mb-md-n12,.my-md-n12{margin-bottom:-12px!important}.ml-md-n12,.mx-md-n12{margin-left:-12px!important}.m-md-n13{margin:-13px!important}.mt-md-n13,.my-md-n13{margin-top:-13px!important}.mr-md-n13,.mx-md-n13{margin-right:-13px!important}.mb-md-n13,.my-md-n13{margin-bottom:-13px!important}.ml-md-n13,.mx-md-n13{margin-left:-13px!important}.m-md-n14{margin:-14px!important}.mt-md-n14,.my-md-n14{margin-top:-14px!important}.mr-md-n14,.mx-md-n14{margin-right:-14px!important}.mb-md-n14,.my-md-n14{margin-bottom:-14px!important}.ml-md-n14,.mx-md-n14{margin-left:-14px!important}.m-md-n15{margin:-15px!important}.mt-md-n15,.my-md-n15{margin-top:-15px!important}.mr-md-n15,.mx-md-n15{margin-right:-15px!important}.mb-md-n15,.my-md-n15{margin-bottom:-15px!important}.ml-md-n15,.mx-md-n15{margin-left:-15px!important}.m-md-n16{margin:-16px!important}.mt-md-n16,.my-md-n16{margin-top:-16px!important}.mr-md-n16,.mx-md-n16{margin-right:-16px!important}.mb-md-n16,.my-md-n16{margin-bottom:-16px!important}.ml-md-n16,.mx-md-n16{margin-left:-16px!important}.m-md-n18{margin:-18px!important}.mt-md-n18,.my-md-n18{margin-top:-18px!important}.mr-md-n18,.mx-md-n18{margin-right:-18px!important}.mb-md-n18,.my-md-n18{margin-bottom:-18px!important}.ml-md-n18,.mx-md-n18{margin-left:-18px!important}.m-md-n20{margin:-20px!important}.mt-md-n20,.my-md-n20{margin-top:-20px!important}.mr-md-n20,.mx-md-n20{margin-right:-20px!important}.mb-md-n20,.my-md-n20{margin-bottom:-20px!important}.ml-md-n20,.mx-md-n20{margin-left:-20px!important}.m-md-n21{margin:-21px!important}.mt-md-n21,.my-md-n21{margin-top:-21px!important}.mr-md-n21,.mx-md-n21{margin-right:-21px!important}.mb-md-n21,.my-md-n21{margin-bottom:-21px!important}.ml-md-n21,.mx-md-n21{margin-left:-21px!important}.m-md-n23{margin:-23px!important}.mt-md-n23,.my-md-n23{margin-top:-23px!important}.mr-md-n23,.mx-md-n23{margin-right:-23px!important}.mb-md-n23,.my-md-n23{margin-bottom:-23px!important}.ml-md-n23,.mx-md-n23{margin-left:-23px!important}.m-md-n24{margin:-24px!important}.mt-md-n24,.my-md-n24{margin-top:-24px!important}.mr-md-n24,.mx-md-n24{margin-right:-24px!important}.mb-md-n24,.my-md-n24{margin-bottom:-24px!important}.ml-md-n24,.mx-md-n24{margin-left:-24px!important}.m-md-n26{margin:-26px!important}.mt-md-n26,.my-md-n26{margin-top:-26px!important}.mr-md-n26,.mx-md-n26{margin-right:-26px!important}.mb-md-n26,.my-md-n26{margin-bottom:-26px!important}.ml-md-n26,.mx-md-n26{margin-left:-26px!important}.m-md-n28{margin:-28px!important}.mt-md-n28,.my-md-n28{margin-top:-28px!important}.mr-md-n28,.mx-md-n28{margin-right:-28px!important}.mb-md-n28,.my-md-n28{margin-bottom:-28px!important}.ml-md-n28,.mx-md-n28{margin-left:-28px!important}.m-md-n29{margin:-29px!important}.mt-md-n29,.my-md-n29{margin-top:-29px!important}.mr-md-n29,.mx-md-n29{margin-right:-29px!important}.mb-md-n29,.my-md-n29{margin-bottom:-29px!important}.ml-md-n29,.mx-md-n29{margin-left:-29px!important}.m-md-n30{margin:-30px!important}.mt-md-n30,.my-md-n30{margin-top:-30px!important}.mr-md-n30,.mx-md-n30{margin-right:-30px!important}.mb-md-n30,.my-md-n30{margin-bottom:-30px!important}.ml-md-n30,.mx-md-n30{margin-left:-30px!important}.m-md-n32{margin:-32px!important}.mt-md-n32,.my-md-n32{margin-top:-32px!important}.mr-md-n32,.mx-md-n32{margin-right:-32px!important}.mb-md-n32,.my-md-n32{margin-bottom:-32px!important}.ml-md-n32,.mx-md-n32{margin-left:-32px!important}.m-md-n38{margin:-38px!important}.mt-md-n38,.my-md-n38{margin-top:-38px!important}.mr-md-n38,.mx-md-n38{margin-right:-38px!important}.mb-md-n38,.my-md-n38{margin-bottom:-38px!important}.ml-md-n38,.mx-md-n38{margin-left:-38px!important}.m-md-n40{margin:-40px!important}.mt-md-n40,.my-md-n40{margin-top:-40px!important}.mr-md-n40,.mx-md-n40{margin-right:-40px!important}.mb-md-n40,.my-md-n40{margin-bottom:-40px!important}.ml-md-n40,.mx-md-n40{margin-left:-40px!important}.m-md-n42{margin:-42px!important}.mt-md-n42,.my-md-n42{margin-top:-42px!important}.mr-md-n42,.mx-md-n42{margin-right:-42px!important}.mb-md-n42,.my-md-n42{margin-bottom:-42px!important}.ml-md-n42,.mx-md-n42{margin-left:-42px!important}.m-md-n48{margin:-48px!important}.mt-md-n48,.my-md-n48{margin-top:-48px!important}.mr-md-n48,.mx-md-n48{margin-right:-48px!important}.mb-md-n48,.my-md-n48{margin-bottom:-48px!important}.ml-md-n48,.mx-md-n48{margin-left:-48px!important}.m-md-n50{margin:-50px!important}.mt-md-n50,.my-md-n50{margin-top:-50px!important}.mr-md-n50,.mx-md-n50{margin-right:-50px!important}.mb-md-n50,.my-md-n50{margin-bottom:-50px!important}.ml-md-n50,.mx-md-n50{margin-left:-50px!important}.m-md-n56{margin:-56px!important}.mt-md-n56,.my-md-n56{margin-top:-56px!important}.mr-md-n56,.mx-md-n56{margin-right:-56px!important}.mb-md-n56,.my-md-n56{margin-bottom:-56px!important}.ml-md-n56,.mx-md-n56{margin-left:-56px!important}.m-md-n58{margin:-58px!important}.mt-md-n58,.my-md-n58{margin-top:-58px!important}.mr-md-n58,.mx-md-n58{margin-right:-58px!important}.mb-md-n58,.my-md-n58{margin-bottom:-58px!important}.ml-md-n58,.mx-md-n58{margin-left:-58px!important}.m-md-n60{margin:-60px!important}.mt-md-n60,.my-md-n60{margin-top:-60px!important}.mr-md-n60,.mx-md-n60{margin-right:-60px!important}.mb-md-n60,.my-md-n60{margin-bottom:-60px!important}.ml-md-n60,.mx-md-n60{margin-left:-60px!important}.m-md-n64{margin:-64px!important}.mt-md-n64,.my-md-n64{margin-top:-64px!important}.mr-md-n64,.mx-md-n64{margin-right:-64px!important}.mb-md-n64,.my-md-n64{margin-bottom:-64px!important}.ml-md-n64,.mx-md-n64{margin-left:-64px!important}.m-md-auto{margin:auto!important}.mt-md-auto,.my-md-auto{margin-top:auto!important}.mr-md-auto,.mx-md-auto{margin-right:auto!important}.mb-md-auto,.my-md-auto{margin-bottom:auto!important}.ml-md-auto,.mx-md-auto{margin-left:auto!important}.text-md-left{text-align:left!important}.text-md-right{text-align:right!important}.text-md-center{text-align:center!important}}@media (min-width:992px){.flex-lg-row{flex-direction:row!important}.flex-lg-column{flex-direction:column!important}.flex-lg-row-reverse{flex-direction:row-reverse!important}.flex-lg-column-reverse{flex-direction:column-reverse!important}.flex-lg-wrap{flex-wrap:wrap!important}.flex-lg-nowrap{flex-wrap:nowrap!important}.flex-lg-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-lg-fill{flex:1 1 auto!important}.flex-lg-grow-0{flex-grow:0!important}.flex-lg-grow-1{flex-grow:1!important}.flex-lg-shrink-0{flex-shrink:0!important}.flex-lg-shrink-1{flex-shrink:1!important}.justify-content-lg-start{justify-content:flex-start!important}.justify-content-lg-end{justify-content:flex-end!important}.justify-content-lg-center{justify-content:center!important}.justify-content-lg-between{justify-content:space-between!important}.justify-content-lg-around{justify-content:space-around!important}.align-items-lg-start{align-items:flex-start!important}.align-items-lg-end{align-items:flex-end!important}.align-items-lg-center{align-items:center!important}.align-items-lg-baseline{align-items:baseline!important}.align-items-lg-stretch{align-items:stretch!important}.align-content-lg-start{align-content:flex-start!important}.align-content-lg-end{align-content:flex-end!important}.align-content-lg-center{align-content:center!important}.align-content-lg-between{align-content:space-between!important}.align-content-lg-around{align-content:space-around!important}.align-content-lg-stretch{align-content:stretch!important}.align-self-lg-auto{align-self:auto!important}.align-self-lg-start{align-self:flex-start!important}.align-self-lg-end{align-self:flex-end!important}.align-self-lg-center{align-self:center!important}.align-self-lg-baseline{align-self:baseline!important}.align-self-lg-stretch{align-self:stretch!important}.float-lg-left{float:left!important}.float-lg-right{float:right!important}.float-lg-none{float:none!important}.m-lg-0{margin:0!important}.mt-lg-0,.my-lg-0{margin-top:0!important}.mr-lg-0,.mx-lg-0{margin-right:0!important}.mb-lg-0,.my-lg-0{margin-bottom:0!important}.ml-lg-0,.mx-lg-0{margin-left:0!important}.m-lg-1{margin:1px!important}.mt-lg-1,.my-lg-1{margin-top:1px!important}.mr-lg-1,.mx-lg-1{margin-right:1px!important}.mb-lg-1,.my-lg-1{margin-bottom:1px!important}.ml-lg-1,.mx-lg-1{margin-left:1px!important}.m-lg-2{margin:2px!important}.mt-lg-2,.my-lg-2{margin-top:2px!important}.mr-lg-2,.mx-lg-2{margin-right:2px!important}.mb-lg-2,.my-lg-2{margin-bottom:2px!important}.ml-lg-2,.mx-lg-2{margin-left:2px!important}.m-lg-3{margin:3px!important}.mt-lg-3,.my-lg-3{margin-top:3px!important}.mr-lg-3,.mx-lg-3{margin-right:3px!important}.mb-lg-3,.my-lg-3{margin-bottom:3px!important}.ml-lg-3,.mx-lg-3{margin-left:3px!important}.m-lg-4{margin:4px!important}.mt-lg-4,.my-lg-4{margin-top:4px!important}.mr-lg-4,.mx-lg-4{margin-right:4px!important}.mb-lg-4,.my-lg-4{margin-bottom:4px!important}.ml-lg-4,.mx-lg-4{margin-left:4px!important}.m-lg-5{margin:5px!important}.mt-lg-5,.my-lg-5{margin-top:5px!important}.mr-lg-5,.mx-lg-5{margin-right:5px!important}.mb-lg-5,.my-lg-5{margin-bottom:5px!important}.ml-lg-5,.mx-lg-5{margin-left:5px!important}.m-lg-6{margin:6px!important}.mt-lg-6,.my-lg-6{margin-top:6px!important}.mr-lg-6,.mx-lg-6{margin-right:6px!important}.mb-lg-6,.my-lg-6{margin-bottom:6px!important}.ml-lg-6,.mx-lg-6{margin-left:6px!important}.m-lg-7{margin:7px!important}.mt-lg-7,.my-lg-7{margin-top:7px!important}.mr-lg-7,.mx-lg-7{margin-right:7px!important}.mb-lg-7,.my-lg-7{margin-bottom:7px!important}.ml-lg-7,.mx-lg-7{margin-left:7px!important}.m-lg-8{margin:8px!important}.mt-lg-8,.my-lg-8{margin-top:8px!important}.mr-lg-8,.mx-lg-8{margin-right:8px!important}.mb-lg-8,.my-lg-8{margin-bottom:8px!important}.ml-lg-8,.mx-lg-8{margin-left:8px!important}.m-lg-9{margin:9px!important}.mt-lg-9,.my-lg-9{margin-top:9px!important}.mr-lg-9,.mx-lg-9{margin-right:9px!important}.mb-lg-9,.my-lg-9{margin-bottom:9px!important}.ml-lg-9,.mx-lg-9{margin-left:9px!important}.m-lg-10{margin:10px!important}.mt-lg-10,.my-lg-10{margin-top:10px!important}.mr-lg-10,.mx-lg-10{margin-right:10px!important}.mb-lg-10,.my-lg-10{margin-bottom:10px!important}.ml-lg-10,.mx-lg-10{margin-left:10px!important}.m-lg-11{margin:11px!important}.mt-lg-11,.my-lg-11{margin-top:11px!important}.mr-lg-11,.mx-lg-11{margin-right:11px!important}.mb-lg-11,.my-lg-11{margin-bottom:11px!important}.ml-lg-11,.mx-lg-11{margin-left:11px!important}.m-lg-12{margin:12px!important}.mt-lg-12,.my-lg-12{margin-top:12px!important}.mr-lg-12,.mx-lg-12{margin-right:12px!important}.mb-lg-12,.my-lg-12{margin-bottom:12px!important}.ml-lg-12,.mx-lg-12{margin-left:12px!important}.m-lg-13{margin:13px!important}.mt-lg-13,.my-lg-13{margin-top:13px!important}.mr-lg-13,.mx-lg-13{margin-right:13px!important}.mb-lg-13,.my-lg-13{margin-bottom:13px!important}.ml-lg-13,.mx-lg-13{margin-left:13px!important}.m-lg-14{margin:14px!important}.mt-lg-14,.my-lg-14{margin-top:14px!important}.mr-lg-14,.mx-lg-14{margin-right:14px!important}.mb-lg-14,.my-lg-14{margin-bottom:14px!important}.ml-lg-14,.mx-lg-14{margin-left:14px!important}.m-lg-15{margin:15px!important}.mt-lg-15,.my-lg-15{margin-top:15px!important}.mr-lg-15,.mx-lg-15{margin-right:15px!important}.mb-lg-15,.my-lg-15{margin-bottom:15px!important}.ml-lg-15,.mx-lg-15{margin-left:15px!important}.m-lg-16{margin:16px!important}.mt-lg-16,.my-lg-16{margin-top:16px!important}.mr-lg-16,.mx-lg-16{margin-right:16px!important}.mb-lg-16,.my-lg-16{margin-bottom:16px!important}.ml-lg-16,.mx-lg-16{margin-left:16px!important}.m-lg-18{margin:18px!important}.mt-lg-18,.my-lg-18{margin-top:18px!important}.mr-lg-18,.mx-lg-18{margin-right:18px!important}.mb-lg-18,.my-lg-18{margin-bottom:18px!important}.ml-lg-18,.mx-lg-18{margin-left:18px!important}.m-lg-20{margin:20px!important}.mt-lg-20,.my-lg-20{margin-top:20px!important}.mr-lg-20,.mx-lg-20{margin-right:20px!important}.mb-lg-20,.my-lg-20{margin-bottom:20px!important}.ml-lg-20,.mx-lg-20{margin-left:20px!important}.m-lg-21{margin:21px!important}.mt-lg-21,.my-lg-21{margin-top:21px!important}.mr-lg-21,.mx-lg-21{margin-right:21px!important}.mb-lg-21,.my-lg-21{margin-bottom:21px!important}.ml-lg-21,.mx-lg-21{margin-left:21px!important}.m-lg-23{margin:23px!important}.mt-lg-23,.my-lg-23{margin-top:23px!important}.mr-lg-23,.mx-lg-23{margin-right:23px!important}.mb-lg-23,.my-lg-23{margin-bottom:23px!important}.ml-lg-23,.mx-lg-23{margin-left:23px!important}.m-lg-24{margin:24px!important}.mt-lg-24,.my-lg-24{margin-top:24px!important}.mr-lg-24,.mx-lg-24{margin-right:24px!important}.mb-lg-24,.my-lg-24{margin-bottom:24px!important}.ml-lg-24,.mx-lg-24{margin-left:24px!important}.m-lg-26{margin:26px!important}.mt-lg-26,.my-lg-26{margin-top:26px!important}.mr-lg-26,.mx-lg-26{margin-right:26px!important}.mb-lg-26,.my-lg-26{margin-bottom:26px!important}.ml-lg-26,.mx-lg-26{margin-left:26px!important}.m-lg-28{margin:28px!important}.mt-lg-28,.my-lg-28{margin-top:28px!important}.mr-lg-28,.mx-lg-28{margin-right:28px!important}.mb-lg-28,.my-lg-28{margin-bottom:28px!important}.ml-lg-28,.mx-lg-28{margin-left:28px!important}.m-lg-29{margin:29px!important}.mt-lg-29,.my-lg-29{margin-top:29px!important}.mr-lg-29,.mx-lg-29{margin-right:29px!important}.mb-lg-29,.my-lg-29{margin-bottom:29px!important}.ml-lg-29,.mx-lg-29{margin-left:29px!important}.m-lg-30{margin:30px!important}.mt-lg-30,.my-lg-30{margin-top:30px!important}.mr-lg-30,.mx-lg-30{margin-right:30px!important}.mb-lg-30,.my-lg-30{margin-bottom:30px!important}.ml-lg-30,.mx-lg-30{margin-left:30px!important}.m-lg-32{margin:32px!important}.mt-lg-32,.my-lg-32{margin-top:32px!important}.mr-lg-32,.mx-lg-32{margin-right:32px!important}.mb-lg-32,.my-lg-32{margin-bottom:32px!important}.ml-lg-32,.mx-lg-32{margin-left:32px!important}.m-lg-38{margin:38px!important}.mt-lg-38,.my-lg-38{margin-top:38px!important}.mr-lg-38,.mx-lg-38{margin-right:38px!important}.mb-lg-38,.my-lg-38{margin-bottom:38px!important}.ml-lg-38,.mx-lg-38{margin-left:38px!important}.m-lg-40{margin:40px!important}.mt-lg-40,.my-lg-40{margin-top:40px!important}.mr-lg-40,.mx-lg-40{margin-right:40px!important}.mb-lg-40,.my-lg-40{margin-bottom:40px!important}.ml-lg-40,.mx-lg-40{margin-left:40px!important}.m-lg-42{margin:42px!important}.mt-lg-42,.my-lg-42{margin-top:42px!important}.mr-lg-42,.mx-lg-42{margin-right:42px!important}.mb-lg-42,.my-lg-42{margin-bottom:42px!important}.ml-lg-42,.mx-lg-42{margin-left:42px!important}.m-lg-48{margin:48px!important}.mt-lg-48,.my-lg-48{margin-top:48px!important}.mr-lg-48,.mx-lg-48{margin-right:48px!important}.mb-lg-48,.my-lg-48{margin-bottom:48px!important}.ml-lg-48,.mx-lg-48{margin-left:48px!important}.m-lg-50{margin:50px!important}.mt-lg-50,.my-lg-50{margin-top:50px!important}.mr-lg-50,.mx-lg-50{margin-right:50px!important}.mb-lg-50,.my-lg-50{margin-bottom:50px!important}.ml-lg-50,.mx-lg-50{margin-left:50px!important}.m-lg-56{margin:56px!important}.mt-lg-56,.my-lg-56{margin-top:56px!important}.mr-lg-56,.mx-lg-56{margin-right:56px!important}.mb-lg-56,.my-lg-56{margin-bottom:56px!important}.ml-lg-56,.mx-lg-56{margin-left:56px!important}.m-lg-58{margin:58px!important}.mt-lg-58,.my-lg-58{margin-top:58px!important}.mr-lg-58,.mx-lg-58{margin-right:58px!important}.mb-lg-58,.my-lg-58{margin-bottom:58px!important}.ml-lg-58,.mx-lg-58{margin-left:58px!important}.m-lg-60{margin:60px!important}.mt-lg-60,.my-lg-60{margin-top:60px!important}.mr-lg-60,.mx-lg-60{margin-right:60px!important}.mb-lg-60,.my-lg-60{margin-bottom:60px!important}.ml-lg-60,.mx-lg-60{margin-left:60px!important}.m-lg-64{margin:64px!important}.mt-lg-64,.my-lg-64{margin-top:64px!important}.mr-lg-64,.mx-lg-64{margin-right:64px!important}.mb-lg-64,.my-lg-64{margin-bottom:64px!important}.ml-lg-64,.mx-lg-64{margin-left:64px!important}.p-lg-0{padding:0!important}.pt-lg-0,.py-lg-0{padding-top:0!important}.pr-lg-0,.px-lg-0{padding-right:0!important}.pb-lg-0,.py-lg-0{padding-bottom:0!important}.pl-lg-0,.px-lg-0{padding-left:0!important}.p-lg-1{padding:1px!important}.pt-lg-1,.py-lg-1{padding-top:1px!important}.pr-lg-1,.px-lg-1{padding-right:1px!important}.pb-lg-1,.py-lg-1{padding-bottom:1px!important}.pl-lg-1,.px-lg-1{padding-left:1px!important}.p-lg-2{padding:2px!important}.pt-lg-2,.py-lg-2{padding-top:2px!important}.pr-lg-2,.px-lg-2{padding-right:2px!important}.pb-lg-2,.py-lg-2{padding-bottom:2px!important}.pl-lg-2,.px-lg-2{padding-left:2px!important}.p-lg-3{padding:3px!important}.pt-lg-3,.py-lg-3{padding-top:3px!important}.pr-lg-3,.px-lg-3{padding-right:3px!important}.pb-lg-3,.py-lg-3{padding-bottom:3px!important}.pl-lg-3,.px-lg-3{padding-left:3px!important}.p-lg-4{padding:4px!important}.pt-lg-4,.py-lg-4{padding-top:4px!important}.pr-lg-4,.px-lg-4{padding-right:4px!important}.pb-lg-4,.py-lg-4{padding-bottom:4px!important}.pl-lg-4,.px-lg-4{padding-left:4px!important}.p-lg-5{padding:5px!important}.pt-lg-5,.py-lg-5{padding-top:5px!important}.pr-lg-5,.px-lg-5{padding-right:5px!important}.pb-lg-5,.py-lg-5{padding-bottom:5px!important}.pl-lg-5,.px-lg-5{padding-left:5px!important}.p-lg-6{padding:6px!important}.pt-lg-6,.py-lg-6{padding-top:6px!important}.pr-lg-6,.px-lg-6{padding-right:6px!important}.pb-lg-6,.py-lg-6{padding-bottom:6px!important}.pl-lg-6,.px-lg-6{padding-left:6px!important}.p-lg-7{padding:7px!important}.pt-lg-7,.py-lg-7{padding-top:7px!important}.pr-lg-7,.px-lg-7{padding-right:7px!important}.pb-lg-7,.py-lg-7{padding-bottom:7px!important}.pl-lg-7,.px-lg-7{padding-left:7px!important}.p-lg-8{padding:8px!important}.pt-lg-8,.py-lg-8{padding-top:8px!important}.pr-lg-8,.px-lg-8{padding-right:8px!important}.pb-lg-8,.py-lg-8{padding-bottom:8px!important}.pl-lg-8,.px-lg-8{padding-left:8px!important}.p-lg-9{padding:9px!important}.pt-lg-9,.py-lg-9{padding-top:9px!important}.pr-lg-9,.px-lg-9{padding-right:9px!important}.pb-lg-9,.py-lg-9{padding-bottom:9px!important}.pl-lg-9,.px-lg-9{padding-left:9px!important}.p-lg-10{padding:10px!important}.pt-lg-10,.py-lg-10{padding-top:10px!important}.pr-lg-10,.px-lg-10{padding-right:10px!important}.pb-lg-10,.py-lg-10{padding-bottom:10px!important}.pl-lg-10,.px-lg-10{padding-left:10px!important}.p-lg-11{padding:11px!important}.pt-lg-11,.py-lg-11{padding-top:11px!important}.pr-lg-11,.px-lg-11{padding-right:11px!important}.pb-lg-11,.py-lg-11{padding-bottom:11px!important}.pl-lg-11,.px-lg-11{padding-left:11px!important}.p-lg-12{padding:12px!important}.pt-lg-12,.py-lg-12{padding-top:12px!important}.pr-lg-12,.px-lg-12{padding-right:12px!important}.pb-lg-12,.py-lg-12{padding-bottom:12px!important}.pl-lg-12,.px-lg-12{padding-left:12px!important}.p-lg-13{padding:13px!important}.pt-lg-13,.py-lg-13{padding-top:13px!important}.pr-lg-13,.px-lg-13{padding-right:13px!important}.pb-lg-13,.py-lg-13{padding-bottom:13px!important}.pl-lg-13,.px-lg-13{padding-left:13px!important}.p-lg-14{padding:14px!important}.pt-lg-14,.py-lg-14{padding-top:14px!important}.pr-lg-14,.px-lg-14{padding-right:14px!important}.pb-lg-14,.py-lg-14{padding-bottom:14px!important}.pl-lg-14,.px-lg-14{padding-left:14px!important}.p-lg-15{padding:15px!important}.pt-lg-15,.py-lg-15{padding-top:15px!important}.pr-lg-15,.px-lg-15{padding-right:15px!important}.pb-lg-15,.py-lg-15{padding-bottom:15px!important}.pl-lg-15,.px-lg-15{padding-left:15px!important}.p-lg-16{padding:16px!important}.pt-lg-16,.py-lg-16{padding-top:16px!important}.pr-lg-16,.px-lg-16{padding-right:16px!important}.pb-lg-16,.py-lg-16{padding-bottom:16px!important}.pl-lg-16,.px-lg-16{padding-left:16px!important}.p-lg-18{padding:18px!important}.pt-lg-18,.py-lg-18{padding-top:18px!important}.pr-lg-18,.px-lg-18{padding-right:18px!important}.pb-lg-18,.py-lg-18{padding-bottom:18px!important}.pl-lg-18,.px-lg-18{padding-left:18px!important}.p-lg-20{padding:20px!important}.pt-lg-20,.py-lg-20{padding-top:20px!important}.pr-lg-20,.px-lg-20{padding-right:20px!important}.pb-lg-20,.py-lg-20{padding-bottom:20px!important}.pl-lg-20,.px-lg-20{padding-left:20px!important}.p-lg-21{padding:21px!important}.pt-lg-21,.py-lg-21{padding-top:21px!important}.pr-lg-21,.px-lg-21{padding-right:21px!important}.pb-lg-21,.py-lg-21{padding-bottom:21px!important}.pl-lg-21,.px-lg-21{padding-left:21px!important}.p-lg-23{padding:23px!important}.pt-lg-23,.py-lg-23{padding-top:23px!important}.pr-lg-23,.px-lg-23{padding-right:23px!important}.pb-lg-23,.py-lg-23{padding-bottom:23px!important}.pl-lg-23,.px-lg-23{padding-left:23px!important}.p-lg-24{padding:24px!important}.pt-lg-24,.py-lg-24{padding-top:24px!important}.pr-lg-24,.px-lg-24{padding-right:24px!important}.pb-lg-24,.py-lg-24{padding-bottom:24px!important}.pl-lg-24,.px-lg-24{padding-left:24px!important}.p-lg-26{padding:26px!important}.pt-lg-26,.py-lg-26{padding-top:26px!important}.pr-lg-26,.px-lg-26{padding-right:26px!important}.pb-lg-26,.py-lg-26{padding-bottom:26px!important}.pl-lg-26,.px-lg-26{padding-left:26px!important}.p-lg-28{padding:28px!important}.pt-lg-28,.py-lg-28{padding-top:28px!important}.pr-lg-28,.px-lg-28{padding-right:28px!important}.pb-lg-28,.py-lg-28{padding-bottom:28px!important}.pl-lg-28,.px-lg-28{padding-left:28px!important}.p-lg-29{padding:29px!important}.pt-lg-29,.py-lg-29{padding-top:29px!important}.pr-lg-29,.px-lg-29{padding-right:29px!important}.pb-lg-29,.py-lg-29{padding-bottom:29px!important}.pl-lg-29,.px-lg-29{padding-left:29px!important}.p-lg-30{padding:30px!important}.pt-lg-30,.py-lg-30{padding-top:30px!important}.pr-lg-30,.px-lg-30{padding-right:30px!important}.pb-lg-30,.py-lg-30{padding-bottom:30px!important}.pl-lg-30,.px-lg-30{padding-left:30px!important}.p-lg-32{padding:32px!important}.pt-lg-32,.py-lg-32{padding-top:32px!important}.pr-lg-32,.px-lg-32{padding-right:32px!important}.pb-lg-32,.py-lg-32{padding-bottom:32px!important}.pl-lg-32,.px-lg-32{padding-left:32px!important}.p-lg-38{padding:38px!important}.pt-lg-38,.py-lg-38{padding-top:38px!important}.pr-lg-38,.px-lg-38{padding-right:38px!important}.pb-lg-38,.py-lg-38{padding-bottom:38px!important}.pl-lg-38,.px-lg-38{padding-left:38px!important}.p-lg-40{padding:40px!important}.pt-lg-40,.py-lg-40{padding-top:40px!important}.pr-lg-40,.px-lg-40{padding-right:40px!important}.pb-lg-40,.py-lg-40{padding-bottom:40px!important}.pl-lg-40,.px-lg-40{padding-left:40px!important}.p-lg-42{padding:42px!important}.pt-lg-42,.py-lg-42{padding-top:42px!important}.pr-lg-42,.px-lg-42{padding-right:42px!important}.pb-lg-42,.py-lg-42{padding-bottom:42px!important}.pl-lg-42,.px-lg-42{padding-left:42px!important}.p-lg-48{padding:48px!important}.pt-lg-48,.py-lg-48{padding-top:48px!important}.pr-lg-48,.px-lg-48{padding-right:48px!important}.pb-lg-48,.py-lg-48{padding-bottom:48px!important}.pl-lg-48,.px-lg-48{padding-left:48px!important}.p-lg-50{padding:50px!important}.pt-lg-50,.py-lg-50{padding-top:50px!important}.pr-lg-50,.px-lg-50{padding-right:50px!important}.pb-lg-50,.py-lg-50{padding-bottom:50px!important}.pl-lg-50,.px-lg-50{padding-left:50px!important}.p-lg-56{padding:56px!important}.pt-lg-56,.py-lg-56{padding-top:56px!important}.pr-lg-56,.px-lg-56{padding-right:56px!important}.pb-lg-56,.py-lg-56{padding-bottom:56px!important}.pl-lg-56,.px-lg-56{padding-left:56px!important}.p-lg-58{padding:58px!important}.pt-lg-58,.py-lg-58{padding-top:58px!important}.pr-lg-58,.px-lg-58{padding-right:58px!important}.pb-lg-58,.py-lg-58{padding-bottom:58px!important}.pl-lg-58,.px-lg-58{padding-left:58px!important}.p-lg-60{padding:60px!important}.pt-lg-60,.py-lg-60{padding-top:60px!important}.pr-lg-60,.px-lg-60{padding-right:60px!important}.pb-lg-60,.py-lg-60{padding-bottom:60px!important}.pl-lg-60,.px-lg-60{padding-left:60px!important}.p-lg-64{padding:64px!important}.pt-lg-64,.py-lg-64{padding-top:64px!important}.pr-lg-64,.px-lg-64{padding-right:64px!important}.pb-lg-64,.py-lg-64{padding-bottom:64px!important}.pl-lg-64,.px-lg-64{padding-left:64px!important}.m-lg-n1{margin:-1px!important}.mt-lg-n1,.my-lg-n1{margin-top:-1px!important}.mr-lg-n1,.mx-lg-n1{margin-right:-1px!important}.mb-lg-n1,.my-lg-n1{margin-bottom:-1px!important}.ml-lg-n1,.mx-lg-n1{margin-left:-1px!important}.m-lg-n2{margin:-2px!important}.mt-lg-n2,.my-lg-n2{margin-top:-2px!important}.mr-lg-n2,.mx-lg-n2{margin-right:-2px!important}.mb-lg-n2,.my-lg-n2{margin-bottom:-2px!important}.ml-lg-n2,.mx-lg-n2{margin-left:-2px!important}.m-lg-n3{margin:-3px!important}.mt-lg-n3,.my-lg-n3{margin-top:-3px!important}.mr-lg-n3,.mx-lg-n3{margin-right:-3px!important}.mb-lg-n3,.my-lg-n3{margin-bottom:-3px!important}.ml-lg-n3,.mx-lg-n3{margin-left:-3px!important}.m-lg-n4{margin:-4px!important}.mt-lg-n4,.my-lg-n4{margin-top:-4px!important}.mr-lg-n4,.mx-lg-n4{margin-right:-4px!important}.mb-lg-n4,.my-lg-n4{margin-bottom:-4px!important}.ml-lg-n4,.mx-lg-n4{margin-left:-4px!important}.m-lg-n5{margin:-5px!important}.mt-lg-n5,.my-lg-n5{margin-top:-5px!important}.mr-lg-n5,.mx-lg-n5{margin-right:-5px!important}.mb-lg-n5,.my-lg-n5{margin-bottom:-5px!important}.ml-lg-n5,.mx-lg-n5{margin-left:-5px!important}.m-lg-n6{margin:-6px!important}.mt-lg-n6,.my-lg-n6{margin-top:-6px!important}.mr-lg-n6,.mx-lg-n6{margin-right:-6px!important}.mb-lg-n6,.my-lg-n6{margin-bottom:-6px!important}.ml-lg-n6,.mx-lg-n6{margin-left:-6px!important}.m-lg-n7{margin:-7px!important}.mt-lg-n7,.my-lg-n7{margin-top:-7px!important}.mr-lg-n7,.mx-lg-n7{margin-right:-7px!important}.mb-lg-n7,.my-lg-n7{margin-bottom:-7px!important}.ml-lg-n7,.mx-lg-n7{margin-left:-7px!important}.m-lg-n8{margin:-8px!important}.mt-lg-n8,.my-lg-n8{margin-top:-8px!important}.mr-lg-n8,.mx-lg-n8{margin-right:-8px!important}.mb-lg-n8,.my-lg-n8{margin-bottom:-8px!important}.ml-lg-n8,.mx-lg-n8{margin-left:-8px!important}.m-lg-n9{margin:-9px!important}.mt-lg-n9,.my-lg-n9{margin-top:-9px!important}.mr-lg-n9,.mx-lg-n9{margin-right:-9px!important}.mb-lg-n9,.my-lg-n9{margin-bottom:-9px!important}.ml-lg-n9,.mx-lg-n9{margin-left:-9px!important}.m-lg-n10{margin:-10px!important}.mt-lg-n10,.my-lg-n10{margin-top:-10px!important}.mr-lg-n10,.mx-lg-n10{margin-right:-10px!important}.mb-lg-n10,.my-lg-n10{margin-bottom:-10px!important}.ml-lg-n10,.mx-lg-n10{margin-left:-10px!important}.m-lg-n11{margin:-11px!important}.mt-lg-n11,.my-lg-n11{margin-top:-11px!important}.mr-lg-n11,.mx-lg-n11{margin-right:-11px!important}.mb-lg-n11,.my-lg-n11{margin-bottom:-11px!important}.ml-lg-n11,.mx-lg-n11{margin-left:-11px!important}.m-lg-n12{margin:-12px!important}.mt-lg-n12,.my-lg-n12{margin-top:-12px!important}.mr-lg-n12,.mx-lg-n12{margin-right:-12px!important}.mb-lg-n12,.my-lg-n12{margin-bottom:-12px!important}.ml-lg-n12,.mx-lg-n12{margin-left:-12px!important}.m-lg-n13{margin:-13px!important}.mt-lg-n13,.my-lg-n13{margin-top:-13px!important}.mr-lg-n13,.mx-lg-n13{margin-right:-13px!important}.mb-lg-n13,.my-lg-n13{margin-bottom:-13px!important}.ml-lg-n13,.mx-lg-n13{margin-left:-13px!important}.m-lg-n14{margin:-14px!important}.mt-lg-n14,.my-lg-n14{margin-top:-14px!important}.mr-lg-n14,.mx-lg-n14{margin-right:-14px!important}.mb-lg-n14,.my-lg-n14{margin-bottom:-14px!important}.ml-lg-n14,.mx-lg-n14{margin-left:-14px!important}.m-lg-n15{margin:-15px!important}.mt-lg-n15,.my-lg-n15{margin-top:-15px!important}.mr-lg-n15,.mx-lg-n15{margin-right:-15px!important}.mb-lg-n15,.my-lg-n15{margin-bottom:-15px!important}.ml-lg-n15,.mx-lg-n15{margin-left:-15px!important}.m-lg-n16{margin:-16px!important}.mt-lg-n16,.my-lg-n16{margin-top:-16px!important}.mr-lg-n16,.mx-lg-n16{margin-right:-16px!important}.mb-lg-n16,.my-lg-n16{margin-bottom:-16px!important}.ml-lg-n16,.mx-lg-n16{margin-left:-16px!important}.m-lg-n18{margin:-18px!important}.mt-lg-n18,.my-lg-n18{margin-top:-18px!important}.mr-lg-n18,.mx-lg-n18{margin-right:-18px!important}.mb-lg-n18,.my-lg-n18{margin-bottom:-18px!important}.ml-lg-n18,.mx-lg-n18{margin-left:-18px!important}.m-lg-n20{margin:-20px!important}.mt-lg-n20,.my-lg-n20{margin-top:-20px!important}.mr-lg-n20,.mx-lg-n20{margin-right:-20px!important}.mb-lg-n20,.my-lg-n20{margin-bottom:-20px!important}.ml-lg-n20,.mx-lg-n20{margin-left:-20px!important}.m-lg-n21{margin:-21px!important}.mt-lg-n21,.my-lg-n21{margin-top:-21px!important}.mr-lg-n21,.mx-lg-n21{margin-right:-21px!important}.mb-lg-n21,.my-lg-n21{margin-bottom:-21px!important}.ml-lg-n21,.mx-lg-n21{margin-left:-21px!important}.m-lg-n23{margin:-23px!important}.mt-lg-n23,.my-lg-n23{margin-top:-23px!important}.mr-lg-n23,.mx-lg-n23{margin-right:-23px!important}.mb-lg-n23,.my-lg-n23{margin-bottom:-23px!important}.ml-lg-n23,.mx-lg-n23{margin-left:-23px!important}.m-lg-n24{margin:-24px!important}.mt-lg-n24,.my-lg-n24{margin-top:-24px!important}.mr-lg-n24,.mx-lg-n24{margin-right:-24px!important}.mb-lg-n24,.my-lg-n24{margin-bottom:-24px!important}.ml-lg-n24,.mx-lg-n24{margin-left:-24px!important}.m-lg-n26{margin:-26px!important}.mt-lg-n26,.my-lg-n26{margin-top:-26px!important}.mr-lg-n26,.mx-lg-n26{margin-right:-26px!important}.mb-lg-n26,.my-lg-n26{margin-bottom:-26px!important}.ml-lg-n26,.mx-lg-n26{margin-left:-26px!important}.m-lg-n28{margin:-28px!important}.mt-lg-n28,.my-lg-n28{margin-top:-28px!important}.mr-lg-n28,.mx-lg-n28{margin-right:-28px!important}.mb-lg-n28,.my-lg-n28{margin-bottom:-28px!important}.ml-lg-n28,.mx-lg-n28{margin-left:-28px!important}.m-lg-n29{margin:-29px!important}.mt-lg-n29,.my-lg-n29{margin-top:-29px!important}.mr-lg-n29,.mx-lg-n29{margin-right:-29px!important}.mb-lg-n29,.my-lg-n29{margin-bottom:-29px!important}.ml-lg-n29,.mx-lg-n29{margin-left:-29px!important}.m-lg-n30{margin:-30px!important}.mt-lg-n30,.my-lg-n30{margin-top:-30px!important}.mr-lg-n30,.mx-lg-n30{margin-right:-30px!important}.mb-lg-n30,.my-lg-n30{margin-bottom:-30px!important}.ml-lg-n30,.mx-lg-n30{margin-left:-30px!important}.m-lg-n32{margin:-32px!important}.mt-lg-n32,.my-lg-n32{margin-top:-32px!important}.mr-lg-n32,.mx-lg-n32{margin-right:-32px!important}.mb-lg-n32,.my-lg-n32{margin-bottom:-32px!important}.ml-lg-n32,.mx-lg-n32{margin-left:-32px!important}.m-lg-n38{margin:-38px!important}.mt-lg-n38,.my-lg-n38{margin-top:-38px!important}.mr-lg-n38,.mx-lg-n38{margin-right:-38px!important}.mb-lg-n38,.my-lg-n38{margin-bottom:-38px!important}.ml-lg-n38,.mx-lg-n38{margin-left:-38px!important}.m-lg-n40{margin:-40px!important}.mt-lg-n40,.my-lg-n40{margin-top:-40px!important}.mr-lg-n40,.mx-lg-n40{margin-right:-40px!important}.mb-lg-n40,.my-lg-n40{margin-bottom:-40px!important}.ml-lg-n40,.mx-lg-n40{margin-left:-40px!important}.m-lg-n42{margin:-42px!important}.mt-lg-n42,.my-lg-n42{margin-top:-42px!important}.mr-lg-n42,.mx-lg-n42{margin-right:-42px!important}.mb-lg-n42,.my-lg-n42{margin-bottom:-42px!important}.ml-lg-n42,.mx-lg-n42{margin-left:-42px!important}.m-lg-n48{margin:-48px!important}.mt-lg-n48,.my-lg-n48{margin-top:-48px!important}.mr-lg-n48,.mx-lg-n48{margin-right:-48px!important}.mb-lg-n48,.my-lg-n48{margin-bottom:-48px!important}.ml-lg-n48,.mx-lg-n48{margin-left:-48px!important}.m-lg-n50{margin:-50px!important}.mt-lg-n50,.my-lg-n50{margin-top:-50px!important}.mr-lg-n50,.mx-lg-n50{margin-right:-50px!important}.mb-lg-n50,.my-lg-n50{margin-bottom:-50px!important}.ml-lg-n50,.mx-lg-n50{margin-left:-50px!important}.m-lg-n56{margin:-56px!important}.mt-lg-n56,.my-lg-n56{margin-top:-56px!important}.mr-lg-n56,.mx-lg-n56{margin-right:-56px!important}.mb-lg-n56,.my-lg-n56{margin-bottom:-56px!important}.ml-lg-n56,.mx-lg-n56{margin-left:-56px!important}.m-lg-n58{margin:-58px!important}.mt-lg-n58,.my-lg-n58{margin-top:-58px!important}.mr-lg-n58,.mx-lg-n58{margin-right:-58px!important}.mb-lg-n58,.my-lg-n58{margin-bottom:-58px!important}.ml-lg-n58,.mx-lg-n58{margin-left:-58px!important}.m-lg-n60{margin:-60px!important}.mt-lg-n60,.my-lg-n60{margin-top:-60px!important}.mr-lg-n60,.mx-lg-n60{margin-right:-60px!important}.mb-lg-n60,.my-lg-n60{margin-bottom:-60px!important}.ml-lg-n60,.mx-lg-n60{margin-left:-60px!important}.m-lg-n64{margin:-64px!important}.mt-lg-n64,.my-lg-n64{margin-top:-64px!important}.mr-lg-n64,.mx-lg-n64{margin-right:-64px!important}.mb-lg-n64,.my-lg-n64{margin-bottom:-64px!important}.ml-lg-n64,.mx-lg-n64{margin-left:-64px!important}.m-lg-auto{margin:auto!important}.mt-lg-auto,.my-lg-auto{margin-top:auto!important}.mr-lg-auto,.mx-lg-auto{margin-right:auto!important}.mb-lg-auto,.my-lg-auto{margin-bottom:auto!important}.ml-lg-auto,.mx-lg-auto{margin-left:auto!important}.text-lg-left{text-align:left!important}.text-lg-right{text-align:right!important}.text-lg-center{text-align:center!important}}@media (min-width:1200px){.flex-xl-row{flex-direction:row!important}.flex-xl-column{flex-direction:column!important}.flex-xl-row-reverse{flex-direction:row-reverse!important}.flex-xl-column-reverse{flex-direction:column-reverse!important}.flex-xl-wrap{flex-wrap:wrap!important}.flex-xl-nowrap{flex-wrap:nowrap!important}.flex-xl-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-xl-fill{flex:1 1 auto!important}.flex-xl-grow-0{flex-grow:0!important}.flex-xl-grow-1{flex-grow:1!important}.flex-xl-shrink-0{flex-shrink:0!important}.flex-xl-shrink-1{flex-shrink:1!important}.justify-content-xl-start{justify-content:flex-start!important}.justify-content-xl-end{justify-content:flex-end!important}.justify-content-xl-center{justify-content:center!important}.justify-content-xl-between{justify-content:space-between!important}.justify-content-xl-around{justify-content:space-around!important}.align-items-xl-start{align-items:flex-start!important}.align-items-xl-end{align-items:flex-end!important}.align-items-xl-center{align-items:center!important}.align-items-xl-baseline{align-items:baseline!important}.align-items-xl-stretch{align-items:stretch!important}.align-content-xl-start{align-content:flex-start!important}.align-content-xl-end{align-content:flex-end!important}.align-content-xl-center{align-content:center!important}.align-content-xl-between{align-content:space-between!important}.align-content-xl-around{align-content:space-around!important}.align-content-xl-stretch{align-content:stretch!important}.align-self-xl-auto{align-self:auto!important}.align-self-xl-start{align-self:flex-start!important}.align-self-xl-end{align-self:flex-end!important}.align-self-xl-center{align-self:center!important}.align-self-xl-baseline{align-self:baseline!important}.align-self-xl-stretch{align-self:stretch!important}.float-xl-left{float:left!important}.float-xl-right{float:right!important}.float-xl-none{float:none!important}.m-xl-0{margin:0!important}.mt-xl-0,.my-xl-0{margin-top:0!important}.mr-xl-0,.mx-xl-0{margin-right:0!important}.mb-xl-0,.my-xl-0{margin-bottom:0!important}.ml-xl-0,.mx-xl-0{margin-left:0!important}.m-xl-1{margin:1px!important}.mt-xl-1,.my-xl-1{margin-top:1px!important}.mr-xl-1,.mx-xl-1{margin-right:1px!important}.mb-xl-1,.my-xl-1{margin-bottom:1px!important}.ml-xl-1,.mx-xl-1{margin-left:1px!important}.m-xl-2{margin:2px!important}.mt-xl-2,.my-xl-2{margin-top:2px!important}.mr-xl-2,.mx-xl-2{margin-right:2px!important}.mb-xl-2,.my-xl-2{margin-bottom:2px!important}.ml-xl-2,.mx-xl-2{margin-left:2px!important}.m-xl-3{margin:3px!important}.mt-xl-3,.my-xl-3{margin-top:3px!important}.mr-xl-3,.mx-xl-3{margin-right:3px!important}.mb-xl-3,.my-xl-3{margin-bottom:3px!important}.ml-xl-3,.mx-xl-3{margin-left:3px!important}.m-xl-4{margin:4px!important}.mt-xl-4,.my-xl-4{margin-top:4px!important}.mr-xl-4,.mx-xl-4{margin-right:4px!important}.mb-xl-4,.my-xl-4{margin-bottom:4px!important}.ml-xl-4,.mx-xl-4{margin-left:4px!important}.m-xl-5{margin:5px!important}.mt-xl-5,.my-xl-5{margin-top:5px!important}.mr-xl-5,.mx-xl-5{margin-right:5px!important}.mb-xl-5,.my-xl-5{margin-bottom:5px!important}.ml-xl-5,.mx-xl-5{margin-left:5px!important}.m-xl-6{margin:6px!important}.mt-xl-6,.my-xl-6{margin-top:6px!important}.mr-xl-6,.mx-xl-6{margin-right:6px!important}.mb-xl-6,.my-xl-6{margin-bottom:6px!important}.ml-xl-6,.mx-xl-6{margin-left:6px!important}.m-xl-7{margin:7px!important}.mt-xl-7,.my-xl-7{margin-top:7px!important}.mr-xl-7,.mx-xl-7{margin-right:7px!important}.mb-xl-7,.my-xl-7{margin-bottom:7px!important}.ml-xl-7,.mx-xl-7{margin-left:7px!important}.m-xl-8{margin:8px!important}.mt-xl-8,.my-xl-8{margin-top:8px!important}.mr-xl-8,.mx-xl-8{margin-right:8px!important}.mb-xl-8,.my-xl-8{margin-bottom:8px!important}.ml-xl-8,.mx-xl-8{margin-left:8px!important}.m-xl-9{margin:9px!important}.mt-xl-9,.my-xl-9{margin-top:9px!important}.mr-xl-9,.mx-xl-9{margin-right:9px!important}.mb-xl-9,.my-xl-9{margin-bottom:9px!important}.ml-xl-9,.mx-xl-9{margin-left:9px!important}.m-xl-10{margin:10px!important}.mt-xl-10,.my-xl-10{margin-top:10px!important}.mr-xl-10,.mx-xl-10{margin-right:10px!important}.mb-xl-10,.my-xl-10{margin-bottom:10px!important}.ml-xl-10,.mx-xl-10{margin-left:10px!important}.m-xl-11{margin:11px!important}.mt-xl-11,.my-xl-11{margin-top:11px!important}.mr-xl-11,.mx-xl-11{margin-right:11px!important}.mb-xl-11,.my-xl-11{margin-bottom:11px!important}.ml-xl-11,.mx-xl-11{margin-left:11px!important}.m-xl-12{margin:12px!important}.mt-xl-12,.my-xl-12{margin-top:12px!important}.mr-xl-12,.mx-xl-12{margin-right:12px!important}.mb-xl-12,.my-xl-12{margin-bottom:12px!important}.ml-xl-12,.mx-xl-12{margin-left:12px!important}.m-xl-13{margin:13px!important}.mt-xl-13,.my-xl-13{margin-top:13px!important}.mr-xl-13,.mx-xl-13{margin-right:13px!important}.mb-xl-13,.my-xl-13{margin-bottom:13px!important}.ml-xl-13,.mx-xl-13{margin-left:13px!important}.m-xl-14{margin:14px!important}.mt-xl-14,.my-xl-14{margin-top:14px!important}.mr-xl-14,.mx-xl-14{margin-right:14px!important}.mb-xl-14,.my-xl-14{margin-bottom:14px!important}.ml-xl-14,.mx-xl-14{margin-left:14px!important}.m-xl-15{margin:15px!important}.mt-xl-15,.my-xl-15{margin-top:15px!important}.mr-xl-15,.mx-xl-15{margin-right:15px!important}.mb-xl-15,.my-xl-15{margin-bottom:15px!important}.ml-xl-15,.mx-xl-15{margin-left:15px!important}.m-xl-16{margin:16px!important}.mt-xl-16,.my-xl-16{margin-top:16px!important}.mr-xl-16,.mx-xl-16{margin-right:16px!important}.mb-xl-16,.my-xl-16{margin-bottom:16px!important}.ml-xl-16,.mx-xl-16{margin-left:16px!important}.m-xl-18{margin:18px!important}.mt-xl-18,.my-xl-18{margin-top:18px!important}.mr-xl-18,.mx-xl-18{margin-right:18px!important}.mb-xl-18,.my-xl-18{margin-bottom:18px!important}.ml-xl-18,.mx-xl-18{margin-left:18px!important}.m-xl-20{margin:20px!important}.mt-xl-20,.my-xl-20{margin-top:20px!important}.mr-xl-20,.mx-xl-20{margin-right:20px!important}.mb-xl-20,.my-xl-20{margin-bottom:20px!important}.ml-xl-20,.mx-xl-20{margin-left:20px!important}.m-xl-21{margin:21px!important}.mt-xl-21,.my-xl-21{margin-top:21px!important}.mr-xl-21,.mx-xl-21{margin-right:21px!important}.mb-xl-21,.my-xl-21{margin-bottom:21px!important}.ml-xl-21,.mx-xl-21{margin-left:21px!important}.m-xl-23{margin:23px!important}.mt-xl-23,.my-xl-23{margin-top:23px!important}.mr-xl-23,.mx-xl-23{margin-right:23px!important}.mb-xl-23,.my-xl-23{margin-bottom:23px!important}.ml-xl-23,.mx-xl-23{margin-left:23px!important}.m-xl-24{margin:24px!important}.mt-xl-24,.my-xl-24{margin-top:24px!important}.mr-xl-24,.mx-xl-24{margin-right:24px!important}.mb-xl-24,.my-xl-24{margin-bottom:24px!important}.ml-xl-24,.mx-xl-24{margin-left:24px!important}.m-xl-26{margin:26px!important}.mt-xl-26,.my-xl-26{margin-top:26px!important}.mr-xl-26,.mx-xl-26{margin-right:26px!important}.mb-xl-26,.my-xl-26{margin-bottom:26px!important}.ml-xl-26,.mx-xl-26{margin-left:26px!important}.m-xl-28{margin:28px!important}.mt-xl-28,.my-xl-28{margin-top:28px!important}.mr-xl-28,.mx-xl-28{margin-right:28px!important}.mb-xl-28,.my-xl-28{margin-bottom:28px!important}.ml-xl-28,.mx-xl-28{margin-left:28px!important}.m-xl-29{margin:29px!important}.mt-xl-29,.my-xl-29{margin-top:29px!important}.mr-xl-29,.mx-xl-29{margin-right:29px!important}.mb-xl-29,.my-xl-29{margin-bottom:29px!important}.ml-xl-29,.mx-xl-29{margin-left:29px!important}.m-xl-30{margin:30px!important}.mt-xl-30,.my-xl-30{margin-top:30px!important}.mr-xl-30,.mx-xl-30{margin-right:30px!important}.mb-xl-30,.my-xl-30{margin-bottom:30px!important}.ml-xl-30,.mx-xl-30{margin-left:30px!important}.m-xl-32{margin:32px!important}.mt-xl-32,.my-xl-32{margin-top:32px!important}.mr-xl-32,.mx-xl-32{margin-right:32px!important}.mb-xl-32,.my-xl-32{margin-bottom:32px!important}.ml-xl-32,.mx-xl-32{margin-left:32px!important}.m-xl-38{margin:38px!important}.mt-xl-38,.my-xl-38{margin-top:38px!important}.mr-xl-38,.mx-xl-38{margin-right:38px!important}.mb-xl-38,.my-xl-38{margin-bottom:38px!important}.ml-xl-38,.mx-xl-38{margin-left:38px!important}.m-xl-40{margin:40px!important}.mt-xl-40,.my-xl-40{margin-top:40px!important}.mr-xl-40,.mx-xl-40{margin-right:40px!important}.mb-xl-40,.my-xl-40{margin-bottom:40px!important}.ml-xl-40,.mx-xl-40{margin-left:40px!important}.m-xl-42{margin:42px!important}.mt-xl-42,.my-xl-42{margin-top:42px!important}.mr-xl-42,.mx-xl-42{margin-right:42px!important}.mb-xl-42,.my-xl-42{margin-bottom:42px!important}.ml-xl-42,.mx-xl-42{margin-left:42px!important}.m-xl-48{margin:48px!important}.mt-xl-48,.my-xl-48{margin-top:48px!important}.mr-xl-48,.mx-xl-48{margin-right:48px!important}.mb-xl-48,.my-xl-48{margin-bottom:48px!important}.ml-xl-48,.mx-xl-48{margin-left:48px!important}.m-xl-50{margin:50px!important}.mt-xl-50,.my-xl-50{margin-top:50px!important}.mr-xl-50,.mx-xl-50{margin-right:50px!important}.mb-xl-50,.my-xl-50{margin-bottom:50px!important}.ml-xl-50,.mx-xl-50{margin-left:50px!important}.m-xl-56{margin:56px!important}.mt-xl-56,.my-xl-56{margin-top:56px!important}.mr-xl-56,.mx-xl-56{margin-right:56px!important}.mb-xl-56,.my-xl-56{margin-bottom:56px!important}.ml-xl-56,.mx-xl-56{margin-left:56px!important}.m-xl-58{margin:58px!important}.mt-xl-58,.my-xl-58{margin-top:58px!important}.mr-xl-58,.mx-xl-58{margin-right:58px!important}.mb-xl-58,.my-xl-58{margin-bottom:58px!important}.ml-xl-58,.mx-xl-58{margin-left:58px!important}.m-xl-60{margin:60px!important}.mt-xl-60,.my-xl-60{margin-top:60px!important}.mr-xl-60,.mx-xl-60{margin-right:60px!important}.mb-xl-60,.my-xl-60{margin-bottom:60px!important}.ml-xl-60,.mx-xl-60{margin-left:60px!important}.m-xl-64{margin:64px!important}.mt-xl-64,.my-xl-64{margin-top:64px!important}.mr-xl-64,.mx-xl-64{margin-right:64px!important}.mb-xl-64,.my-xl-64{margin-bottom:64px!important}.ml-xl-64,.mx-xl-64{margin-left:64px!important}.p-xl-0{padding:0!important}.pt-xl-0,.py-xl-0{padding-top:0!important}.pr-xl-0,.px-xl-0{padding-right:0!important}.pb-xl-0,.py-xl-0{padding-bottom:0!important}.pl-xl-0,.px-xl-0{padding-left:0!important}.p-xl-1{padding:1px!important}.pt-xl-1,.py-xl-1{padding-top:1px!important}.pr-xl-1,.px-xl-1{padding-right:1px!important}.pb-xl-1,.py-xl-1{padding-bottom:1px!important}.pl-xl-1,.px-xl-1{padding-left:1px!important}.p-xl-2{padding:2px!important}.pt-xl-2,.py-xl-2{padding-top:2px!important}.pr-xl-2,.px-xl-2{padding-right:2px!important}.pb-xl-2,.py-xl-2{padding-bottom:2px!important}.pl-xl-2,.px-xl-2{padding-left:2px!important}.p-xl-3{padding:3px!important}.pt-xl-3,.py-xl-3{padding-top:3px!important}.pr-xl-3,.px-xl-3{padding-right:3px!important}.pb-xl-3,.py-xl-3{padding-bottom:3px!important}.pl-xl-3,.px-xl-3{padding-left:3px!important}.p-xl-4{padding:4px!important}.pt-xl-4,.py-xl-4{padding-top:4px!important}.pr-xl-4,.px-xl-4{padding-right:4px!important}.pb-xl-4,.py-xl-4{padding-bottom:4px!important}.pl-xl-4,.px-xl-4{padding-left:4px!important}.p-xl-5{padding:5px!important}.pt-xl-5,.py-xl-5{padding-top:5px!important}.pr-xl-5,.px-xl-5{padding-right:5px!important}.pb-xl-5,.py-xl-5{padding-bottom:5px!important}.pl-xl-5,.px-xl-5{padding-left:5px!important}.p-xl-6{padding:6px!important}.pt-xl-6,.py-xl-6{padding-top:6px!important}.pr-xl-6,.px-xl-6{padding-right:6px!important}.pb-xl-6,.py-xl-6{padding-bottom:6px!important}.pl-xl-6,.px-xl-6{padding-left:6px!important}.p-xl-7{padding:7px!important}.pt-xl-7,.py-xl-7{padding-top:7px!important}.pr-xl-7,.px-xl-7{padding-right:7px!important}.pb-xl-7,.py-xl-7{padding-bottom:7px!important}.pl-xl-7,.px-xl-7{padding-left:7px!important}.p-xl-8{padding:8px!important}.pt-xl-8,.py-xl-8{padding-top:8px!important}.pr-xl-8,.px-xl-8{padding-right:8px!important}.pb-xl-8,.py-xl-8{padding-bottom:8px!important}.pl-xl-8,.px-xl-8{padding-left:8px!important}.p-xl-9{padding:9px!important}.pt-xl-9,.py-xl-9{padding-top:9px!important}.pr-xl-9,.px-xl-9{padding-right:9px!important}.pb-xl-9,.py-xl-9{padding-bottom:9px!important}.pl-xl-9,.px-xl-9{padding-left:9px!important}.p-xl-10{padding:10px!important}.pt-xl-10,.py-xl-10{padding-top:10px!important}.pr-xl-10,.px-xl-10{padding-right:10px!important}.pb-xl-10,.py-xl-10{padding-bottom:10px!important}.pl-xl-10,.px-xl-10{padding-left:10px!important}.p-xl-11{padding:11px!important}.pt-xl-11,.py-xl-11{padding-top:11px!important}.pr-xl-11,.px-xl-11{padding-right:11px!important}.pb-xl-11,.py-xl-11{padding-bottom:11px!important}.pl-xl-11,.px-xl-11{padding-left:11px!important}.p-xl-12{padding:12px!important}.pt-xl-12,.py-xl-12{padding-top:12px!important}.pr-xl-12,.px-xl-12{padding-right:12px!important}.pb-xl-12,.py-xl-12{padding-bottom:12px!important}.pl-xl-12,.px-xl-12{padding-left:12px!important}.p-xl-13{padding:13px!important}.pt-xl-13,.py-xl-13{padding-top:13px!important}.pr-xl-13,.px-xl-13{padding-right:13px!important}.pb-xl-13,.py-xl-13{padding-bottom:13px!important}.pl-xl-13,.px-xl-13{padding-left:13px!important}.p-xl-14{padding:14px!important}.pt-xl-14,.py-xl-14{padding-top:14px!important}.pr-xl-14,.px-xl-14{padding-right:14px!important}.pb-xl-14,.py-xl-14{padding-bottom:14px!important}.pl-xl-14,.px-xl-14{padding-left:14px!important}.p-xl-15{padding:15px!important}.pt-xl-15,.py-xl-15{padding-top:15px!important}.pr-xl-15,.px-xl-15{padding-right:15px!important}.pb-xl-15,.py-xl-15{padding-bottom:15px!important}.pl-xl-15,.px-xl-15{padding-left:15px!important}.p-xl-16{padding:16px!important}.pt-xl-16,.py-xl-16{padding-top:16px!important}.pr-xl-16,.px-xl-16{padding-right:16px!important}.pb-xl-16,.py-xl-16{padding-bottom:16px!important}.pl-xl-16,.px-xl-16{padding-left:16px!important}.p-xl-18{padding:18px!important}.pt-xl-18,.py-xl-18{padding-top:18px!important}.pr-xl-18,.px-xl-18{padding-right:18px!important}.pb-xl-18,.py-xl-18{padding-bottom:18px!important}.pl-xl-18,.px-xl-18{padding-left:18px!important}.p-xl-20{padding:20px!important}.pt-xl-20,.py-xl-20{padding-top:20px!important}.pr-xl-20,.px-xl-20{padding-right:20px!important}.pb-xl-20,.py-xl-20{padding-bottom:20px!important}.pl-xl-20,.px-xl-20{padding-left:20px!important}.p-xl-21{padding:21px!important}.pt-xl-21,.py-xl-21{padding-top:21px!important}.pr-xl-21,.px-xl-21{padding-right:21px!important}.pb-xl-21,.py-xl-21{padding-bottom:21px!important}.pl-xl-21,.px-xl-21{padding-left:21px!important}.p-xl-23{padding:23px!important}.pt-xl-23,.py-xl-23{padding-top:23px!important}.pr-xl-23,.px-xl-23{padding-right:23px!important}.pb-xl-23,.py-xl-23{padding-bottom:23px!important}.pl-xl-23,.px-xl-23{padding-left:23px!important}.p-xl-24{padding:24px!important}.pt-xl-24,.py-xl-24{padding-top:24px!important}.pr-xl-24,.px-xl-24{padding-right:24px!important}.pb-xl-24,.py-xl-24{padding-bottom:24px!important}.pl-xl-24,.px-xl-24{padding-left:24px!important}.p-xl-26{padding:26px!important}.pt-xl-26,.py-xl-26{padding-top:26px!important}.pr-xl-26,.px-xl-26{padding-right:26px!important}.pb-xl-26,.py-xl-26{padding-bottom:26px!important}.pl-xl-26,.px-xl-26{padding-left:26px!important}.p-xl-28{padding:28px!important}.pt-xl-28,.py-xl-28{padding-top:28px!important}.pr-xl-28,.px-xl-28{padding-right:28px!important}.pb-xl-28,.py-xl-28{padding-bottom:28px!important}.pl-xl-28,.px-xl-28{padding-left:28px!important}.p-xl-29{padding:29px!important}.pt-xl-29,.py-xl-29{padding-top:29px!important}.pr-xl-29,.px-xl-29{padding-right:29px!important}.pb-xl-29,.py-xl-29{padding-bottom:29px!important}.pl-xl-29,.px-xl-29{padding-left:29px!important}.p-xl-30{padding:30px!important}.pt-xl-30,.py-xl-30{padding-top:30px!important}.pr-xl-30,.px-xl-30{padding-right:30px!important}.pb-xl-30,.py-xl-30{padding-bottom:30px!important}.pl-xl-30,.px-xl-30{padding-left:30px!important}.p-xl-32{padding:32px!important}.pt-xl-32,.py-xl-32{padding-top:32px!important}.pr-xl-32,.px-xl-32{padding-right:32px!important}.pb-xl-32,.py-xl-32{padding-bottom:32px!important}.pl-xl-32,.px-xl-32{padding-left:32px!important}.p-xl-38{padding:38px!important}.pt-xl-38,.py-xl-38{padding-top:38px!important}.pr-xl-38,.px-xl-38{padding-right:38px!important}.pb-xl-38,.py-xl-38{padding-bottom:38px!important}.pl-xl-38,.px-xl-38{padding-left:38px!important}.p-xl-40{padding:40px!important}.pt-xl-40,.py-xl-40{padding-top:40px!important}.pr-xl-40,.px-xl-40{padding-right:40px!important}.pb-xl-40,.py-xl-40{padding-bottom:40px!important}.pl-xl-40,.px-xl-40{padding-left:40px!important}.p-xl-42{padding:42px!important}.pt-xl-42,.py-xl-42{padding-top:42px!important}.pr-xl-42,.px-xl-42{padding-right:42px!important}.pb-xl-42,.py-xl-42{padding-bottom:42px!important}.pl-xl-42,.px-xl-42{padding-left:42px!important}.p-xl-48{padding:48px!important}.pt-xl-48,.py-xl-48{padding-top:48px!important}.pr-xl-48,.px-xl-48{padding-right:48px!important}.pb-xl-48,.py-xl-48{padding-bottom:48px!important}.pl-xl-48,.px-xl-48{padding-left:48px!important}.p-xl-50{padding:50px!important}.pt-xl-50,.py-xl-50{padding-top:50px!important}.pr-xl-50,.px-xl-50{padding-right:50px!important}.pb-xl-50,.py-xl-50{padding-bottom:50px!important}.pl-xl-50,.px-xl-50{padding-left:50px!important}.p-xl-56{padding:56px!important}.pt-xl-56,.py-xl-56{padding-top:56px!important}.pr-xl-56,.px-xl-56{padding-right:56px!important}.pb-xl-56,.py-xl-56{padding-bottom:56px!important}.pl-xl-56,.px-xl-56{padding-left:56px!important}.p-xl-58{padding:58px!important}.pt-xl-58,.py-xl-58{padding-top:58px!important}.pr-xl-58,.px-xl-58{padding-right:58px!important}.pb-xl-58,.py-xl-58{padding-bottom:58px!important}.pl-xl-58,.px-xl-58{padding-left:58px!important}.p-xl-60{padding:60px!important}.pt-xl-60,.py-xl-60{padding-top:60px!important}.pr-xl-60,.px-xl-60{padding-right:60px!important}.pb-xl-60,.py-xl-60{padding-bottom:60px!important}.pl-xl-60,.px-xl-60{padding-left:60px!important}.p-xl-64{padding:64px!important}.pt-xl-64,.py-xl-64{padding-top:64px!important}.pr-xl-64,.px-xl-64{padding-right:64px!important}.pb-xl-64,.py-xl-64{padding-bottom:64px!important}.pl-xl-64,.px-xl-64{padding-left:64px!important}.m-xl-n1{margin:-1px!important}.mt-xl-n1,.my-xl-n1{margin-top:-1px!important}.mr-xl-n1,.mx-xl-n1{margin-right:-1px!important}.mb-xl-n1,.my-xl-n1{margin-bottom:-1px!important}.ml-xl-n1,.mx-xl-n1{margin-left:-1px!important}.m-xl-n2{margin:-2px!important}.mt-xl-n2,.my-xl-n2{margin-top:-2px!important}.mr-xl-n2,.mx-xl-n2{margin-right:-2px!important}.mb-xl-n2,.my-xl-n2{margin-bottom:-2px!important}.ml-xl-n2,.mx-xl-n2{margin-left:-2px!important}.m-xl-n3{margin:-3px!important}.mt-xl-n3,.my-xl-n3{margin-top:-3px!important}.mr-xl-n3,.mx-xl-n3{margin-right:-3px!important}.mb-xl-n3,.my-xl-n3{margin-bottom:-3px!important}.ml-xl-n3,.mx-xl-n3{margin-left:-3px!important}.m-xl-n4{margin:-4px!important}.mt-xl-n4,.my-xl-n4{margin-top:-4px!important}.mr-xl-n4,.mx-xl-n4{margin-right:-4px!important}.mb-xl-n4,.my-xl-n4{margin-bottom:-4px!important}.ml-xl-n4,.mx-xl-n4{margin-left:-4px!important}.m-xl-n5{margin:-5px!important}.mt-xl-n5,.my-xl-n5{margin-top:-5px!important}.mr-xl-n5,.mx-xl-n5{margin-right:-5px!important}.mb-xl-n5,.my-xl-n5{margin-bottom:-5px!important}.ml-xl-n5,.mx-xl-n5{margin-left:-5px!important}.m-xl-n6{margin:-6px!important}.mt-xl-n6,.my-xl-n6{margin-top:-6px!important}.mr-xl-n6,.mx-xl-n6{margin-right:-6px!important}.mb-xl-n6,.my-xl-n6{margin-bottom:-6px!important}.ml-xl-n6,.mx-xl-n6{margin-left:-6px!important}.m-xl-n7{margin:-7px!important}.mt-xl-n7,.my-xl-n7{margin-top:-7px!important}.mr-xl-n7,.mx-xl-n7{margin-right:-7px!important}.mb-xl-n7,.my-xl-n7{margin-bottom:-7px!important}.ml-xl-n7,.mx-xl-n7{margin-left:-7px!important}.m-xl-n8{margin:-8px!important}.mt-xl-n8,.my-xl-n8{margin-top:-8px!important}.mr-xl-n8,.mx-xl-n8{margin-right:-8px!important}.mb-xl-n8,.my-xl-n8{margin-bottom:-8px!important}.ml-xl-n8,.mx-xl-n8{margin-left:-8px!important}.m-xl-n9{margin:-9px!important}.mt-xl-n9,.my-xl-n9{margin-top:-9px!important}.mr-xl-n9,.mx-xl-n9{margin-right:-9px!important}.mb-xl-n9,.my-xl-n9{margin-bottom:-9px!important}.ml-xl-n9,.mx-xl-n9{margin-left:-9px!important}.m-xl-n10{margin:-10px!important}.mt-xl-n10,.my-xl-n10{margin-top:-10px!important}.mr-xl-n10,.mx-xl-n10{margin-right:-10px!important}.mb-xl-n10,.my-xl-n10{margin-bottom:-10px!important}.ml-xl-n10,.mx-xl-n10{margin-left:-10px!important}.m-xl-n11{margin:-11px!important}.mt-xl-n11,.my-xl-n11{margin-top:-11px!important}.mr-xl-n11,.mx-xl-n11{margin-right:-11px!important}.mb-xl-n11,.my-xl-n11{margin-bottom:-11px!important}.ml-xl-n11,.mx-xl-n11{margin-left:-11px!important}.m-xl-n12{margin:-12px!important}.mt-xl-n12,.my-xl-n12{margin-top:-12px!important}.mr-xl-n12,.mx-xl-n12{margin-right:-12px!important}.mb-xl-n12,.my-xl-n12{margin-bottom:-12px!important}.ml-xl-n12,.mx-xl-n12{margin-left:-12px!important}.m-xl-n13{margin:-13px!important}.mt-xl-n13,.my-xl-n13{margin-top:-13px!important}.mr-xl-n13,.mx-xl-n13{margin-right:-13px!important}.mb-xl-n13,.my-xl-n13{margin-bottom:-13px!important}.ml-xl-n13,.mx-xl-n13{margin-left:-13px!important}.m-xl-n14{margin:-14px!important}.mt-xl-n14,.my-xl-n14{margin-top:-14px!important}.mr-xl-n14,.mx-xl-n14{margin-right:-14px!important}.mb-xl-n14,.my-xl-n14{margin-bottom:-14px!important}.ml-xl-n14,.mx-xl-n14{margin-left:-14px!important}.m-xl-n15{margin:-15px!important}.mt-xl-n15,.my-xl-n15{margin-top:-15px!important}.mr-xl-n15,.mx-xl-n15{margin-right:-15px!important}.mb-xl-n15,.my-xl-n15{margin-bottom:-15px!important}.ml-xl-n15,.mx-xl-n15{margin-left:-15px!important}.m-xl-n16{margin:-16px!important}.mt-xl-n16,.my-xl-n16{margin-top:-16px!important}.mr-xl-n16,.mx-xl-n16{margin-right:-16px!important}.mb-xl-n16,.my-xl-n16{margin-bottom:-16px!important}.ml-xl-n16,.mx-xl-n16{margin-left:-16px!important}.m-xl-n18{margin:-18px!important}.mt-xl-n18,.my-xl-n18{margin-top:-18px!important}.mr-xl-n18,.mx-xl-n18{margin-right:-18px!important}.mb-xl-n18,.my-xl-n18{margin-bottom:-18px!important}.ml-xl-n18,.mx-xl-n18{margin-left:-18px!important}.m-xl-n20{margin:-20px!important}.mt-xl-n20,.my-xl-n20{margin-top:-20px!important}.mr-xl-n20,.mx-xl-n20{margin-right:-20px!important}.mb-xl-n20,.my-xl-n20{margin-bottom:-20px!important}.ml-xl-n20,.mx-xl-n20{margin-left:-20px!important}.m-xl-n21{margin:-21px!important}.mt-xl-n21,.my-xl-n21{margin-top:-21px!important}.mr-xl-n21,.mx-xl-n21{margin-right:-21px!important}.mb-xl-n21,.my-xl-n21{margin-bottom:-21px!important}.ml-xl-n21,.mx-xl-n21{margin-left:-21px!important}.m-xl-n23{margin:-23px!important}.mt-xl-n23,.my-xl-n23{margin-top:-23px!important}.mr-xl-n23,.mx-xl-n23{margin-right:-23px!important}.mb-xl-n23,.my-xl-n23{margin-bottom:-23px!important}.ml-xl-n23,.mx-xl-n23{margin-left:-23px!important}.m-xl-n24{margin:-24px!important}.mt-xl-n24,.my-xl-n24{margin-top:-24px!important}.mr-xl-n24,.mx-xl-n24{margin-right:-24px!important}.mb-xl-n24,.my-xl-n24{margin-bottom:-24px!important}.ml-xl-n24,.mx-xl-n24{margin-left:-24px!important}.m-xl-n26{margin:-26px!important}.mt-xl-n26,.my-xl-n26{margin-top:-26px!important}.mr-xl-n26,.mx-xl-n26{margin-right:-26px!important}.mb-xl-n26,.my-xl-n26{margin-bottom:-26px!important}.ml-xl-n26,.mx-xl-n26{margin-left:-26px!important}.m-xl-n28{margin:-28px!important}.mt-xl-n28,.my-xl-n28{margin-top:-28px!important}.mr-xl-n28,.mx-xl-n28{margin-right:-28px!important}.mb-xl-n28,.my-xl-n28{margin-bottom:-28px!important}.ml-xl-n28,.mx-xl-n28{margin-left:-28px!important}.m-xl-n29{margin:-29px!important}.mt-xl-n29,.my-xl-n29{margin-top:-29px!important}.mr-xl-n29,.mx-xl-n29{margin-right:-29px!important}.mb-xl-n29,.my-xl-n29{margin-bottom:-29px!important}.ml-xl-n29,.mx-xl-n29{margin-left:-29px!important}.m-xl-n30{margin:-30px!important}.mt-xl-n30,.my-xl-n30{margin-top:-30px!important}.mr-xl-n30,.mx-xl-n30{margin-right:-30px!important}.mb-xl-n30,.my-xl-n30{margin-bottom:-30px!important}.ml-xl-n30,.mx-xl-n30{margin-left:-30px!important}.m-xl-n32{margin:-32px!important}.mt-xl-n32,.my-xl-n32{margin-top:-32px!important}.mr-xl-n32,.mx-xl-n32{margin-right:-32px!important}.mb-xl-n32,.my-xl-n32{margin-bottom:-32px!important}.ml-xl-n32,.mx-xl-n32{margin-left:-32px!important}.m-xl-n38{margin:-38px!important}.mt-xl-n38,.my-xl-n38{margin-top:-38px!important}.mr-xl-n38,.mx-xl-n38{margin-right:-38px!important}.mb-xl-n38,.my-xl-n38{margin-bottom:-38px!important}.ml-xl-n38,.mx-xl-n38{margin-left:-38px!important}.m-xl-n40{margin:-40px!important}.mt-xl-n40,.my-xl-n40{margin-top:-40px!important}.mr-xl-n40,.mx-xl-n40{margin-right:-40px!important}.mb-xl-n40,.my-xl-n40{margin-bottom:-40px!important}.ml-xl-n40,.mx-xl-n40{margin-left:-40px!important}.m-xl-n42{margin:-42px!important}.mt-xl-n42,.my-xl-n42{margin-top:-42px!important}.mr-xl-n42,.mx-xl-n42{margin-right:-42px!important}.mb-xl-n42,.my-xl-n42{margin-bottom:-42px!important}.ml-xl-n42,.mx-xl-n42{margin-left:-42px!important}.m-xl-n48{margin:-48px!important}.mt-xl-n48,.my-xl-n48{margin-top:-48px!important}.mr-xl-n48,.mx-xl-n48{margin-right:-48px!important}.mb-xl-n48,.my-xl-n48{margin-bottom:-48px!important}.ml-xl-n48,.mx-xl-n48{margin-left:-48px!important}.m-xl-n50{margin:-50px!important}.mt-xl-n50,.my-xl-n50{margin-top:-50px!important}.mr-xl-n50,.mx-xl-n50{margin-right:-50px!important}.mb-xl-n50,.my-xl-n50{margin-bottom:-50px!important}.ml-xl-n50,.mx-xl-n50{margin-left:-50px!important}.m-xl-n56{margin:-56px!important}.mt-xl-n56,.my-xl-n56{margin-top:-56px!important}.mr-xl-n56,.mx-xl-n56{margin-right:-56px!important}.mb-xl-n56,.my-xl-n56{margin-bottom:-56px!important}.ml-xl-n56,.mx-xl-n56{margin-left:-56px!important}.m-xl-n58{margin:-58px!important}.mt-xl-n58,.my-xl-n58{margin-top:-58px!important}.mr-xl-n58,.mx-xl-n58{margin-right:-58px!important}.mb-xl-n58,.my-xl-n58{margin-bottom:-58px!important}.ml-xl-n58,.mx-xl-n58{margin-left:-58px!important}.m-xl-n60{margin:-60px!important}.mt-xl-n60,.my-xl-n60{margin-top:-60px!important}.mr-xl-n60,.mx-xl-n60{margin-right:-60px!important}.mb-xl-n60,.my-xl-n60{margin-bottom:-60px!important}.ml-xl-n60,.mx-xl-n60{margin-left:-60px!important}.m-xl-n64{margin:-64px!important}.mt-xl-n64,.my-xl-n64{margin-top:-64px!important}.mr-xl-n64,.mx-xl-n64{margin-right:-64px!important}.mb-xl-n64,.my-xl-n64{margin-bottom:-64px!important}.ml-xl-n64,.mx-xl-n64{margin-left:-64px!important}.m-xl-auto{margin:auto!important}.mt-xl-auto,.my-xl-auto{margin-top:auto!important}.mr-xl-auto,.mx-xl-auto{margin-right:auto!important}.mb-xl-auto,.my-xl-auto{margin-bottom:auto!important}.ml-xl-auto,.mx-xl-auto{margin-left:auto!important}.text-xl-left{text-align:left!important}.text-xl-right{text-align:right!important}.text-xl-center{text-align:center!important}}.text-lowercase{text-transform:lowercase!important}.text-uppercase{text-transform:uppercase!important}.text-capitalize{text-transform:capitalize!important}.font-weight-light{font-weight:300!important}.font-weight-lighter{font-weight:lighter!important}.font-weight-normal{font-weight:400!important}.font-weight-bold{font-weight:700!important}.font-weight-bolder{font-weight:bolder!important}.font-italic{font-style:italic!important}.text-white{color:#fff!important}.text-primary{color:#c82c37!important}a.text-primary:focus,a.text-primary:hover{color:#891e26!important}.text-secondary{color:#919191!important}a.text-secondary:focus,a.text-secondary:hover{color:#6b6b6b!important}.text-success{color:#4caf50!important}a.text-success:focus,a.text-success:hover{color:#357a38!important}.text-info{color:#00bcd4!important}a.text-info:focus,a.text-info:hover{color:#007888!important}.text-warning{color:#ff9800!important}a.text-warning:focus,a.text-warning:hover{color:#b36a00!important}.text-danger{color:#f44336!important}a.text-danger:focus,a.text-danger:hover{color:#d2190b!important}.text-light{color:#f8f9fa!important}a.text-light:focus,a.text-light:hover{color:#cbd3da!important}.text-dark{color:#343a40!important}a.text-dark:focus,a.text-dark:hover{color:#121416!important}.text-body{color:#212529!important}.text-muted{color:#6c757d!important}.text-black-50{color:rgba(0,0,0,.5)!important}.text-white-50{color:rgba(255,255,255,.5)!important}.text-hide{font:0/0 a;color:transparent;text-shadow:none;background-color:transparent;border:0}.text-decoration-none{text-decoration:none!important}.text-break{word-wrap:break-word!important}.text-reset{color:inherit!important}.visible{visibility:visible!important}.invisible{visibility:hidden!important}@media print{*,::after,::before{text-shadow:none!important;box-shadow:none!important}a:not(.btn){text-decoration:underline}abbr[title]::after{content:\" (\" attr(title) \")\"}pre{white-space:pre-wrap!important}blockquote,pre{border:1px solid #adb5bd;page-break-inside:avoid}thead{display:table-header-group}img,tr{page-break-inside:avoid}h2,h3,p{orphans:3;widows:3}h2,h3{page-break-after:avoid}@page{size:a3}.container,body{min-width:992px!important}.navbar{display:none}.badge{border:1px solid #000}.table{border-collapse:collapse!important}.table td,.table th{background-color:#fff!important}.table-bordered td,.table-bordered th{border:1px solid #dee2e6!important}.table-dark{color:inherit}.table-dark tbody+tbody,.table-dark td,.table-dark th,.table-dark thead th{border-color:#f2f3f4}.table .thead-dark th{color:inherit;border-color:#f2f3f4}}.table.c-table.table-bordered,.table.c-table.table-bordered td,.table.c-table.table-bordered th{border:1px solid #dee2e6!important}.table.c-table.table-bordered td.c-sticky-spliter,.table.c-table.table-bordered th.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.c-table.table-bordered td.c-sticky-left,.table.c-table.table-bordered th.c-sticky-left{border-right:0!important;border-left:0!important}.table.c-table.table-bordered td.c-sticky-all,.table.c-table.table-bordered th.c-sticky-all{border:0!important}.table.c-table.table-bordered td.c-empty,.table.c-table.table-bordered th.c-empty{text-align:center;background-color:#fff;border-bottom:none!important}.table.c-table.table-bordered td.c-empty img,.table.c-table.table-bordered th.c-empty img{margin-top:20px;margin-bottom:20px;opacity:.2}.table.c-table thead.thead-light th{color:#495057;background-color:#eceff1;font-size:14px!important;min-width:0;min-height:50px;height:50px;border-top:none!important}.table.c-table thead.thead-light th.c-cell{padding:3px 5px!important}.table.c-table tbody td{font-size:13px!important;min-width:0;min-height:25px}.table.c-table tbody td.c-cell{padding:3px 5px!important}.table.table-striped tbody tr:not(.c-no-hover):hover,.table.table-striped tbody tr:not(.c-no-hover):hover td.c-sticky-left{background-color:#e3f2fd!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd){background-color:#fafafa}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left{background-color:#fafafa!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-selected{background-color:#00bcd4!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-error{background-color:#f44336!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even){background-color:#fff}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left{background-color:#fff!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-selected{background-color:#00bcd4!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-error{background-color:#f44336!important}.grid-header{overflow-x:hidden;overflow-y:hidden}.c-cell-padding{padding:3px 5px!important}.c-header-title{text-transform:uppercase;font-weight:500}span.c-header-title{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:0 .3rem}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase}.status.c-desktop-status{width:100%}.status.c-align-left{text-align:left!important}.status-success{color:#43a047}.status-danger{color:#f44336}.page-item{cursor:pointer}.sumarize{padding:8px 12px;text-transform:uppercase;font-size:12px;color:#fff;display:inline-block;white-space:normal;font-weight:500;line-height:1;text-align:center;border-radius:10rem;background-color:#00bcd4}.cursor-pointer{cursor:pointer}label.custom-control.custom-checkbox{margin:0}.c-overflow-x-hidden{overflow-x:hidden}.c-overflow-y-hidden{overflow-y:hidden}.c-grid-header{overflow-x:hidden;overflow-y:hidden}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px!important;height:28px!important}.c-sticky-top{z-index:20;top:0!important}.c-sticky-left{z-index:20;left:0}.c-sticky-all{z-index:30;top:0!important;left:0}.c-sticky-spliter{z-index:40!important;background-color:#dee2e6!important;border:none!important;width:1px!important;min-width:1px!important}.c-badge:not(.c-children){display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge.c-children{padding:5px!important;font-weight:500;font-size:14px}.blinker{-webkit-animation:.5s linear infinite blinker;animation:.5s linear infinite blinker;color:#1c87c9;font-weight:500}@-webkit-keyframes blinker{50%{opacity:0}}@keyframes blinker{50%{opacity:0}}.c-loading{opacity:.4}.c-loading-icon{position:-webkit-sticky;position:sticky;top:calc(50% - 2.5rem);left:calc(50% - 2.5rem)}.c-loading-margin{margin-top:-5rem}fieldset.c-fieldset-mobile{border-radius:5px;border:1px solid #e0e0e0;padding:3px 5px}legend.c-legend-mobile{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:16px;font-weight:500}@media (min-width:481px) and (max-width:767px){.c-mobile-hidden{display:none!important}}@media (min-width:320px) and (max-width:480px){.c-mobile-hidden{display:none!important}}.c-mobile-box{border-top:none!important;box-shadow:0 0 3px 0 rgba(0,0,0,.3)}.c-mobile-body{margin-top:5px;margin-bottom:5px;overflow-x:auto}.c-mobile-item{border:1px solid #fff;border-radius:5px;margin:8px 0;padding:5px;box-shadow:0 0 3px 0 rgba(0,0,0,.3)}.c-mobile-item.c-mobile-item-selected{border:2px solid #00bcd4}.c-mobile-item:nth-of-type(odd){background-color:#fafafa}.c-mobile-item:nth-of-type(even){background-color:#fff}.c-mobile-row{margin-top:0;margin-bottom:3px}.c-desktop-title{font-size:13px;margin-right:3px;font-weight:700;color:#212529;line-height:1.7}.c-mobile-title{font-size:14px;margin-right:3px;font-weight:700;color:#212529}.c-children,.c-mobile-value{font-size:14px;overflow-wrap:break-word;color:#212529}.c-mobile-badge{padding:5px!important;font-weight:500;font-size:14px}.c-mobile-command{padding:5px 3px 0;border-top:1px solid #f4f4f4;display:flex;align-items:center;justify-content:space-between}.c-mobile-action{font-size:18px!important}.c-mobile-checkable{margin:5px 0 5px -5px!important}.c-m-3{margin:3px!important}.c-m-5{margin:5px!important}fieldset.c-fieldset{border-radius:5px;border:1px solid #919191}legend.c-legend{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:20px}"]
    })
], GridControlComponent);

let ModalControl = 
// tslint:disable-next-line: component-class-suffix
class ModalControl {
    constructor(dialog, bottomSheet, deviceService) {
        this.dialog = dialog;
        this.bottomSheet = bottomSheet;
        this.height = 'auto';
        this.isOpened = false;
        this.isMobileOrTablet = false;
        this.open = () => {
            this.isOpened = true;
            if (this.isMobileOrTablet) {
                this.bottomSheetRef = this.bottomSheet.open(this.templateRef);
            }
            else {
                this.dialogRef = this.dialog.open(this.templateRef, {
                    width: this.width
                });
            }
        };
        this.close = () => {
            var _a, _b;
            if (this.isMobileOrTablet) {
                (_a = this.bottomSheetRef) === null || _a === void 0 ? void 0 : _a.dismiss();
            }
            else {
                (_b = this.dialogRef) === null || _b === void 0 ? void 0 : _b.close();
            }
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
        this.type = this.type || 'primary';
        this.width = this.width || '80vw';
        if (!this.isMobileOrTablet) {
            switch (this.width) {
                case 'md':
                    this.width = '60vw';
                    break;
                case 'sm':
                    this.width = '40vw';
                    break;
            }
        }
    }
    ngAfterViewInit() {
        // $('body').append(this.modal.nativeElement);
    }
    ngOnDestroy() {
        // $(this.modal.nativeElement).remove();
    }
};
ModalControl.index = 0;
ModalControl.ctorParameters = () => [
    { type: MatDialog },
    { type: MatBottomSheet },
    { type: DeviceDetectorService }
];
__decorate([
    ViewChild('templateRef')
], ModalControl.prototype, "templateRef", void 0);
__decorate([
    Input()
], ModalControl.prototype, "title", void 0);
__decorate([
    Input()
], ModalControl.prototype, "type", void 0);
__decorate([
    Input()
], ModalControl.prototype, "width", void 0);
__decorate([
    Input()
], ModalControl.prototype, "height", void 0);
__decorate([
    ViewChild('modal')
], ModalControl.prototype, "modal", void 0);
ModalControl = __decorate([
    Component({
        selector: 'sd-modal-control',
        template: "<ng-template #templateRef>\r\n  <ng-container *ngIf=\"isOpened\">\r\n    <sd-modal-header *ngIf=\"title\">\r\n      {{title}}\r\n      <button class=\"float-right\" type=\"button\" (click)=\"close()\" mat-icon-button>\r\n        <mat-icon>close</mat-icon>\r\n      </button>\r\n    </sd-modal-header>\r\n    <ng-content></ng-content>\r\n  </ng-container>\r\n</ng-template>",
        encapsulation: ViewEncapsulation.None,
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".mat-dialog-container{padding:16px}.mat-dialog-container .mat-dialog-content{margin:0 -16px;padding:0 16px;max-height:80vh}.mat-dialog-container .mat-dialog-actions{min-height:auto;margin-bottom:-16px}.mat-bottom-sheet-container{max-height:inherit}"]
    })
    // tslint:disable-next-line: component-class-suffix
], ModalControl);

let SelectControlComponent = class SelectControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.name = v4();
        this.multiple = false;
        this.cItems = [];
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.onChanges = () => {
            var _a;
            this.cItems = this.pItems;
            this.value = this.pModel;
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = this.pItems.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = this.pItems;
            }
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            if (!this.value && !this.multiple && this.required && this.cItems.length > 0) {
                setTimeout(() => {
                    this.onChange(this.cItems[0][this.valueField]);
                });
            }
        };
        this.onSelectionChange = (change) => {
            var _a;
            const value = ((_a = change) === null || _a === void 0 ? void 0 : _a.value) || '';
            if (this.multiple) {
                this.onChange(value || []);
            }
            else {
                this.onChange(value);
            }
        };
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.onChange = (value) => {
            this.value = value;
            this.modelChange.emit(this.value);
            this.change.emit(this.value);
            this.sdChange.emit(this.value);
        };
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items.filter(item => !!item);
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(value) {
        this.pModel = value || '';
        if (this.initialized) {
            this.onChanges();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
};
SelectControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], SelectControlComponent.prototype, "multiple", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "items", null);
__decorate([
    Input()
], SelectControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "model", null);
__decorate([
    Output()
], SelectControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], SelectControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], SelectControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "validator", void 0);
__decorate([
    ViewChild('formModel')
], SelectControlComponent.prototype, "formModel", void 0);
SelectControlComponent = __decorate([
    Component({
        selector: 'sd-select-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <mat-select class=\"sd-select\" #formModel=\"ngModel\" [ngModel]=\"value\" [name]=\"name\" placeholder=\"{{label}}\"\r\n    [required]=\"required\" [disabled]=\"disabled\" [sdCustomValidator]=\"validator\" [multiple]=\"multiple\"\r\n    (selectionChange)=\"onSelectionChange($event)\">\r\n    <mat-option *ngIf=\"!required && !multiple\" value=\"\">{{'Please select' | sdTranslate}}</mat-option>\r\n    <mat-option *ngFor=\"let item of cItems\" [value]=\"item[valueField]\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-select>\r\n  <mat-error *ngIf=\"formModel.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    {{formModel?.errors?.customValidator}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}"]
    })
], SelectControlComponent);

// Document: https://xdsoft.net/jqplugins/datetimepicker/
let DatePickerControlComponent = class DatePickerControlComponent {
    constructor(ref, deviceService) {
        this.ref = ref;
        this.isMobileOrTablet = false;
        this.initialized = false;
        this.pMinDate = null;
        this.pMaxDate = null;
        this.name = v4();
        this.type = 'datetime';
        this.disabled = false;
        this.required = false;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.onFocus = () => {
            if (this.isMobileOrTablet) {
                $$1(this.control.nativeElement).trigger('blur');
            }
        };
        this.onChanges = () => {
            this.date = this.pDate;
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    set minDate(date) {
        if (!Date.isDate(date)) {
            this.pMinDate = null;
        }
        else {
            this.pMinDate = Date.toFormat(date, 'yyyy/MM/dd HH:mm');
        }
        this.setOption();
    }
    set maxDate(date) {
        if (!Date.isDate(date)) {
            this.pMaxDate = null;
        }
        else {
            this.pMaxDate = Date.toFormat(date, 'yyyy/MM/dd HH:mm'); // this.datePipe.transform(date, 'yyyy/MM/dd HH:mm');
        }
        this.setOption();
    }
    set model(val) {
        if (!Date.isDate(val)) {
            this.pDate = null;
        }
        else {
            if (this.type === 'datetime') {
                this.pDate = Date.toFormat(val, 'dd/MM/yyyy HH:mm');
            }
            else if (this.type === 'date') {
                this.pDate = Date.toFormat(val, 'dd/MM/yyyy');
            }
            else {
                this.pDate = Date.toFormat(val, 'HH:mm');
            }
        }
        if (this.initialized) {
            this.onChanges();
        }
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.setOption();
        this.ref.detectChanges();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).datetimepicker({
                datepicker: this.type === 'datetime' || this.type === 'date',
                timepicker: this.type === 'datetime' || this.type === 'time',
                format: this.type === 'datetime' ? 'd/m/Y H:i' : (this.type === 'date' ? 'd/m/Y' : 'H:i'),
                step: 15,
                minDate: this.pMinDate || undefined,
                maxDate: this.pMaxDate || undefined,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false,
                onChangeDateTime: (date) => {
                    if (!date && !this.date) {
                        return;
                    }
                    if (this.type === 'datetime') {
                        date = Date.toFormat(date, 'dd/MM/yyyy HH:mm');
                    }
                    else if (this.type === 'time') {
                        date = Date.toFormat(date, 'HH:mm');
                    }
                    else {
                        date = Date.toFormat(date, 'dd/MM/yyyy');
                    }
                    if (!this.equal(date, this.date)) {
                        this.model = this.parse(date);
                        this.modelChange.emit(this.parse(date));
                        this.change.emit(this.parse(date));
                        this.sdChange.emit(this.parse(date));
                    }
                    this.ref.detectChanges();
                }
            });
        }
    }
    parse(date) {
        if (this.type === 'date') {
            return Date.parseFrom(date, 'dd/MM/yyyy');
        }
        else if (this.type === 'time') {
            return Date.parseFrom(date, 'HH:mm');
        }
        return Date.parseFrom(date, 'dd/MM/yyyy HH:mm');
    }
    equal(date1, date2) {
        return Date.equal(this.parse(date1), this.parse(date2));
    }
};
DatePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], DatePickerControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "minDate", null);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "maxDate", null);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "validator", void 0);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "model", null);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "modelChange", void 0);
__decorate([
    ViewChild('control')
], DatePickerControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], DatePickerControlComponent.prototype, "formModel", void 0);
DatePickerControlComponent = __decorate([
    Component({
        selector: 'sd-date-picker-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #formModel=\"ngModel\" [name]=\"name\" autocomplete=\"false\" #control matInput\r\n    placeholder=\"{{label}}\" [ngModel]=\"date\" (focus)=\"onFocus()\" [required]=\"required\" [disabled]=\"disabled\"\r\n    [sdMinDate]=\"pMinDate\" [sdMaxDate]=\"pMaxDate\" [sdCustomValidator]=\"validator\" autocomplete=\"off\">\r\n  <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon>\r\n  <!-- <i matSuffix class=\"fa\" [ngClass]=\"{'fa-clock-o':type === 'time', 'fa-calendar':type !== 'time'}\"></i> -->\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.minDate\">\r\n    {{'Min date' | sdTranslate}}: <strong>{{pMinDate | date:'dd/MM/yyyy HH:mm'}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.maxDate\">\r\n    {{'Max date' | sdTranslate}}: <strong>{{pMaxDate | date:'dd/MM/yyyy HH:mm'}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    <strong>{{formModel?.errors?.customValidator}}</strong>\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}", ".xdsoft_datetimepicker{z-index:99999}"]
    })
], DatePickerControlComponent);

let ModalHeaderComponent = class ModalHeaderComponent {
    constructor(deviceService) {
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalHeaderComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
ModalHeaderComponent = __decorate([
    Component({
        selector: 'sd-modal-header',
        template: "<h3 class=\"mb-16\" mat-dialog-title *ngIf=\"!isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</h3>\r\n<sd-bottom-sheet-header *ngIf=\"isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-header>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        styles: [""]
    })
], ModalHeaderComponent);

let ModalBodyComponent = class ModalBodyComponent {
    constructor(deviceService) {
        this.height = 'auto';
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalBodyComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], ModalBodyComponent.prototype, "height", void 0);
ModalBodyComponent = __decorate([
    Component({
        selector: 'sd-modal-body',
        template: "<mat-dialog-content *ngIf=\"!isMobileOrTablet\" [ngStyle]=\"{'height': height}\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</mat-dialog-content>\r\n<sd-bottom-sheet-body *ngIf=\"isMobileOrTablet\" [height]=\"height\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-body>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ""]
    })
], ModalBodyComponent);

let ModalFooterComponent = class ModalFooterComponent {
    constructor(deviceService) {
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalFooterComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
ModalFooterComponent = __decorate([
    Component({
        selector: 'sd-modal-footer',
        template: "<!-- <div class=\"modal-footer\" style=\"padding:5px\"><ng-content></ng-content></div> -->\r\n<mat-dialog-actions *ngIf=\"!isMobileOrTablet\">\r\n  <div class=\"c-footer\">\r\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n  </div>\r\n</mat-dialog-actions>\r\n<sd-bottom-sheet-footer *ngIf=\"isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-footer>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        encapsulation: ViewEncapsulation.None,
        styles: [".c-footer{flex:auto;display:flex}"]
    })
], ModalFooterComponent);

let UploadExcelControlComponent = class UploadExcelControlComponent {
    constructor(ref, excelService, translateService, notifyService, utilityService, loadingService) {
        this.ref = ref;
        this.excelService = excelService;
        this.translateService = translateService;
        this.notifyService = notifyService;
        this.utilityService = utilityService;
        this.loadingService = loadingService;
        this.items = [];
        this.hasDescription = false;
        // Paginate
        this.pages = [1];
        this.pageSize = 50;
        this.currentPage = 1;
        this.pageCount = 5;
        this.totalPage = 1;
        this.showing = 'ALL';
        this.filteredItems = [];
        this.viewItems = [];
        this.numberOfSuccess = 0;
        this.numberOfError = 0;
        this.numberOfWarning = 0;
        this.upload = () => __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            try {
                const { translate } = this.translateService;
                const { items, file } = yield this.excelService.import();
                if (this.option.columns.some(e => !!e.description)) {
                    this.hasDescription = true;
                }
                else {
                    this.hasDescription = false;
                }
                const offset = this.hasDescription ? 2 : 1;
                items.splice(0, offset);
                if (items.length === 0) {
                    this.notifyService.notify.warning(`${translate(`No data to import`)}`);
                    return;
                }
                if (items.length > this.option.limit) {
                    this.notifyService.notify.warning(`${translate(`Limit rows`)}: ${this.option.limit}`);
                    return;
                }
                this.items = ((_b = (_a = this.option).mappingItems) === null || _b === void 0 ? void 0 : _b.call(_a, items)) || items;
                this.filteredItems = this.items;
                this.showing = 'ALL';
                this.file = file;
                this.currentPage = 1;
                this.generatePaginate();
                for (const [idx, item] of this.items.entries()) {
                    item.lineId = v4();
                    item.excelIndex = idx + (this.hasDescription ? 4 : 3);
                    yield this.validate(item);
                }
                // Nếu không có error thì tiếp tục validate từ option validate truyền vào
                if (!this.items.some(item => !!item.validation.error) && this.option.errorValidation) {
                    this.loadingService.start();
                    const results = yield this.option.errorValidation(this.items);
                    results.forEach(result => this.items[result.idx].validation.error = result.message);
                    this.loadingService.stop();
                }
                // Nếu không có warning thì tiếp tục validate từ option validate truyền vào
                if (!this.items.some(item => !!item.validation.warning) && this.option.warningValidation) {
                    this.loadingService.start();
                    const results = yield this.option.warningValidation(this.items);
                    results.forEach(result => this.items[result.idx].validation.warning = result.message);
                    this.loadingService.stop();
                }
                this.reload();
                this.ref.detectChanges();
            }
            catch (err) {
                this.utilityService.handle.error(err);
            }
        });
        this.setValidation = (validates) => {
            if (Array.isArray(validates)) {
                validates.forEach(validate => this.items[validate.idx].validation.error = validate.message);
            }
            this.reload();
            this.ref.detectChanges();
        };
        this.view = (showing = 'ALL') => {
            this.showing = showing;
            this.currentPage = 1;
            this.reload();
            this.generatePaginate();
        };
    }
    ngOnInit() {
        this.uploadExcelConfig.setOption({
            key: this.option.key,
            columns: this.option.columns
        });
    }
    loadConfig(configResult) {
        return __awaiter(this, void 0, void 0, function* () {
            this.configResult = configResult;
            this.option.columns = configResult.columns;
        });
    }
    open() {
        this.items = [];
        this.numberOfSuccess = 0;
        this.numberOfError = 0;
        this.numberOfWarning = 0;
        this.modal.open();
    }
    close() {
        this.modal.close();
    }
    reload() {
        this.currentPage = this.currentPage || 1;
        this.filteredItems = this.items.filter((item) => {
            if (this.showing === 'SUCCESS') {
                return !item.validation.error && !item.validation.warning;
            }
            else if (this.showing === 'WARNING') {
                return !!item.validation.warning && !item.validation.error;
            }
            else if (this.showing === 'ERROR') {
                return !!item.validation.error;
            }
            return true;
        });
        this.viewItems = this.filteredItems
            .filter((item, index) => index >= (this.currentPage - 1) * this.pageSize && index < this.currentPage * this.pageSize);
        this.numberOfSuccess = this.items.filter(item => !item.validation.error && !item.validation.warning).length;
        this.numberOfError = this.items.filter(item => item.validation.error).length;
        this.numberOfWarning = this.items.filter(item => item.validation.warning && !item.validation.error).length;
    }
    validate(item) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            const validation = {
                error: '',
                warning: '',
                data: {}
            };
            const { translate } = this.translateService;
            for (const column of this.option.columns) {
                validation.data[column.field] = {};
                try {
                    if (column.defaultValue !== undefined) {
                        item[column.field] = (_a = item[column.field], (_a !== null && _a !== void 0 ? _a : column.defaultValue));
                    }
                    else if (column.required && !item[column.field] && item[column.field] !== 0) {
                        validation.data[column.field].error = `${translate('required')}`;
                        validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                        continue;
                    }
                    if (column.type === 'string') {
                        const value = (item[column.field] || '').toString();
                        if (column.minLength !== undefined && value.length < column.minLength) {
                            validation.data[column.field].error = `${translate('Min length')}: ${column.minLength}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.maxLength !== undefined && value.length > column.maxLength) {
                            validation.data[column.field].error = `${translate('Max length')}: ${column.maxLength}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'number') {
                        if (item[column.field]) {
                            const value = +item[column.field];
                            if (Number.isNaN(value)) {
                                validation.data[column.field].error = `${item[column.field]} ${translate('is not a number')}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                                continue;
                            }
                            item[column.field] = value;
                        }
                        if (!item[column.field] && item[column.field] !== 0) {
                            item[column.field] = undefined;
                        }
                        if (column.minValue !== undefined && item[column.field] < column.minValue) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Min value')}: ${column.minValue}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.maxValue !== undefined && item[column.field] > column.maxValue) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Max value')}: ${column.maxValue}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'bool') {
                        if (item[column.field] === 0 || item[column.field] === false) {
                            item[column.field] = '0';
                        }
                        if (item[column.field] === 1 || item[column.field] === true) {
                            item[column.field] = '1';
                        }
                        if (item[column.field]) {
                            const value = +item[column.field];
                            if (Number.isNaN(value) || (value !== 0 && value !== 1)) {
                                validation.data[column.field].error = `${translate('Value shoud be 0 or 1')}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            }
                        }
                    }
                    else if (column.type === 'values') {
                        if (typeof (item[column.field]) !== 'number' && typeof (item[column.field]) !== 'string') {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Invalid data type')}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.checkValueInArray && item[column.field] && !column.values.some(e => e.toString() === item[column.field].toString())) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Value not in')} [${column.values.join()}]`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'radio') {
                        if (typeof (item[column.field]) !== 'number' && typeof (item[column.field]) !== 'string') {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Invalid data type')}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.checkValueInArray && item[column.field] && !column.values.some(e => e.toString() === item[column.field].toString())) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Value not in')} [${column.values.join()}]`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'date') {
                        if (column.format && item[column.field]) {
                            if (!Date.isDate(Date.parseFrom(item[column.field], column.format))) {
                                validation.data[column.field].error = `${translate('Invalid format')} ${column.format}: ${item[column.field]}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            }
                        }
                        if (item[column.field] && !Date.isDate(item[column.field])) {
                            validation.data[column.field].error = `${translate('Invalid date')}: ${item[column.field]}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    if (!validation.data[column.field].error && column.errorValidation) {
                        const error = yield column.errorValidation(item, item[column.field]);
                        if (error) {
                            validation.data[column.field].error = `${error}`;
                            validation.error += `[${column.field}] ${error}\n`;
                        }
                    }
                    if (!validation.data[column.field].warning && column.warningValidation) {
                        const warning = yield column.warningValidation(item, item[column.field]);
                        if (warning) {
                            validation.data[column.field].warning = `${warning}`;
                            validation.warning += `[${column.field}] ${warning}\n`;
                        }
                    }
                }
                catch (ex) {
                    validation.data[column.field].error = `${((_b = ex) === null || _b === void 0 ? void 0 : _b.message) || ((_c = ex) === null || _c === void 0 ? void 0 : _c.error) || ex || 'Có lỗi xảy ra'}`;
                    validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                }
            }
            item.validation = validation;
        });
    }
    generatePaginate() {
        this.pages = [];
        this.totalPage = Math.trunc(this.filteredItems.length / this.pageSize) + (this.filteredItems.length % this.pageSize === 0 ? 0 : 1);
        if (this.currentPage > this.totalPage) {
            this.currentPage = this.totalPage;
        }
        if (this.totalPage <= this.pageCount) {
            for (let i = 1; i <= this.totalPage; i++) {
                this.pages.push(i);
            }
        }
        else {
            if (this.currentPage < 3) {
                this.pages = [1, 2, 3, 4, 5];
            }
            else if (this.currentPage > this.totalPage - 2) {
                this.pages = [this.totalPage - 4, this.totalPage - 3, this.totalPage - 2, this.totalPage - 1, this.totalPage];
            }
            else {
                this.pages = [this.currentPage - 2, this.currentPage - 1, this.currentPage, this.currentPage + 1, this.currentPage + 2];
            }
        }
    }
    selectPage(selectedPage) {
        const page = +selectedPage;
        if (this.currentPage !== page && page > 0 && page <= this.totalPage) {
            this.currentPage = page;
        }
        this.reload();
        this.generatePaginate();
    }
    accept() {
        var _a;
        const successItems = this.items.filter(item => !item.validation.error && !item.validation.warning);
        const errorItems = this.items.filter(item => item.validation.error);
        const warningItems = this.items.filter(item => !item.validation.error && item.validation.warning);
        (_a = this.option) === null || _a === void 0 ? void 0 : _a.onAccept(this.items, successItems, errorItems, warningItems, this.file);
    }
    downloadTemplate() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const excelTemplate = {
                fileName: this.option.fileName || 'Template.xlsx',
                columns: this.option.columns.map(column => {
                    return {
                        field: column.field,
                        title: column.title,
                        width: column.width,
                        required: column.required,
                        description: column.description
                    };
                })
            };
            const result = yield this.excelService.generateExcelTemplate(excelTemplate);
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                yield this.excelService.downloadTemplate(result.filePath, excelTemplate.fileName || 'Template.xlsx');
            }
        });
    }
};
UploadExcelControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ExcelService },
    { type: TranslateService },
    { type: NotifyService },
    { type: UtilityService },
    { type: LoadingService }
];
__decorate([
    Input()
], UploadExcelControlComponent.prototype, "option", void 0);
__decorate([
    ViewChild('modal')
], UploadExcelControlComponent.prototype, "modal", void 0);
__decorate([
    ViewChild('uploadExcelConfig', { static: true })
], UploadExcelControlComponent.prototype, "uploadExcelConfig", void 0);
UploadExcelControlComponent = __decorate([
    Component({
        selector: 'sd-upload-excel-control',
        template: "<sd-modal-control [title]=\"'Import Excel' | sdTranslate\" #modal>\r\n  <sd-modal-body background=\"#F0F8FF\">\r\n    <div class=\"row mx-0 mb-2\">\r\n      <sd-button *ngIf=\"items?.length\" class=\"mr-1\" (action)=\"view('ALL')\" icon=\"cached\"\r\n        [title]=\"'View all' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfSuccess\" class=\"mr-1\" (action)=\"view('SUCCESS')\" icon=\"done\" [title]=\"numberOfSuccess\"\r\n        [tooltip]=\"'Number of success rows' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfWarning\" class=\"mr-1\" (action)=\"view('WARNING')\" icon=\"warning\"\r\n        [title]=\"numberOfWarning\" [tooltip]=\"'Number of warning rows' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfError\" class=\"mr-1\" (action)=\"view('ERROR')\" icon=\"error\" [title]=\"numberOfError\"\r\n        color=\"accent\" [tooltip]=\"'Number of error rows' | sdTranslate\"></sd-button>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\" style=\"position: relative; height:50vh\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center position-sticky c-sticky-left\" style=\"width: 50px\">#</th>\r\n                <th *ngFor=\"let column of option.columns\"\r\n                  [ngStyle]=\"{'min-width':column.width ? column.width : '300px'}\">\r\n                  <span class=\"c-ellipsis\"\r\n                    [ngStyle]=\"{'min-width':column.width ? column.width : '300px', 'max-width':column.width ? column.width : '300px'}\">{{column.title}}</span>\r\n                </th>\r\n              </tr>\r\n            </thead>\r\n            <tbody *ngIf=\"items.length\">\r\n              <tr *ngFor=\"let item of viewItems\">\r\n                <td class=\"text-center position-sticky c-sticky-left\" style=\"width: 50px\">\r\n                  <span class=\"badge\"\r\n                    [ngClass]=\"{'badge-success':!item.validation?.warning && !item.validation?.error, 'badge-warning':item.validation?.warning && !item.validation?.error, 'badge-danger':item.validation?.error}\"\r\n                    [matTooltip]=\"item.validation?.error || item.validation?.warning\" matTooltipPosition=\"right\"\r\n                    style=\"width: 100%\" matTooltipClass=\"white-space-pre-line\">{{item.excelIndex}}</span>\r\n                </td>\r\n                <td *ngFor=\"let column of option.columns\" class=\"align-middle\"\r\n                  [ngClass]=\"{'table-warning':item.validation?.data[column.field]?.warning && !item.validation?.data[column.field]?.error, 'table-danger':item.validation?.data[column.field]?.error}\"\r\n                  [matTooltip]=\"item.validation?.data[column.field]?.error || item.validation?.data[column.field]?.warning\"\r\n                  matTooltipPosition=\"above\">\r\n                  <span class=\"c-ellipsis\"\r\n                    [ngStyle]=\"{'min-width':column.width ? column.width : '300px', 'max-width':column.width ? column.width : '300px'}\">\r\n                    <ng-container *ngIf=\"column.type === 'date'\">\r\n                      {{item.validation?.data[column.field]?.error ?  item[column.field] : (item[column.field] | date:'dd/MM/yyyy HH:mm')}}\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"column.type === 'number'\">\r\n                      {{item.validation?.data[column.field]?.error ?  item[column.field] : (item[column.field] | number : '1.0-2')}}\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"column.type !== 'date' && column.type !== 'number'\">{{item[column.field]}}\r\n                    </ng-container>\r\n                  </span>\r\n                </td>\r\n              </tr>\r\n            </tbody>\r\n          </table>\r\n        </div>\r\n      </div>\r\n      <div class=\"sd-box-footer clearfix\">\r\n        <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n          <ul class=\"pagination pagination-primary m-0\">\r\n            <li class=\"page-item cursor-pointer\" *ngIf=\"currentPage > 1\" placement=\"top\" ngbTooltip=\"Previous\"\r\n              (click)=\"selectPage(currentPage-1)\">\r\n              <a class=\"page-link\">\r\n                {{'Previous' | sdTranslate | uppercase}}\r\n              </a>\r\n            </li>\r\n            <li class=\"page-item cursor-pointer\" [ngClass]=\"{'active':page === currentPage}\" *ngFor=\"let page of pages\"\r\n              (click)=\"selectPage(page)\">\r\n              <a class=\"page-link\">{{page}}</a>\r\n            </li>\r\n            <li class=\"page-item cursor-pointer\" *ngIf=\"currentPage < totalPage\" placement=\"top\" ngbTooltip=\"Next\"\r\n              (click)=\"selectPage(currentPage+1)\">\r\n              <a class=\"page-link\">\r\n                {{'Next' | sdTranslate | uppercase}}\r\n              </a>\r\n            </li>\r\n          </ul>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <div class=\"mr-auto\">\r\n      <sd-button class=\"mr-1\" (action)=\"upload()\" icon=\"publish\" [title]=\"'Upload' | sdTranslate\" size=\"sm\"></sd-button>\r\n      <sd-button class=\"mr-1\" (action)=\"downloadTemplate()\" icon=\"get_app\" [title]=\"'Download' | sdTranslate\" size=\"sm\">\r\n      </sd-button>\r\n    </div>\r\n    <sd-button (action)=\"accept()\" icon=\"check\" [title]=\"'Accept' | sdTranslate\"\r\n      [disabled]=\"numberOfSuccess === 0 || numberOfError > 0\" color=\"primary\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button style=\"flex: 1; padding-right: 5px;\" (action)=\"upload()\" icon=\"publish\" [title]=\"'Upload' | sdTranslate\"\r\n      width=\"100%\" size=\"sm\"></sd-button>\r\n    <sd-button style=\"flex: 1; padding-left: 5px;\" (action)=\"accept()\" icon=\"check\" [title]=\"'Accept' | sdTranslate\"\r\n      color=\"primary\" width=\"100%\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>\r\n<sd-upload-excel-config (change)=\"loadConfig($event)\" #uploadExcelConfig></sd-upload-excel-config>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".pagination>li>a{border:0;border-radius:24px!important;transition:.3s;padding:0 9px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>span{border:0;border-radius:24px!important;transition:.3s;padding:0 8px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>a:focus,.pagination>li>a:hover,.pagination>li>span:focus,.pagination>li>span:hover{z-index:3;color:#23527c;background-color:#eee;border-color:#ddd}.pagination>.active>a,.pagination>.active>a:focus,.pagination>.active>a:hover,.pagination>.active>span,.pagination>.active>span:focus,.pagination>.active>span:hover{background-color:#c82c37;border-color:#c82c37;color:#fff;box-shadow:0 4px 5px 0 rgba(156,39,176,.14),0 1px 10px 0 rgba(156,39,176,.12),0 2px 4px -1px rgba(156,39,176,.2)}.pagination.pagination-info>.active>a,.pagination.pagination-info>.active>a:focus,.pagination.pagination-info>.active>a:hover,.pagination.pagination-info>.active>span,.pagination.pagination-info>.active>span:focus,.pagination.pagination-info>.active>span:hover{background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 4px 5px 0 rgba(0,188,212,.14),0 1px 10px 0 rgba(0,188,212,.12),0 2px 4px -1px rgba(0,188,212,.2)}.pagination.pagination-success>.active>a,.pagination.pagination-success>.active>a:focus,.pagination.pagination-success>.active>a:hover,.pagination.pagination-success>.active>span,.pagination.pagination-success>.active>span:focus,.pagination.pagination-success>.active>span:hover{background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.pagination.pagination-warning>.active>a,.pagination.pagination-warning>.active>a:focus,.pagination.pagination-warning>.active>a:hover,.pagination.pagination-warning>.active>span,.pagination.pagination-warning>.active>span:focus,.pagination.pagination-warning>.active>span:hover{background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.pagination.pagination-danger>.active>a,.pagination.pagination-danger>.active>a:focus,.pagination.pagination-danger>.active>a:hover,.pagination.pagination-danger>.active>span,.pagination.pagination-danger>.active>span:focus,.pagination.pagination-danger>.active>span:hover{background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".table thead td,.table thead th{padding-top:5px;padding-bottom:5px}.table-striped tbody tr:nth-of-type(even) .c-sticky-left{background-color:#fff}.table-striped tbody tr:nth-of-type(odd) .c-sticky-left{background-color:#f2f2f2}.c-sticky-left{z-index:20;left:0!important;border-left:none!important;border-right:none!important}.c-ellipsis{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:.1rem}"]
    })
], UploadExcelControlComponent);

let TextareaControlComponent = class TextareaControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.name = v4();
        this.rows = 5;
        this.modelChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        // setTimeout(() => {
        //     this._model = value;
        // }, 0);
        this._model = value;
    }
    ngAfterViewInit() {
        if (this.form && this.formModel) {
            this.form.addControl(this.formModel);
        }
    }
    ngOnDestroy() {
        if (this.form && this.formModel) {
            this.form.removeControl(this.formModel);
        }
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
    }
};
TextareaControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], TextareaControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "placeholder", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "rows", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "model", null);
__decorate([
    Output()
], TextareaControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "maxlength", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "pattern", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel')
], TextareaControlComponent.prototype, "formModel", void 0);
TextareaControlComponent = __decorate([
    Component({
        selector: 'sd-textarea-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <textarea class=\"sd-input\" #formModel=\"ngModel\" [name]=\"name\" matInput placeholder=\"{{placeholder || label}}\" [ngModel]=\"_model\"\r\n    (ngModelChange)=\"onChange($event)\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"off\" [rows]=\"rows\" [maxlength]=\"maxlength\"></textarea>\r\n  <span *ngIf=\"maxlength\" matSuffix>{{_model?.length || 0}}/{{maxlength}}</span>\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}", "textarea.mat-input-element{resize:none}"]
    })
], TextareaControlComponent);

let AutocompleteControlComponent = class AutocompleteControlComponent {
    constructor(ref, utilityService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.previousResults = [];
        this.delay = 500; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện gọi hàm
        this.isServerFilter = false;
        this.name = v4();
        this.loading = false;
        // tslint:disable-next-line: variable-name
        this.cItems = [];
        this.limit = 100;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.onChanges = (searchText) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            this.cModel = this.pModel;
            let items = [];
            if (typeof (this.pItems) === 'function') {
                items = yield this.loadItems(searchText, this.pItems);
            }
            else {
                items = this.pItems;
            }
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = items.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = items;
            }
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            this.ref.detectChanges();
        });
        this.loadItems = (searchText, items) => __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return this.previousResults;
            }
            this.loading = true;
            this.previousResults = yield items(searchText).finally(() => this.loading = false);
            return this.previousResults;
        });
        this.onChange = (item) => {
            if (typeof item !== 'string') {
                this.cModel = item ? item[this.valueField] : undefined;
                this.modelChange.emit(this.cModel);
                this.change.emit(item);
                this.sdChange.emit(item);
            }
            else {
                if (!item) {
                    this.clear();
                }
                this.onChanges(item);
            }
        };
        this.filter = (value) => {
            const items = this.cItems;
            if (!this.name || this.isServerFilter) {
                return this.cItems.filter((item, index) => index < this.limit);
            }
            return this.cItems
                .filter(item => {
                return this.utilityService.changeAliasLowerCase(item[this.displayField])
                    .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
            }).filter((item, index) => index < this.limit);
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.cItems) {
                    return value;
                }
                const selectedItem = this.cItems.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                return value;
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            this.cModel = undefined;
            this.modelChange.emit(this.cModel);
            this.change.emit(this.cModel);
            this.sdChange.emit(this.cModel);
            this.formModel.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            if ($event) {
                (_b = this.autocompleteTrigger) === null || _b === void 0 ? void 0 : _b.openPanel();
            }
        };
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
    }
    set items(items) {
        this.pItems = items || [];
        this.isServerFilter = !Array.isArray(this.pItems);
        if (this.initialized) {
            this.onChanges().then(() => { var _a, _b; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value); });
        }
    }
    set model(value) {
        this.pModel = value;
        if (this.initialized) {
            this.onChanges(value).then(() => { var _a; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue(value); });
        }
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => typeof item === 'string' ? item : (item ? item[this.displayField] : '')), map(this.filter));
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges(this.pModel).then(() => { var _a; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue(this.pModel); });
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
};
AutocompleteControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService }
];
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "items", null);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "limit", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "model", null);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], AutocompleteControlComponent.prototype, "formModel", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], AutocompleteControlComponent.prototype, "autocompleteTrigger", void 0);
AutocompleteControlComponent = __decorate([
    Component({
        selector: 'sd-autocomplete-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #autocompleteTrigger #formModel=\"ngModel\" [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [name]=\"name\" placeholder=\"{{label}}\" [matAutocomplete]=\"auto\" [required]=\"required\" [disabled]=\"disabled\" matInput autocomplete=\"off\">\r\n  <!-- <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon> -->\r\n  \r\n  <!-- <i *ngIf=\"!loading && !cModel && !disabled\" matSuffix class=\"fa fa-search fa-fw\"></i> -->\r\n  <!-- <i *ngIf=\"!loading && cModel && !disabled\" matSuffix class=\"fa fa-times fa-fw text-danger\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i> -->\r\n  <mat-icon *ngIf=\"!loading && !cModel && !disabled\" matSuffix>search</mat-icon>\r\n  <mat-icon *ngIf=\"!loading && cModel && !disabled\" class=\"cursor-pointer\" (click)=\"clear($event)\" matSuffix>close</mat-icon>\r\n  <mat-spinner *ngIf=\"loading\" matSuffix></mat-spinner>\r\n  <!-- <i *ngIf=\"loading\" matSuffix class=\"fa fa-spinner fa-spin\"></i> -->\r\n  <mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\">\r\n    <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-autocomplete>\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}"]
    })
], AutocompleteControlComponent);

const MobileMaxWidth = 767;
const IsMobile = window.innerWidth < MobileMaxWidth;

// Document: https://xdsoft.net/jqplugins/datetimepicker/
let GridDatePickerControlComponent = class GridDatePickerControlComponent {
    constructor(ref, datePipe) {
        this.ref = ref;
        this.datePipe = datePipe;
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.initialized = false;
        this.type = 'datetime';
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.onFocus = () => {
            if (this.isMobile) {
                // tslint:disable-next-line: deprecation
                $$1(this.control.nativeElement).blur();
            }
        };
        this.onChanges = () => {
            this.date = this.pDate;
        };
    }
    set model(val) {
        if (!Date.isDate(val)) {
            this.pDate = null;
        }
        else {
            if (this.type === 'datetime') {
                this.pDate = this.datePipe.transform(val, 'dd/MM/yyyy HH:mm');
            }
            else if (this.type === 'date') {
                this.pDate = this.datePipe.transform(val, 'dd/MM/yyyy');
            }
            else {
                this.pDate = this.datePipe.transform(val, 'HH:mm');
            }
        }
        if (this.initialized) {
            this.onChanges();
        }
        this.ref.detectChanges();
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.onChanges();
        this.initialized = true;
        this.setOption();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).datetimepicker({
                datepicker: this.type === 'datetime' || this.type === 'date',
                timepicker: this.type === 'datetime' || this.type === 'time',
                format: this.type === 'datetime' ? 'd/m/Y H:i' : (this.type === 'date' ? 'd/m/Y' : 'H:i'),
                step: 15,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false,
                onChangeDateTime: (date) => {
                    if (!date && !this.date) {
                        return;
                    }
                    date = Date.toFormat(date, 'dd/MM/yyyy HH:mm');
                    if (!this.equal(date, this.date)) {
                        this.model = this.parse(date);
                        this.modelChange.emit(this.parse(date));
                        this.sdChange.emit(this.parse(date));
                        this.ref.detectChanges();
                    }
                }
            });
        }
    }
    parse(date) {
        if (this.type === 'date') {
            return Date.parseFrom(date, 'dd/MM/yyyy');
        }
        else if (this.type === 'time') {
            return Date.parseFrom(date, 'HH:mm');
        }
        return Date.parseFrom(date, 'dd/MM/yyyy HH:mm');
    }
    equal(date1, date2) {
        return Date.equal(this.parse(date1), this.parse(date2));
    }
};
GridDatePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DatePipe }
];
__decorate([
    Input()
], GridDatePickerControlComponent.prototype, "type", void 0);
__decorate([
    Output()
], GridDatePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], GridDatePickerControlComponent.prototype, "model", null);
__decorate([
    Output()
], GridDatePickerControlComponent.prototype, "modelChange", void 0);
__decorate([
    ViewChild('control')
], GridDatePickerControlComponent.prototype, "control", void 0);
GridDatePickerControlComponent = __decorate([
    Component({
        selector: 'sd-grid-date-picker-control',
        template: "<div class=\"w-100 c-container\">\r\n  <input #control class=\"form-control c-input-xs\" [ngModel]=\"date\" (focus)=\"onFocus()\">\r\n  <i class=\"fa c-icon\" [ngClass]=\"{'fa-clock-o':type === 'time', 'fa-calendar':type !== 'time'}\"></i>\r\n</div>",
        styles: [".c-container{position:relative}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}.c-icon{position:absolute;top:7px;right:7px;font-size:13px!important}"]
    })
], GridDatePickerControlComponent);

let Login01Component = class Login01Component {
    constructor() {
        this.loginForm = new FormGroup({
            username: new FormControl('', [Validators.required]),
            password: new FormControl('', [Validators.required]),
            rememberme: new FormControl(true)
        });
        this.textSignIn = 'SIGN IN';
        this.textUsername = 'Username';
        this.textPassword = 'Password';
        this.textRememberMe = 'Remember me';
        this.textLoginButton = 'Login';
        this.textForgotPassword = 'Forgot Password?';
        this.textCreateAccount = 'Create Account';
        this.textCopyRight = '2018 © SuperDev Angular Core';
        this.onLogin = new EventEmitter();
        this.onForgotPassword = new EventEmitter();
        this.onCreateAccount = new EventEmitter();
    }
    ngOnInit() {
    }
    login() {
        this.onLogin.emit({
            username: this.loginForm.value.username,
            password: this.loginForm.value.password,
            rememberme: this.loginForm.value.rememberme
        });
    }
    forgotPassword() {
        this.onForgotPassword.emit();
    }
    createAccount() {
        this.onCreateAccount.emit();
    }
};
__decorate([
    Input()
], Login01Component.prototype, "logoUrl", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textSignIn", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textUsername", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textPassword", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textRememberMe", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textLoginButton", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textForgotPassword", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textCreateAccount", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textCopyRight", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onLogin", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onForgotPassword", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onCreateAccount", void 0);
Login01Component = __decorate([
    Component({
        selector: 'sd-login01',
        template: "<div style=\"height:100vh; width: 100vw; position:fixed\" class=\"sd-login\">\r\n  <div class=\"menu-toggler sidebar-toggler\"></div>\r\n  <!-- END SIDEBAR TOGGLER BUTTON -->\r\n  <!-- BEGIN LOGO -->\r\n  <div *ngIf=\"logoUrl\" class=\"sd-logo\">\r\n    <a href=\"javascript:;\"> <img [src]=\"logoUrl\" alt=\"SuperDev\" /> </a>\r\n  </div>\r\n  <!-- END LOGO -->\r\n  <!-- BEGIN LOGIN -->\r\n  <div class=\"content\">\r\n    <!-- BEGIN LOGIN FORM -->\r\n    <form class=\"sd-login-form\" [formGroup]=\"loginForm\" (ngSubmit)=\"login()\">\r\n      <h3 class=\"sd-form-title font-green\">{{textSignIn}}</h3>\r\n      <div class=\"form-group\">\r\n        <input class=\"form-control form-control-solid placeholder-no-fix\" type=\"text\" placeholder=\"{{textUsername}}\"\r\n          formControlName=\"username\" /></div>\r\n      <div class=\"form-group\">\r\n        <input class=\"form-control form-control-solid placeholder-no-fix\" type=\"password\" placeholder=\"{{textPassword}}\"\r\n          formControlName=\"password\" /> </div>\r\n      <div class=\"custom-control custom-checkbox\">\r\n        <input type=\"checkbox\" class=\"custom-control-input\" formControlName=\"rememberme\">\r\n        <label class=\"custom-control-label\">{{textRememberMe}}</label>\r\n      </div>\r\n      <div class=\"form-actions\">\r\n        <button type=\"submit\" class=\"btn green uppercase\" [disabled]=\"loginForm.invalid\">{{textLoginButton}}</button>\r\n        <a *ngIf=\"onForgotPassword.observers.length\" (click)=\"forgotPassword()\" href=\"javascript:;\" class=\"forget-password\">{{textForgotPassword}}</a>\r\n      </div>\r\n      <div *ngIf=\"onCreateAccount.observers.length\" class=\"create-account\">\r\n        <p>\r\n          <a (click)=\"createAccount()\" href=\"javascript:;\" class=\"uppercase\">Create Account</a>\r\n        </p>\r\n      </div>\r\n    </form>\r\n    <!-- END LOGIN FORM -->\r\n  </div>\r\n  <div class=\"copyright\"> {{textCopyRight}} </div>\r\n</div>",
        styles: [".sd-login{background-color:#dcdee0!important}.sd-login .sd-logo{margin:60px auto 0;padding:15px;text-align:center}.sd-login .content{background-color:#eceef1;border-radius:7px;width:400px;margin:40px auto 10px;padding:10px 30px 30px;overflow:hidden;position:relative}.sd-login .content h3{margin-top:20px;color:#4db3a5;text-align:center;font-size:28px;font-weight:400!important}.sd-login .content .form-control{border:1px solid #dde3ec;background-color:#dde3ec;height:43px;color:#8290a3}.login .content .form-control:active,.sd-login .content .form-control:focus{border:1px solid #c3ccda}.sd-login .content .form-control::-moz-placeholder{color:#8290a3;opacity:1}.sd-login .content .form-control:-ms-input-placeholder{color:#8290a3}.sd-login .content .form-control::-webkit-input-placeholder{color:#8290a3}.sd-login .content .sd-form-title{text-transform:uppercase;font-weight:300;margin-bottom:25px}.sd-login .content .form-actions{clear:both;border:0;border-bottom:1px solid #eee;padding:25px 30px;margin-left:-30px;margin-right:-30px}.sd-login .content .form-actions .btn{margin-top:1px;font-weight:600;padding:10px 20px!important}.sd-login .content .forget-password{margin-top:10px;font-size:14px;float:right}.sd-login .content .create-account{margin:0 -40px -30px;padding:15px 0 17px;text-align:center;background-color:#6c7a8d;border-radius:0 0 7px 7px}.sd-login .content .create-account>p{margin:0}.sd-login .content .create-account p a{font-weight:600;font-size:14px;color:#c3cedd}.sd-login .content .create-account a{display:inline-block;margin-top:5px}.sd-login .copyright{text-align:center;margin:0 auto 30px 0;padding:10px;color:#7a8ca5;font-size:13px}@media (max-width:440px){.sd-login .sd-logo{margin-top:10px}.sd-login .content{width:280px;margin-top:10px}.sd-login .content h3{font-size:22px}.sd-login .checkbox{font-size:13px}}.uppercase{text-transform:uppercase!important}a{text-shadow:none;color:#337ab7}.btn{outline:0!important;font-size:12px;transition:box-shadow .28s cubic-bezier(.4,0,.2,1);box-shadow:0 1px 3px rgba(0,0,0,.1),0 1px 2px rgba(0,0,0,.18);border-radius:2px;border-width:0!important;overflow:hidden;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;padding:9px 14px 8px}.btn:disabled{opacity:.65;cursor:not-allowed}.btn.green{color:#fff;background-color:#32c5d2;border-color:#32c5d2}.btn.green:active,.btn.green:focus,.btn.green:hover{color:#fff;background-color:#26a1ab;border-color:#26a1ab}"]
    })
], Login01Component);

let CheckboxControlComponent = class CheckboxControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.color = 'primary';
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        this._model = value;
    }
    onChange() {
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
        this.sdChange.emit(this._model);
    }
};
CheckboxControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], CheckboxControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "color", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "disabled", void 0);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "model", null);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "modelChange", void 0);
CheckboxControlComponent = __decorate([
    Component({
        selector: 'sd-checkbox-control',
        template: "<mat-checkbox [(ngModel)]=\"_model\" (change)=\"onChange()\" [disabled]=\"disabled\" [color]=\"color\"><span class=\"sd-label\">{{label}}</span></mat-checkbox>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}"]
    })
], CheckboxControlComponent);

let SwitchControlComponent = class SwitchControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.color = 'primary';
        this.modelChange = new EventEmitter();
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        this.cModel = value;
    }
    ngOnInit() {
    }
    onChange(value) {
        this.cModel = value;
        this.modelChange.emit(this.cModel);
        this.change.emit(this.cModel);
        this.sdChange.emit(this.cModel);
    }
};
SwitchControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], SwitchControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "color", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "model", null);
__decorate([
    Output()
], SwitchControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], SwitchControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], SwitchControlComponent.prototype, "sdChange", void 0);
SwitchControlComponent = __decorate([
    Component({
        selector: 'sd-switch-control',
        template: "<mat-slide-toggle [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [disabled]=\"disabled\" [color]=\"color\"><span class=\"sd-label\">{{label}}</span></mat-slide-toggle>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}"]
    })
], SwitchControlComponent);

let RadioControlComponent = class RadioControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.initialized = false;
        this.pItems = [];
        this.name = v4();
        this.valueField = 'value';
        this.displayField = 'display';
        this.display = 'row';
        // tslint:disable-next-line: variable-name
        this._items = [];
        // Optional
        this.required = false;
        this.disabled = false;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.onChanges = () => {
            this._items = this.pItems;
            this._model = this.pModel;
            if (!this._model && this.required && this._items.length > 0) {
                setTimeout(() => {
                    this.onChange(this._items[0][this.valueField]);
                });
            }
        };
    }
    get items() {
        return this._items;
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(value) {
        this.pModel = value || '';
        if (this.initialized) {
            this.onChanges();
        }
    }
    // @ViewChild('formModel') formModel: NgModel;
    ngAfterViewInit() {
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
    }
};
RadioControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], RadioControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "display", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "items", null);
__decorate([
    Input()
], RadioControlComponent.prototype, "model", null);
__decorate([
    Input()
], RadioControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "disabled", void 0);
__decorate([
    Output()
], RadioControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], RadioControlComponent.prototype, "change", void 0);
RadioControlComponent = __decorate([
    Component({
        selector: 'sd-radio-control',
        template: "<section [ngClass]=\"{'c-section': display == 'row'}\">\r\n  <label *ngIf=\"label\" class=\"sd-label d-block mr-2\">{{label}} </label>\r\n  <mat-radio-group [disabled]=\"disabled\" [ngClass]=\"{'c-radio-group-column': display == 'column', 'c-radio-group-row': display == 'row'}\" [ngModel]=\"_model\" (ngModelChange)=\"onChange($event)\" [name]=\"name\">\r\n    <mat-radio-button *ngIf=\"!required\" color=\"warn\" [ngClass]=\"{'m-0': display == 'column', 'mr-4': display == 'row'}\" value=\"\">\r\n      {{'All' | sdTranslate}}\r\n    </mat-radio-button>\r\n    <mat-radio-button color=\"primary\" [ngClass]=\"{'m-0': display == 'column', 'mr-4': display == 'row'}\" *ngFor=\"let item of _items\" [value]=\"item[valueField]\">\r\n      {{item[displayField]}}\r\n    </mat-radio-button>\r\n  </mat-radio-group>\r\n</section>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ".c-section{align-content:center;align-items:center}.c-radio-group-column{display:flex;flex-direction:column}.c-radio-group-row{display:flex;flex-direction:row}"]
    })
], RadioControlComponent);

let SettingService = class SettingService {
    constructor(configurationService) {
        this.configurationService = configurationService;
        this.cache = {};
        this.getKey = (key) => {
            var _a;
            if (!key) {
                throw new Error(`[Setting Service] key is required`);
            }
            const hashedKey = typeof (key) === 'string' ? key : hash__default(key);
            if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.convertKey) {
                return this.configuration.convertKey(hashedKey);
            }
            return hashedKey;
        };
    }
    init() {
        this.configuration = this.configurationService.getSettingConfiguration();
    }
    hasKey(key) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            try {
                const hashKey = this.getKey(key);
                if (this.cache[hashKey] === undefined) {
                    let result = localStorage.getItem(hashKey);
                    if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.get) {
                        result = yield this.configuration.get(hashKey);
                    }
                    if (!result) {
                        this.cache[hashKey] = null;
                    }
                    else {
                        this.cache[hashKey] = JSON.parse(result);
                    }
                }
                return !!this.cache[hashKey];
            }
            catch (err) {
                console.error(`[SETTING HASKEY] ${err}`);
                return null;
            }
        });
    }
    set(key, value, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            const hashKey = this.getKey(key);
            if (hashKey) {
                localStorage.setItem(hashKey, JSON.stringify(value));
                if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.set) {
                    yield this.configuration.set(hashKey, value, args);
                }
                this.cache[hashKey] = value;
            }
        });
    }
    get(key, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            try {
                const hashKey = this.getKey(key);
                if (this.cache[hashKey] === undefined) {
                    let result = localStorage.getItem(hashKey);
                    if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.get) {
                        result = yield this.configuration.get(hashKey, args);
                    }
                    if (!result) {
                        this.cache[hashKey] = null;
                    }
                    else {
                        this.cache[hashKey] = JSON.parse(result);
                    }
                }
                return this.cache[hashKey];
            }
            catch (err) {
                console.error(`[SETTING GET] ${err}`);
                return null;
            }
        });
    }
    remove(key, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            const hashKey = typeof (key) === 'string' ? key : hash__default(key);
            if (hashKey) {
                localStorage.removeItem(hashKey);
                if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.remove) {
                    yield this.configuration.remove(hashKey, args);
                }
                this.cache[hashKey] = null;
            }
        });
    }
};
SettingService.ctorParameters = () => [
    { type: ConfigurationService }
];
SettingService = __decorate([
    Injectable()
], SettingService);

let GridConfigComponent = class GridConfigComponent {
    constructor(ref, notifyService, settingService, translateService) {
        this.ref = ref;
        this.notifyService = notifyService;
        this.settingService = settingService;
        this.translateService = translateService;
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.sdChange = new EventEmitter();
    }
    ngOnInit() {
    }
    setOption(option) {
        return __awaiter(this, void 0, void 0, function* () {
            this.ref.detectChanges();
            this.option = option;
            yield this.init();
            this.emitOnChange();
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.option.key) {
                const storage = yield this.settingService.get(this.option.key).catch(() => undefined);
                try {
                    if (!storage) {
                        this.settingService.remove(this.option.key).catch(console.error);
                        this.initDefault();
                        return;
                    }
                    this.storage = storage;
                    // Loại bỏ những column đã bị xóa khỏi originColumns
                    this.storage.columnConfigs = this.storage.columnConfigs
                        .filter(column => this.option.columns.some(e => e.field === column.originColumn.field));
                    // Thêm những column mới vào storage nếu có
                    this.option.columns.forEach(column => {
                        if (!this.storage.columnConfigs.some(e => e.originColumn.field === column.field)) {
                            this.storage.columnConfigs.push({
                                originColumn: {
                                    field: column.field,
                                    title: column.title,
                                    width: column.width,
                                    fixed: column.fixed
                                },
                                hidden: false,
                                fixed: column.fixed
                            });
                        }
                    });
                    // Cập nhật originColumn
                    this.storage.columnConfigs.forEach(column => {
                        const originColumn = this.option.columns.find(e => e.field === column.originColumn.field);
                        if (originColumn) {
                            Object.assign(column.originColumn, {
                                title: originColumn.title,
                                width: originColumn.width,
                                fixed: originColumn.fixed
                            });
                        }
                    });
                }
                catch (ex) {
                    this.settingService.remove(this.option.key).catch(console.error);
                    this.initDefault();
                }
            }
            else {
                this.initDefault();
            }
        });
    }
    initDefault() {
        this.storage = {};
        this.storage.pageSize = this.option.pageSize;
        this.storage.columnConfigs = [];
        this.option.columns.forEach(column => {
            this.storage.columnConfigs.push({
                originColumn: {
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    fixed: column.fixed
                },
                hidden: false,
                fixed: column.fixed
            });
        });
    }
    open() {
        this.modal.open();
    }
    save() {
        if (!Number.isSafeInteger(+this.storage.pageSize)) {
            this.notifyService.notify.warning(this.translateService.translate('Page size must be an integer'));
            return;
        }
        if (this.storage.pageSize > 200) {
            this.notifyService.notify.warning(this.translateService.translate('Page size is too large'));
            return;
        }
        this.settingService.set(this.option.key, this.storage);
        this.emitOnChange();
        this.modal.close();
        this.ref.detectChanges();
    }
    reset() {
        this.settingService.remove(this.option.key);
        this.initDefault();
        // this.reload();
        this.emitOnChange();
        this.modal.close();
        this.ref.detectChanges();
    }
    moveColumnUp(index) {
        const temp = this.storage.columnConfigs[index];
        this.storage.columnConfigs[index] = this.storage.columnConfigs[index - 1];
        this.storage.columnConfigs[index - 1] = temp;
    }
    moveColumnDown(index) {
        const temp = this.storage.columnConfigs[index];
        this.storage.columnConfigs[index] = this.storage.columnConfigs[index + 1];
        this.storage.columnConfigs[index + 1] = temp;
    }
    emitOnChange() {
        const pageSize = +this.storage.pageSize || this.option.pageSize;
        const columns = this.option.columns.filter(column => {
            // Hidden column theo config
            // Lấy các thuộc tính Title, Width, Fixed từ config
            const columnConfig = this.storage.columnConfigs.find(e => e.originColumn.field === column.field);
            if (columnConfig) {
                column.title = columnConfig.title || column.title;
                column.width = columnConfig.width || column.width;
                column.fixed = columnConfig.fixed;
                return !columnConfig.hidden;
            }
            return true;
        }).sort((current, next) => {
            // Sắp xếp theo config
            const currentIndex = this.storage.columnConfigs.findIndex(e => e.originColumn.field === current.field);
            const nextIndex = this.storage.columnConfigs.findIndex(e => e.originColumn.field === next.field);
            return currentIndex - nextIndex;
        }).filter(column => {
            // Hidden column theo option truyền vào
            if (column.hidden === undefined) {
                return true;
            }
            if (typeof (column.hidden) === 'boolean') {
                return !column.hidden;
            }
            if (typeof (column.hidden) === 'function') {
                return !column.hidden();
            }
            return false;
        });
        const result = {
            pageSize,
            columns,
            fixedColumns: columns.filter(e => e.fixed),
            normalColumns: columns.filter(e => !e.fixed)
        };
        this.sdChange.emit(result);
    }
};
GridConfigComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NotifyService },
    { type: SettingService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridConfigComponent.prototype, "modal", void 0);
__decorate([
    Output()
], GridConfigComponent.prototype, "sdChange", void 0);
GridConfigComponent = __decorate([
    Component({
        selector: 'sd-grid-config',
        template: "<sd-modal-control [title]=\"'Configuration' | sdTranslate\" #modal>\r\n  <sd-modal-body *ngIf=\"storage\">\r\n    <div class=\"row\">\r\n      <div class=\"col-6\">\r\n        <sd-input-control [label]=\"'Page size' | sdTranslate\" [(model)]=\"storage.pageSize\" type=\"number\" step=\"1\">\r\n        </sd-input-control>\r\n      </div>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered mb-1\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center\" style=\"width: 50px\">#</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-center\" style=\"width: 80px\"></th>\r\n                <!-- <th class=\"text-uppercase\" style=\"width: 120px\">Field </th> -->\r\n                <th class=\"text-uppercase\">{{'Title' | sdTranslate}}</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-uppercase\" style=\"width: 80px\">{{'Width' | sdTranslate}}</th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\">{{'Hidden' | sdTranslate}}</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-uppercase\" style=\"width: 80px\">{{'Freeze' | sdTranslate}}</th>\r\n              </tr>\r\n            </thead>\r\n            <tbody>\r\n              <tr *ngFor=\"let column of storage.columnConfigs; let idx = index\">\r\n                <td class=\"align-middle text-center\">\r\n                  {{idx+1}}\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle text-center\">\r\n                  <button type=\"button\" [disabled]=\"idx==0\" type=\"button\" class=\"c-btn-icon\" placement=\"top\"\r\n                    matTooltip=\"Up\" (click)=\"moveColumnUp(idx)\">\r\n                    <i class=\"fa fa-arrow-up text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                  <button type=\"button\" [disabled]=\"idx==storage.columnConfigs.length-1\" type=\"button\"\r\n                    class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Down\" (click)=\"moveColumnDown(idx)\">\r\n                    <i class=\"fa fa-arrow-down text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                </td>\r\n                <!-- <td class=\"align-middle\">{{column.originColumn.field}}</td> -->\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.title}}\" [(ngModel)]=\"column.title\"\r\n                    class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.width}}\" [(ngModel)]=\"column.width\"\r\n                    class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.hidden\" color=\"primary\"></mat-slide-toggle>\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.fixed\" color=\"primary\"></mat-slide-toggle>\r\n                </td>\r\n              </tr>\r\n          </table>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <sd-button class=\"mr-auto\" (action)=\"reset()\" icon=\"refresh\" [title]=\"'Reset' | sdTranslate\" size=\"sm\"></sd-button>\r\n    <sd-button (action)=\"save()\" icon=\"save\" [title]=\"'Save' | sdTranslate\" color=\"primary\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button style=\"flex: 1; padding-right: 5px;\" (action)=\"reset()\" icon=\"refresh\" [title]=\"'Reset' | sdTranslate\"\r\n      width=\"100%\" size=\"sm\"></sd-button>\r\n    <sd-button style=\"flex: 1; padding-left: 5px;\" (action)=\"save()\" icon=\"save\" [title]=\"'Save' | sdTranslate\" color=\"primary\" width=\"100%\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.table td,.table th{padding:.2rem!important}"]
    })
], GridConfigComponent);

let CkeditorControlComponent = class CkeditorControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.disabled = false;
        this.required = false;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.config = {
            entities_latin: false
        };
    }
    set model(value) {
        this.cModel = value;
        this.ref.detectChanges();
    }
    onChange(value) {
        this.model = value;
        this.modelChange.emit(value);
        this.change.emit(value);
        this.sdChange.emit(value);
    }
};
CkeditorControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], CkeditorControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "model", null);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "sdChange", void 0);
CkeditorControlComponent = __decorate([
    Component({
        selector: 'sd-ckeditor-control',
        template: "\r\n<label *ngIf=\"label\" class=\"sd-label d-block\">{{label}} <span *ngIf=\"required\" class=\"text-danger\">*</span></label>\r\n<ckeditor [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [config]=\"config\" [readOnly]=\"disabled\"></ckeditor>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ":host ::ng-deep .ck-editor__editable{min-height:500px}"]
    })
], CkeditorControlComponent);

let TranslatePipe = class TranslatePipe {
    constructor(translateService) {
        this.translateService = translateService;
    }
    transform(value) {
        return this.translateService.translate(value);
    }
};
TranslatePipe.ctorParameters = () => [
    { type: TranslateService }
];
TranslatePipe = __decorate([
    Pipe({
        name: 'sdTranslate'
    })
], TranslatePipe);

let CacheService = class CacheService {
    constructor() {
        this.cache = {};
    }
    set(key, data, group = null) {
        let objHash = null;
        let objGroup = null;
        if (typeof (key) === 'object') {
            objHash = Object.assign({}, key);
            key = hash__default(key);
        }
        if (typeof (group) === 'object') {
            objGroup = Object.assign({}, group);
            group = hash__default(group);
        }
        if (this.has(key) && typeof (this.cache[key].data) === 'object' && typeof (data) === 'object') {
            Object.assign(this.cache[key].data, data);
        }
        else {
            this.cache[key] = {
                objHash,
                objGroup,
                group,
                data
            };
        }
    }
    get(key) {
        if (typeof (key) === 'object') {
            key = hash__default(key);
        }
        if (!this.has(key)) {
            return null;
        }
        return this.cache[key].data;
    }
    has(key) {
        if (typeof (key) === 'object') {
            key = hash__default(key);
        }
        return !!this.cache[key];
    }
    clear() {
        this.cache = {};
    }
    allByGroup(group) {
        if (typeof (group) === 'object') {
            group = hash__default(group);
        }
        const results = [];
        Object.keys(this.cache)
            .filter(key => this.cache[key] && this.cache[key].group === group)
            .forEach(key => results.push(this.cache[key].data));
        return results;
    }
    clearByGroup(group) {
        if (typeof (group) === 'object') {
            group = hash__default(group);
        }
        Object.keys(this.cache).forEach(key => {
            if (this.cache[key].group === group) {
                this.cache[key] = undefined;
            }
        });
    }
};
CacheService = __decorate([
    Injectable()
], CacheService);

let UploadExcelConfigComponent = class UploadExcelConfigComponent {
    constructor(settingService, translateService) {
        this.settingService = settingService;
        this.translateService = translateService;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
    }
    ngOnInit() {
    }
    setOption(option) {
        return __awaiter(this, void 0, void 0, function* () {
            this.option = option;
            yield this.init();
            this.emitOnChange();
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.option.key && this.settingService.get(this.option.key)) {
                try {
                    this.storage = yield this.settingService.get(this.option.key);
                    if (!this.storage) {
                        // Xóa setting
                        this.settingService.remove(this.option.key);
                        // Lấy setting mặc định
                        this.initDefault();
                        return;
                    }
                    // Loại bỏ những column đã bị xóa khỏi originColumns
                    this.storage.columns = this.storage.columns.filter(column => this.option.columns.some(e => e.field === column.originColumn.field));
                    // Thêm những column mới vào storage nếu có
                    this.option.columns.forEach(column => {
                        if (!this.storage.columns.some(e => e.originColumn.field === column.field)) {
                            this.storage.columns.push({
                                originColumn: {
                                    field: column.field,
                                    title: column.title,
                                    width: column.width,
                                    required: column.required
                                },
                                hidden: false
                            });
                        }
                    });
                    // Cập nhật originColumn
                    this.storage.columns.forEach(column => {
                        const originColumn = this.option.columns.find(e => e.field === column.originColumn.field);
                        if (originColumn) {
                            Object.assign(column.originColumn, {
                                title: originColumn.title,
                                width: originColumn.width
                            });
                        }
                    });
                }
                catch (err) {
                    // Xóa setting
                    this.settingService.remove(this.option.key);
                    // Lấy setting mặc định
                    this.initDefault();
                }
            }
            else {
                this.initDefault(); // Lấy setting mặc định
            }
        });
    }
    initDefault() {
        this.storage = {};
        this.storage.formatDate = '';
        this.storage.columns = [];
        this.option.columns.forEach(column => {
            this.storage.columns.push({
                originColumn: {
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    required: column.required
                },
                hidden: false
            });
        });
    }
    open() {
        this.modal.open();
    }
    save() {
        this.settingService.set(this.option.key, this.storage);
        this.emitOnChange();
        this.modal.close();
    }
    reset() {
        this.settingService.remove(this.option.key);
        this.initDefault();
        // this.reload();
        this.emitOnChange();
        this.modal.close();
    }
    moveColumnUp(index) {
        const temp = this.storage.columns[index];
        this.storage.columns[index] = this.storage.columns[index - 1];
        this.storage.columns[index - 1] = temp;
    }
    moveColumnDown(index) {
        const temp = this.storage.columns[index];
        this.storage.columns[index] = this.storage.columns[index + 1];
        this.storage.columns[index + 1] = temp;
    }
    emitOnChange() {
        const formatDate = this.storage.formatDate || '';
        const columns = this.option.columns.filter(column => {
            // Hidden column theo config
            // Lấy các thuộc tính Title, Width từ config
            const columnConfig = this.storage.columns.find(e => e.originColumn.field === column.field);
            if (columnConfig) {
                column.title = columnConfig.title || this.translateService.translate(columnConfig.originColumn.title);
                column.width = columnConfig.width || columnConfig.originColumn.width;
                return !columnConfig.hidden;
            }
            else {
                return true;
            }
        }).sort((current, next) => {
            // Sắp xếp theo config
            const currentIndex = this.storage.columns.findIndex(e => e.originColumn.field === current.field);
            const nextIndex = this.storage.columns.findIndex(e => e.originColumn.field === next.field);
            return currentIndex - nextIndex;
        });
        const result = {
            formatDate: '',
            // pageSize: pageSize,
            columns
        };
        this.change.emit(result);
    }
};
UploadExcelConfigComponent.ctorParameters = () => [
    { type: SettingService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], UploadExcelConfigComponent.prototype, "modal", void 0);
__decorate([
    Output()
], UploadExcelConfigComponent.prototype, "change", void 0);
UploadExcelConfigComponent = __decorate([
    Component({
        selector: 'sd-upload-excel-config',
        template: "<sd-modal-control width=\"sm\" title=\"Configure Upload Excel\" #modal>\r\n  <sd-modal-body *ngIf=\"storage\">\r\n    <div class=\"row\">\r\n      <div class=\"col-md-12 mt-2\">\r\n        <sd-input-control [(model)]=\"storage.formatDate\"></sd-input-control>\r\n      </div>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\" style=\"height: calc(100vh - 20rem)\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center\" style=\"width: 50px\">#</th>\r\n                <th class=\"text-center\" style=\"width: 80px\"></th>\r\n                <th class=\"text-uppercase\" style=\"width: 120px\" translate>Field </th>\r\n                <th class=\"text-uppercase\" translate>Title </th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\" translate>Width </th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\" translate>Hidden </th>\r\n              </tr>\r\n            </thead>\r\n            <tbody>\r\n              <tr *ngFor=\"let column of storage.columns; let idx = index\">\r\n                <td class=\"align-middle text-center\">\r\n                  {{idx+1}}\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <button type=\"button\" [disabled]=\"idx==0\" type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Up\" (click)=\"moveColumnUp(idx)\">\r\n                    <i class=\"fa fa-arrow-up text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                  <button type=\"button\" [disabled]=\"idx==storage.columns.length-1\" type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Down\" (click)=\"moveColumnDown(idx)\">\r\n                    <i class=\"fa fa-arrow-down text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                </td>\r\n                <td class=\"align-middle\">{{column.originColumn.field}}</td>\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.title}}\" [(ngModel)]=\"column.title\" class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.width}}\" [(ngModel)]=\"column.width\" class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.hidden\" color=\"primary\" [disabled]=\"column.originColumn.required\"></mat-slide-toggle>\r\n                </td>\r\n              </tr>\r\n          </table>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <button type=\"button\" class=\"btn btn-info btn-sm mr-auto\" (click)=\"reset()\">\r\n      <i class=\"fa fa-refresh mr-1\"></i> <span translate>Reset</span></button>\r\n    <button type=\"button\" class=\"btn btn-primary btn-sm\" (click)=\"save()\">\r\n      <i class=\"fa fa-floppy-o mr-1\"></i> <span translate>Save</span></button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.table td,.table th{padding:.2rem!important}.btn{color:#fff;background-color:#999;border-color:#999;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:hover{color:#fff;background-color:#919191;border-color:#7a7a7a}.btn.btn-sm{font-size:.6875rem}.btn.btn-primary{color:#fff;background-color:#9c27b0;border-color:#9c27b0;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,188,212,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}"]
    })
], UploadExcelConfigComponent);

let GridAutocompleteControl = 
// tslint:disable-next-line: component-class-suffix
class GridAutocompleteControl {
    constructor(ref, utilityService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.name = v4();
        this.cItems = [];
        this.limit = 30;
        this.loading = false;
        this.modelChange = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.search = new EventEmitter();
        this.subcription = new Subscription();
        this.visibility = true;
        this.onChanges = () => {
            this.cModel = this.pModel;
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = this.pItems.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = this.pItems;
            }
            // this.formModel?.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.reload = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.filter = (value) => {
            let results = this.cItems;
            if (value) {
                results = this.cItems.filter(item => {
                    return this.utilityService.changeAliasLowerCase(item[this.displayField])
                        .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
                });
            }
            return results.filter((item, index) => index < this.limit);
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.cItems) {
                    return value;
                }
                const selectedItem = this.cItems.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                return value;
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            (_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.setValue(undefined);
        };
    }
    set items(items) {
        var _a, _b, _c, _d;
        if (!items) {
            items = [];
        }
        if (Array.isArray(items)) {
            this.pItems = items || [];
            if (this.initialized) {
                this.onChanges();
                (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value);
                this.reload();
            }
        }
        else if ((_c = items) === null || _c === void 0 ? void 0 : _c.pipe) {
            this.subcription.add((_d = items) === null || _d === void 0 ? void 0 : _d.subscribe(values => {
                var _a, _b;
                this.pItems = values || [];
                if (this.initialized) {
                    this.onChanges();
                    (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value);
                    this.reload();
                }
            }));
        }
    }
    set model(value) {
        this.pModel = value;
        if (this.initialized) {
            this.onChanges();
            this.reload();
        }
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => typeof item === 'string' ? item : (item ? item[this.displayField] : '')), map(this.filter));
    }
    ngAfterViewInit() {
        this.onChanges();
        this.reload();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.subcription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    onChange(value) {
        var _a;
        if (typeof value !== 'string') {
            this.cModel = value ? value[this.valueField] : undefined;
            this.modelChange.emit(this.cModel);
            this.sdChange.emit(value);
        }
        else {
            if (!value) {
                this.cModel = undefined;
                this.modelChange.emit(this.cModel);
                this.sdChange.emit(this.cModel);
                this.reload();
                (_a = this.autocompleteTrigger) === null || _a === void 0 ? void 0 : _a.openPanel();
                // this.clear();
            }
            this.search.emit(value);
        }
    }
};
GridAutocompleteControl.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService }
];
__decorate([
    Input()
], GridAutocompleteControl.prototype, "loading", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "valueField", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "displayField", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "items", null);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "model", null);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "modelChange", void 0);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "sdChange", void 0);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "search", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "required", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], GridAutocompleteControl.prototype, "formModel", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], GridAutocompleteControl.prototype, "autocompleteTrigger", void 0);
GridAutocompleteControl = __decorate([
    Component({
        selector: 'sd-grid-autocomplete-control',
        template: "<div class=\"w-100 c-container\">\r\n  <input #autocompleteTrigger class=\"form-control c-input-xs\" #formModel=\"ngModel\" [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\"\r\n    [name]=\"name\" [matAutocomplete]=\"auto\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"false\">\r\n  <i *ngIf=\"!cModel; else clearIcon\" class=\"fa fa-search c-icon\"></i>\r\n  <ng-template #clearIcon>\r\n    <i class=\"fa fa-times text-danger c-icon\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i>\r\n  </ng-template>\r\n</div>\r\n<mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\" autoActiveFirstOption>\r\n  <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n    {{item[displayField]}}\r\n  </mat-option>\r\n</mat-autocomplete>",
        styles: [".c-container{position:relative}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}.c-icon{position:absolute;top:7px;right:7px;font-size:13px!important}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}"]
    })
    // tslint:disable-next-line: component-class-suffix
], GridAutocompleteControl);

let GridPopupEditorComponent = class GridPopupEditorComponent {
    constructor(settingService) {
        this.settingService = settingService;
        this.save = new EventEmitter();
        this.columns = [];
    }
    ngOnInit() {
    }
    setGridOption(gridOption) {
        this.gridOption = gridOption;
    }
    open(item) {
        this.item = item;
        this.columns = this.gridOption.columns.filter(column => item.editorHandler[column.field].visible);
    }
    onCancel() {
        this.modal.close();
    }
    onSave() {
        this.modal.close();
        this.save.emit(this.item);
    }
};
GridPopupEditorComponent.ctorParameters = () => [
    { type: SettingService }
];
__decorate([
    ViewChild('modal')
], GridPopupEditorComponent.prototype, "modal", void 0);
__decorate([
    Output()
], GridPopupEditorComponent.prototype, "save", void 0);
GridPopupEditorComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-editor',
        template: "<sd-modal-control title=\"Configuration\" #modal>\r\n  <sd-modal-body *ngIf=\"item && gridOption?.columns\">\r\n    <form #formEditor=\"ngForm\">\r\n      <ng-template ngFor let-column [ngForOf]=\"columns\">\r\n        <div class=\"row\">\r\n          <div class=\"col-md-4\"></div>\r\n          <div class=\"col-md-8\">\r\n            <sd-input-control *ngIf=\"column.type === 'string'\" [(model)]=\"item[column.field]\"></sd-input-control>\r\n            <sd-input-control *ngIf=\"column.type === 'number'\" [(model)]=\"item[column.field]\" type=\"number\">\r\n            </sd-input-control>\r\n            <sd-select-control *ngIf=\"column.type === 'values'\" [(model)]=\"item[column.field]\" [items]=\"column.values\">\r\n            </sd-select-control>\r\n            <sd-switch-control *ngIf=\"column.type === 'boolean'\" [(model)]=\"item[column.field]\">\r\n            </sd-switch-control>\r\n            <sd-radio-control *ngIf=\"column.type === 'radio'\" [(model)]=\"item[column.field]\" [items]=\"column.values\">\r\n            </sd-radio-control>\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </form>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <button type=\"button\" class=\"btn btn-info btn-sm mr-auto\" (click)=\"onCancel()\">\r\n      <i class=\"fa fa-refresh\"></i> {{'Cancel' | sdTranslate }}</button>\r\n    <button type=\"button\" class=\"btn btn-primary btn-sm\" (click)=\"onSave()\">\r\n      <i class=\"fa fa-floppy-o\"></i> {{'Save' | sdTranslate }}</button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}"]
    })
], GridPopupEditorComponent);

let FilterMobilePipe = class FilterMobilePipe {
    transform(columns, item) {
        // Những giá trị undefined, null và rỗng sẽ bỏ qua khi hiển thị trên mobile
        return columns.filter(column => {
            var _a;
            return (item[column.field] !== undefined
                && item[column.field] !== null
                && item[column.field] !== '')
                || column.htmlTemplate
                || column.type === 'children'
                || (column.type === 'string' && ((_a = column.commands) === null || _a === void 0 ? void 0 : _a.length) > 0);
        });
    }
};
FilterMobilePipe = __decorate([
    Pipe({
        name: 'filterMobile',
        pure: false
    })
], FilterMobilePipe);

let GridPopupFilterComponent = class GridPopupFilterComponent {
    constructor(ref, deviceService, settingService, notifyService, translateService) {
        this.ref = ref;
        this.settingService = settingService;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.keyPrefix = 'PopupFilter';
        this.displayKey = 'SDCUSTOM';
        this.isMobileOrTablet = false;
        this.filterType = 'inline';
        this.key = '';
        this.accept = new EventEmitter();
        this.clear = new EventEmitter();
        this.loadInlineFilter = new EventEmitter();
        this.newQuickFilter = 'e1ef1d43-d689-424f-959e-e6cd154cfee7';
        this.filter = {};
        this.externalFilter = {};
        this.columns = [];
        this.externalFilters = [];
        this.quickFilters = [];
        this.showInlineFilter = true;
        this.numberOfQuickFiltes = 0;
        this.maxQuickFilters = 5;
        this.remove = (quickFilter) => {
            this.notifyService.confirm(this.translateService.translate('Remove filter')).then(() => __awaiter(this, void 0, void 0, function* () {
                if (quickFilter.code === this.selectedCode) {
                    delete this.selectedCode;
                }
                const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
                this.quickFilters.splice(idx, 1);
                yield this.updateConfiguration();
            }));
        };
        this.select = (quickFilter) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (quickFilter.code === this.selectedCode) {
                delete this.selectedCode;
            }
            else {
                const f1 = JSON.stringify(quickFilter.filter);
                const f2 = JSON.stringify(quickFilter.externalFilter);
                this.selectedCode = (_a = quickFilter) === null || _a === void 0 ? void 0 : _a.code;
                this.filter = JSON.parse(f1);
                this.externalFilter = JSON.parse(f2);
            }
            yield this.updateConfiguration();
        });
        this.onSelectionChange = (change) => {
            var _a;
            const value = ((_a = change) === null || _a === void 0 ? void 0 : _a.value) || '';
            if (value === this.newQuickFilter) {
                this.selectedCode = '';
                this.onCreateQuickFilter();
                this.ref.detectChanges();
            }
            else {
                const quickFilter = this.quickFilters.find(e => e.code === value);
                if (quickFilter) {
                    this.onDetailQuickFilter(quickFilter);
                }
            }
        };
        this.onCreateQuickFilter = () => {
            this.popupQuickFilterDetail.open(this.columns, this.externalFilters);
        };
        this.onDetailQuickFilter = (quickFilter) => __awaiter(this, void 0, void 0, function* () {
            if (quickFilter) {
                this.selectedCode = quickFilter.code;
                const f1 = JSON.stringify(quickFilter.filter);
                const f2 = JSON.stringify(quickFilter.externalFilter);
                this.filter = JSON.parse(f1);
                this.externalFilter = JSON.parse(f2);
                yield this.updateConfiguration();
            }
        });
        this.onEditQuickFilter = (ev, quickFilter) => {
            ev.stopPropagation();
            ev.preventDefault();
            if (quickFilter) {
                // tslint:disable-next-line: max-line-length
                this.popupQuickFilterDetail.open(this.columns, this.externalFilters, quickFilter.filter, quickFilter.externalFilter, quickFilter.code);
                this.ref.detectChanges();
            }
        };
        this.onDeleteQuickFilter = (ev, quickFilter) => {
            ev.stopPropagation();
            ev.preventDefault();
            if (quickFilter) {
                this.notifyService.confirm(this.translateService.translate('Remove filter')).then(() => __awaiter(this, void 0, void 0, function* () {
                    if (quickFilter.code === this.selectedCode) {
                        this.selectedCode = '';
                    }
                    const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
                    this.quickFilters.splice(idx, 1);
                    yield this.updateConfiguration();
                    this.ref.detectChanges();
                }));
            }
        };
        this.onAcceptQuickFilter = (args) => __awaiter(this, void 0, void 0, function* () {
            const quickFilter = this.quickFilters.find(e => e.code === args.code);
            if (!quickFilter) {
                this.quickFilters.push({
                    code: args.code,
                    filter: args.filter,
                    externalFilter: args.externalFilter
                });
            }
            else {
                quickFilter.filter = args.filter;
                quickFilter.externalFilter = args.externalFilter;
            }
            yield this.updateConfiguration();
        });
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
        this.loadConfiguration().then(() => {
            var _a;
            this.loadInlineFilter.emit({
                showInlineFilter: (_a = this.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true)),
                quickFilters: this.quickFilters || [],
                selectedQuickFilter: this.selectedCode || ''
            });
        });
    }
    ngAfterViewInit() {
    }
    open(fixedColums, normalColumns, filter, externalFilter, externalFilters) {
        this.columns = [...fixedColums, ...normalColumns].filter(e => !e.preventFilter);
        this.columns.forEach(column => {
            if (column.type === 'children') {
                column.children = column.children.filter(e => !e.preventFilter);
            }
        });
        if (externalFilters) {
            this.externalFilters = externalFilters;
            for (const item of this.externalFilters) {
                if (item.type === 'daterange' || item.type === 'numberrange') {
                    this.externalFilter[item.field] = this.externalFilter[item.field] || { from: '', to: '' };
                }
            }
        }
        else {
            this.externalFilters = [];
        }
        this.filter = filter;
        this.externalFilter = externalFilter;
        this.modal.open();
    }
    onAccept() {
        this.accept.emit({
            filter: this.filter,
            externalFilter: this.externalFilter
        });
        this.modal.close();
    }
    onClear() {
        delete this.selectedCode;
        this.clear.emit();
    }
    createQuickFilter() {
        return __awaiter(this, void 0, void 0, function* () {
            this.notifyService.confirmWithInput(this.translateService.translate('Enter quick filter name')).then((code) => __awaiter(this, void 0, void 0, function* () {
                if (code) {
                    if (code.length > 100) {
                        this.notifyService.notify.warning(this.translateService.translate('Code too long'));
                        return;
                    }
                    yield this.add(code);
                    this.notifyService.notify.success();
                }
                else {
                    this.notifyService.notify.warning(this.translateService.translate('Code can not be empty'));
                }
            }));
        });
    }
    updateQuickFilter() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.selectedCode) {
                yield this.update(this.selectedCode);
                this.notifyService.notify.success();
                this.selectedCode = null;
            }
        });
    }
    add(code) {
        return __awaiter(this, void 0, void 0, function* () {
            const f1 = JSON.stringify(this.filter);
            const f2 = JSON.stringify(this.externalFilter);
            const quickFilter = {
                code,
                filter: JSON.parse(f1),
                externalFilter: JSON.parse(f2),
            };
            const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
            if (idx !== -1) {
                this.notifyService.notify.warning(`${this.translateService.translate('Code is existed')}: ${quickFilter.code}`);
                return;
            }
            this.quickFilters.push(quickFilter);
            yield this.updateConfiguration();
        });
    }
    update(code) {
        return __awaiter(this, void 0, void 0, function* () {
            const f1 = JSON.stringify(this.filter);
            const f2 = JSON.stringify(this.externalFilter);
            const quickFilter = {
                code,
                filter: JSON.parse(f1),
                externalFilter: JSON.parse(f2)
            };
            const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
            if (idx === -1) {
                this.notifyService.notify.warning(`Code ${quickFilter.code} is not existed`);
                return;
            }
            this.quickFilters[idx] = quickFilter;
            yield this.updateConfiguration();
        });
    }
    loadConfiguration() {
        var _a, _b, _c, _d, _e;
        return __awaiter(this, void 0, void 0, function* () {
            this.quickFilters = [];
            this.showInlineFilter = true;
            if (!this.key) {
                return;
            }
            if (!(yield this.settingService.hasKey(this.keyPrefix + this.key))) {
                return;
            }
            const configuration = yield this.settingService.get(this.keyPrefix + this.key);
            if (Array.isArray((_a = configuration) === null || _a === void 0 ? void 0 : _a.quickFilters)) {
                this.quickFilters = configuration.quickFilters;
            }
            this.numberOfQuickFiltes = ((_b = this.quickFilters) === null || _b === void 0 ? void 0 : _b.length) || 0;
            this.showInlineFilter = (_d = (_c = configuration) === null || _c === void 0 ? void 0 : _c.showInlineFilter, (_d !== null && _d !== void 0 ? _d : true));
            this.selectedCode = ((_e = configuration) === null || _e === void 0 ? void 0 : _e.selectedQuickFilter) || '';
        });
    }
    updateConfiguration(selectedQuickFilterCode) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.key) {
                return;
            }
            if (selectedQuickFilterCode !== undefined) {
                this.selectedCode = selectedQuickFilterCode;
            }
            yield this.settingService.set(this.keyPrefix + this.key, {
                quickFilters: this.quickFilters,
                showInlineFilter: this.showInlineFilter,
                selectedQuickFilter: this.selectedCode
            });
            this.loadInlineFilter.emit({
                showInlineFilter: (_a = this.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true)),
                quickFilters: this.quickFilters || [],
                selectedQuickFilter: this.selectedCode || ''
            });
            this.numberOfQuickFiltes = ((_b = this.quickFilters) === null || _b === void 0 ? void 0 : _b.length) || 0;
            this.ref.detectChanges();
        });
    }
};
GridPopupFilterComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: SettingService },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridPopupFilterComponent.prototype, "modal", void 0);
__decorate([
    ViewChild('popupQuickFilterDetail')
], GridPopupFilterComponent.prototype, "popupQuickFilterDetail", void 0);
__decorate([
    Input()
], GridPopupFilterComponent.prototype, "filterType", void 0);
__decorate([
    Input()
], GridPopupFilterComponent.prototype, "key", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "accept", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "clear", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "loadInlineFilter", void 0);
GridPopupFilterComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-filter',
        template: "<sd-modal-control width=\"sm\" [title]=\"'Filter' | sdTranslate\" #modal>\r\n  <sd-modal-body>\r\n    <div *ngIf=\"key\">\r\n      <mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n        <mat-label>{{'Quick filters' | sdTranslate}}</mat-label>\r\n        <mat-select [(ngModel)]=\"selectedCode\" (selectionChange)=\"onSelectionChange($event)\">\r\n          <mat-option value=\"\">{{'Please select' | sdTranslate}}</mat-option>\r\n          <mat-option *ngFor=\"let quickFilter of quickFilters\" [value]=\"quickFilter.code\">\r\n            <div style=\"display:flex; justify-content: space-between\">\r\n              <span>{{quickFilter.code}}</span>\r\n              <div>\r\n                <mat-icon class=\"mr-1 c-fa-icon\" (click)=\"onEditQuickFilter($event, quickFilter)\" fontSet=\"fa\" fontIcon=\"fa-pencil\"></mat-icon>\r\n                <mat-icon class=\"mr-0 c-fa-icon\" (click)=\"onDeleteQuickFilter($event, quickFilter)\" fontSet=\"fa\" fontIcon=\"fa-trash-o\"></mat-icon>\r\n              </div>\r\n            </div>\r\n          </mat-option>\r\n          <mat-option [value]=\"newQuickFilter\">\r\n            <div>\r\n              <mat-icon class=\"mr-1 c-fa-icon\" fontSet=\"fa\" fontIcon=\"fa-plus\"></mat-icon>\r\n              <a href=\"javascript:;\">{{'Create quick filter' | sdTranslate}}</a>\r\n            </div>\r\n          </mat-option>\r\n        </mat-select>\r\n      </mat-form-field>\r\n    </div>\r\n    <div *ngFor=\"let item of externalFilters\">\r\n      <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-input-control>\r\n      <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-input-control>\r\n      <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\" [{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-select-control>\r\n      <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n        [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n      </sd-radio-control>\r\n      <ng-container *ngIf=\"item.type === 'values'\">\r\n        <sd-select-control *ngIf=\"item.selection === 'MULTIPLE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          multiple=\"true\">\r\n        </sd-select-control>\r\n        <sd-autocomplete-control *ngIf=\"item.selection === 'AUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-autocomplete-control>\r\n        <sd-chip-control *ngIf=\"item.selection === 'MULTIPLEAUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-chip-control>\r\n        <sd-select-control *ngIf=\"!item.selection\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-select-control>\r\n      </ng-container>\r\n      <sd-input-control *ngIf=\"item.type === 'custom'\" [label]=\"item.title\"\r\n        [(model)]=\"externalFilter[displayKey + item.field]\"\r\n        (sdClick)=\"item?.onClick(externalFilter, item.field, displayKey + item.field)\">\r\n      </sd-input-control>\r\n      <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n        type=\"date\">\r\n      </sd-date-picker-control>\r\n      <sd-date-range-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='daterangefull'\"\r\n        [(fromDate)]=\"externalFilter[item.field].from\" [(toDate)]=\"externalFilter[item.field].to\"\r\n        [minDate]=\"item.minDate\" [maxDate]=\"item.maxDate\" type=\"date\">\r\n      </sd-date-range-picker-control>\r\n      <ng-container *ngIf=\"item.type ==='daterange'\">\r\n        <div class=\"row\">\r\n          <div class=\"col-6\">\r\n            <sd-date-picker-control [label]=\"item.fromTitle\" [(model)]=\"externalFilter[item.field].from\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate\"\r\n              [maxDate]=\"externalFilter[item.field].to || item.maxDate\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n          <div class=\"col-6\">\r\n            <sd-date-picker-control [label]=\"item.toTitle\" [(model)]=\"externalFilter[item.field].to\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate || externalFilter[item.field].from\"\r\n              [maxDate]=\"item.maxDate\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <div class=\"row\" *ngIf=\"item.type ==='numberrange'\">\r\n        <div class=\"col-6\">\r\n          <sd-input-control [label]=\"item.fromTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].from\">\r\n          </sd-input-control>\r\n        </div>\r\n        <div class=\"col-6\">\r\n          <sd-input-control [label]=\"item.toTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].to\">\r\n          </sd-input-control>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngFor=\"let column of columns\">\r\n      <div>\r\n        <sd-input-control *ngIf=\"column.type === 'string'\" [label]=\"column.title\" type=\"text\"\r\n          [(model)]=\"filter[column.field]\">\r\n        </sd-input-control>\r\n        <sd-input-control *ngIf=\"column.type === 'number'\" [label]=\"column.title\" type=\" number\"\r\n          [(model)]=\"filter[column.field]\">\r\n        </sd-input-control>\r\n        <sd-radio-control *ngIf=\"column.type === 'bool'\" [label]=\"column.title\" [items]=\"[{value:'1',display:column.trueValue || 'True' },\r\n          {value:'0',display:column.falseValue || 'False' }]\" [(model)]=\"filter[column.field]\">\r\n        </sd-radio-control>\r\n        <sd-radio-control *ngIf=\"column.type === 'radio'\" [label]=\"column.title\" [items]=\"column.values\"\r\n          [valueField]=\"column.valueField\" [displayField]=\"column.displayField\" [(model)]=\"filter[column.field]\">\r\n        </sd-radio-control>\r\n        <sd-autocomplete-control *ngIf=\"column.type === 'values'\" [label]=\"column.title\" [items]=\"column.values\"\r\n          valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\">\r\n        </sd-autocomplete-control>\r\n        <sd-date-picker-control *ngIf=\"column.type ==='date' || column.type==='datetime' ||\r\n          column.type==='time'\" [label]=\"column.title\" [(model)]=\" filter[column.field]\" type=\"date\">\r\n        </sd-date-picker-control>\r\n      </div>\r\n      <div *ngIf=\"column.type === 'children' && column.children?.length\">\r\n        <ng-template ngFor let-childColumn [ngForOf]=\"column.children\">\r\n          <sd-input-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'string'\" type=\"text\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-input-control>\r\n          <sd-input-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'number'\" type=\" number\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-input-control>\r\n          <sd-radio-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'bool'\" [items]=\"[{value:'1',display:column.trueValue || 'True' },\r\n          {value:'0',display:childColumn.falseValue || 'False' }]\" [(model)]=\"filter[childColumn.field]\">\r\n          </sd-radio-control>\r\n          <sd-radio-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'radio'\"\r\n            [items]=\"childColumn.values\" [valueField]=\"childColumn.valueField\" [displayField]=\"childColumn.displayField\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-radio-control>\r\n          <sd-autocomplete-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'values'\"\r\n            [items]=\"childColumn.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[childColumn.field]\">\r\n          </sd-autocomplete-control>\r\n          <sd-date-picker-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type ==='date' || childColumn.type==='datetime' ||\r\n          childColumn.type==='time'\" [(model)]=\" filter[childColumn.field]\" type=\"date\">\r\n          </sd-date-picker-control>\r\n        </ng-template>\r\n      </div>\r\n    </ng-container>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <!-- <div class=\"mr-auto\">\r\n      <sd-button class=\"mr-1\" (action)=\"onClear()\" icon=\"clear\" [tooltip]=\"'Clear filter' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"key && !selectedCode && numberOfQuickFiltes < maxQuickFilters\" class=\"mr-1\" (action)=\"createQuickFilter()\" icon=\"add\" [tooltip]=\"'Create quick filter' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"key && selectedCode\" class=\"mr-1\" (action)=\"updateQuickFilter()\" icon=\"save\" [tooltip]=\"'Update quick filter' | sdTranslate\"></sd-button>\r\n    </div> -->\r\n    <sd-button class=\"mr-auto\" (action)=\"onClear()\" icon=\"clear\" [title]=\"'Clear filter' | sdTranslate\" size=\"sm\"></sd-button>\r\n    <sd-button (action)=\"onAccept()\" icon=\"done\" [title]=\"'Accept' | sdTranslate\" color=\"primary\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button  style=\"flex: 1; padding-right: 5px;\" (action)=\"onClear()\" icon=\"clear\"\r\n      [title]=\"'Clear filter' | sdTranslate\" width=\"100%\" size=\"sm\"></sd-button>\r\n    <sd-button  style=\"flex: 1; padding-left: 5px;\" (action)=\"onAccept()\" icon=\"done\" [title]=\"'Accept' | sdTranslate\"\r\n      color=\"primary\" width=\"100%\" size=\"sm\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>\r\n<sd-grid-popup-quick-filter-detail #popupQuickFilterDetail (accept)=\"onAcceptQuickFilter($event)\"></sd-grid-popup-quick-filter-detail>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", "@charset \"UTF-8\";.cdk-overlay-container{z-index:10000}html{scroll-behavior:smooth;font-family:sans-serif;line-height:1.15;-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:transparent}.c-fs14{font-size:14px}.c-fs15{font-size:15px}.c-fs16{font-size:16px}.c-fs21{font-size:21px}/*!\n * Bootstrap v4.5.0 (https://getbootstrap.com/)\n * Copyright 2011-2020 The Bootstrap Authors\n * Copyright 2011-2020 Twitter, Inc.\n * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)\n */:root{--blue:#007bff;--indigo:#6610f2;--purple:#6f42c1;--pink:#e83e8c;--red:#dc3545;--orange:#fd7e14;--yellow:#ffc107;--green:#28a745;--teal:#20c997;--cyan:#17a2b8;--white:#fff;--gray:#6c757d;--gray-dark:#343a40;--primary:#c82c37;--secondary:#919191;--success:#4caf50;--info:#00bcd4;--warning:#ff9800;--danger:#f44336;--light:#f8f9fa;--dark:#343a40;--breakpoint-xs:0;--breakpoint-sm:576px;--breakpoint-md:768px;--breakpoint-lg:992px;--breakpoint-xl:1200px;--font-family-sans-serif:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";--font-family-monospace:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace}*,::after,::before{box-sizing:border-box}article,aside,figcaption,figure,footer,header,hgroup,main,nav,section{display:block}body{margin:0;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-size:1rem;font-weight:400;line-height:1.5;color:#212529;text-align:left;background-color:#fff}[tabindex=\"-1\"]:focus:not(:focus-visible){outline:0!important}h1,h2,h3,h4,h5,h6{margin-top:0}dl,ol,p,ul{margin-top:0;margin-bottom:1rem}abbr[data-original-title],abbr[title]{text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;cursor:help;border-bottom:0;-webkit-text-decoration-skip-ink:none;text-decoration-skip-ink:none}address{margin-bottom:1rem;font-style:normal;line-height:inherit}ol ol,ol ul,ul ol,ul ul{margin-bottom:0}dt{font-weight:700}dd{margin-bottom:.5rem;margin-left:0}blockquote,figure{margin:0 0 1rem}b,strong{font-weight:bolder}sub,sup{position:relative;font-size:75%;line-height:0;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}a{color:#344468;text-decoration:none;background-color:transparent}a:hover{color:#c82c37;text-decoration:underline}a:not([href]),a:not([href]):hover{color:inherit;text-decoration:none}code,kbd,pre,samp{font-family:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace;font-size:1em}pre{margin-top:0;margin-bottom:1rem;overflow:auto;-ms-overflow-style:scrollbar}img{vertical-align:middle;border-style:none}svg{overflow:hidden;vertical-align:middle}table{border-collapse:collapse}caption{padding-top:.75rem;padding-bottom:.75rem;color:#6c757d;text-align:left;caption-side:bottom}th{text-align:inherit}label{display:inline-block;margin-bottom:.5rem}button{border-radius:0}button:focus{outline:dotted 1px;outline:-webkit-focus-ring-color auto 5px}button,input,optgroup,select,textarea{margin:0;font-family:inherit;font-size:inherit;line-height:inherit}button,input{overflow:visible}button,select{text-transform:none}[role=button],[type=button]:not(:disabled),[type=reset]:not(:disabled),[type=submit]:not(:disabled),button:not(:disabled){cursor:pointer}select{word-wrap:normal}[type=button],[type=reset],[type=submit],button{-webkit-appearance:button}[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner,button::-moz-focus-inner{padding:0;border-style:none}input[type=checkbox],input[type=radio]{box-sizing:border-box;padding:0}textarea{overflow:auto;resize:vertical}fieldset{min-width:0;padding:0;margin:0;border:0}legend{display:block;width:100%;max-width:100%;padding:0;margin-bottom:.5rem;font-size:1.5rem;line-height:inherit;color:inherit;white-space:normal}progress{vertical-align:baseline}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{outline-offset:-2px;-webkit-appearance:none}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{font:inherit;-webkit-appearance:button}output{display:inline-block}summary{display:list-item;cursor:pointer}template{display:none}[hidden]{display:none!important}.h1,.h2,.h3,.h4,.h5,.h6,h1,h2,h3,h4,h5,h6{margin-bottom:.5px;font-weight:500;line-height:1.2}.h1,h1{font-size:3rem}.h2,h2{font-size:2rem}.h3,h3{font-size:1.75rem}.h4,.h5,h4,h5{font-size:1.25rem}.h6,h6{font-size:1rem}.lead{font-size:1.25rem;font-weight:300}.display-1{font-size:6rem;font-weight:300;line-height:1.2}.display-2{font-size:5.5rem;font-weight:300;line-height:1.2}.display-3{font-size:4.5rem;font-weight:300;line-height:1.2}.display-4{font-size:3.5rem;font-weight:300;line-height:1.2}hr{box-sizing:content-box;height:0;overflow:visible;margin-top:1px;margin-bottom:1px;border:0;border-top:1px solid rgba(0,0,0,.1)}.small,small{font-size:80%;font-weight:400}.mark,mark{padding:.2em;background-color:#fcf8e3}.list-inline,.list-unstyled{padding-left:0;list-style:none}.list-inline-item{display:inline-block}.list-inline-item:not(:last-child){margin-right:.5rem}.initialism{font-size:90%;text-transform:uppercase}.blockquote{margin-bottom:1px;font-size:1.25rem}.blockquote-footer{display:block;font-size:80%;color:#6c757d}.blockquote-footer::before{content:\"\u2014\u00A0\"}.img-fluid{max-width:100%;height:auto}.img-thumbnail{padding:.25rem;background-color:#fff;border:1px solid #dee2e6;border-radius:8px;max-width:100%;height:auto}.figure{display:inline-block}.figure-img{margin-bottom:.5px;line-height:1}.figure-caption{font-size:90%;color:#6c757d}code{font-size:87.5%;color:#e83e8c;word-wrap:break-word}a>code{color:inherit}kbd{padding:.2rem .4rem;font-size:87.5%;color:#fff;background-color:#212529;border-radius:.2rem}kbd kbd{padding:0;font-size:100%;font-weight:700}pre{display:block;font-size:87.5%;color:#212529}pre code{font-size:inherit;color:inherit;word-break:normal}.pre-scrollable{max-height:340px;overflow-y:scroll}.container{width:100%;padding-right:16px;padding-left:16px;margin-right:auto;margin-left:auto}@media (min-width:576px){.container{max-width:540px}}@media (min-width:768px){.container{max-width:720px}}@media (min-width:992px){.container{max-width:960px}}@media (min-width:1200px){.container{max-width:1264px}}.container-fluid,.container-lg,.container-md,.container-sm,.container-xl{width:100%;padding-right:16px;padding-left:16px;margin-right:auto;margin-left:auto}@media (min-width:576px){.container,.container-sm{max-width:540px}}@media (min-width:768px){.container,.container-md,.container-sm{max-width:720px}}@media (min-width:992px){.container,.container-lg,.container-md,.container-sm{max-width:960px}}@media (min-width:1200px){.container,.container-lg,.container-md,.container-sm,.container-xl{max-width:1264px}}.row{display:flex;flex-wrap:wrap;margin-right:-16px;margin-left:-16px}.no-gutters{margin-right:0;margin-left:0}.no-gutters>.col,.no-gutters>[class*=col-]{padding-right:0;padding-left:0}.col,.col-1,.col-10,.col-11,.col-12,.col-2,.col-3,.col-4,.col-5,.col-6,.col-7,.col-8,.col-9,.col-auto,.col-lg,.col-lg-1,.col-lg-10,.col-lg-11,.col-lg-12,.col-lg-2,.col-lg-3,.col-lg-4,.col-lg-5,.col-lg-6,.col-lg-7,.col-lg-8,.col-lg-9,.col-lg-auto,.col-md,.col-md-1,.col-md-10,.col-md-11,.col-md-12,.col-md-2,.col-md-3,.col-md-4,.col-md-5,.col-md-6,.col-md-7,.col-md-8,.col-md-9,.col-md-auto,.col-sm,.col-sm-1,.col-sm-10,.col-sm-11,.col-sm-12,.col-sm-2,.col-sm-3,.col-sm-4,.col-sm-5,.col-sm-6,.col-sm-7,.col-sm-8,.col-sm-9,.col-sm-auto,.col-xl,.col-xl-1,.col-xl-10,.col-xl-11,.col-xl-12,.col-xl-2,.col-xl-3,.col-xl-4,.col-xl-5,.col-xl-6,.col-xl-7,.col-xl-8,.col-xl-9,.col-xl-auto{position:relative;width:100%;padding-right:16px;padding-left:16px}.col{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-1>*{flex:0 0 100%;max-width:100%}.row-cols-2>*{flex:0 0 50%;max-width:50%}.row-cols-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-4>*{flex:0 0 25%;max-width:25%}.row-cols-5>*{flex:0 0 20%;max-width:20%}.row-cols-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-auto{flex:0 0 auto;width:auto;max-width:100%}.col-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-3{flex:0 0 25%;max-width:25%}.col-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-6{flex:0 0 50%;max-width:50%}.col-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-9{flex:0 0 75%;max-width:75%}.col-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-12{flex:0 0 100%;max-width:100%}.order-first{order:-1}.order-last{order:13}.order-0{order:0}.order-1{order:1}.order-2{order:2}.order-3{order:3}.order-4{order:4}.order-5{order:5}.order-6{order:6}.order-7{order:7}.order-8{order:8}.order-9{order:9}.order-10{order:10}.order-11{order:11}.order-12{order:12}.offset-1{margin-left:8.3333333333%}.offset-2{margin-left:16.6666666667%}.offset-3{margin-left:25%}.offset-4{margin-left:33.3333333333%}.offset-5{margin-left:41.6666666667%}.offset-6{margin-left:50%}.offset-7{margin-left:58.3333333333%}.offset-8{margin-left:66.6666666667%}.offset-9{margin-left:75%}.offset-10{margin-left:83.3333333333%}.offset-11{margin-left:91.6666666667%}@media (min-width:576px){.col-sm{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-sm-1>*{flex:0 0 100%;max-width:100%}.row-cols-sm-2>*{flex:0 0 50%;max-width:50%}.row-cols-sm-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-sm-4>*{flex:0 0 25%;max-width:25%}.row-cols-sm-5>*{flex:0 0 20%;max-width:20%}.row-cols-sm-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-sm-auto{flex:0 0 auto;width:auto;max-width:100%}.col-sm-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-sm-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-sm-3{flex:0 0 25%;max-width:25%}.col-sm-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-sm-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-sm-6{flex:0 0 50%;max-width:50%}.col-sm-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-sm-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-sm-9{flex:0 0 75%;max-width:75%}.col-sm-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-sm-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-sm-12{flex:0 0 100%;max-width:100%}.order-sm-first{order:-1}.order-sm-last{order:13}.order-sm-0{order:0}.order-sm-1{order:1}.order-sm-2{order:2}.order-sm-3{order:3}.order-sm-4{order:4}.order-sm-5{order:5}.order-sm-6{order:6}.order-sm-7{order:7}.order-sm-8{order:8}.order-sm-9{order:9}.order-sm-10{order:10}.order-sm-11{order:11}.order-sm-12{order:12}.offset-sm-0{margin-left:0}.offset-sm-1{margin-left:8.3333333333%}.offset-sm-2{margin-left:16.6666666667%}.offset-sm-3{margin-left:25%}.offset-sm-4{margin-left:33.3333333333%}.offset-sm-5{margin-left:41.6666666667%}.offset-sm-6{margin-left:50%}.offset-sm-7{margin-left:58.3333333333%}.offset-sm-8{margin-left:66.6666666667%}.offset-sm-9{margin-left:75%}.offset-sm-10{margin-left:83.3333333333%}.offset-sm-11{margin-left:91.6666666667%}}@media (min-width:768px){.col-md{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-md-1>*{flex:0 0 100%;max-width:100%}.row-cols-md-2>*{flex:0 0 50%;max-width:50%}.row-cols-md-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-md-4>*{flex:0 0 25%;max-width:25%}.row-cols-md-5>*{flex:0 0 20%;max-width:20%}.row-cols-md-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-md-auto{flex:0 0 auto;width:auto;max-width:100%}.col-md-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-md-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-md-3{flex:0 0 25%;max-width:25%}.col-md-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-md-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-md-6{flex:0 0 50%;max-width:50%}.col-md-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-md-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-md-9{flex:0 0 75%;max-width:75%}.col-md-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-md-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-md-12{flex:0 0 100%;max-width:100%}.order-md-first{order:-1}.order-md-last{order:13}.order-md-0{order:0}.order-md-1{order:1}.order-md-2{order:2}.order-md-3{order:3}.order-md-4{order:4}.order-md-5{order:5}.order-md-6{order:6}.order-md-7{order:7}.order-md-8{order:8}.order-md-9{order:9}.order-md-10{order:10}.order-md-11{order:11}.order-md-12{order:12}.offset-md-0{margin-left:0}.offset-md-1{margin-left:8.3333333333%}.offset-md-2{margin-left:16.6666666667%}.offset-md-3{margin-left:25%}.offset-md-4{margin-left:33.3333333333%}.offset-md-5{margin-left:41.6666666667%}.offset-md-6{margin-left:50%}.offset-md-7{margin-left:58.3333333333%}.offset-md-8{margin-left:66.6666666667%}.offset-md-9{margin-left:75%}.offset-md-10{margin-left:83.3333333333%}.offset-md-11{margin-left:91.6666666667%}}@media (min-width:992px){.col-lg{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-lg-1>*{flex:0 0 100%;max-width:100%}.row-cols-lg-2>*{flex:0 0 50%;max-width:50%}.row-cols-lg-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-lg-4>*{flex:0 0 25%;max-width:25%}.row-cols-lg-5>*{flex:0 0 20%;max-width:20%}.row-cols-lg-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-lg-auto{flex:0 0 auto;width:auto;max-width:100%}.col-lg-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-lg-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-lg-3{flex:0 0 25%;max-width:25%}.col-lg-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-lg-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-lg-6{flex:0 0 50%;max-width:50%}.col-lg-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-lg-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-lg-9{flex:0 0 75%;max-width:75%}.col-lg-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-lg-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-lg-12{flex:0 0 100%;max-width:100%}.order-lg-first{order:-1}.order-lg-last{order:13}.order-lg-0{order:0}.order-lg-1{order:1}.order-lg-2{order:2}.order-lg-3{order:3}.order-lg-4{order:4}.order-lg-5{order:5}.order-lg-6{order:6}.order-lg-7{order:7}.order-lg-8{order:8}.order-lg-9{order:9}.order-lg-10{order:10}.order-lg-11{order:11}.order-lg-12{order:12}.offset-lg-0{margin-left:0}.offset-lg-1{margin-left:8.3333333333%}.offset-lg-2{margin-left:16.6666666667%}.offset-lg-3{margin-left:25%}.offset-lg-4{margin-left:33.3333333333%}.offset-lg-5{margin-left:41.6666666667%}.offset-lg-6{margin-left:50%}.offset-lg-7{margin-left:58.3333333333%}.offset-lg-8{margin-left:66.6666666667%}.offset-lg-9{margin-left:75%}.offset-lg-10{margin-left:83.3333333333%}.offset-lg-11{margin-left:91.6666666667%}}@media (min-width:1200px){.col-xl{flex-basis:0;flex-grow:1;min-width:0;max-width:100%}.row-cols-xl-1>*{flex:0 0 100%;max-width:100%}.row-cols-xl-2>*{flex:0 0 50%;max-width:50%}.row-cols-xl-3>*{flex:0 0 33.3333333333%;max-width:33.3333333333%}.row-cols-xl-4>*{flex:0 0 25%;max-width:25%}.row-cols-xl-5>*{flex:0 0 20%;max-width:20%}.row-cols-xl-6>*{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-xl-auto{flex:0 0 auto;width:auto;max-width:100%}.col-xl-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}.col-xl-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}.col-xl-3{flex:0 0 25%;max-width:25%}.col-xl-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}.col-xl-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}.col-xl-6{flex:0 0 50%;max-width:50%}.col-xl-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}.col-xl-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}.col-xl-9{flex:0 0 75%;max-width:75%}.col-xl-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}.col-xl-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}.col-xl-12{flex:0 0 100%;max-width:100%}.order-xl-first{order:-1}.order-xl-last{order:13}.order-xl-0{order:0}.order-xl-1{order:1}.order-xl-2{order:2}.order-xl-3{order:3}.order-xl-4{order:4}.order-xl-5{order:5}.order-xl-6{order:6}.order-xl-7{order:7}.order-xl-8{order:8}.order-xl-9{order:9}.order-xl-10{order:10}.order-xl-11{order:11}.order-xl-12{order:12}.offset-xl-0{margin-left:0}.offset-xl-1{margin-left:8.3333333333%}.offset-xl-2{margin-left:16.6666666667%}.offset-xl-3{margin-left:25%}.offset-xl-4{margin-left:33.3333333333%}.offset-xl-5{margin-left:41.6666666667%}.offset-xl-6{margin-left:50%}.offset-xl-7{margin-left:58.3333333333%}.offset-xl-8{margin-left:66.6666666667%}.offset-xl-9{margin-left:75%}.offset-xl-10{margin-left:83.3333333333%}.offset-xl-11{margin-left:91.6666666667%}}.table{width:100%;margin-bottom:1px;color:#212529}.table td,.table th{padding:.75rem;vertical-align:top;border-top:1px solid #f2f3f4}.table thead th{vertical-align:bottom;border-bottom:2px solid #f2f3f4}.table tbody+tbody{border-top:2px solid #f2f3f4}.table-sm td,.table-sm th{padding:.3rem}.table-bordered,.table-bordered td,.table-bordered th{border:1px solid #f2f3f4}.table-bordered thead td,.table-bordered thead th{border-bottom-width:2px}.table-borderless tbody+tbody,.table-borderless td,.table-borderless th,.table-borderless thead th{border:0}.table-striped tbody tr:nth-of-type(odd){background-color:rgba(0,0,0,.05)}.table-hover tbody tr:hover{color:#212529;background-color:rgba(0,0,0,.075)}.table-primary,.table-primary>td,.table-primary>th{background-color:#f0c4c7}.table-primary tbody+tbody,.table-primary td,.table-primary th,.table-primary thead th{border-color:#e29197}.table-hover .table-primary:hover,.table-hover .table-primary:hover>td,.table-hover .table-primary:hover>th{background-color:#ebb0b4}.table-secondary,.table-secondary>td,.table-secondary>th{background-color:#e0e0e0}.table-secondary tbody+tbody,.table-secondary td,.table-secondary th,.table-secondary thead th{border-color:#c6c6c6}.table-hover .table-secondary:hover,.table-hover .table-secondary:hover>td,.table-hover .table-secondary:hover>th{background-color:#d3d3d3}.table-success,.table-success>td,.table-success>th{background-color:#cde9ce}.table-success tbody+tbody,.table-success td,.table-success th,.table-success thead th{border-color:#a2d5a4}.table-hover .table-success:hover,.table-hover .table-success:hover>td,.table-hover .table-success:hover>th{background-color:#bbe1bd}.table-info,.table-info>td,.table-info>th{background-color:#b8ecf3}.table-info tbody+tbody,.table-info td,.table-info th,.table-info thead th{border-color:#7adce9}.table-hover .table-info:hover,.table-hover .table-info:hover>td,.table-hover .table-info:hover>th{background-color:#a2e6ef}.table-warning,.table-warning>td,.table-warning>th{background-color:#ffe2b8}.table-warning tbody+tbody,.table-warning td,.table-warning th,.table-warning thead th{border-color:#ffc97a}.table-hover .table-warning:hover,.table-hover .table-warning:hover>td,.table-hover .table-warning:hover>th{background-color:#ffd89f}.table-danger,.table-danger>td,.table-danger>th{background-color:#fccac7}.table-danger tbody+tbody,.table-danger td,.table-danger th,.table-danger thead th{border-color:#f99d96}.table-hover .table-danger:hover,.table-hover .table-danger:hover>td,.table-hover .table-danger:hover>th{background-color:#fbb3af}.table-light,.table-light>td,.table-light>th{background-color:#fdfdfe}.table-light tbody+tbody,.table-light td,.table-light th,.table-light thead th{border-color:#fbfcfc}.table-hover .table-light:hover,.table-hover .table-light:hover>td,.table-hover .table-light:hover>th{background-color:#ececf6}.table-dark,.table-dark>td,.table-dark>th{background-color:#c6c8ca}.table-dark tbody+tbody,.table-dark td,.table-dark th,.table-dark thead th{border-color:#95999c}.table-hover .table-dark:hover,.table-hover .table-dark:hover>td,.table-hover .table-dark:hover>th{background-color:#b9bbbe}.table-active,.table-active>td,.table-active>th,.table-hover .table-active:hover,.table-hover .table-active:hover>td,.table-hover .table-active:hover>th{background-color:rgba(0,0,0,.075)}.table .thead-dark th{color:#fff;background-color:#343a40;border-color:#454d55}.table .thead-light th{color:#495057;background-color:#e9ecef;border-color:#f2f3f4}.table-dark{color:#fff;background-color:#343a40}.table-dark td,.table-dark th,.table-dark thead th{border-color:#454d55}.table-dark.table-bordered{border:0}.table-dark.table-striped tbody tr:nth-of-type(odd){background-color:rgba(255,255,255,.05)}.table-dark.table-hover tbody tr:hover{color:#fff;background-color:rgba(255,255,255,.075)}@media (max-width:575.98px){.table-responsive-sm{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-sm>.table-bordered{border:0}}@media (max-width:767.98px){.table-responsive-md{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-md>.table-bordered{border:0}}@media (max-width:991.98px){.table-responsive-lg{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-lg>.table-bordered{border:0}}@media (max-width:1199.98px){.table-responsive-xl{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive-xl>.table-bordered{border:0}}.table-responsive{display:block;width:100%;overflow-x:auto;-webkit-overflow-scrolling:touch}.table-responsive>.table-bordered{border:0}.form-control{display:block;width:100%;height:56px;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;background-color:#fff;background-clip:padding-box;border:1px solid #e6e7e9;border-radius:8px;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.form-control{transition:none}}.form-control::-ms-expand{background-color:transparent;border:0}.form-control:-moz-focusring{color:transparent;text-shadow:0 0 0 #344468}.form-control:focus{color:#344468;background-color:#fff;border-color:rgba(47,107,255,.1);outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.form-control::-webkit-input-placeholder{color:#6c757d;opacity:1}.form-control::-moz-placeholder{color:#6c757d;opacity:1}.form-control::-ms-input-placeholder{color:#6c757d;opacity:1}.form-control::placeholder{color:#6c757d;opacity:1}.form-control:disabled,.form-control[readonly]{background-color:#e9ecef;opacity:1}input[type=date].form-control,input[type=datetime-local].form-control,input[type=month].form-control,input[type=time].form-control{-webkit-appearance:none;-moz-appearance:none;appearance:none}select.form-control:focus::-ms-value{color:#344468;background-color:#fff}.form-control-file,.form-control-range{display:block;width:100%}.col-form-label{padding-top:calc(.375rem + 1px);padding-bottom:calc(.375rem + 1px);margin-bottom:0;font-size:inherit;line-height:1.5}.col-form-label-lg{padding-top:calc(.5rem + 1px);padding-bottom:calc(.5rem + 1px);font-size:1.25rem;line-height:1.5}.col-form-label-sm{padding-top:calc(.25rem + 1px);padding-bottom:calc(.25rem + 1px);font-size:.875rem;line-height:1.5}.form-control-plaintext{display:block;width:100%;padding:.375rem 0;margin-bottom:0;font-size:1rem;line-height:1.5;color:#212529;background-color:transparent;border:solid transparent;border-width:1px 0}.form-control-plaintext.form-control-lg,.form-control-plaintext.form-control-sm{padding-right:0;padding-left:0}.form-control-sm{height:calc(1.5em + .5rem + 2px);padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.form-control-lg{height:calc(1.5em + 1rem + 2px);padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}select.form-control[multiple],select.form-control[size],textarea.form-control{height:auto}.form-group{margin-bottom:1rem}.form-text{display:block;margin-top:.25rem}.form-row{display:flex;flex-wrap:wrap;margin-right:-5px;margin-left:-5px}.form-row>.col,.form-row>[class*=col-]{padding-right:5px;padding-left:5px}.form-check{position:relative;display:block;padding-left:1.25rem}.form-check-input{position:absolute;margin-top:.3rem;margin-left:-1.25rem}.form-check-input:disabled~.form-check-label,.form-check-input[disabled]~.form-check-label{color:#6c757d}.form-check-label{margin-bottom:0}.form-check-inline{display:inline-flex;align-items:center;padding-left:0;margin-right:.75rem}.form-check-inline .form-check-input{position:static;margin-top:0;margin-right:.3125rem;margin-left:0}.valid-feedback{display:none;width:100%;margin-top:.25rem;font-size:80%;color:#4caf50}.valid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;line-height:1.5;color:#fff;background-color:rgba(76,175,80,.9);border-radius:8px}.is-valid~.valid-feedback,.is-valid~.valid-tooltip,.was-validated :valid~.valid-feedback,.was-validated :valid~.valid-tooltip{display:block}.form-control.is-valid,.was-validated .form-control:valid{border-color:#4caf50;padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%234caf50' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.form-control.is-valid:focus,.was-validated .form-control:valid:focus{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.was-validated textarea.form-control:valid,textarea.form-control.is-valid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.custom-select.is-valid,.was-validated .custom-select:valid{border-color:#4caf50;padding-right:calc(.75em + 2.3125rem);background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat,url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%234caf50' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e\") center right 1.75rem/calc(.75em + .375rem) calc(.75em + .375rem) no-repeat #fff}.custom-select.is-valid:focus,.was-validated .custom-select:valid:focus{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.form-check-input.is-valid~.form-check-label,.was-validated .form-check-input:valid~.form-check-label{color:#4caf50}.form-check-input.is-valid~.valid-feedback,.form-check-input.is-valid~.valid-tooltip,.was-validated .form-check-input:valid~.valid-feedback,.was-validated .form-check-input:valid~.valid-tooltip{display:block}.custom-control-input.is-valid~.custom-control-label,.was-validated .custom-control-input:valid~.custom-control-label{color:#4caf50}.custom-control-input.is-valid~.custom-control-label::before,.was-validated .custom-control-input:valid~.custom-control-label::before{border-color:#4caf50}.custom-control-input.is-valid:checked~.custom-control-label::before,.was-validated .custom-control-input:valid:checked~.custom-control-label::before{border-color:#6ec071;background-color:#6ec071}.custom-control-input.is-valid:focus~.custom-control-label::before,.was-validated .custom-control-input:valid:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.custom-control-input.is-valid:focus:not(:checked)~.custom-control-label::before,.was-validated .custom-control-input:valid:focus:not(:checked)~.custom-control-label::before{border-color:#4caf50}.custom-file-input.is-valid~.custom-file-label,.was-validated .custom-file-input:valid~.custom-file-label{border-color:#4caf50}.custom-file-input.is-valid:focus~.custom-file-label,.was-validated .custom-file-input:valid:focus~.custom-file-label{border-color:#4caf50;box-shadow:0 0 0 .2rem rgba(76,175,80,.25)}.invalid-feedback{display:none;width:100%;margin-top:.25rem;font-size:80%;color:#f44336}.invalid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;line-height:1.5;color:#fff;background-color:rgba(244,67,54,.9);border-radius:8px}.is-invalid~.invalid-feedback,.is-invalid~.invalid-tooltip,.was-validated :invalid~.invalid-feedback,.was-validated :invalid~.invalid-tooltip{display:block}.form-control.is-invalid,.was-validated .form-control:invalid{border-color:#f44336;padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none' stroke='%23f44336' viewBox='0 0 12 12'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23f44336' stroke='none'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.form-control.is-invalid:focus,.was-validated .form-control:invalid:focus{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.was-validated textarea.form-control:invalid,textarea.form-control.is-invalid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.custom-select.is-invalid,.was-validated .custom-select:invalid{border-color:#f44336;padding-right:calc(.75em + 2.3125rem);background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat,url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' fill='none' stroke='%23f44336' viewBox='0 0 12 12'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23f44336' stroke='none'/%3e%3c/svg%3e\") center right 1.75rem/calc(.75em + .375rem) calc(.75em + .375rem) no-repeat #fff}.custom-select.is-invalid:focus,.was-validated .custom-select:invalid:focus{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.form-check-input.is-invalid~.form-check-label,.was-validated .form-check-input:invalid~.form-check-label{color:#f44336}.form-check-input.is-invalid~.invalid-feedback,.form-check-input.is-invalid~.invalid-tooltip,.was-validated .form-check-input:invalid~.invalid-feedback,.was-validated .form-check-input:invalid~.invalid-tooltip{display:block}.custom-control-input.is-invalid~.custom-control-label,.was-validated .custom-control-input:invalid~.custom-control-label{color:#f44336}.custom-control-input.is-invalid~.custom-control-label::before,.was-validated .custom-control-input:invalid~.custom-control-label::before{border-color:#f44336}.custom-control-input.is-invalid:checked~.custom-control-label::before,.was-validated .custom-control-input:invalid:checked~.custom-control-label::before{border-color:#f77066;background-color:#f77066}.custom-control-input.is-invalid:focus~.custom-control-label::before,.was-validated .custom-control-input:invalid:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.custom-control-input.is-invalid:focus:not(:checked)~.custom-control-label::before,.was-validated .custom-control-input:invalid:focus:not(:checked)~.custom-control-label::before{border-color:#f44336}.custom-file-input.is-invalid~.custom-file-label,.was-validated .custom-file-input:invalid~.custom-file-label{border-color:#f44336}.custom-file-input.is-invalid:focus~.custom-file-label,.was-validated .custom-file-input:invalid:focus~.custom-file-label{border-color:#f44336;box-shadow:0 0 0 .2rem rgba(244,67,54,.25)}.form-inline{display:flex;flex-flow:row wrap;align-items:center}.form-inline .form-check{width:100%}@media (min-width:576px){.form-inline label{display:flex;align-items:center;justify-content:center;margin-bottom:0}.form-inline .form-group{display:flex;flex:0 0 auto;flex-flow:row wrap;align-items:center;margin-bottom:0}.form-inline .form-control{display:inline-block;width:auto;vertical-align:middle}.form-inline .form-control-plaintext{display:inline-block}.form-inline .custom-select,.form-inline .input-group{width:auto}.form-inline .form-check{display:flex;align-items:center;justify-content:center;width:auto;padding-left:0}.form-inline .form-check-input{position:relative;flex-shrink:0;margin-top:0;margin-right:.25rem;margin-left:0}.form-inline .custom-control{align-items:center;justify-content:center}.form-inline .custom-control-label{margin-bottom:0}}.btn{display:inline-block;font-weight:400;color:#212529;text-align:center;vertical-align:middle;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-color:transparent;border:1px solid transparent;padding:12px .75rem;font-size:1rem;line-height:1.4;border-radius:8px;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.btn{transition:none}}.btn:hover{color:#212529;text-decoration:none}.btn.focus,.btn:focus{outline:0!important;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.btn.disabled,.btn:disabled{opacity:.65}.btn:not(:disabled):not(.disabled){cursor:pointer}a.btn.disabled,fieldset:disabled a.btn{pointer-events:none}.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-primary:hover{color:#fff;background-color:#a9252e;border-color:#9e232c}.btn-primary.focus,.btn-primary:focus{color:#fff;background-color:#a9252e;border-color:#9e232c;box-shadow:0 0 0 .2rem rgba(208,76,85,.5)}.btn-primary.disabled,.btn-primary:disabled{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-primary:not(:disabled):not(.disabled).active,.btn-primary:not(:disabled):not(.disabled):active,.show>.btn-primary.dropdown-toggle{color:#fff;background-color:#9e232c;border-color:#942129}.btn-primary:not(:disabled):not(.disabled).active:focus,.btn-primary:not(:disabled):not(.disabled):active:focus,.show>.btn-primary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(208,76,85,.5)}.btn-secondary{color:#fff;background-color:#919191;border-color:#919191}.btn-secondary:hover{color:#fff;background-color:#7e7e7e;border-color:#787878}.btn-secondary.focus,.btn-secondary:focus{color:#fff;background-color:#7e7e7e;border-color:#787878;box-shadow:0 0 0 .2rem rgba(162,162,162,.5)}.btn-secondary.disabled,.btn-secondary:disabled{color:#fff;background-color:#919191;border-color:#919191}.btn-secondary:not(:disabled):not(.disabled).active,.btn-secondary:not(:disabled):not(.disabled):active,.show>.btn-secondary.dropdown-toggle{color:#fff;background-color:#787878;border-color:#717171}.btn-secondary:not(:disabled):not(.disabled).active:focus,.btn-secondary:not(:disabled):not(.disabled):active:focus,.show>.btn-secondary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(162,162,162,.5)}.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-success:hover{color:#fff;background-color:#409444;border-color:#3d8b40}.btn-success.focus,.btn-success:focus{color:#fff;background-color:#409444;border-color:#3d8b40;box-shadow:0 0 0 .2rem rgba(103,187,106,.5)}.btn-success.disabled,.btn-success:disabled{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-success:not(:disabled):not(.disabled).active,.btn-success:not(:disabled):not(.disabled):active,.show>.btn-success.dropdown-toggle{color:#fff;background-color:#3d8b40;border-color:#39833c}.btn-success:not(:disabled):not(.disabled).active:focus,.btn-success:not(:disabled):not(.disabled):active:focus,.show>.btn-success.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(103,187,106,.5)}.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-info:hover{color:#fff;background-color:#009aae;border-color:#008fa1}.btn-info.focus,.btn-info:focus{color:#fff;background-color:#009aae;border-color:#008fa1;box-shadow:0 0 0 .2rem rgba(38,198,218,.5)}.btn-info.disabled,.btn-info:disabled{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-info:not(:disabled):not(.disabled).active,.btn-info:not(:disabled):not(.disabled):active,.show>.btn-info.dropdown-toggle{color:#fff;background-color:#008fa1;border-color:#008394}.btn-info:not(:disabled):not(.disabled).active:focus,.btn-info:not(:disabled):not(.disabled):active:focus,.show>.btn-info.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(38,198,218,.5)}.btn-warning{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-warning:hover{color:#fff;background-color:#d98100;border-color:#cc7a00}.btn-warning.focus,.btn-warning:focus{color:#fff;background-color:#d98100;border-color:#cc7a00;box-shadow:0 0 0 .2rem rgba(222,135,6,.5)}.btn-warning.disabled,.btn-warning:disabled{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-warning:not(:disabled):not(.disabled).active,.btn-warning:not(:disabled):not(.disabled):active,.show>.btn-warning.dropdown-toggle{color:#fff;background-color:#cc7a00;border-color:#bf7200}.btn-warning:not(:disabled):not(.disabled).active:focus,.btn-warning:not(:disabled):not(.disabled):active:focus,.show>.btn-warning.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(222,135,6,.5)}.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336}.btn-danger:hover{color:#fff;background-color:#f22112;border-color:#ea1c0d}.btn-danger.focus,.btn-danger:focus{color:#fff;background-color:#f22112;border-color:#ea1c0d;box-shadow:0 0 0 .2rem rgba(246,95,84,.5)}.btn-danger.disabled,.btn-danger:disabled{color:#fff;background-color:#f44336;border-color:#f44336}.btn-danger:not(:disabled):not(.disabled).active,.btn-danger:not(:disabled):not(.disabled):active,.show>.btn-danger.dropdown-toggle{color:#fff;background-color:#ea1c0d;border-color:#de1b0c}.btn-danger:not(:disabled):not(.disabled).active:focus,.btn-danger:not(:disabled):not(.disabled):active:focus,.show>.btn-danger.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(246,95,84,.5)}.btn-light{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-light:hover{color:#212529;background-color:#e2e6ea;border-color:#dae0e5}.btn-light.focus,.btn-light:focus{color:#212529;background-color:#e2e6ea;border-color:#dae0e5;box-shadow:0 0 0 .2rem rgba(216,217,219,.5)}.btn-light.disabled,.btn-light:disabled{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-light:not(:disabled):not(.disabled).active,.btn-light:not(:disabled):not(.disabled):active,.show>.btn-light.dropdown-toggle{color:#212529;background-color:#dae0e5;border-color:#d3d9df}.btn-light:not(:disabled):not(.disabled).active:focus,.btn-light:not(:disabled):not(.disabled):active:focus,.show>.btn-light.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(216,217,219,.5)}.btn-dark{color:#fff;background-color:#343a40;border-color:#343a40}.btn-dark:hover{color:#fff;background-color:#23272b;border-color:#1d2124}.btn-dark.focus,.btn-dark:focus{color:#fff;background-color:#23272b;border-color:#1d2124;box-shadow:0 0 0 .2rem rgba(82,88,93,.5)}.btn-dark.disabled,.btn-dark:disabled{color:#fff;background-color:#343a40;border-color:#343a40}.btn-dark:not(:disabled):not(.disabled).active,.btn-dark:not(:disabled):not(.disabled):active,.show>.btn-dark.dropdown-toggle{color:#fff;background-color:#1d2124;border-color:#171a1d}.btn-dark:not(:disabled):not(.disabled).active:focus,.btn-dark:not(:disabled):not(.disabled):active:focus,.show>.btn-dark.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(82,88,93,.5)}.btn-outline-primary{color:#c82c37;border-color:#c82c37}.btn-outline-primary:hover{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-outline-primary.focus,.btn-outline-primary:focus{box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.btn-outline-primary.disabled,.btn-outline-primary:disabled{color:#c82c37;background-color:transparent}.btn-outline-primary:not(:disabled):not(.disabled).active,.btn-outline-primary:not(:disabled):not(.disabled):active,.show>.btn-outline-primary.dropdown-toggle{color:#fff;background-color:#c82c37;border-color:#c82c37}.btn-outline-primary:not(:disabled):not(.disabled).active:focus,.btn-outline-primary:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-primary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.btn-outline-secondary{color:#919191;border-color:#919191}.btn-outline-secondary:hover{color:#fff;background-color:#919191;border-color:#919191}.btn-outline-secondary.focus,.btn-outline-secondary:focus{box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.btn-outline-secondary.disabled,.btn-outline-secondary:disabled{color:#919191;background-color:transparent}.btn-outline-secondary:not(:disabled):not(.disabled).active,.btn-outline-secondary:not(:disabled):not(.disabled):active,.show>.btn-outline-secondary.dropdown-toggle{color:#fff;background-color:#919191;border-color:#919191}.btn-outline-secondary:not(:disabled):not(.disabled).active:focus,.btn-outline-secondary:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-secondary.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.btn-outline-success{color:#4caf50;border-color:#4caf50}.btn-outline-success:hover{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-outline-success.focus,.btn-outline-success:focus{box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.btn-outline-success.disabled,.btn-outline-success:disabled{color:#4caf50;background-color:transparent}.btn-outline-success:not(:disabled):not(.disabled).active,.btn-outline-success:not(:disabled):not(.disabled):active,.show>.btn-outline-success.dropdown-toggle{color:#fff;background-color:#4caf50;border-color:#4caf50}.btn-outline-success:not(:disabled):not(.disabled).active:focus,.btn-outline-success:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-success.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.btn-outline-info{color:#00bcd4;border-color:#00bcd4}.btn-outline-info:hover{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-outline-info.focus,.btn-outline-info:focus{box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.btn-outline-info.disabled,.btn-outline-info:disabled{color:#00bcd4;background-color:transparent}.btn-outline-info:not(:disabled):not(.disabled).active,.btn-outline-info:not(:disabled):not(.disabled):active,.show>.btn-outline-info.dropdown-toggle{color:#fff;background-color:#00bcd4;border-color:#00bcd4}.btn-outline-info:not(:disabled):not(.disabled).active:focus,.btn-outline-info:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-info.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.btn-outline-warning{color:#ff9800;border-color:#ff9800}.btn-outline-warning:hover{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-outline-warning.focus,.btn-outline-warning:focus{box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.btn-outline-warning.disabled,.btn-outline-warning:disabled{color:#ff9800;background-color:transparent}.btn-outline-warning:not(:disabled):not(.disabled).active,.btn-outline-warning:not(:disabled):not(.disabled):active,.show>.btn-outline-warning.dropdown-toggle{color:#212529;background-color:#ff9800;border-color:#ff9800}.btn-outline-warning:not(:disabled):not(.disabled).active:focus,.btn-outline-warning:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-warning.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.btn-outline-danger{color:#f44336;border-color:#f44336}.btn-outline-danger:hover{color:#fff;background-color:#f44336;border-color:#f44336}.btn-outline-danger.focus,.btn-outline-danger:focus{box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.btn-outline-danger.disabled,.btn-outline-danger:disabled{color:#f44336;background-color:transparent}.btn-outline-danger:not(:disabled):not(.disabled).active,.btn-outline-danger:not(:disabled):not(.disabled):active,.show>.btn-outline-danger.dropdown-toggle{color:#fff;background-color:#f44336;border-color:#f44336}.btn-outline-danger:not(:disabled):not(.disabled).active:focus,.btn-outline-danger:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-danger.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.btn-outline-light{color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light:hover{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light.focus,.btn-outline-light:focus{box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.btn-outline-light.disabled,.btn-outline-light:disabled{color:#f8f9fa;background-color:transparent}.btn-outline-light:not(:disabled):not(.disabled).active,.btn-outline-light:not(:disabled):not(.disabled):active,.show>.btn-outline-light.dropdown-toggle{color:#212529;background-color:#f8f9fa;border-color:#f8f9fa}.btn-outline-light:not(:disabled):not(.disabled).active:focus,.btn-outline-light:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-light.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.btn-outline-dark{color:#343a40;border-color:#343a40}.btn-outline-dark:hover{color:#fff;background-color:#343a40;border-color:#343a40}.btn-outline-dark.focus,.btn-outline-dark:focus{box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.btn-outline-dark.disabled,.btn-outline-dark:disabled{color:#343a40;background-color:transparent}.btn-outline-dark:not(:disabled):not(.disabled).active,.btn-outline-dark:not(:disabled):not(.disabled):active,.show>.btn-outline-dark.dropdown-toggle{color:#fff;background-color:#343a40;border-color:#343a40}.btn-outline-dark:not(:disabled):not(.disabled).active:focus,.btn-outline-dark:not(:disabled):not(.disabled):active:focus,.show>.btn-outline-dark.dropdown-toggle:focus{box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.btn-link{font-weight:400;color:#344468;text-decoration:none}.btn-link:hover{color:#c82c37;text-decoration:underline}.btn-link.focus,.btn-link:focus{text-decoration:underline}.btn-link.disabled,.btn-link:disabled{color:#6c757d;pointer-events:none}.btn-group-lg>.btn,.btn-lg{padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}.btn-group-sm>.btn,.btn-sm{padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.btn-block{display:block;width:100%}.btn-block+.btn-block{margin-top:.5rem}input[type=button].btn-block,input[type=reset].btn-block,input[type=submit].btn-block{width:100%}.fade{transition:opacity .15s linear}@media (prefers-reduced-motion:reduce){.fade{transition:none}}.fade:not(.show){opacity:0}.collapse:not(.show){display:none}.collapsing{position:relative;height:0;overflow:hidden;transition:height .35s}.dropdown,.dropleft,.dropright,.dropup{position:relative}.dropdown-toggle{white-space:nowrap}.dropdown-toggle::after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}.dropdown-toggle:empty::after{margin-left:0}.dropdown-menu{position:absolute;top:100%;left:0;z-index:1000;display:none;float:left;min-width:10rem;padding:.5rem 0;margin:.125rem 0 0;font-size:1rem;color:#212529;text-align:left;list-style:none;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.15);border-radius:8px}.dropdown-menu-left{right:auto;left:0}.dropdown-menu-right{right:0;left:auto}@media (min-width:576px){.dropdown-menu-sm-left{right:auto;left:0}.dropdown-menu-sm-right{right:0;left:auto}}@media (min-width:768px){.dropdown-menu-md-left{right:auto;left:0}.dropdown-menu-md-right{right:0;left:auto}}@media (min-width:992px){.dropdown-menu-lg-left{right:auto;left:0}.dropdown-menu-lg-right{right:0;left:auto}}@media (min-width:1200px){.dropdown-menu-xl-left{right:auto;left:0}.dropdown-menu-xl-right{right:0;left:auto}}.dropup .dropdown-menu{top:auto;bottom:100%;margin-top:0;margin-bottom:.125rem}.dropup .dropdown-toggle::after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}.dropup .dropdown-toggle:empty::after{margin-left:0}.dropright .dropdown-menu{top:0;right:auto;left:100%;margin-top:0;margin-left:.125rem}.dropright .dropdown-toggle::after{display:inline-block;margin-left:.255em;content:\"\";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid;vertical-align:0}.dropright .dropdown-toggle:empty::after{margin-left:0}.dropleft .dropdown-menu{top:0;right:100%;left:auto;margin-top:0;margin-right:.125rem}.dropleft .dropdown-toggle::after{margin-left:.255em;vertical-align:.255em;content:\"\";display:none}.dropleft .dropdown-toggle::before{display:inline-block;margin-right:.255em;content:\"\";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent;vertical-align:0}.dropleft .dropdown-toggle:empty::after{margin-left:0}.dropdown-menu[x-placement^=bottom],.dropdown-menu[x-placement^=left],.dropdown-menu[x-placement^=right],.dropdown-menu[x-placement^=top]{right:auto;bottom:auto}.dropdown-divider{height:0;margin:.5px 0;overflow:hidden;border-top:1px solid #e9ecef}.dropdown-item{display:block;width:100%;padding:.25rem 1.5rem;clear:both;font-weight:400;color:#212529;text-align:inherit;white-space:nowrap;background-color:transparent;border:0}.dropdown-item:focus,.dropdown-item:hover{color:#16181b;text-decoration:none;background-color:#f8f9fa}.dropdown-item.active,.dropdown-item:active{color:#fff;text-decoration:none;background-color:#c82c37}.dropdown-item.disabled,.dropdown-item:disabled{color:#6c757d;pointer-events:none;background-color:transparent}.dropdown-menu.show{display:block}.dropdown-header{display:block;padding:.5rem 1.5rem;margin-bottom:0;font-size:.875rem;color:#6c757d;white-space:nowrap}.dropdown-item-text{display:block;padding:.25rem 1.5rem;color:#212529}.btn-group,.btn-group-vertical{position:relative;display:inline-flex;vertical-align:middle}.btn-group-vertical>.btn,.btn-group>.btn{position:relative;flex:1 1 auto}.btn-group-vertical>.btn.active,.btn-group-vertical>.btn:active,.btn-group-vertical>.btn:focus,.btn-group-vertical>.btn:hover,.btn-group>.btn.active,.btn-group>.btn:active,.btn-group>.btn:focus,.btn-group>.btn:hover{z-index:1}.btn-toolbar{display:flex;flex-wrap:wrap;justify-content:flex-start}.btn-toolbar .input-group{width:auto}.btn-group>.btn-group:not(:first-child),.btn-group>.btn:not(:first-child){margin-left:-1px}.btn-group>.btn-group:not(:last-child)>.btn,.btn-group>.btn:not(:last-child):not(.dropdown-toggle){border-top-right-radius:0;border-bottom-right-radius:0}.btn-group>.btn-group:not(:first-child)>.btn,.btn-group>.btn:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.dropdown-toggle-split{padding-right:.5625rem;padding-left:.5625rem}.dropdown-toggle-split::after,.dropright .dropdown-toggle-split::after,.dropup .dropdown-toggle-split::after{margin-left:0}.dropleft .dropdown-toggle-split::before{margin-right:0}.btn-group-sm>.btn+.dropdown-toggle-split,.btn-sm+.dropdown-toggle-split{padding-right:.375rem;padding-left:.375rem}.btn-group-lg>.btn+.dropdown-toggle-split,.btn-lg+.dropdown-toggle-split{padding-right:.75rem;padding-left:.75rem}.btn-group-vertical{flex-direction:column;align-items:flex-start;justify-content:center}.btn-group-vertical>.btn,.btn-group-vertical>.btn-group{width:100%}.btn-group-vertical>.btn-group:not(:first-child),.btn-group-vertical>.btn:not(:first-child){margin-top:-1px}.btn-group-vertical>.btn-group:not(:last-child)>.btn,.btn-group-vertical>.btn:not(:last-child):not(.dropdown-toggle){border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn-group:not(:first-child)>.btn,.btn-group-vertical>.btn:not(:first-child){border-top-left-radius:0;border-top-right-radius:0}.btn-group-toggle>.btn,.btn-group-toggle>.btn-group>.btn{margin-bottom:0}.btn-group-toggle>.btn input[type=checkbox],.btn-group-toggle>.btn input[type=radio],.btn-group-toggle>.btn-group>.btn input[type=checkbox],.btn-group-toggle>.btn-group>.btn input[type=radio]{position:absolute;clip:rect(0,0,0,0);pointer-events:none}.input-group{position:relative;display:flex;flex-wrap:wrap;align-items:stretch;width:100%}.input-group>.custom-file,.input-group>.custom-select,.input-group>.form-control,.input-group>.form-control-plaintext{position:relative;flex:1 1 auto;width:1%;min-width:0;margin-bottom:0}.input-group>.custom-file+.custom-file,.input-group>.custom-file+.custom-select,.input-group>.custom-file+.form-control,.input-group>.custom-select+.custom-file,.input-group>.custom-select+.custom-select,.input-group>.custom-select+.form-control,.input-group>.form-control+.custom-file,.input-group>.form-control+.custom-select,.input-group>.form-control+.form-control,.input-group>.form-control-plaintext+.custom-file,.input-group>.form-control-plaintext+.custom-select,.input-group>.form-control-plaintext+.form-control{margin-left:-1px}.input-group>.custom-file .custom-file-input:focus~.custom-file-label,.input-group>.custom-select:focus,.input-group>.form-control:focus{z-index:3}.input-group>.custom-file .custom-file-input:focus{z-index:4}.input-group>.custom-select:not(:last-child),.input-group>.form-control:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.custom-select:not(:first-child),.input-group>.form-control:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.input-group>.custom-file{display:flex;align-items:center}.input-group>.custom-file:not(:last-child) .custom-file-label,.input-group>.custom-file:not(:last-child) .custom-file-label::after{border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.custom-file:not(:first-child) .custom-file-label{border-top-left-radius:0;border-bottom-left-radius:0}.input-group-append,.input-group-prepend{display:flex}.input-group-append .btn,.input-group-prepend .btn{position:relative;z-index:2}.input-group-append .btn:focus,.input-group-prepend .btn:focus{z-index:3}.input-group-append .btn+.btn,.input-group-append .btn+.input-group-text,.input-group-append .input-group-text+.btn,.input-group-append .input-group-text+.input-group-text,.input-group-prepend .btn+.btn,.input-group-prepend .btn+.input-group-text,.input-group-prepend .input-group-text+.btn,.input-group-prepend .input-group-text+.input-group-text{margin-left:-1px}.input-group-prepend{margin-right:-1px}.input-group-append{margin-left:-1px}.input-group-text{display:flex;align-items:center;padding:.375rem .75rem;margin-bottom:0;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;text-align:center;white-space:nowrap;background-color:#e9ecef;border:1px solid #e6e7e9;border-radius:8px}.input-group-text input[type=checkbox],.input-group-text input[type=radio]{margin-top:0}.input-group-lg>.custom-select,.input-group-lg>.form-control:not(textarea){height:calc(1.5em + 1rem + 2px)}.input-group-lg>.custom-select,.input-group-lg>.form-control,.input-group-lg>.input-group-append>.btn,.input-group-lg>.input-group-append>.input-group-text,.input-group-lg>.input-group-prepend>.btn,.input-group-lg>.input-group-prepend>.input-group-text{padding:.5rem 1rem;font-size:1.25rem;line-height:1.5;border-radius:.3rem}.input-group-sm>.custom-select,.input-group-sm>.form-control:not(textarea){height:calc(1.5em + .5rem + 2px)}.input-group-sm>.custom-select,.input-group-sm>.form-control,.input-group-sm>.input-group-append>.btn,.input-group-sm>.input-group-append>.input-group-text,.input-group-sm>.input-group-prepend>.btn,.input-group-sm>.input-group-prepend>.input-group-text{padding:.25rem .5rem;font-size:.875rem;line-height:1.5;border-radius:.2rem}.input-group-lg>.custom-select,.input-group-sm>.custom-select{padding-right:1.75rem}.input-group>.input-group-append:last-child>.btn:not(:last-child):not(.dropdown-toggle),.input-group>.input-group-append:last-child>.input-group-text:not(:last-child),.input-group>.input-group-append:not(:last-child)>.btn,.input-group>.input-group-append:not(:last-child)>.input-group-text,.input-group>.input-group-prepend>.btn,.input-group>.input-group-prepend>.input-group-text{border-top-right-radius:0;border-bottom-right-radius:0}.input-group>.input-group-append>.btn,.input-group>.input-group-append>.input-group-text,.input-group>.input-group-prepend:first-child>.btn:not(:first-child),.input-group>.input-group-prepend:first-child>.input-group-text:not(:first-child),.input-group>.input-group-prepend:not(:first-child)>.btn,.input-group>.input-group-prepend:not(:first-child)>.input-group-text{border-top-left-radius:0;border-bottom-left-radius:0}.custom-control{position:relative;display:block;min-height:1.5rem;padding-left:1.5rem}.custom-control-inline{display:inline-flex;margin-right:1rem}.custom-control-input{position:absolute;left:0;z-index:-1;width:1rem;height:1.25rem;opacity:0}.custom-control-input:checked~.custom-control-label::before{color:#fff;border-color:#c82c37;background-color:#c82c37}.custom-control-input:focus~.custom-control-label::before{box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-control-input:focus:not(:checked)~.custom-control-label::before{border-color:rgba(47,107,255,.1)}.custom-control-input:not(:disabled):active~.custom-control-label::before{color:#fff;background-color:#efb7bb;border-color:#efb7bb}.custom-control-input:disabled~.custom-control-label,.custom-control-input[disabled]~.custom-control-label{color:#6c757d}.custom-control-input:disabled~.custom-control-label::before,.custom-control-input[disabled]~.custom-control-label::before{background-color:#e9ecef}.custom-control-label{position:relative;margin-bottom:0;vertical-align:top}.custom-control-label::before{position:absolute;top:.25rem;left:-1.5rem;display:block;width:1rem;height:1rem;pointer-events:none;content:\"\";background-color:#fff;border:1px solid #adb5bd}.custom-control-label::after{position:absolute;top:.25rem;left:-1.5rem;display:block;width:1rem;height:1rem;content:\"\";background:50%/50% 50% no-repeat}.custom-checkbox .custom-control-label::before{border-radius:8px}.custom-checkbox .custom-control-input:checked~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath fill='%23fff' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26l2.974 2.99L8 2.193z'/%3e%3c/svg%3e\")}.custom-checkbox .custom-control-input:indeterminate~.custom-control-label::before{border-color:#c82c37;background-color:#c82c37}.custom-checkbox .custom-control-input:indeterminate~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='4' viewBox='0 0 4 4'%3e%3cpath stroke='%23fff' d='M0 2h4'/%3e%3c/svg%3e\")}.custom-checkbox .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-checkbox .custom-control-input:disabled:indeterminate~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-radio .custom-control-label::before{border-radius:50%}.custom-radio .custom-control-input:checked~.custom-control-label::after{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='12' height='12' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='%23fff'/%3e%3c/svg%3e\")}.custom-radio .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-switch{padding-left:2.25rem}.custom-switch .custom-control-label::before{left:-2.25rem;width:1.75rem;pointer-events:all;border-radius:.5rem}.custom-switch .custom-control-label::after{top:calc(.25rem + 2px);left:calc(-2.25rem + 2px);width:calc(1rem - 4px);height:calc(1rem - 4px);background-color:#adb5bd;border-radius:.5rem;transition:transform .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.collapsing,.custom-switch .custom-control-label::after{transition:none}}.custom-switch .custom-control-input:checked~.custom-control-label::after{background-color:#fff;transform:translateX(.75rem)}.custom-switch .custom-control-input:disabled:checked~.custom-control-label::before{background-color:rgba(200,44,55,.5)}.custom-select{display:inline-block;width:100%;height:56px;padding:.375rem 1.75rem .375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:#344468;vertical-align:middle;background:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='4' height='5' viewBox='0 0 4 5'%3e%3cpath fill='%23343a40' d='M2 0L0 2h4zm0 5L0 3h4z'/%3e%3c/svg%3e\") right .75rem center/8px 10px no-repeat #fff;border:1px solid #e6e7e9;border-radius:8px;-webkit-appearance:none;-moz-appearance:none;appearance:none}.custom-select:focus{border-color:rgba(47,107,255,.1);outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-select:focus::-ms-value{color:#344468;background-color:#fff}.custom-select[multiple],.custom-select[size]:not([size=\"1\"]){height:auto;padding-right:.75rem;background-image:none}.custom-select:disabled{color:#6c757d;background-color:#e9ecef}.custom-select::-ms-expand{display:none}.custom-select:-moz-focusring{color:transparent;text-shadow:0 0 0 #344468}.custom-select-sm{height:calc(1.5em + .5rem + 2px);padding-top:.25rem;padding-bottom:.25rem;padding-left:.5rem;font-size:.875rem}.custom-select-lg{height:calc(1.5em + 1rem + 2px);padding-top:.5rem;padding-bottom:.5rem;padding-left:1rem;font-size:1.25rem}.custom-file{position:relative;display:inline-block;width:100%;height:56px;margin-bottom:0}.custom-file-input{position:relative;z-index:2;width:100%;height:56px;margin:0;opacity:0}.custom-file-input:focus~.custom-file-label{border-color:rgba(47,107,255,.1);box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.custom-file-input:disabled~.custom-file-label,.custom-file-input[disabled]~.custom-file-label{background-color:#e9ecef}.custom-file-input:lang(en)~.custom-file-label::after{content:\"Browse\"}.custom-file-input~.custom-file-label[data-browse]::after{content:attr(data-browse)}.custom-file-label{position:absolute;top:0;right:0;left:0;z-index:1;height:56px;padding:.375rem .75rem;font-weight:400;line-height:1.5;color:#344468;background-color:#fff;border:1px solid #e6e7e9;border-radius:8px}.custom-file-label::after{position:absolute;top:0;right:0;bottom:0;z-index:3;display:block;height:calc(1.5em + .75rem);padding:.375rem .75rem;line-height:1.5;color:#344468;content:\"Browse\";background-color:#e9ecef;border-left:inherit;border-radius:0 8px 8px 0}.custom-range{width:100%;height:1.4rem;padding:0;background-color:transparent;-webkit-appearance:none;-moz-appearance:none;appearance:none}.custom-range:focus{outline:0}.custom-range:focus::-webkit-slider-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range:focus::-moz-range-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range:focus::-ms-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .2rem rgba(47,107,255,.1)}.custom-range::-moz-focus-outer{border:0}.custom-range::-webkit-slider-thumb{width:1rem;height:1rem;margin-top:-.25rem;background-color:#c82c37;border:0;border-radius:1rem;-webkit-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-webkit-appearance:none;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-webkit-slider-thumb{-webkit-transition:none;transition:none}}.custom-range::-webkit-slider-thumb:active{background-color:#efb7bb}.custom-range::-webkit-slider-runnable-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:#dee2e6;border-color:transparent;border-radius:1rem}.custom-range::-moz-range-thumb{width:1rem;height:1rem;background-color:#c82c37;border:0;border-radius:1rem;-moz-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;-moz-appearance:none;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-moz-range-thumb{-moz-transition:none;transition:none}}.custom-range::-moz-range-thumb:active{background-color:#efb7bb}.custom-range::-moz-range-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:#dee2e6;border-color:transparent;border-radius:1rem}.custom-range::-ms-thumb{width:1rem;height:1rem;margin-top:0;margin-right:.2rem;margin-left:.2rem;background-color:#c82c37;border:0;border-radius:1rem;-ms-transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out;appearance:none}@media (prefers-reduced-motion:reduce){.custom-range::-ms-thumb{-ms-transition:none;transition:none}}.custom-range::-ms-thumb:active{background-color:#efb7bb}.custom-range::-ms-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:transparent;border-color:transparent;border-width:.5rem}.custom-range::-ms-fill-lower{background-color:#dee2e6;border-radius:1rem}.custom-range::-ms-fill-upper{margin-right:15px;background-color:#dee2e6;border-radius:1rem}.custom-range:disabled::-webkit-slider-thumb{background-color:#adb5bd}.custom-range:disabled::-webkit-slider-runnable-track{cursor:default}.custom-range:disabled::-moz-range-thumb{background-color:#adb5bd}.custom-range:disabled::-moz-range-track{cursor:default}.custom-range:disabled::-ms-thumb{background-color:#adb5bd}.custom-control-label::before,.custom-file-label,.custom-select{transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.custom-control-label::before,.custom-file-label,.custom-select{transition:none}}.nav{display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}.nav-link{display:block;padding:.5rem 1rem}.nav-link:focus,.nav-link:hover{text-decoration:none}.nav-link.disabled{color:#6c757d;pointer-events:none;cursor:default}.nav-tabs{border-bottom:1px solid #dee2e6}.nav-tabs .nav-item{margin-bottom:-1px}.nav-tabs .nav-link{border:1px solid transparent;border-top-left-radius:8px;border-top-right-radius:8px}.nav-tabs .nav-link:focus,.nav-tabs .nav-link:hover{border-color:#e9ecef #e9ecef #dee2e6}.nav-tabs .nav-link.disabled{color:#6c757d;background-color:transparent;border-color:transparent}.nav-tabs .nav-item.show .nav-link,.nav-tabs .nav-link.active{color:#495057;background-color:#fff;border-color:#dee2e6 #dee2e6 #fff}.nav-tabs .dropdown-menu{margin-top:-1px;border-top-left-radius:0;border-top-right-radius:0}.nav-pills .nav-link{border-radius:8px}.nav-pills .nav-link.active,.nav-pills .show>.nav-link{color:#fff;background-color:#c82c37}.nav-fill .nav-item{flex:1 1 auto;text-align:center}.nav-justified .nav-item{flex-basis:0;flex-grow:1;text-align:center}.tab-content>.tab-pane{display:none}.tab-content>.active{display:block}.navbar{position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:.5px 1px}.navbar .container,.navbar .container-fluid,.navbar .container-lg,.navbar .container-md,.navbar .container-sm,.navbar .container-xl{display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between}.navbar-brand{display:inline-block;padding-top:.3125rem;padding-bottom:.3125rem;margin-right:1px;font-size:1.25rem;line-height:inherit;white-space:nowrap}.navbar-brand:focus,.navbar-brand:hover{text-decoration:none}.navbar-nav{display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}.navbar-nav .nav-link{padding-right:0;padding-left:0}.navbar-nav .dropdown-menu{position:static;float:none}.navbar-text{display:inline-block;padding-top:.5rem;padding-bottom:.5rem}.navbar-collapse{flex-basis:100%;flex-grow:1;align-items:center}.navbar-toggler{padding:.25rem .75rem;font-size:1.25rem;line-height:1;background-color:transparent;border:1px solid transparent;border-radius:8px}.navbar-toggler:focus,.navbar-toggler:hover{text-decoration:none}.navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;content:\"\";background:center center/100% 100% no-repeat}@media (max-width:575.98px){.navbar-expand-sm>.container,.navbar-expand-sm>.container-fluid,.navbar-expand-sm>.container-lg,.navbar-expand-sm>.container-md,.navbar-expand-sm>.container-sm,.navbar-expand-sm>.container-xl{padding-right:0;padding-left:0}}@media (min-width:576px){.navbar-expand-sm{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-sm .navbar-nav{flex-direction:row}.navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-sm .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-sm>.container,.navbar-expand-sm>.container-fluid,.navbar-expand-sm>.container-lg,.navbar-expand-sm>.container-md,.navbar-expand-sm>.container-sm,.navbar-expand-sm>.container-xl{flex-wrap:nowrap}.navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-sm .navbar-toggler{display:none}}@media (max-width:767.98px){.navbar-expand-md>.container,.navbar-expand-md>.container-fluid,.navbar-expand-md>.container-lg,.navbar-expand-md>.container-md,.navbar-expand-md>.container-sm,.navbar-expand-md>.container-xl{padding-right:0;padding-left:0}}@media (min-width:768px){.navbar-expand-md{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-md .navbar-nav{flex-direction:row}.navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-md .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-md>.container,.navbar-expand-md>.container-fluid,.navbar-expand-md>.container-lg,.navbar-expand-md>.container-md,.navbar-expand-md>.container-sm,.navbar-expand-md>.container-xl{flex-wrap:nowrap}.navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-md .navbar-toggler{display:none}}@media (max-width:991.98px){.navbar-expand-lg>.container,.navbar-expand-lg>.container-fluid,.navbar-expand-lg>.container-lg,.navbar-expand-lg>.container-md,.navbar-expand-lg>.container-sm,.navbar-expand-lg>.container-xl{padding-right:0;padding-left:0}}@media (min-width:992px){.navbar-expand-lg{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-lg .navbar-nav{flex-direction:row}.navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-lg .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-lg>.container,.navbar-expand-lg>.container-fluid,.navbar-expand-lg>.container-lg,.navbar-expand-lg>.container-md,.navbar-expand-lg>.container-sm,.navbar-expand-lg>.container-xl{flex-wrap:nowrap}.navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-lg .navbar-toggler{display:none}}@media (max-width:1199.98px){.navbar-expand-xl>.container,.navbar-expand-xl>.container-fluid,.navbar-expand-xl>.container-lg,.navbar-expand-xl>.container-md,.navbar-expand-xl>.container-sm,.navbar-expand-xl>.container-xl{padding-right:0;padding-left:0}}@media (min-width:1200px){.navbar-expand-xl{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand-xl .navbar-nav{flex-direction:row}.navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}.navbar-expand-xl .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand-xl>.container,.navbar-expand-xl>.container-fluid,.navbar-expand-xl>.container-lg,.navbar-expand-xl>.container-md,.navbar-expand-xl>.container-sm,.navbar-expand-xl>.container-xl{flex-wrap:nowrap}.navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand-xl .navbar-toggler{display:none}}.navbar-expand{flex-flow:row nowrap;justify-content:flex-start}.navbar-expand .navbar-nav{flex-direction:row}.navbar-expand .navbar-nav .dropdown-menu{position:absolute}.navbar-expand .navbar-nav .nav-link{padding-right:.5rem;padding-left:.5rem}.navbar-expand>.container,.navbar-expand>.container-fluid,.navbar-expand>.container-lg,.navbar-expand>.container-md,.navbar-expand>.container-sm,.navbar-expand>.container-xl{padding-right:0;padding-left:0;flex-wrap:nowrap}.navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}.navbar-expand .navbar-toggler{display:none}.navbar-light .navbar-brand,.navbar-light .navbar-brand:focus,.navbar-light .navbar-brand:hover{color:rgba(0,0,0,.9)}.navbar-light .navbar-nav .nav-link{color:rgba(0,0,0,.5)}.navbar-light .navbar-nav .nav-link:focus,.navbar-light .navbar-nav .nav-link:hover{color:rgba(0,0,0,.7)}.navbar-light .navbar-nav .nav-link.disabled{color:rgba(0,0,0,.3)}.navbar-light .navbar-nav .active>.nav-link,.navbar-light .navbar-nav .nav-link.active,.navbar-light .navbar-nav .nav-link.show,.navbar-light .navbar-nav .show>.nav-link{color:rgba(0,0,0,.9)}.navbar-light .navbar-toggler{color:rgba(0,0,0,.5);border-color:rgba(0,0,0,.1)}.navbar-light .navbar-toggler-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='30' height='30' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%280, 0, 0, 0.5%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.navbar-light .navbar-text{color:rgba(0,0,0,.5)}.navbar-light .navbar-text a,.navbar-light .navbar-text a:focus,.navbar-light .navbar-text a:hover{color:rgba(0,0,0,.9)}.navbar-dark .navbar-brand,.navbar-dark .navbar-brand:focus,.navbar-dark .navbar-brand:hover{color:#fff}.navbar-dark .navbar-nav .nav-link{color:rgba(255,255,255,.5)}.navbar-dark .navbar-nav .nav-link:focus,.navbar-dark .navbar-nav .nav-link:hover{color:rgba(255,255,255,.75)}.navbar-dark .navbar-nav .nav-link.disabled{color:rgba(255,255,255,.25)}.navbar-dark .navbar-nav .active>.nav-link,.navbar-dark .navbar-nav .nav-link.active,.navbar-dark .navbar-nav .nav-link.show,.navbar-dark .navbar-nav .show>.nav-link{color:#fff}.navbar-dark .navbar-toggler{color:rgba(255,255,255,.5);border-color:rgba(255,255,255,.1)}.navbar-dark .navbar-toggler-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='30' height='30' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.5%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.navbar-dark .navbar-text{color:rgba(255,255,255,.5)}.navbar-dark .navbar-text a,.navbar-dark .navbar-text a:focus,.navbar-dark .navbar-text a:hover{color:#fff}.card{position:relative;display:flex;flex-direction:column;min-width:0;word-wrap:break-word;background-color:#fff;background-clip:border-box;border:1px solid rgba(0,0,0,.125);border-radius:8px}.card>hr{margin-right:0;margin-left:0}.card>.list-group{border-top:inherit;border-bottom:inherit}.card>.list-group:first-child{border-top-width:0;border-top-left-radius:7px;border-top-right-radius:7px}.card>.list-group:last-child{border-bottom-width:0;border-bottom-right-radius:7px;border-bottom-left-radius:7px}.card-body{flex:1 1 auto;min-height:1px;padding:1.25rem}.card-title{margin-bottom:.75rem}.card-subtitle{margin-top:-.375rem;margin-bottom:0}.card-text:last-child{margin-bottom:0}.card-link:hover{text-decoration:none}.card-link+.card-link{margin-left:1.25rem}.card-header{padding:.75rem 1.25rem;margin-bottom:0;background-color:rgba(0,0,0,.03);border-bottom:1px solid rgba(0,0,0,.125)}.card-header:first-child{border-radius:7px 7px 0 0}.card-header+.list-group .list-group-item:first-child{border-top:0}.card-footer{padding:.75rem 1.25rem;background-color:rgba(0,0,0,.03);border-top:1px solid rgba(0,0,0,.125)}.card-footer:last-child{border-radius:0 0 7px 7px}.card-header-tabs{margin-right:-.625rem;margin-bottom:-.75rem;margin-left:-.625rem;border-bottom:0}.card-header-pills{margin-right:-.625rem;margin-left:-.625rem}.card-img-overlay{position:absolute;top:0;right:0;bottom:0;left:0;padding:1.25rem}.card-img,.card-img-bottom,.card-img-top{flex-shrink:0;width:100%}.card-img,.card-img-top{border-top-left-radius:7px;border-top-right-radius:7px}.card-img,.card-img-bottom{border-bottom-right-radius:7px;border-bottom-left-radius:7px}.card-deck .card{margin-bottom:16px}@media (min-width:576px){.card-deck{display:flex;flex-flow:row wrap;margin-right:-16px;margin-left:-16px}.card-deck .card{flex:1 0 0%;margin-right:16px;margin-bottom:0;margin-left:16px}}.card-group>.card{margin-bottom:16px}@media (min-width:576px){.card-group{display:flex;flex-flow:row wrap}.card-group>.card{flex:1 0 0%;margin-bottom:0}.card-group>.card+.card{margin-left:0;border-left:0}.card-group>.card:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.card-group>.card:not(:last-child) .card-header,.card-group>.card:not(:last-child) .card-img-top{border-top-right-radius:0}.card-group>.card:not(:last-child) .card-footer,.card-group>.card:not(:last-child) .card-img-bottom{border-bottom-right-radius:0}.card-group>.card:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.card-group>.card:not(:first-child) .card-header,.card-group>.card:not(:first-child) .card-img-top{border-top-left-radius:0}.card-group>.card:not(:first-child) .card-footer,.card-group>.card:not(:first-child) .card-img-bottom{border-bottom-left-radius:0}.card-columns{-moz-column-count:3;column-count:3;-moz-column-gap:1.25rem;column-gap:1.25rem;orphans:1;widows:1}.card-columns .card{display:inline-block;width:100%}}.card-columns .card{margin-bottom:.75rem}.accordion>.card{overflow:hidden}.accordion>.card:not(:last-of-type){border-bottom:0;border-bottom-right-radius:0;border-bottom-left-radius:0}.accordion>.card:not(:first-of-type){border-top-left-radius:0;border-top-right-radius:0}.accordion>.card>.card-header{border-radius:0;margin-bottom:-1px}.breadcrumb{display:flex;flex-wrap:wrap;padding:.75rem 1rem;margin-bottom:1rem;list-style:none;background-color:#e9ecef;border-radius:8px}.breadcrumb-item{display:flex}.breadcrumb-item+.breadcrumb-item{padding-left:.5rem}.breadcrumb-item+.breadcrumb-item::before{display:inline-block;padding-right:.5rem;color:#6c757d;content:\"/\"}.breadcrumb-item+.breadcrumb-item:hover::before{text-decoration:none}.breadcrumb-item.active{color:#6c757d}.pagination{display:flex;padding-left:0;list-style:none;border-radius:8px}.page-link{position:relative;display:block;padding:.5rem .75rem;margin-left:-1px;line-height:1.25;color:#344468;background-color:#fff;border:1px solid #dee2e6}.page-link:hover{z-index:2;color:#c82c37;text-decoration:none;background-color:#e9ecef;border-color:#dee2e6}.page-link:focus{z-index:3;outline:0;box-shadow:0 0 0 .2rem rgba(47,107,255,.1)}.page-item:first-child .page-link{margin-left:0;border-top-left-radius:8px;border-bottom-left-radius:8px}.page-item:last-child .page-link{border-top-right-radius:8px;border-bottom-right-radius:8px}.page-item.active .page-link{z-index:3;color:#fff;background-color:#c82c37;border-color:#c82c37}.page-item.disabled .page-link{color:#6c757d;pointer-events:none;cursor:auto;background-color:#fff;border-color:#dee2e6}.pagination-lg .page-link{padding:.75rem 1.5rem;font-size:1.25rem;line-height:1.5}.pagination-lg .page-item:first-child .page-link{border-top-left-radius:.3rem;border-bottom-left-radius:.3rem}.pagination-lg .page-item:last-child .page-link{border-top-right-radius:.3rem;border-bottom-right-radius:.3rem}.pagination-sm .page-link{padding:.25rem .5rem;font-size:.875rem;line-height:1.5}.pagination-sm .page-item:first-child .page-link{border-top-left-radius:.2rem;border-bottom-left-radius:.2rem}.pagination-sm .page-item:last-child .page-link{border-top-right-radius:.2rem;border-bottom-right-radius:.2rem}.badge{display:inline-block;padding:.25em .4em;font-size:75%;font-weight:700;line-height:1;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:8px;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion:reduce){.badge{transition:none}}a.badge:focus,a.badge:hover{text-decoration:none}.badge:empty{display:none}.btn .badge{position:relative;top:-1px}.badge-pill{padding-right:.6em;padding-left:.6em;border-radius:10rem}.badge-primary{color:#fff;background-color:#c82c37}a.badge-primary:focus,a.badge-primary:hover{color:#fff;background-color:#9e232c}a.badge-primary.focus,a.badge-primary:focus{outline:0;box-shadow:0 0 0 .2rem rgba(200,44,55,.5)}.badge-secondary{color:#fff;background-color:#919191}a.badge-secondary:focus,a.badge-secondary:hover{color:#fff;background-color:#787878}a.badge-secondary.focus,a.badge-secondary:focus{outline:0;box-shadow:0 0 0 .2rem rgba(145,145,145,.5)}.badge-success{color:#fff;background-color:#4caf50}a.badge-success:focus,a.badge-success:hover{color:#fff;background-color:#3d8b40}a.badge-success.focus,a.badge-success:focus{outline:0;box-shadow:0 0 0 .2rem rgba(76,175,80,.5)}.badge-info{color:#fff;background-color:#00bcd4}a.badge-info:focus,a.badge-info:hover{color:#fff;background-color:#008fa1}a.badge-info.focus,a.badge-info:focus{outline:0;box-shadow:0 0 0 .2rem rgba(0,188,212,.5)}.badge-warning{color:#212529;background-color:#ff9800}a.badge-warning:focus,a.badge-warning:hover{color:#212529;background-color:#cc7a00}a.badge-warning.focus,a.badge-warning:focus{outline:0;box-shadow:0 0 0 .2rem rgba(255,152,0,.5)}.badge-danger{color:#fff;background-color:#f44336}a.badge-danger:focus,a.badge-danger:hover{color:#fff;background-color:#ea1c0d}a.badge-danger.focus,a.badge-danger:focus{outline:0;box-shadow:0 0 0 .2rem rgba(244,67,54,.5)}.badge-light{color:#212529;background-color:#f8f9fa}a.badge-light:focus,a.badge-light:hover{color:#212529;background-color:#dae0e5}a.badge-light.focus,a.badge-light:focus{outline:0;box-shadow:0 0 0 .2rem rgba(248,249,250,.5)}.badge-dark{color:#fff;background-color:#343a40}a.badge-dark:focus,a.badge-dark:hover{color:#fff;background-color:#1d2124}a.badge-dark.focus,a.badge-dark:focus{outline:0;box-shadow:0 0 0 .2rem rgba(52,58,64,.5)}.jumbotron{padding:2rem 1rem;margin-bottom:2rem;background-color:#e9ecef;border-radius:.3rem}@media (min-width:576px){.jumbotron{padding:4rem 2rem}}.jumbotron-fluid{padding-right:0;padding-left:0;border-radius:0}.alert{position:relative;padding:.75rem 1.25rem;margin-bottom:1rem;border:1px solid transparent;border-radius:8px}.alert-heading{color:inherit}.alert-link{font-weight:700}.alert-dismissible{padding-right:4rem}.alert-dismissible .close{position:absolute;top:0;right:0;padding:.75rem 1.25rem;color:inherit}.alert-primary{color:#68171d;background-color:#f4d5d7;border-color:#f0c4c7}.alert-primary hr{border-top-color:#ebb0b4}.alert-primary .alert-link{color:#3e0e11}.alert-secondary{color:#4b4b4b;background-color:#e9e9e9;border-color:#e0e0e0}.alert-secondary hr{border-top-color:#d3d3d3}.alert-secondary .alert-link{color:#323232}.alert-success{color:#285b2a;background-color:#dbefdc;border-color:#cde9ce}.alert-success hr{border-top-color:#bbe1bd}.alert-success .alert-link{color:#18381a}.alert-info{color:#00626e;background-color:#ccf2f6;border-color:#b8ecf3}.alert-info hr{border-top-color:#a2e6ef}.alert-info .alert-link{color:#00353b}.alert-warning{color:#854f00;background-color:#ffeacc;border-color:#ffe2b8}.alert-warning hr{border-top-color:#ffd89f}.alert-warning .alert-link{color:#523100}.alert-danger{color:#7f231c;background-color:#fdd9d7;border-color:#fccac7}.alert-danger hr{border-top-color:#fbb3af}.alert-danger .alert-link{color:#551713}.alert-light{color:#818182;background-color:#fefefe;border-color:#fdfdfe}.alert-light hr{border-top-color:#ececf6}.alert-light .alert-link{color:#686868}.alert-dark{color:#1b1e21;background-color:#d6d8d9;border-color:#c6c8ca}.alert-dark hr{border-top-color:#b9bbbe}.alert-dark .alert-link{color:#040505}@-webkit-keyframes progress-bar-stripes{from{background-position:1rem 0}to{background-position:0 0}}@keyframes progress-bar-stripes{from{background-position:1rem 0}to{background-position:0 0}}.progress{display:flex;height:1rem;overflow:hidden;line-height:0;font-size:.75rem;background-color:#e9ecef;border-radius:8px}.progress-bar{display:flex;flex-direction:column;justify-content:center;overflow:hidden;color:#fff;text-align:center;white-space:nowrap;background-color:#c82c37;transition:width .6s}.progress-bar-striped{background-image:linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);background-size:1rem 1rem}.progress-bar-animated{-webkit-animation:1s linear infinite progress-bar-stripes;animation:1s linear infinite progress-bar-stripes}.media{display:flex;align-items:flex-start}.media-body{flex:1}.list-group{display:flex;flex-direction:column;padding-left:0;margin-bottom:0;border-radius:8px}.list-group-item-action{width:100%;color:#495057;text-align:inherit}.list-group-item-action:focus,.list-group-item-action:hover{z-index:1;color:#495057;text-decoration:none;background-color:#f8f9fa}.list-group-item-action:active{color:#212529;background-color:#e9ecef}.list-group-item{position:relative;display:block;padding:.75rem 1.25rem;background-color:#fff;border:1px solid rgba(0,0,0,.125)}.list-group-item:first-child{border-top-left-radius:inherit;border-top-right-radius:inherit}.list-group-item:last-child{border-bottom-right-radius:inherit;border-bottom-left-radius:inherit}.list-group-item.disabled,.list-group-item:disabled{color:#6c757d;pointer-events:none;background-color:#fff}.list-group-item.active{z-index:2;color:#fff;background-color:#c82c37;border-color:#c82c37}.list-group-item+.list-group-item{border-top-width:0}.list-group-item+.list-group-item.active{margin-top:-1px;border-top-width:1px}.list-group-horizontal{flex-direction:row}.list-group-horizontal>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal>.list-group-item.active{margin-top:0}.list-group-horizontal>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}@media (min-width:576px){.list-group-horizontal-sm{flex-direction:row}.list-group-horizontal-sm>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-sm>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-sm>.list-group-item.active{margin-top:0}.list-group-horizontal-sm>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-sm>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:768px){.list-group-horizontal-md{flex-direction:row}.list-group-horizontal-md>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-md>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-md>.list-group-item.active{margin-top:0}.list-group-horizontal-md>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-md>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:992px){.list-group-horizontal-lg{flex-direction:row}.list-group-horizontal-lg>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-lg>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-lg>.list-group-item.active{margin-top:0}.list-group-horizontal-lg>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-lg>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}@media (min-width:1200px){.list-group-horizontal-xl{flex-direction:row}.list-group-horizontal-xl>.list-group-item:first-child{border-bottom-left-radius:8px;border-top-right-radius:0}.list-group-horizontal-xl>.list-group-item:last-child{border-top-right-radius:8px;border-bottom-left-radius:0}.list-group-horizontal-xl>.list-group-item.active{margin-top:0}.list-group-horizontal-xl>.list-group-item+.list-group-item{border-top-width:1px;border-left-width:0}.list-group-horizontal-xl>.list-group-item+.list-group-item.active{margin-left:-1px;border-left-width:1px}}.list-group-flush{border-radius:0}.list-group-flush>.list-group-item{border-width:0 0 1px}.list-group-flush>.list-group-item:last-child{border-bottom-width:0}.list-group-item-primary{color:#68171d;background-color:#f0c4c7}.list-group-item-primary.list-group-item-action:focus,.list-group-item-primary.list-group-item-action:hover{color:#68171d;background-color:#ebb0b4}.list-group-item-primary.list-group-item-action.active{color:#fff;background-color:#68171d;border-color:#68171d}.list-group-item-secondary{color:#4b4b4b;background-color:#e0e0e0}.list-group-item-secondary.list-group-item-action:focus,.list-group-item-secondary.list-group-item-action:hover{color:#4b4b4b;background-color:#d3d3d3}.list-group-item-secondary.list-group-item-action.active{color:#fff;background-color:#4b4b4b;border-color:#4b4b4b}.list-group-item-success{color:#285b2a;background-color:#cde9ce}.list-group-item-success.list-group-item-action:focus,.list-group-item-success.list-group-item-action:hover{color:#285b2a;background-color:#bbe1bd}.list-group-item-success.list-group-item-action.active{color:#fff;background-color:#285b2a;border-color:#285b2a}.list-group-item-info{color:#00626e;background-color:#b8ecf3}.list-group-item-info.list-group-item-action:focus,.list-group-item-info.list-group-item-action:hover{color:#00626e;background-color:#a2e6ef}.list-group-item-info.list-group-item-action.active{color:#fff;background-color:#00626e;border-color:#00626e}.list-group-item-warning{color:#854f00;background-color:#ffe2b8}.list-group-item-warning.list-group-item-action:focus,.list-group-item-warning.list-group-item-action:hover{color:#854f00;background-color:#ffd89f}.list-group-item-warning.list-group-item-action.active{color:#fff;background-color:#854f00;border-color:#854f00}.list-group-item-danger{color:#7f231c;background-color:#fccac7}.list-group-item-danger.list-group-item-action:focus,.list-group-item-danger.list-group-item-action:hover{color:#7f231c;background-color:#fbb3af}.list-group-item-danger.list-group-item-action.active{color:#fff;background-color:#7f231c;border-color:#7f231c}.list-group-item-light{color:#818182;background-color:#fdfdfe}.list-group-item-light.list-group-item-action:focus,.list-group-item-light.list-group-item-action:hover{color:#818182;background-color:#ececf6}.list-group-item-light.list-group-item-action.active{color:#fff;background-color:#818182;border-color:#818182}.list-group-item-dark{color:#1b1e21;background-color:#c6c8ca}.list-group-item-dark.list-group-item-action:focus,.list-group-item-dark.list-group-item-action:hover{color:#1b1e21;background-color:#b9bbbe}.list-group-item-dark.list-group-item-action.active{color:#fff;background-color:#1b1e21;border-color:#1b1e21}.close{float:right;font-size:1.5rem;font-weight:700;line-height:1;color:#000;text-shadow:0 1px 0 #fff;opacity:.5}.close:hover{color:#000;text-decoration:none}.close:not(:disabled):not(.disabled):focus,.close:not(:disabled):not(.disabled):hover{opacity:.75}button.close{padding:0;background-color:transparent;border:0}a.close.disabled{pointer-events:none}.toast{max-width:350px;overflow:hidden;font-size:.875rem;background-color:rgba(255,255,255,.85);background-clip:padding-box;border:1px solid rgba(0,0,0,.1);box-shadow:0 .25rem .75rem rgba(0,0,0,.1);-webkit-backdrop-filter:blur(10px);backdrop-filter:blur(10px);opacity:0;border-radius:.25rem}.toast:not(:last-child){margin-bottom:.75rem}.toast.showing{opacity:1}.toast.show{display:block;opacity:1}.toast.hide{display:none}.toast-header{display:flex;align-items:center;padding:.25rem .75rem;color:#6c757d;background-color:rgba(255,255,255,.85);background-clip:padding-box;border-bottom:1px solid rgba(0,0,0,.05)}.toast-body{padding:.75rem}.modal-open{overflow:hidden}.modal-open .modal{overflow-x:hidden;overflow-y:auto}.modal{position:fixed;top:0;left:0;z-index:1050;display:none;width:100%;height:100%;overflow:hidden;outline:0}.modal-dialog{position:relative;width:auto;margin:.5rem;pointer-events:none}.modal.fade .modal-dialog{transition:transform .3s ease-out;transform:translate(0,-50px)}@media (prefers-reduced-motion:reduce){.progress-bar{transition:none}.progress-bar-animated{-webkit-animation:none;animation:none}.modal.fade .modal-dialog{transition:none}}.modal.show .modal-dialog{transform:none}.modal.modal-static .modal-dialog{transform:scale(1.02)}.modal-dialog-scrollable{display:flex;max-height:calc(100% - 1rem)}.modal-dialog-scrollable .modal-content{max-height:calc(100vh - 1rem);overflow:hidden}.modal-dialog-scrollable .modal-footer,.modal-dialog-scrollable .modal-header{flex-shrink:0}.modal-dialog-scrollable .modal-body{overflow-y:auto}.modal-dialog-centered{display:flex;align-items:center;min-height:calc(100% - 1rem)}.modal-dialog-centered::before{display:block;height:calc(100vh - 1rem);height:-webkit-min-content;height:-moz-min-content;height:min-content;content:\"\"}.modal-dialog-centered.modal-dialog-scrollable{flex-direction:column;justify-content:center;height:100%}.modal-dialog-centered.modal-dialog-scrollable .modal-content{max-height:none}.modal-dialog-centered.modal-dialog-scrollable::before{content:none}.modal-content{position:relative;display:flex;flex-direction:column;width:100%;pointer-events:auto;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.2);border-radius:.3rem;outline:0}.modal-backdrop{position:fixed;top:0;left:0;z-index:1040;width:100vw;height:100vh;background-color:#000}.modal-backdrop.fade{opacity:0}.modal-backdrop.show{opacity:.5}.modal-header{display:flex;align-items:flex-start;justify-content:space-between;padding:1rem;border-bottom:1px solid #f2f3f4;border-top-left-radius:calc(.3rem - 1px);border-top-right-radius:calc(.3rem - 1px)}.modal-header .close{padding:1rem;margin:-1rem -1rem -1rem auto}.modal-title{margin-bottom:0;line-height:1.5}.modal-body{position:relative;flex:1 1 auto;padding:1rem}.modal-footer{display:flex;flex-wrap:wrap;align-items:center;justify-content:flex-end;padding:.75rem;border-top:1px solid #f2f3f4;border-bottom-right-radius:calc(.3rem - 1px);border-bottom-left-radius:calc(.3rem - 1px)}.modal-footer>*{margin:.25rem}.modal-scrollbar-measure{position:absolute;top:-9999px;width:50px;height:50px;overflow:scroll}@media (min-width:576px){.modal-dialog{max-width:500px;margin:1.75rem auto}.modal-dialog-scrollable{max-height:calc(100% - 3.5rem)}.modal-dialog-scrollable .modal-content{max-height:calc(100vh - 3.5rem)}.modal-dialog-centered{min-height:calc(100% - 3.5rem)}.modal-dialog-centered::before{height:calc(100vh - 3.5rem);height:-webkit-min-content;height:-moz-min-content;height:min-content}.modal-sm{max-width:300px}}@media (min-width:992px){.modal-lg,.modal-xl{max-width:800px}}@media (min-width:1200px){.modal-xl{max-width:1140px}}.tooltip{position:absolute;z-index:1070;display:block;margin:0;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-style:normal;font-weight:400;line-height:1.5;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;white-space:normal;line-break:auto;font-size:.875rem;word-wrap:break-word;opacity:0}.tooltip.show{opacity:.9}.tooltip .arrow{position:absolute;display:block;width:.8rem;height:.4rem}.tooltip .arrow::before{position:absolute;content:\"\";border-color:transparent;border-style:solid}.bs-tooltip-auto[x-placement^=top],.bs-tooltip-top{padding:.4rem 0}.bs-tooltip-auto[x-placement^=top] .arrow,.bs-tooltip-top .arrow{bottom:0}.bs-tooltip-auto[x-placement^=top] .arrow::before,.bs-tooltip-top .arrow::before{top:0;border-width:.4rem .4rem 0;border-top-color:#000}.bs-tooltip-auto[x-placement^=right],.bs-tooltip-right{padding:0 .4rem}.bs-tooltip-auto[x-placement^=right] .arrow,.bs-tooltip-right .arrow{left:0;width:.4rem;height:.8rem}.bs-tooltip-auto[x-placement^=right] .arrow::before,.bs-tooltip-right .arrow::before{right:0;border-width:.4rem .4rem .4rem 0;border-right-color:#000}.bs-tooltip-auto[x-placement^=bottom],.bs-tooltip-bottom{padding:.4rem 0}.bs-tooltip-auto[x-placement^=bottom] .arrow,.bs-tooltip-bottom .arrow{top:0}.bs-tooltip-auto[x-placement^=bottom] .arrow::before,.bs-tooltip-bottom .arrow::before{bottom:0;border-width:0 .4rem .4rem;border-bottom-color:#000}.bs-tooltip-auto[x-placement^=left],.bs-tooltip-left{padding:0 .4rem}.bs-tooltip-auto[x-placement^=left] .arrow,.bs-tooltip-left .arrow{right:0;width:.4rem;height:.8rem}.bs-tooltip-auto[x-placement^=left] .arrow::before,.bs-tooltip-left .arrow::before{left:0;border-width:.4rem 0 .4rem .4rem;border-left-color:#000}.tooltip-inner{max-width:200px;padding:.25rem .5rem;color:#fff;text-align:center;background-color:#000;border-radius:8px}.popover{position:absolute;top:0;left:0;z-index:1060;display:block;max-width:276px;font-family:Roboto,\"Helvetica Neue\",Arial,\"Noto Sans\",sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";font-style:normal;font-weight:400;line-height:1.5;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;white-space:normal;line-break:auto;font-size:.875rem;word-wrap:break-word;background-color:#fff;background-clip:padding-box;border:1px solid rgba(0,0,0,.2);border-radius:.3rem}.popover .arrow{position:absolute;display:block;width:1rem;height:.5rem;margin:0 .3rem}.popover .arrow::after,.popover .arrow::before{position:absolute;display:block;content:\"\";border-color:transparent;border-style:solid}.bs-popover-auto[x-placement^=top],.bs-popover-top{margin-bottom:.5rem}.bs-popover-auto[x-placement^=top]>.arrow,.bs-popover-top>.arrow{bottom:calc(-.5rem - 1px)}.bs-popover-auto[x-placement^=top]>.arrow::before,.bs-popover-top>.arrow::before{bottom:0;border-width:.5rem .5rem 0;border-top-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=top]>.arrow::after,.bs-popover-top>.arrow::after{bottom:1px;border-width:.5rem .5rem 0;border-top-color:#fff}.bs-popover-auto[x-placement^=right],.bs-popover-right{margin-left:.5rem}.bs-popover-auto[x-placement^=right]>.arrow,.bs-popover-right>.arrow{left:calc(-.5rem - 1px);width:.5rem;height:1rem;margin:.3rem 0}.bs-popover-auto[x-placement^=right]>.arrow::before,.bs-popover-right>.arrow::before{left:0;border-width:.5rem .5rem .5rem 0;border-right-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=right]>.arrow::after,.bs-popover-right>.arrow::after{left:1px;border-width:.5rem .5rem .5rem 0;border-right-color:#fff}.bs-popover-auto[x-placement^=bottom],.bs-popover-bottom{margin-top:.5rem}.bs-popover-auto[x-placement^=bottom]>.arrow,.bs-popover-bottom>.arrow{top:calc(-.5rem - 1px)}.bs-popover-auto[x-placement^=bottom]>.arrow::before,.bs-popover-bottom>.arrow::before{top:0;border-width:0 .5rem .5rem;border-bottom-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=bottom]>.arrow::after,.bs-popover-bottom>.arrow::after{top:1px;border-width:0 .5rem .5rem;border-bottom-color:#fff}.bs-popover-auto[x-placement^=bottom] .popover-header::before,.bs-popover-bottom .popover-header::before{position:absolute;top:0;left:50%;display:block;width:1rem;margin-left:-.5rem;content:\"\";border-bottom:1px solid #f7f7f7}.bs-popover-auto[x-placement^=left],.bs-popover-left{margin-right:.5rem}.bs-popover-auto[x-placement^=left]>.arrow,.bs-popover-left>.arrow{right:calc(-.5rem - 1px);width:.5rem;height:1rem;margin:.3rem 0}.bs-popover-auto[x-placement^=left]>.arrow::before,.bs-popover-left>.arrow::before{right:0;border-width:.5rem 0 .5rem .5rem;border-left-color:rgba(0,0,0,.25)}.bs-popover-auto[x-placement^=left]>.arrow::after,.bs-popover-left>.arrow::after{right:1px;border-width:.5rem 0 .5rem .5rem;border-left-color:#fff}.popover-header{padding:.5rem .75rem;margin-bottom:0;font-size:1rem;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;border-top-left-radius:calc(.3rem - 1px);border-top-right-radius:calc(.3rem - 1px)}.popover-header:empty{display:none}.popover-body{padding:.5rem .75rem;color:#212529}.carousel{position:relative}.carousel.pointer-event{touch-action:pan-y}.carousel-inner{position:relative;width:100%;overflow:hidden}.carousel-inner::after{display:block;clear:both;content:\"\"}.carousel-item{position:relative;display:none;float:left;width:100%;margin-right:-100%;-webkit-backface-visibility:hidden;backface-visibility:hidden;transition:transform .6s ease-in-out}.carousel-item-next,.carousel-item-prev,.carousel-item.active{display:block}.active.carousel-item-right,.carousel-item-next:not(.carousel-item-left){transform:translateX(100%)}.active.carousel-item-left,.carousel-item-prev:not(.carousel-item-right){transform:translateX(-100%)}.carousel-fade .carousel-item{opacity:0;transition-property:opacity;transform:none}.carousel-fade .carousel-item-next.carousel-item-left,.carousel-fade .carousel-item-prev.carousel-item-right,.carousel-fade .carousel-item.active{z-index:1;opacity:1}.carousel-fade .active.carousel-item-left,.carousel-fade .active.carousel-item-right{z-index:0;opacity:0;transition:opacity .6s}@media (prefers-reduced-motion:reduce){.carousel-fade .active.carousel-item-left,.carousel-fade .active.carousel-item-right,.carousel-item{transition:none}}.carousel-control-next,.carousel-control-prev{position:absolute;top:0;bottom:0;z-index:1;display:flex;align-items:center;justify-content:center;width:15%;color:#fff;text-align:center;opacity:.5;transition:opacity .15s}.carousel-control-next:focus,.carousel-control-next:hover,.carousel-control-prev:focus,.carousel-control-prev:hover{color:#fff;text-decoration:none;outline:0;opacity:.9}.carousel-control-prev{left:0}.carousel-control-next{right:0}.carousel-control-next-icon,.carousel-control-prev-icon{display:inline-block;width:20px;height:20px;background:50%/100% 100% no-repeat}.carousel-control-prev-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath d='M5.25 0l-4 4 4 4 1.5-1.5L4.25 4l2.5-2.5L5.25 0z'/%3e%3c/svg%3e\")}.carousel-control-next-icon{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' width='8' height='8' viewBox='0 0 8 8'%3e%3cpath d='M2.75 0l-1.5 1.5L3.75 4l-2.5 2.5L2.75 8l4-4-4-4z'/%3e%3c/svg%3e\")}.carousel-indicators{position:absolute;right:0;bottom:0;left:0;z-index:15;display:flex;justify-content:center;padding-left:0;margin-right:15%;margin-left:15%;list-style:none}.carousel-indicators li{box-sizing:content-box;flex:0 1 auto;width:30px;height:3px;margin-right:3px;margin-left:3px;text-indent:-999px;cursor:pointer;background-color:#fff;background-clip:padding-box;border-top:10px solid transparent;border-bottom:10px solid transparent;opacity:.5;transition:opacity .6s}@media (prefers-reduced-motion:reduce){.carousel-control-next,.carousel-control-prev,.carousel-indicators li{transition:none}}.carousel-indicators .active{opacity:1}.carousel-caption{position:absolute;right:15%;bottom:20px;left:15%;z-index:10;padding-top:20px;padding-bottom:20px;color:#fff;text-align:center}@-webkit-keyframes spinner-border{to{transform:rotate(360deg)}}@keyframes spinner-border{to{transform:rotate(360deg)}}.spinner-border{display:inline-block;width:2rem;height:2rem;vertical-align:text-bottom;border:.25em solid currentColor;border-right-color:transparent;border-radius:50%;-webkit-animation:.75s linear infinite spinner-border;animation:.75s linear infinite spinner-border}.spinner-border-sm{width:1rem;height:1rem;border-width:.2em}@-webkit-keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}@keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}.spinner-grow{display:inline-block;width:2rem;height:2rem;vertical-align:text-bottom;background-color:currentColor;border-radius:50%;opacity:0;-webkit-animation:.75s linear infinite spinner-grow;animation:.75s linear infinite spinner-grow}.spinner-grow-sm{width:1rem;height:1rem}.align-baseline{vertical-align:baseline!important}.align-top{vertical-align:top!important}.align-middle{vertical-align:middle!important}.align-bottom{vertical-align:bottom!important}.align-text-bottom{vertical-align:text-bottom!important}.align-text-top{vertical-align:text-top!important}.bg-primary{background-color:#c82c37!important}a.bg-primary:focus,a.bg-primary:hover,button.bg-primary:focus,button.bg-primary:hover{background-color:#9e232c!important}.bg-secondary{background-color:#919191!important}a.bg-secondary:focus,a.bg-secondary:hover,button.bg-secondary:focus,button.bg-secondary:hover{background-color:#787878!important}.bg-success{background-color:#4caf50!important}a.bg-success:focus,a.bg-success:hover,button.bg-success:focus,button.bg-success:hover{background-color:#3d8b40!important}.bg-info{background-color:#00bcd4!important}a.bg-info:focus,a.bg-info:hover,button.bg-info:focus,button.bg-info:hover{background-color:#008fa1!important}.bg-warning{background-color:#ff9800!important}a.bg-warning:focus,a.bg-warning:hover,button.bg-warning:focus,button.bg-warning:hover{background-color:#cc7a00!important}.bg-danger{background-color:#f44336!important}a.bg-danger:focus,a.bg-danger:hover,button.bg-danger:focus,button.bg-danger:hover{background-color:#ea1c0d!important}.bg-light{background-color:#f8f9fa!important}a.bg-light:focus,a.bg-light:hover,button.bg-light:focus,button.bg-light:hover{background-color:#dae0e5!important}.bg-dark{background-color:#343a40!important}a.bg-dark:focus,a.bg-dark:hover,button.bg-dark:focus,button.bg-dark:hover{background-color:#1d2124!important}.bg-white{background-color:#fff!important}.bg-transparent{background-color:transparent!important}.border{border:1px solid #f2f3f4!important}.border-top{border-top:1px solid #f2f3f4!important}.border-right{border-right:1px solid #f2f3f4!important}.border-bottom{border-bottom:1px solid #f2f3f4!important}.border-left{border-left:1px solid #f2f3f4!important}.border-0{border:0!important}.border-top-0{border-top:0!important}.border-right-0{border-right:0!important}.border-bottom-0{border-bottom:0!important}.border-left-0{border-left:0!important}.border-primary{border-color:#c82c37!important}.border-secondary{border-color:#919191!important}.border-success{border-color:#4caf50!important}.border-info{border-color:#00bcd4!important}.border-warning{border-color:#ff9800!important}.border-danger{border-color:#f44336!important}.border-light{border-color:#f8f9fa!important}.border-dark{border-color:#343a40!important}.border-white{border-color:#fff!important}.rounded-sm{border-radius:.2rem!important}.rounded{border-radius:8px!important}.rounded-top{border-top-left-radius:8px!important;border-top-right-radius:8px!important}.rounded-right{border-top-right-radius:8px!important;border-bottom-right-radius:8px!important}.rounded-bottom{border-bottom-right-radius:8px!important;border-bottom-left-radius:8px!important}.rounded-left{border-top-left-radius:8px!important;border-bottom-left-radius:8px!important}.rounded-lg{border-radius:.3rem!important}.rounded-circle{border-radius:50%!important}.rounded-pill{border-radius:50rem!important}.rounded-0{border-radius:0!important}.clearfix::after{display:block;clear:both;content:\"\"}.d-none{display:none!important}.d-inline{display:inline!important}.d-inline-block{display:inline-block!important}.d-block{display:block!important}.d-table{display:table!important}.d-table-row{display:table-row!important}.d-table-cell{display:table-cell!important}.d-flex{display:flex!important}.d-inline-flex{display:inline-flex!important}@media (min-width:576px){.d-sm-none{display:none!important}.d-sm-inline{display:inline!important}.d-sm-inline-block{display:inline-block!important}.d-sm-block{display:block!important}.d-sm-table{display:table!important}.d-sm-table-row{display:table-row!important}.d-sm-table-cell{display:table-cell!important}.d-sm-flex{display:flex!important}.d-sm-inline-flex{display:inline-flex!important}}@media (min-width:768px){.d-md-none{display:none!important}.d-md-inline{display:inline!important}.d-md-inline-block{display:inline-block!important}.d-md-block{display:block!important}.d-md-table{display:table!important}.d-md-table-row{display:table-row!important}.d-md-table-cell{display:table-cell!important}.d-md-flex{display:flex!important}.d-md-inline-flex{display:inline-flex!important}}@media (min-width:992px){.d-lg-none{display:none!important}.d-lg-inline{display:inline!important}.d-lg-inline-block{display:inline-block!important}.d-lg-block{display:block!important}.d-lg-table{display:table!important}.d-lg-table-row{display:table-row!important}.d-lg-table-cell{display:table-cell!important}.d-lg-flex{display:flex!important}.d-lg-inline-flex{display:inline-flex!important}}@media (min-width:1200px){.d-xl-none{display:none!important}.d-xl-inline{display:inline!important}.d-xl-inline-block{display:inline-block!important}.d-xl-block{display:block!important}.d-xl-table{display:table!important}.d-xl-table-row{display:table-row!important}.d-xl-table-cell{display:table-cell!important}.d-xl-flex{display:flex!important}.d-xl-inline-flex{display:inline-flex!important}}@media print{.d-print-none{display:none!important}.d-print-inline{display:inline!important}.d-print-inline-block{display:inline-block!important}.d-print-block{display:block!important}.d-print-table{display:table!important}.d-print-table-row{display:table-row!important}.d-print-table-cell{display:table-cell!important}.d-print-flex{display:flex!important}.d-print-inline-flex{display:inline-flex!important}}.embed-responsive{position:relative;display:block;width:100%;padding:0;overflow:hidden}.embed-responsive::before{display:block;content:\"\"}.embed-responsive .embed-responsive-item,.embed-responsive embed,.embed-responsive iframe,.embed-responsive object,.embed-responsive video{position:absolute;top:0;bottom:0;left:0;width:100%;height:100%;border:0}.embed-responsive-21by9::before{padding-top:42.8571428571%}.embed-responsive-16by9::before{padding-top:56.25%}.embed-responsive-4by3::before{padding-top:75%}.embed-responsive-1by1::before{padding-top:100%}.flex-row{flex-direction:row!important}.flex-column{flex-direction:column!important}.flex-row-reverse{flex-direction:row-reverse!important}.flex-column-reverse{flex-direction:column-reverse!important}.flex-wrap{flex-wrap:wrap!important}.flex-nowrap{flex-wrap:nowrap!important}.flex-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-fill{flex:1 1 auto!important}.flex-grow-0{flex-grow:0!important}.flex-grow-1{flex-grow:1!important}.flex-shrink-0{flex-shrink:0!important}.flex-shrink-1{flex-shrink:1!important}.justify-content-start{justify-content:flex-start!important}.justify-content-end{justify-content:flex-end!important}.justify-content-center{justify-content:center!important}.justify-content-between{justify-content:space-between!important}.justify-content-around{justify-content:space-around!important}.align-items-start{align-items:flex-start!important}.align-items-end{align-items:flex-end!important}.align-items-center{align-items:center!important}.align-items-baseline{align-items:baseline!important}.align-items-stretch{align-items:stretch!important}.align-content-start{align-content:flex-start!important}.align-content-end{align-content:flex-end!important}.align-content-center{align-content:center!important}.align-content-between{align-content:space-between!important}.align-content-around{align-content:space-around!important}.align-content-stretch{align-content:stretch!important}.align-self-auto{align-self:auto!important}.align-self-start{align-self:flex-start!important}.align-self-end{align-self:flex-end!important}.align-self-center{align-self:center!important}.align-self-baseline{align-self:baseline!important}.align-self-stretch{align-self:stretch!important}.float-left{float:left!important}.float-right{float:right!important}.float-none{float:none!important}.user-select-all{-webkit-user-select:all!important;-moz-user-select:all!important;-ms-user-select:all!important;user-select:all!important}.user-select-auto{-webkit-user-select:auto!important;-moz-user-select:auto!important;-ms-user-select:auto!important;user-select:auto!important}.user-select-none{-webkit-user-select:none!important;-moz-user-select:none!important;-ms-user-select:none!important;user-select:none!important}.overflow-auto{overflow:auto!important}.overflow-hidden{overflow:hidden!important}.position-static{position:static!important}.position-relative{position:relative!important}.position-absolute{position:absolute!important}.position-fixed{position:fixed!important}.position-sticky{position:-webkit-sticky!important;position:sticky!important}.fixed-top{position:fixed;top:0;right:0;left:0;z-index:1030}.fixed-bottom{position:fixed;right:0;bottom:0;left:0;z-index:1030}@supports ((position:-webkit-sticky) or (position:sticky)){.sticky-top{position:-webkit-sticky;position:sticky;top:0;z-index:1020}}.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);white-space:nowrap;border:0}.sr-only-focusable:active,.sr-only-focusable:focus{position:static;width:auto;height:auto;overflow:visible;clip:auto;white-space:normal}.shadow-sm{box-shadow:0 .125rem .25rem rgba(0,0,0,.075)!important}.shadow{box-shadow:0 .5rem 1rem rgba(0,0,0,.15)!important}.shadow-lg{box-shadow:0 1rem 3rem rgba(0,0,0,.175)!important}.shadow-none{box-shadow:none!important}.w-25{width:25%!important}.w-50{width:50%!important}.w-75{width:75%!important}.w-100{width:100%!important}.w-auto{width:auto!important}.h-25{height:25%!important}.h-50{height:50%!important}.h-75{height:75%!important}.h-100{height:100%!important}.h-auto{height:auto!important}.mw-100{max-width:100%!important}.mh-100{max-height:100%!important}.min-vw-100{min-width:100vw!important}.min-vh-100{min-height:100vh!important}.vw-100{width:100vw!important}.vh-100{height:100vh!important}.m-0{margin:0!important}.mt-0,.my-0{margin-top:0!important}.mr-0,.mx-0{margin-right:0!important}.mb-0,.my-0{margin-bottom:0!important}.ml-0,.mx-0{margin-left:0!important}.m-1{margin:1px!important}.mt-1,.my-1{margin-top:1px!important}.mr-1,.mx-1{margin-right:1px!important}.mb-1,.my-1{margin-bottom:1px!important}.ml-1,.mx-1{margin-left:1px!important}.m-2{margin:2px!important}.mt-2,.my-2{margin-top:2px!important}.mr-2,.mx-2{margin-right:2px!important}.mb-2,.my-2{margin-bottom:2px!important}.ml-2,.mx-2{margin-left:2px!important}.m-3{margin:3px!important}.mt-3,.my-3{margin-top:3px!important}.mr-3,.mx-3{margin-right:3px!important}.mb-3,.my-3{margin-bottom:3px!important}.ml-3,.mx-3{margin-left:3px!important}.m-4{margin:4px!important}.mt-4,.my-4{margin-top:4px!important}.mr-4,.mx-4{margin-right:4px!important}.mb-4,.my-4{margin-bottom:4px!important}.ml-4,.mx-4{margin-left:4px!important}.m-5{margin:5px!important}.mt-5,.my-5{margin-top:5px!important}.mr-5,.mx-5{margin-right:5px!important}.mb-5,.my-5{margin-bottom:5px!important}.ml-5,.mx-5{margin-left:5px!important}.m-6{margin:6px!important}.mt-6,.my-6{margin-top:6px!important}.mr-6,.mx-6{margin-right:6px!important}.mb-6,.my-6{margin-bottom:6px!important}.ml-6,.mx-6{margin-left:6px!important}.m-7{margin:7px!important}.mt-7,.my-7{margin-top:7px!important}.mr-7,.mx-7{margin-right:7px!important}.mb-7,.my-7{margin-bottom:7px!important}.ml-7,.mx-7{margin-left:7px!important}.m-8{margin:8px!important}.mt-8,.my-8{margin-top:8px!important}.mr-8,.mx-8{margin-right:8px!important}.mb-8,.my-8{margin-bottom:8px!important}.ml-8,.mx-8{margin-left:8px!important}.m-9{margin:9px!important}.mt-9,.my-9{margin-top:9px!important}.mr-9,.mx-9{margin-right:9px!important}.mb-9,.my-9{margin-bottom:9px!important}.ml-9,.mx-9{margin-left:9px!important}.m-10{margin:10px!important}.mt-10,.my-10{margin-top:10px!important}.mr-10,.mx-10{margin-right:10px!important}.mb-10,.my-10{margin-bottom:10px!important}.ml-10,.mx-10{margin-left:10px!important}.m-11{margin:11px!important}.mt-11,.my-11{margin-top:11px!important}.mr-11,.mx-11{margin-right:11px!important}.mb-11,.my-11{margin-bottom:11px!important}.ml-11,.mx-11{margin-left:11px!important}.m-12{margin:12px!important}.mt-12,.my-12{margin-top:12px!important}.mr-12,.mx-12{margin-right:12px!important}.mb-12,.my-12{margin-bottom:12px!important}.ml-12,.mx-12{margin-left:12px!important}.m-13{margin:13px!important}.mt-13,.my-13{margin-top:13px!important}.mr-13,.mx-13{margin-right:13px!important}.mb-13,.my-13{margin-bottom:13px!important}.ml-13,.mx-13{margin-left:13px!important}.m-14{margin:14px!important}.mt-14,.my-14{margin-top:14px!important}.mr-14,.mx-14{margin-right:14px!important}.mb-14,.my-14{margin-bottom:14px!important}.ml-14,.mx-14{margin-left:14px!important}.m-15{margin:15px!important}.mt-15,.my-15{margin-top:15px!important}.mr-15,.mx-15{margin-right:15px!important}.mb-15,.my-15{margin-bottom:15px!important}.ml-15,.mx-15{margin-left:15px!important}.m-16{margin:16px!important}.mt-16,.my-16{margin-top:16px!important}.mr-16,.mx-16{margin-right:16px!important}.mb-16,.my-16{margin-bottom:16px!important}.ml-16,.mx-16{margin-left:16px!important}.m-18{margin:18px!important}.mt-18,.my-18{margin-top:18px!important}.mr-18,.mx-18{margin-right:18px!important}.mb-18,.my-18{margin-bottom:18px!important}.ml-18,.mx-18{margin-left:18px!important}.m-20{margin:20px!important}.mt-20,.my-20{margin-top:20px!important}.mr-20,.mx-20{margin-right:20px!important}.mb-20,.my-20{margin-bottom:20px!important}.ml-20,.mx-20{margin-left:20px!important}.m-21{margin:21px!important}.mt-21,.my-21{margin-top:21px!important}.mr-21,.mx-21{margin-right:21px!important}.mb-21,.my-21{margin-bottom:21px!important}.ml-21,.mx-21{margin-left:21px!important}.m-23{margin:23px!important}.mt-23,.my-23{margin-top:23px!important}.mr-23,.mx-23{margin-right:23px!important}.mb-23,.my-23{margin-bottom:23px!important}.ml-23,.mx-23{margin-left:23px!important}.m-24{margin:24px!important}.mt-24,.my-24{margin-top:24px!important}.mr-24,.mx-24{margin-right:24px!important}.mb-24,.my-24{margin-bottom:24px!important}.ml-24,.mx-24{margin-left:24px!important}.m-26{margin:26px!important}.mt-26,.my-26{margin-top:26px!important}.mr-26,.mx-26{margin-right:26px!important}.mb-26,.my-26{margin-bottom:26px!important}.ml-26,.mx-26{margin-left:26px!important}.m-28{margin:28px!important}.mt-28,.my-28{margin-top:28px!important}.mr-28,.mx-28{margin-right:28px!important}.mb-28,.my-28{margin-bottom:28px!important}.ml-28,.mx-28{margin-left:28px!important}.m-29{margin:29px!important}.mt-29,.my-29{margin-top:29px!important}.mr-29,.mx-29{margin-right:29px!important}.mb-29,.my-29{margin-bottom:29px!important}.ml-29,.mx-29{margin-left:29px!important}.m-30{margin:30px!important}.mt-30,.my-30{margin-top:30px!important}.mr-30,.mx-30{margin-right:30px!important}.mb-30,.my-30{margin-bottom:30px!important}.ml-30,.mx-30{margin-left:30px!important}.m-32{margin:32px!important}.mt-32,.my-32{margin-top:32px!important}.mr-32,.mx-32{margin-right:32px!important}.mb-32,.my-32{margin-bottom:32px!important}.ml-32,.mx-32{margin-left:32px!important}.m-38{margin:38px!important}.mt-38,.my-38{margin-top:38px!important}.mr-38,.mx-38{margin-right:38px!important}.mb-38,.my-38{margin-bottom:38px!important}.ml-38,.mx-38{margin-left:38px!important}.m-40{margin:40px!important}.mt-40,.my-40{margin-top:40px!important}.mr-40,.mx-40{margin-right:40px!important}.mb-40,.my-40{margin-bottom:40px!important}.ml-40,.mx-40{margin-left:40px!important}.m-42{margin:42px!important}.mt-42,.my-42{margin-top:42px!important}.mr-42,.mx-42{margin-right:42px!important}.mb-42,.my-42{margin-bottom:42px!important}.ml-42,.mx-42{margin-left:42px!important}.m-48{margin:48px!important}.mt-48,.my-48{margin-top:48px!important}.mr-48,.mx-48{margin-right:48px!important}.mb-48,.my-48{margin-bottom:48px!important}.ml-48,.mx-48{margin-left:48px!important}.m-50{margin:50px!important}.mt-50,.my-50{margin-top:50px!important}.mr-50,.mx-50{margin-right:50px!important}.mb-50,.my-50{margin-bottom:50px!important}.ml-50,.mx-50{margin-left:50px!important}.m-56{margin:56px!important}.mt-56,.my-56{margin-top:56px!important}.mr-56,.mx-56{margin-right:56px!important}.mb-56,.my-56{margin-bottom:56px!important}.ml-56,.mx-56{margin-left:56px!important}.m-58{margin:58px!important}.mt-58,.my-58{margin-top:58px!important}.mr-58,.mx-58{margin-right:58px!important}.mb-58,.my-58{margin-bottom:58px!important}.ml-58,.mx-58{margin-left:58px!important}.m-60{margin:60px!important}.mt-60,.my-60{margin-top:60px!important}.mr-60,.mx-60{margin-right:60px!important}.mb-60,.my-60{margin-bottom:60px!important}.ml-60,.mx-60{margin-left:60px!important}.m-64{margin:64px!important}.mt-64,.my-64{margin-top:64px!important}.mr-64,.mx-64{margin-right:64px!important}.mb-64,.my-64{margin-bottom:64px!important}.ml-64,.mx-64{margin-left:64px!important}.p-0{padding:0!important}.pt-0,.py-0{padding-top:0!important}.pr-0,.px-0{padding-right:0!important}.pb-0,.py-0{padding-bottom:0!important}.pl-0,.px-0{padding-left:0!important}.p-1{padding:1px!important}.pt-1,.py-1{padding-top:1px!important}.pr-1,.px-1{padding-right:1px!important}.pb-1,.py-1{padding-bottom:1px!important}.pl-1,.px-1{padding-left:1px!important}.p-2{padding:2px!important}.pt-2,.py-2{padding-top:2px!important}.pr-2,.px-2{padding-right:2px!important}.pb-2,.py-2{padding-bottom:2px!important}.pl-2,.px-2{padding-left:2px!important}.p-3{padding:3px!important}.pt-3,.py-3{padding-top:3px!important}.pr-3,.px-3{padding-right:3px!important}.pb-3,.py-3{padding-bottom:3px!important}.pl-3,.px-3{padding-left:3px!important}.p-4{padding:4px!important}.pt-4,.py-4{padding-top:4px!important}.pr-4,.px-4{padding-right:4px!important}.pb-4,.py-4{padding-bottom:4px!important}.pl-4,.px-4{padding-left:4px!important}.p-5{padding:5px!important}.pt-5,.py-5{padding-top:5px!important}.pr-5,.px-5{padding-right:5px!important}.pb-5,.py-5{padding-bottom:5px!important}.pl-5,.px-5{padding-left:5px!important}.p-6{padding:6px!important}.pt-6,.py-6{padding-top:6px!important}.pr-6,.px-6{padding-right:6px!important}.pb-6,.py-6{padding-bottom:6px!important}.pl-6,.px-6{padding-left:6px!important}.p-7{padding:7px!important}.pt-7,.py-7{padding-top:7px!important}.pr-7,.px-7{padding-right:7px!important}.pb-7,.py-7{padding-bottom:7px!important}.pl-7,.px-7{padding-left:7px!important}.p-8{padding:8px!important}.pt-8,.py-8{padding-top:8px!important}.pr-8,.px-8{padding-right:8px!important}.pb-8,.py-8{padding-bottom:8px!important}.pl-8,.px-8{padding-left:8px!important}.p-9{padding:9px!important}.pt-9,.py-9{padding-top:9px!important}.pr-9,.px-9{padding-right:9px!important}.pb-9,.py-9{padding-bottom:9px!important}.pl-9,.px-9{padding-left:9px!important}.p-10{padding:10px!important}.pt-10,.py-10{padding-top:10px!important}.pr-10,.px-10{padding-right:10px!important}.pb-10,.py-10{padding-bottom:10px!important}.pl-10,.px-10{padding-left:10px!important}.p-11{padding:11px!important}.pt-11,.py-11{padding-top:11px!important}.pr-11,.px-11{padding-right:11px!important}.pb-11,.py-11{padding-bottom:11px!important}.pl-11,.px-11{padding-left:11px!important}.p-12{padding:12px!important}.pt-12,.py-12{padding-top:12px!important}.pr-12,.px-12{padding-right:12px!important}.pb-12,.py-12{padding-bottom:12px!important}.pl-12,.px-12{padding-left:12px!important}.p-13{padding:13px!important}.pt-13,.py-13{padding-top:13px!important}.pr-13,.px-13{padding-right:13px!important}.pb-13,.py-13{padding-bottom:13px!important}.pl-13,.px-13{padding-left:13px!important}.p-14{padding:14px!important}.pt-14,.py-14{padding-top:14px!important}.pr-14,.px-14{padding-right:14px!important}.pb-14,.py-14{padding-bottom:14px!important}.pl-14,.px-14{padding-left:14px!important}.p-15{padding:15px!important}.pt-15,.py-15{padding-top:15px!important}.pr-15,.px-15{padding-right:15px!important}.pb-15,.py-15{padding-bottom:15px!important}.pl-15,.px-15{padding-left:15px!important}.p-16{padding:16px!important}.pt-16,.py-16{padding-top:16px!important}.pr-16,.px-16{padding-right:16px!important}.pb-16,.py-16{padding-bottom:16px!important}.pl-16,.px-16{padding-left:16px!important}.p-18{padding:18px!important}.pt-18,.py-18{padding-top:18px!important}.pr-18,.px-18{padding-right:18px!important}.pb-18,.py-18{padding-bottom:18px!important}.pl-18,.px-18{padding-left:18px!important}.p-20{padding:20px!important}.pt-20,.py-20{padding-top:20px!important}.pr-20,.px-20{padding-right:20px!important}.pb-20,.py-20{padding-bottom:20px!important}.pl-20,.px-20{padding-left:20px!important}.p-21{padding:21px!important}.pt-21,.py-21{padding-top:21px!important}.pr-21,.px-21{padding-right:21px!important}.pb-21,.py-21{padding-bottom:21px!important}.pl-21,.px-21{padding-left:21px!important}.p-23{padding:23px!important}.pt-23,.py-23{padding-top:23px!important}.pr-23,.px-23{padding-right:23px!important}.pb-23,.py-23{padding-bottom:23px!important}.pl-23,.px-23{padding-left:23px!important}.p-24{padding:24px!important}.pt-24,.py-24{padding-top:24px!important}.pr-24,.px-24{padding-right:24px!important}.pb-24,.py-24{padding-bottom:24px!important}.pl-24,.px-24{padding-left:24px!important}.p-26{padding:26px!important}.pt-26,.py-26{padding-top:26px!important}.pr-26,.px-26{padding-right:26px!important}.pb-26,.py-26{padding-bottom:26px!important}.pl-26,.px-26{padding-left:26px!important}.p-28{padding:28px!important}.pt-28,.py-28{padding-top:28px!important}.pr-28,.px-28{padding-right:28px!important}.pb-28,.py-28{padding-bottom:28px!important}.pl-28,.px-28{padding-left:28px!important}.p-29{padding:29px!important}.pt-29,.py-29{padding-top:29px!important}.pr-29,.px-29{padding-right:29px!important}.pb-29,.py-29{padding-bottom:29px!important}.pl-29,.px-29{padding-left:29px!important}.p-30{padding:30px!important}.pt-30,.py-30{padding-top:30px!important}.pr-30,.px-30{padding-right:30px!important}.pb-30,.py-30{padding-bottom:30px!important}.pl-30,.px-30{padding-left:30px!important}.p-32{padding:32px!important}.pt-32,.py-32{padding-top:32px!important}.pr-32,.px-32{padding-right:32px!important}.pb-32,.py-32{padding-bottom:32px!important}.pl-32,.px-32{padding-left:32px!important}.p-38{padding:38px!important}.pt-38,.py-38{padding-top:38px!important}.pr-38,.px-38{padding-right:38px!important}.pb-38,.py-38{padding-bottom:38px!important}.pl-38,.px-38{padding-left:38px!important}.p-40{padding:40px!important}.pt-40,.py-40{padding-top:40px!important}.pr-40,.px-40{padding-right:40px!important}.pb-40,.py-40{padding-bottom:40px!important}.pl-40,.px-40{padding-left:40px!important}.p-42{padding:42px!important}.pt-42,.py-42{padding-top:42px!important}.pr-42,.px-42{padding-right:42px!important}.pb-42,.py-42{padding-bottom:42px!important}.pl-42,.px-42{padding-left:42px!important}.p-48{padding:48px!important}.pt-48,.py-48{padding-top:48px!important}.pr-48,.px-48{padding-right:48px!important}.pb-48,.py-48{padding-bottom:48px!important}.pl-48,.px-48{padding-left:48px!important}.p-50{padding:50px!important}.pt-50,.py-50{padding-top:50px!important}.pr-50,.px-50{padding-right:50px!important}.pb-50,.py-50{padding-bottom:50px!important}.pl-50,.px-50{padding-left:50px!important}.p-56{padding:56px!important}.pt-56,.py-56{padding-top:56px!important}.pr-56,.px-56{padding-right:56px!important}.pb-56,.py-56{padding-bottom:56px!important}.pl-56,.px-56{padding-left:56px!important}.p-58{padding:58px!important}.pt-58,.py-58{padding-top:58px!important}.pr-58,.px-58{padding-right:58px!important}.pb-58,.py-58{padding-bottom:58px!important}.pl-58,.px-58{padding-left:58px!important}.p-60{padding:60px!important}.pt-60,.py-60{padding-top:60px!important}.pr-60,.px-60{padding-right:60px!important}.pb-60,.py-60{padding-bottom:60px!important}.pl-60,.px-60{padding-left:60px!important}.p-64{padding:64px!important}.pt-64,.py-64{padding-top:64px!important}.pr-64,.px-64{padding-right:64px!important}.pb-64,.py-64{padding-bottom:64px!important}.pl-64,.px-64{padding-left:64px!important}.m-n1{margin:-1px!important}.mt-n1,.my-n1{margin-top:-1px!important}.mr-n1,.mx-n1{margin-right:-1px!important}.mb-n1,.my-n1{margin-bottom:-1px!important}.ml-n1,.mx-n1{margin-left:-1px!important}.m-n2{margin:-2px!important}.mt-n2,.my-n2{margin-top:-2px!important}.mr-n2,.mx-n2{margin-right:-2px!important}.mb-n2,.my-n2{margin-bottom:-2px!important}.ml-n2,.mx-n2{margin-left:-2px!important}.m-n3{margin:-3px!important}.mt-n3,.my-n3{margin-top:-3px!important}.mr-n3,.mx-n3{margin-right:-3px!important}.mb-n3,.my-n3{margin-bottom:-3px!important}.ml-n3,.mx-n3{margin-left:-3px!important}.m-n4{margin:-4px!important}.mt-n4,.my-n4{margin-top:-4px!important}.mr-n4,.mx-n4{margin-right:-4px!important}.mb-n4,.my-n4{margin-bottom:-4px!important}.ml-n4,.mx-n4{margin-left:-4px!important}.m-n5{margin:-5px!important}.mt-n5,.my-n5{margin-top:-5px!important}.mr-n5,.mx-n5{margin-right:-5px!important}.mb-n5,.my-n5{margin-bottom:-5px!important}.ml-n5,.mx-n5{margin-left:-5px!important}.m-n6{margin:-6px!important}.mt-n6,.my-n6{margin-top:-6px!important}.mr-n6,.mx-n6{margin-right:-6px!important}.mb-n6,.my-n6{margin-bottom:-6px!important}.ml-n6,.mx-n6{margin-left:-6px!important}.m-n7{margin:-7px!important}.mt-n7,.my-n7{margin-top:-7px!important}.mr-n7,.mx-n7{margin-right:-7px!important}.mb-n7,.my-n7{margin-bottom:-7px!important}.ml-n7,.mx-n7{margin-left:-7px!important}.m-n8{margin:-8px!important}.mt-n8,.my-n8{margin-top:-8px!important}.mr-n8,.mx-n8{margin-right:-8px!important}.mb-n8,.my-n8{margin-bottom:-8px!important}.ml-n8,.mx-n8{margin-left:-8px!important}.m-n9{margin:-9px!important}.mt-n9,.my-n9{margin-top:-9px!important}.mr-n9,.mx-n9{margin-right:-9px!important}.mb-n9,.my-n9{margin-bottom:-9px!important}.ml-n9,.mx-n9{margin-left:-9px!important}.m-n10{margin:-10px!important}.mt-n10,.my-n10{margin-top:-10px!important}.mr-n10,.mx-n10{margin-right:-10px!important}.mb-n10,.my-n10{margin-bottom:-10px!important}.ml-n10,.mx-n10{margin-left:-10px!important}.m-n11{margin:-11px!important}.mt-n11,.my-n11{margin-top:-11px!important}.mr-n11,.mx-n11{margin-right:-11px!important}.mb-n11,.my-n11{margin-bottom:-11px!important}.ml-n11,.mx-n11{margin-left:-11px!important}.m-n12{margin:-12px!important}.mt-n12,.my-n12{margin-top:-12px!important}.mr-n12,.mx-n12{margin-right:-12px!important}.mb-n12,.my-n12{margin-bottom:-12px!important}.ml-n12,.mx-n12{margin-left:-12px!important}.m-n13{margin:-13px!important}.mt-n13,.my-n13{margin-top:-13px!important}.mr-n13,.mx-n13{margin-right:-13px!important}.mb-n13,.my-n13{margin-bottom:-13px!important}.ml-n13,.mx-n13{margin-left:-13px!important}.m-n14{margin:-14px!important}.mt-n14,.my-n14{margin-top:-14px!important}.mr-n14,.mx-n14{margin-right:-14px!important}.mb-n14,.my-n14{margin-bottom:-14px!important}.ml-n14,.mx-n14{margin-left:-14px!important}.m-n15{margin:-15px!important}.mt-n15,.my-n15{margin-top:-15px!important}.mr-n15,.mx-n15{margin-right:-15px!important}.mb-n15,.my-n15{margin-bottom:-15px!important}.ml-n15,.mx-n15{margin-left:-15px!important}.m-n16{margin:-16px!important}.mt-n16,.my-n16{margin-top:-16px!important}.mr-n16,.mx-n16{margin-right:-16px!important}.mb-n16,.my-n16{margin-bottom:-16px!important}.ml-n16,.mx-n16{margin-left:-16px!important}.m-n18{margin:-18px!important}.mt-n18,.my-n18{margin-top:-18px!important}.mr-n18,.mx-n18{margin-right:-18px!important}.mb-n18,.my-n18{margin-bottom:-18px!important}.ml-n18,.mx-n18{margin-left:-18px!important}.m-n20{margin:-20px!important}.mt-n20,.my-n20{margin-top:-20px!important}.mr-n20,.mx-n20{margin-right:-20px!important}.mb-n20,.my-n20{margin-bottom:-20px!important}.ml-n20,.mx-n20{margin-left:-20px!important}.m-n21{margin:-21px!important}.mt-n21,.my-n21{margin-top:-21px!important}.mr-n21,.mx-n21{margin-right:-21px!important}.mb-n21,.my-n21{margin-bottom:-21px!important}.ml-n21,.mx-n21{margin-left:-21px!important}.m-n23{margin:-23px!important}.mt-n23,.my-n23{margin-top:-23px!important}.mr-n23,.mx-n23{margin-right:-23px!important}.mb-n23,.my-n23{margin-bottom:-23px!important}.ml-n23,.mx-n23{margin-left:-23px!important}.m-n24{margin:-24px!important}.mt-n24,.my-n24{margin-top:-24px!important}.mr-n24,.mx-n24{margin-right:-24px!important}.mb-n24,.my-n24{margin-bottom:-24px!important}.ml-n24,.mx-n24{margin-left:-24px!important}.m-n26{margin:-26px!important}.mt-n26,.my-n26{margin-top:-26px!important}.mr-n26,.mx-n26{margin-right:-26px!important}.mb-n26,.my-n26{margin-bottom:-26px!important}.ml-n26,.mx-n26{margin-left:-26px!important}.m-n28{margin:-28px!important}.mt-n28,.my-n28{margin-top:-28px!important}.mr-n28,.mx-n28{margin-right:-28px!important}.mb-n28,.my-n28{margin-bottom:-28px!important}.ml-n28,.mx-n28{margin-left:-28px!important}.m-n29{margin:-29px!important}.mt-n29,.my-n29{margin-top:-29px!important}.mr-n29,.mx-n29{margin-right:-29px!important}.mb-n29,.my-n29{margin-bottom:-29px!important}.ml-n29,.mx-n29{margin-left:-29px!important}.m-n30{margin:-30px!important}.mt-n30,.my-n30{margin-top:-30px!important}.mr-n30,.mx-n30{margin-right:-30px!important}.mb-n30,.my-n30{margin-bottom:-30px!important}.ml-n30,.mx-n30{margin-left:-30px!important}.m-n32{margin:-32px!important}.mt-n32,.my-n32{margin-top:-32px!important}.mr-n32,.mx-n32{margin-right:-32px!important}.mb-n32,.my-n32{margin-bottom:-32px!important}.ml-n32,.mx-n32{margin-left:-32px!important}.m-n38{margin:-38px!important}.mt-n38,.my-n38{margin-top:-38px!important}.mr-n38,.mx-n38{margin-right:-38px!important}.mb-n38,.my-n38{margin-bottom:-38px!important}.ml-n38,.mx-n38{margin-left:-38px!important}.m-n40{margin:-40px!important}.mt-n40,.my-n40{margin-top:-40px!important}.mr-n40,.mx-n40{margin-right:-40px!important}.mb-n40,.my-n40{margin-bottom:-40px!important}.ml-n40,.mx-n40{margin-left:-40px!important}.m-n42{margin:-42px!important}.mt-n42,.my-n42{margin-top:-42px!important}.mr-n42,.mx-n42{margin-right:-42px!important}.mb-n42,.my-n42{margin-bottom:-42px!important}.ml-n42,.mx-n42{margin-left:-42px!important}.m-n48{margin:-48px!important}.mt-n48,.my-n48{margin-top:-48px!important}.mr-n48,.mx-n48{margin-right:-48px!important}.mb-n48,.my-n48{margin-bottom:-48px!important}.ml-n48,.mx-n48{margin-left:-48px!important}.m-n50{margin:-50px!important}.mt-n50,.my-n50{margin-top:-50px!important}.mr-n50,.mx-n50{margin-right:-50px!important}.mb-n50,.my-n50{margin-bottom:-50px!important}.ml-n50,.mx-n50{margin-left:-50px!important}.m-n56{margin:-56px!important}.mt-n56,.my-n56{margin-top:-56px!important}.mr-n56,.mx-n56{margin-right:-56px!important}.mb-n56,.my-n56{margin-bottom:-56px!important}.ml-n56,.mx-n56{margin-left:-56px!important}.m-n58{margin:-58px!important}.mt-n58,.my-n58{margin-top:-58px!important}.mr-n58,.mx-n58{margin-right:-58px!important}.mb-n58,.my-n58{margin-bottom:-58px!important}.ml-n58,.mx-n58{margin-left:-58px!important}.m-n60{margin:-60px!important}.mt-n60,.my-n60{margin-top:-60px!important}.mr-n60,.mx-n60{margin-right:-60px!important}.mb-n60,.my-n60{margin-bottom:-60px!important}.ml-n60,.mx-n60{margin-left:-60px!important}.m-n64{margin:-64px!important}.mt-n64,.my-n64{margin-top:-64px!important}.mr-n64,.mx-n64{margin-right:-64px!important}.mb-n64,.my-n64{margin-bottom:-64px!important}.ml-n64,.mx-n64{margin-left:-64px!important}.m-auto{margin:auto!important}.mt-auto,.my-auto{margin-top:auto!important}.mr-auto,.mx-auto{margin-right:auto!important}.mb-auto,.my-auto{margin-bottom:auto!important}.ml-auto,.mx-auto{margin-left:auto!important}.stretched-link::after{position:absolute;top:0;right:0;bottom:0;left:0;z-index:1;pointer-events:auto;content:\"\";background-color:rgba(0,0,0,0)}.text-monospace{font-family:SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace!important}.text-justify{text-align:justify!important}.text-wrap{white-space:normal!important}.text-nowrap{white-space:nowrap!important}.text-truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.text-left{text-align:left!important}.text-right{text-align:right!important}.text-center{text-align:center!important}@media (min-width:576px){.flex-sm-row{flex-direction:row!important}.flex-sm-column{flex-direction:column!important}.flex-sm-row-reverse{flex-direction:row-reverse!important}.flex-sm-column-reverse{flex-direction:column-reverse!important}.flex-sm-wrap{flex-wrap:wrap!important}.flex-sm-nowrap{flex-wrap:nowrap!important}.flex-sm-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-sm-fill{flex:1 1 auto!important}.flex-sm-grow-0{flex-grow:0!important}.flex-sm-grow-1{flex-grow:1!important}.flex-sm-shrink-0{flex-shrink:0!important}.flex-sm-shrink-1{flex-shrink:1!important}.justify-content-sm-start{justify-content:flex-start!important}.justify-content-sm-end{justify-content:flex-end!important}.justify-content-sm-center{justify-content:center!important}.justify-content-sm-between{justify-content:space-between!important}.justify-content-sm-around{justify-content:space-around!important}.align-items-sm-start{align-items:flex-start!important}.align-items-sm-end{align-items:flex-end!important}.align-items-sm-center{align-items:center!important}.align-items-sm-baseline{align-items:baseline!important}.align-items-sm-stretch{align-items:stretch!important}.align-content-sm-start{align-content:flex-start!important}.align-content-sm-end{align-content:flex-end!important}.align-content-sm-center{align-content:center!important}.align-content-sm-between{align-content:space-between!important}.align-content-sm-around{align-content:space-around!important}.align-content-sm-stretch{align-content:stretch!important}.align-self-sm-auto{align-self:auto!important}.align-self-sm-start{align-self:flex-start!important}.align-self-sm-end{align-self:flex-end!important}.align-self-sm-center{align-self:center!important}.align-self-sm-baseline{align-self:baseline!important}.align-self-sm-stretch{align-self:stretch!important}.float-sm-left{float:left!important}.float-sm-right{float:right!important}.float-sm-none{float:none!important}.m-sm-0{margin:0!important}.mt-sm-0,.my-sm-0{margin-top:0!important}.mr-sm-0,.mx-sm-0{margin-right:0!important}.mb-sm-0,.my-sm-0{margin-bottom:0!important}.ml-sm-0,.mx-sm-0{margin-left:0!important}.m-sm-1{margin:1px!important}.mt-sm-1,.my-sm-1{margin-top:1px!important}.mr-sm-1,.mx-sm-1{margin-right:1px!important}.mb-sm-1,.my-sm-1{margin-bottom:1px!important}.ml-sm-1,.mx-sm-1{margin-left:1px!important}.m-sm-2{margin:2px!important}.mt-sm-2,.my-sm-2{margin-top:2px!important}.mr-sm-2,.mx-sm-2{margin-right:2px!important}.mb-sm-2,.my-sm-2{margin-bottom:2px!important}.ml-sm-2,.mx-sm-2{margin-left:2px!important}.m-sm-3{margin:3px!important}.mt-sm-3,.my-sm-3{margin-top:3px!important}.mr-sm-3,.mx-sm-3{margin-right:3px!important}.mb-sm-3,.my-sm-3{margin-bottom:3px!important}.ml-sm-3,.mx-sm-3{margin-left:3px!important}.m-sm-4{margin:4px!important}.mt-sm-4,.my-sm-4{margin-top:4px!important}.mr-sm-4,.mx-sm-4{margin-right:4px!important}.mb-sm-4,.my-sm-4{margin-bottom:4px!important}.ml-sm-4,.mx-sm-4{margin-left:4px!important}.m-sm-5{margin:5px!important}.mt-sm-5,.my-sm-5{margin-top:5px!important}.mr-sm-5,.mx-sm-5{margin-right:5px!important}.mb-sm-5,.my-sm-5{margin-bottom:5px!important}.ml-sm-5,.mx-sm-5{margin-left:5px!important}.m-sm-6{margin:6px!important}.mt-sm-6,.my-sm-6{margin-top:6px!important}.mr-sm-6,.mx-sm-6{margin-right:6px!important}.mb-sm-6,.my-sm-6{margin-bottom:6px!important}.ml-sm-6,.mx-sm-6{margin-left:6px!important}.m-sm-7{margin:7px!important}.mt-sm-7,.my-sm-7{margin-top:7px!important}.mr-sm-7,.mx-sm-7{margin-right:7px!important}.mb-sm-7,.my-sm-7{margin-bottom:7px!important}.ml-sm-7,.mx-sm-7{margin-left:7px!important}.m-sm-8{margin:8px!important}.mt-sm-8,.my-sm-8{margin-top:8px!important}.mr-sm-8,.mx-sm-8{margin-right:8px!important}.mb-sm-8,.my-sm-8{margin-bottom:8px!important}.ml-sm-8,.mx-sm-8{margin-left:8px!important}.m-sm-9{margin:9px!important}.mt-sm-9,.my-sm-9{margin-top:9px!important}.mr-sm-9,.mx-sm-9{margin-right:9px!important}.mb-sm-9,.my-sm-9{margin-bottom:9px!important}.ml-sm-9,.mx-sm-9{margin-left:9px!important}.m-sm-10{margin:10px!important}.mt-sm-10,.my-sm-10{margin-top:10px!important}.mr-sm-10,.mx-sm-10{margin-right:10px!important}.mb-sm-10,.my-sm-10{margin-bottom:10px!important}.ml-sm-10,.mx-sm-10{margin-left:10px!important}.m-sm-11{margin:11px!important}.mt-sm-11,.my-sm-11{margin-top:11px!important}.mr-sm-11,.mx-sm-11{margin-right:11px!important}.mb-sm-11,.my-sm-11{margin-bottom:11px!important}.ml-sm-11,.mx-sm-11{margin-left:11px!important}.m-sm-12{margin:12px!important}.mt-sm-12,.my-sm-12{margin-top:12px!important}.mr-sm-12,.mx-sm-12{margin-right:12px!important}.mb-sm-12,.my-sm-12{margin-bottom:12px!important}.ml-sm-12,.mx-sm-12{margin-left:12px!important}.m-sm-13{margin:13px!important}.mt-sm-13,.my-sm-13{margin-top:13px!important}.mr-sm-13,.mx-sm-13{margin-right:13px!important}.mb-sm-13,.my-sm-13{margin-bottom:13px!important}.ml-sm-13,.mx-sm-13{margin-left:13px!important}.m-sm-14{margin:14px!important}.mt-sm-14,.my-sm-14{margin-top:14px!important}.mr-sm-14,.mx-sm-14{margin-right:14px!important}.mb-sm-14,.my-sm-14{margin-bottom:14px!important}.ml-sm-14,.mx-sm-14{margin-left:14px!important}.m-sm-15{margin:15px!important}.mt-sm-15,.my-sm-15{margin-top:15px!important}.mr-sm-15,.mx-sm-15{margin-right:15px!important}.mb-sm-15,.my-sm-15{margin-bottom:15px!important}.ml-sm-15,.mx-sm-15{margin-left:15px!important}.m-sm-16{margin:16px!important}.mt-sm-16,.my-sm-16{margin-top:16px!important}.mr-sm-16,.mx-sm-16{margin-right:16px!important}.mb-sm-16,.my-sm-16{margin-bottom:16px!important}.ml-sm-16,.mx-sm-16{margin-left:16px!important}.m-sm-18{margin:18px!important}.mt-sm-18,.my-sm-18{margin-top:18px!important}.mr-sm-18,.mx-sm-18{margin-right:18px!important}.mb-sm-18,.my-sm-18{margin-bottom:18px!important}.ml-sm-18,.mx-sm-18{margin-left:18px!important}.m-sm-20{margin:20px!important}.mt-sm-20,.my-sm-20{margin-top:20px!important}.mr-sm-20,.mx-sm-20{margin-right:20px!important}.mb-sm-20,.my-sm-20{margin-bottom:20px!important}.ml-sm-20,.mx-sm-20{margin-left:20px!important}.m-sm-21{margin:21px!important}.mt-sm-21,.my-sm-21{margin-top:21px!important}.mr-sm-21,.mx-sm-21{margin-right:21px!important}.mb-sm-21,.my-sm-21{margin-bottom:21px!important}.ml-sm-21,.mx-sm-21{margin-left:21px!important}.m-sm-23{margin:23px!important}.mt-sm-23,.my-sm-23{margin-top:23px!important}.mr-sm-23,.mx-sm-23{margin-right:23px!important}.mb-sm-23,.my-sm-23{margin-bottom:23px!important}.ml-sm-23,.mx-sm-23{margin-left:23px!important}.m-sm-24{margin:24px!important}.mt-sm-24,.my-sm-24{margin-top:24px!important}.mr-sm-24,.mx-sm-24{margin-right:24px!important}.mb-sm-24,.my-sm-24{margin-bottom:24px!important}.ml-sm-24,.mx-sm-24{margin-left:24px!important}.m-sm-26{margin:26px!important}.mt-sm-26,.my-sm-26{margin-top:26px!important}.mr-sm-26,.mx-sm-26{margin-right:26px!important}.mb-sm-26,.my-sm-26{margin-bottom:26px!important}.ml-sm-26,.mx-sm-26{margin-left:26px!important}.m-sm-28{margin:28px!important}.mt-sm-28,.my-sm-28{margin-top:28px!important}.mr-sm-28,.mx-sm-28{margin-right:28px!important}.mb-sm-28,.my-sm-28{margin-bottom:28px!important}.ml-sm-28,.mx-sm-28{margin-left:28px!important}.m-sm-29{margin:29px!important}.mt-sm-29,.my-sm-29{margin-top:29px!important}.mr-sm-29,.mx-sm-29{margin-right:29px!important}.mb-sm-29,.my-sm-29{margin-bottom:29px!important}.ml-sm-29,.mx-sm-29{margin-left:29px!important}.m-sm-30{margin:30px!important}.mt-sm-30,.my-sm-30{margin-top:30px!important}.mr-sm-30,.mx-sm-30{margin-right:30px!important}.mb-sm-30,.my-sm-30{margin-bottom:30px!important}.ml-sm-30,.mx-sm-30{margin-left:30px!important}.m-sm-32{margin:32px!important}.mt-sm-32,.my-sm-32{margin-top:32px!important}.mr-sm-32,.mx-sm-32{margin-right:32px!important}.mb-sm-32,.my-sm-32{margin-bottom:32px!important}.ml-sm-32,.mx-sm-32{margin-left:32px!important}.m-sm-38{margin:38px!important}.mt-sm-38,.my-sm-38{margin-top:38px!important}.mr-sm-38,.mx-sm-38{margin-right:38px!important}.mb-sm-38,.my-sm-38{margin-bottom:38px!important}.ml-sm-38,.mx-sm-38{margin-left:38px!important}.m-sm-40{margin:40px!important}.mt-sm-40,.my-sm-40{margin-top:40px!important}.mr-sm-40,.mx-sm-40{margin-right:40px!important}.mb-sm-40,.my-sm-40{margin-bottom:40px!important}.ml-sm-40,.mx-sm-40{margin-left:40px!important}.m-sm-42{margin:42px!important}.mt-sm-42,.my-sm-42{margin-top:42px!important}.mr-sm-42,.mx-sm-42{margin-right:42px!important}.mb-sm-42,.my-sm-42{margin-bottom:42px!important}.ml-sm-42,.mx-sm-42{margin-left:42px!important}.m-sm-48{margin:48px!important}.mt-sm-48,.my-sm-48{margin-top:48px!important}.mr-sm-48,.mx-sm-48{margin-right:48px!important}.mb-sm-48,.my-sm-48{margin-bottom:48px!important}.ml-sm-48,.mx-sm-48{margin-left:48px!important}.m-sm-50{margin:50px!important}.mt-sm-50,.my-sm-50{margin-top:50px!important}.mr-sm-50,.mx-sm-50{margin-right:50px!important}.mb-sm-50,.my-sm-50{margin-bottom:50px!important}.ml-sm-50,.mx-sm-50{margin-left:50px!important}.m-sm-56{margin:56px!important}.mt-sm-56,.my-sm-56{margin-top:56px!important}.mr-sm-56,.mx-sm-56{margin-right:56px!important}.mb-sm-56,.my-sm-56{margin-bottom:56px!important}.ml-sm-56,.mx-sm-56{margin-left:56px!important}.m-sm-58{margin:58px!important}.mt-sm-58,.my-sm-58{margin-top:58px!important}.mr-sm-58,.mx-sm-58{margin-right:58px!important}.mb-sm-58,.my-sm-58{margin-bottom:58px!important}.ml-sm-58,.mx-sm-58{margin-left:58px!important}.m-sm-60{margin:60px!important}.mt-sm-60,.my-sm-60{margin-top:60px!important}.mr-sm-60,.mx-sm-60{margin-right:60px!important}.mb-sm-60,.my-sm-60{margin-bottom:60px!important}.ml-sm-60,.mx-sm-60{margin-left:60px!important}.m-sm-64{margin:64px!important}.mt-sm-64,.my-sm-64{margin-top:64px!important}.mr-sm-64,.mx-sm-64{margin-right:64px!important}.mb-sm-64,.my-sm-64{margin-bottom:64px!important}.ml-sm-64,.mx-sm-64{margin-left:64px!important}.p-sm-0{padding:0!important}.pt-sm-0,.py-sm-0{padding-top:0!important}.pr-sm-0,.px-sm-0{padding-right:0!important}.pb-sm-0,.py-sm-0{padding-bottom:0!important}.pl-sm-0,.px-sm-0{padding-left:0!important}.p-sm-1{padding:1px!important}.pt-sm-1,.py-sm-1{padding-top:1px!important}.pr-sm-1,.px-sm-1{padding-right:1px!important}.pb-sm-1,.py-sm-1{padding-bottom:1px!important}.pl-sm-1,.px-sm-1{padding-left:1px!important}.p-sm-2{padding:2px!important}.pt-sm-2,.py-sm-2{padding-top:2px!important}.pr-sm-2,.px-sm-2{padding-right:2px!important}.pb-sm-2,.py-sm-2{padding-bottom:2px!important}.pl-sm-2,.px-sm-2{padding-left:2px!important}.p-sm-3{padding:3px!important}.pt-sm-3,.py-sm-3{padding-top:3px!important}.pr-sm-3,.px-sm-3{padding-right:3px!important}.pb-sm-3,.py-sm-3{padding-bottom:3px!important}.pl-sm-3,.px-sm-3{padding-left:3px!important}.p-sm-4{padding:4px!important}.pt-sm-4,.py-sm-4{padding-top:4px!important}.pr-sm-4,.px-sm-4{padding-right:4px!important}.pb-sm-4,.py-sm-4{padding-bottom:4px!important}.pl-sm-4,.px-sm-4{padding-left:4px!important}.p-sm-5{padding:5px!important}.pt-sm-5,.py-sm-5{padding-top:5px!important}.pr-sm-5,.px-sm-5{padding-right:5px!important}.pb-sm-5,.py-sm-5{padding-bottom:5px!important}.pl-sm-5,.px-sm-5{padding-left:5px!important}.p-sm-6{padding:6px!important}.pt-sm-6,.py-sm-6{padding-top:6px!important}.pr-sm-6,.px-sm-6{padding-right:6px!important}.pb-sm-6,.py-sm-6{padding-bottom:6px!important}.pl-sm-6,.px-sm-6{padding-left:6px!important}.p-sm-7{padding:7px!important}.pt-sm-7,.py-sm-7{padding-top:7px!important}.pr-sm-7,.px-sm-7{padding-right:7px!important}.pb-sm-7,.py-sm-7{padding-bottom:7px!important}.pl-sm-7,.px-sm-7{padding-left:7px!important}.p-sm-8{padding:8px!important}.pt-sm-8,.py-sm-8{padding-top:8px!important}.pr-sm-8,.px-sm-8{padding-right:8px!important}.pb-sm-8,.py-sm-8{padding-bottom:8px!important}.pl-sm-8,.px-sm-8{padding-left:8px!important}.p-sm-9{padding:9px!important}.pt-sm-9,.py-sm-9{padding-top:9px!important}.pr-sm-9,.px-sm-9{padding-right:9px!important}.pb-sm-9,.py-sm-9{padding-bottom:9px!important}.pl-sm-9,.px-sm-9{padding-left:9px!important}.p-sm-10{padding:10px!important}.pt-sm-10,.py-sm-10{padding-top:10px!important}.pr-sm-10,.px-sm-10{padding-right:10px!important}.pb-sm-10,.py-sm-10{padding-bottom:10px!important}.pl-sm-10,.px-sm-10{padding-left:10px!important}.p-sm-11{padding:11px!important}.pt-sm-11,.py-sm-11{padding-top:11px!important}.pr-sm-11,.px-sm-11{padding-right:11px!important}.pb-sm-11,.py-sm-11{padding-bottom:11px!important}.pl-sm-11,.px-sm-11{padding-left:11px!important}.p-sm-12{padding:12px!important}.pt-sm-12,.py-sm-12{padding-top:12px!important}.pr-sm-12,.px-sm-12{padding-right:12px!important}.pb-sm-12,.py-sm-12{padding-bottom:12px!important}.pl-sm-12,.px-sm-12{padding-left:12px!important}.p-sm-13{padding:13px!important}.pt-sm-13,.py-sm-13{padding-top:13px!important}.pr-sm-13,.px-sm-13{padding-right:13px!important}.pb-sm-13,.py-sm-13{padding-bottom:13px!important}.pl-sm-13,.px-sm-13{padding-left:13px!important}.p-sm-14{padding:14px!important}.pt-sm-14,.py-sm-14{padding-top:14px!important}.pr-sm-14,.px-sm-14{padding-right:14px!important}.pb-sm-14,.py-sm-14{padding-bottom:14px!important}.pl-sm-14,.px-sm-14{padding-left:14px!important}.p-sm-15{padding:15px!important}.pt-sm-15,.py-sm-15{padding-top:15px!important}.pr-sm-15,.px-sm-15{padding-right:15px!important}.pb-sm-15,.py-sm-15{padding-bottom:15px!important}.pl-sm-15,.px-sm-15{padding-left:15px!important}.p-sm-16{padding:16px!important}.pt-sm-16,.py-sm-16{padding-top:16px!important}.pr-sm-16,.px-sm-16{padding-right:16px!important}.pb-sm-16,.py-sm-16{padding-bottom:16px!important}.pl-sm-16,.px-sm-16{padding-left:16px!important}.p-sm-18{padding:18px!important}.pt-sm-18,.py-sm-18{padding-top:18px!important}.pr-sm-18,.px-sm-18{padding-right:18px!important}.pb-sm-18,.py-sm-18{padding-bottom:18px!important}.pl-sm-18,.px-sm-18{padding-left:18px!important}.p-sm-20{padding:20px!important}.pt-sm-20,.py-sm-20{padding-top:20px!important}.pr-sm-20,.px-sm-20{padding-right:20px!important}.pb-sm-20,.py-sm-20{padding-bottom:20px!important}.pl-sm-20,.px-sm-20{padding-left:20px!important}.p-sm-21{padding:21px!important}.pt-sm-21,.py-sm-21{padding-top:21px!important}.pr-sm-21,.px-sm-21{padding-right:21px!important}.pb-sm-21,.py-sm-21{padding-bottom:21px!important}.pl-sm-21,.px-sm-21{padding-left:21px!important}.p-sm-23{padding:23px!important}.pt-sm-23,.py-sm-23{padding-top:23px!important}.pr-sm-23,.px-sm-23{padding-right:23px!important}.pb-sm-23,.py-sm-23{padding-bottom:23px!important}.pl-sm-23,.px-sm-23{padding-left:23px!important}.p-sm-24{padding:24px!important}.pt-sm-24,.py-sm-24{padding-top:24px!important}.pr-sm-24,.px-sm-24{padding-right:24px!important}.pb-sm-24,.py-sm-24{padding-bottom:24px!important}.pl-sm-24,.px-sm-24{padding-left:24px!important}.p-sm-26{padding:26px!important}.pt-sm-26,.py-sm-26{padding-top:26px!important}.pr-sm-26,.px-sm-26{padding-right:26px!important}.pb-sm-26,.py-sm-26{padding-bottom:26px!important}.pl-sm-26,.px-sm-26{padding-left:26px!important}.p-sm-28{padding:28px!important}.pt-sm-28,.py-sm-28{padding-top:28px!important}.pr-sm-28,.px-sm-28{padding-right:28px!important}.pb-sm-28,.py-sm-28{padding-bottom:28px!important}.pl-sm-28,.px-sm-28{padding-left:28px!important}.p-sm-29{padding:29px!important}.pt-sm-29,.py-sm-29{padding-top:29px!important}.pr-sm-29,.px-sm-29{padding-right:29px!important}.pb-sm-29,.py-sm-29{padding-bottom:29px!important}.pl-sm-29,.px-sm-29{padding-left:29px!important}.p-sm-30{padding:30px!important}.pt-sm-30,.py-sm-30{padding-top:30px!important}.pr-sm-30,.px-sm-30{padding-right:30px!important}.pb-sm-30,.py-sm-30{padding-bottom:30px!important}.pl-sm-30,.px-sm-30{padding-left:30px!important}.p-sm-32{padding:32px!important}.pt-sm-32,.py-sm-32{padding-top:32px!important}.pr-sm-32,.px-sm-32{padding-right:32px!important}.pb-sm-32,.py-sm-32{padding-bottom:32px!important}.pl-sm-32,.px-sm-32{padding-left:32px!important}.p-sm-38{padding:38px!important}.pt-sm-38,.py-sm-38{padding-top:38px!important}.pr-sm-38,.px-sm-38{padding-right:38px!important}.pb-sm-38,.py-sm-38{padding-bottom:38px!important}.pl-sm-38,.px-sm-38{padding-left:38px!important}.p-sm-40{padding:40px!important}.pt-sm-40,.py-sm-40{padding-top:40px!important}.pr-sm-40,.px-sm-40{padding-right:40px!important}.pb-sm-40,.py-sm-40{padding-bottom:40px!important}.pl-sm-40,.px-sm-40{padding-left:40px!important}.p-sm-42{padding:42px!important}.pt-sm-42,.py-sm-42{padding-top:42px!important}.pr-sm-42,.px-sm-42{padding-right:42px!important}.pb-sm-42,.py-sm-42{padding-bottom:42px!important}.pl-sm-42,.px-sm-42{padding-left:42px!important}.p-sm-48{padding:48px!important}.pt-sm-48,.py-sm-48{padding-top:48px!important}.pr-sm-48,.px-sm-48{padding-right:48px!important}.pb-sm-48,.py-sm-48{padding-bottom:48px!important}.pl-sm-48,.px-sm-48{padding-left:48px!important}.p-sm-50{padding:50px!important}.pt-sm-50,.py-sm-50{padding-top:50px!important}.pr-sm-50,.px-sm-50{padding-right:50px!important}.pb-sm-50,.py-sm-50{padding-bottom:50px!important}.pl-sm-50,.px-sm-50{padding-left:50px!important}.p-sm-56{padding:56px!important}.pt-sm-56,.py-sm-56{padding-top:56px!important}.pr-sm-56,.px-sm-56{padding-right:56px!important}.pb-sm-56,.py-sm-56{padding-bottom:56px!important}.pl-sm-56,.px-sm-56{padding-left:56px!important}.p-sm-58{padding:58px!important}.pt-sm-58,.py-sm-58{padding-top:58px!important}.pr-sm-58,.px-sm-58{padding-right:58px!important}.pb-sm-58,.py-sm-58{padding-bottom:58px!important}.pl-sm-58,.px-sm-58{padding-left:58px!important}.p-sm-60{padding:60px!important}.pt-sm-60,.py-sm-60{padding-top:60px!important}.pr-sm-60,.px-sm-60{padding-right:60px!important}.pb-sm-60,.py-sm-60{padding-bottom:60px!important}.pl-sm-60,.px-sm-60{padding-left:60px!important}.p-sm-64{padding:64px!important}.pt-sm-64,.py-sm-64{padding-top:64px!important}.pr-sm-64,.px-sm-64{padding-right:64px!important}.pb-sm-64,.py-sm-64{padding-bottom:64px!important}.pl-sm-64,.px-sm-64{padding-left:64px!important}.m-sm-n1{margin:-1px!important}.mt-sm-n1,.my-sm-n1{margin-top:-1px!important}.mr-sm-n1,.mx-sm-n1{margin-right:-1px!important}.mb-sm-n1,.my-sm-n1{margin-bottom:-1px!important}.ml-sm-n1,.mx-sm-n1{margin-left:-1px!important}.m-sm-n2{margin:-2px!important}.mt-sm-n2,.my-sm-n2{margin-top:-2px!important}.mr-sm-n2,.mx-sm-n2{margin-right:-2px!important}.mb-sm-n2,.my-sm-n2{margin-bottom:-2px!important}.ml-sm-n2,.mx-sm-n2{margin-left:-2px!important}.m-sm-n3{margin:-3px!important}.mt-sm-n3,.my-sm-n3{margin-top:-3px!important}.mr-sm-n3,.mx-sm-n3{margin-right:-3px!important}.mb-sm-n3,.my-sm-n3{margin-bottom:-3px!important}.ml-sm-n3,.mx-sm-n3{margin-left:-3px!important}.m-sm-n4{margin:-4px!important}.mt-sm-n4,.my-sm-n4{margin-top:-4px!important}.mr-sm-n4,.mx-sm-n4{margin-right:-4px!important}.mb-sm-n4,.my-sm-n4{margin-bottom:-4px!important}.ml-sm-n4,.mx-sm-n4{margin-left:-4px!important}.m-sm-n5{margin:-5px!important}.mt-sm-n5,.my-sm-n5{margin-top:-5px!important}.mr-sm-n5,.mx-sm-n5{margin-right:-5px!important}.mb-sm-n5,.my-sm-n5{margin-bottom:-5px!important}.ml-sm-n5,.mx-sm-n5{margin-left:-5px!important}.m-sm-n6{margin:-6px!important}.mt-sm-n6,.my-sm-n6{margin-top:-6px!important}.mr-sm-n6,.mx-sm-n6{margin-right:-6px!important}.mb-sm-n6,.my-sm-n6{margin-bottom:-6px!important}.ml-sm-n6,.mx-sm-n6{margin-left:-6px!important}.m-sm-n7{margin:-7px!important}.mt-sm-n7,.my-sm-n7{margin-top:-7px!important}.mr-sm-n7,.mx-sm-n7{margin-right:-7px!important}.mb-sm-n7,.my-sm-n7{margin-bottom:-7px!important}.ml-sm-n7,.mx-sm-n7{margin-left:-7px!important}.m-sm-n8{margin:-8px!important}.mt-sm-n8,.my-sm-n8{margin-top:-8px!important}.mr-sm-n8,.mx-sm-n8{margin-right:-8px!important}.mb-sm-n8,.my-sm-n8{margin-bottom:-8px!important}.ml-sm-n8,.mx-sm-n8{margin-left:-8px!important}.m-sm-n9{margin:-9px!important}.mt-sm-n9,.my-sm-n9{margin-top:-9px!important}.mr-sm-n9,.mx-sm-n9{margin-right:-9px!important}.mb-sm-n9,.my-sm-n9{margin-bottom:-9px!important}.ml-sm-n9,.mx-sm-n9{margin-left:-9px!important}.m-sm-n10{margin:-10px!important}.mt-sm-n10,.my-sm-n10{margin-top:-10px!important}.mr-sm-n10,.mx-sm-n10{margin-right:-10px!important}.mb-sm-n10,.my-sm-n10{margin-bottom:-10px!important}.ml-sm-n10,.mx-sm-n10{margin-left:-10px!important}.m-sm-n11{margin:-11px!important}.mt-sm-n11,.my-sm-n11{margin-top:-11px!important}.mr-sm-n11,.mx-sm-n11{margin-right:-11px!important}.mb-sm-n11,.my-sm-n11{margin-bottom:-11px!important}.ml-sm-n11,.mx-sm-n11{margin-left:-11px!important}.m-sm-n12{margin:-12px!important}.mt-sm-n12,.my-sm-n12{margin-top:-12px!important}.mr-sm-n12,.mx-sm-n12{margin-right:-12px!important}.mb-sm-n12,.my-sm-n12{margin-bottom:-12px!important}.ml-sm-n12,.mx-sm-n12{margin-left:-12px!important}.m-sm-n13{margin:-13px!important}.mt-sm-n13,.my-sm-n13{margin-top:-13px!important}.mr-sm-n13,.mx-sm-n13{margin-right:-13px!important}.mb-sm-n13,.my-sm-n13{margin-bottom:-13px!important}.ml-sm-n13,.mx-sm-n13{margin-left:-13px!important}.m-sm-n14{margin:-14px!important}.mt-sm-n14,.my-sm-n14{margin-top:-14px!important}.mr-sm-n14,.mx-sm-n14{margin-right:-14px!important}.mb-sm-n14,.my-sm-n14{margin-bottom:-14px!important}.ml-sm-n14,.mx-sm-n14{margin-left:-14px!important}.m-sm-n15{margin:-15px!important}.mt-sm-n15,.my-sm-n15{margin-top:-15px!important}.mr-sm-n15,.mx-sm-n15{margin-right:-15px!important}.mb-sm-n15,.my-sm-n15{margin-bottom:-15px!important}.ml-sm-n15,.mx-sm-n15{margin-left:-15px!important}.m-sm-n16{margin:-16px!important}.mt-sm-n16,.my-sm-n16{margin-top:-16px!important}.mr-sm-n16,.mx-sm-n16{margin-right:-16px!important}.mb-sm-n16,.my-sm-n16{margin-bottom:-16px!important}.ml-sm-n16,.mx-sm-n16{margin-left:-16px!important}.m-sm-n18{margin:-18px!important}.mt-sm-n18,.my-sm-n18{margin-top:-18px!important}.mr-sm-n18,.mx-sm-n18{margin-right:-18px!important}.mb-sm-n18,.my-sm-n18{margin-bottom:-18px!important}.ml-sm-n18,.mx-sm-n18{margin-left:-18px!important}.m-sm-n20{margin:-20px!important}.mt-sm-n20,.my-sm-n20{margin-top:-20px!important}.mr-sm-n20,.mx-sm-n20{margin-right:-20px!important}.mb-sm-n20,.my-sm-n20{margin-bottom:-20px!important}.ml-sm-n20,.mx-sm-n20{margin-left:-20px!important}.m-sm-n21{margin:-21px!important}.mt-sm-n21,.my-sm-n21{margin-top:-21px!important}.mr-sm-n21,.mx-sm-n21{margin-right:-21px!important}.mb-sm-n21,.my-sm-n21{margin-bottom:-21px!important}.ml-sm-n21,.mx-sm-n21{margin-left:-21px!important}.m-sm-n23{margin:-23px!important}.mt-sm-n23,.my-sm-n23{margin-top:-23px!important}.mr-sm-n23,.mx-sm-n23{margin-right:-23px!important}.mb-sm-n23,.my-sm-n23{margin-bottom:-23px!important}.ml-sm-n23,.mx-sm-n23{margin-left:-23px!important}.m-sm-n24{margin:-24px!important}.mt-sm-n24,.my-sm-n24{margin-top:-24px!important}.mr-sm-n24,.mx-sm-n24{margin-right:-24px!important}.mb-sm-n24,.my-sm-n24{margin-bottom:-24px!important}.ml-sm-n24,.mx-sm-n24{margin-left:-24px!important}.m-sm-n26{margin:-26px!important}.mt-sm-n26,.my-sm-n26{margin-top:-26px!important}.mr-sm-n26,.mx-sm-n26{margin-right:-26px!important}.mb-sm-n26,.my-sm-n26{margin-bottom:-26px!important}.ml-sm-n26,.mx-sm-n26{margin-left:-26px!important}.m-sm-n28{margin:-28px!important}.mt-sm-n28,.my-sm-n28{margin-top:-28px!important}.mr-sm-n28,.mx-sm-n28{margin-right:-28px!important}.mb-sm-n28,.my-sm-n28{margin-bottom:-28px!important}.ml-sm-n28,.mx-sm-n28{margin-left:-28px!important}.m-sm-n29{margin:-29px!important}.mt-sm-n29,.my-sm-n29{margin-top:-29px!important}.mr-sm-n29,.mx-sm-n29{margin-right:-29px!important}.mb-sm-n29,.my-sm-n29{margin-bottom:-29px!important}.ml-sm-n29,.mx-sm-n29{margin-left:-29px!important}.m-sm-n30{margin:-30px!important}.mt-sm-n30,.my-sm-n30{margin-top:-30px!important}.mr-sm-n30,.mx-sm-n30{margin-right:-30px!important}.mb-sm-n30,.my-sm-n30{margin-bottom:-30px!important}.ml-sm-n30,.mx-sm-n30{margin-left:-30px!important}.m-sm-n32{margin:-32px!important}.mt-sm-n32,.my-sm-n32{margin-top:-32px!important}.mr-sm-n32,.mx-sm-n32{margin-right:-32px!important}.mb-sm-n32,.my-sm-n32{margin-bottom:-32px!important}.ml-sm-n32,.mx-sm-n32{margin-left:-32px!important}.m-sm-n38{margin:-38px!important}.mt-sm-n38,.my-sm-n38{margin-top:-38px!important}.mr-sm-n38,.mx-sm-n38{margin-right:-38px!important}.mb-sm-n38,.my-sm-n38{margin-bottom:-38px!important}.ml-sm-n38,.mx-sm-n38{margin-left:-38px!important}.m-sm-n40{margin:-40px!important}.mt-sm-n40,.my-sm-n40{margin-top:-40px!important}.mr-sm-n40,.mx-sm-n40{margin-right:-40px!important}.mb-sm-n40,.my-sm-n40{margin-bottom:-40px!important}.ml-sm-n40,.mx-sm-n40{margin-left:-40px!important}.m-sm-n42{margin:-42px!important}.mt-sm-n42,.my-sm-n42{margin-top:-42px!important}.mr-sm-n42,.mx-sm-n42{margin-right:-42px!important}.mb-sm-n42,.my-sm-n42{margin-bottom:-42px!important}.ml-sm-n42,.mx-sm-n42{margin-left:-42px!important}.m-sm-n48{margin:-48px!important}.mt-sm-n48,.my-sm-n48{margin-top:-48px!important}.mr-sm-n48,.mx-sm-n48{margin-right:-48px!important}.mb-sm-n48,.my-sm-n48{margin-bottom:-48px!important}.ml-sm-n48,.mx-sm-n48{margin-left:-48px!important}.m-sm-n50{margin:-50px!important}.mt-sm-n50,.my-sm-n50{margin-top:-50px!important}.mr-sm-n50,.mx-sm-n50{margin-right:-50px!important}.mb-sm-n50,.my-sm-n50{margin-bottom:-50px!important}.ml-sm-n50,.mx-sm-n50{margin-left:-50px!important}.m-sm-n56{margin:-56px!important}.mt-sm-n56,.my-sm-n56{margin-top:-56px!important}.mr-sm-n56,.mx-sm-n56{margin-right:-56px!important}.mb-sm-n56,.my-sm-n56{margin-bottom:-56px!important}.ml-sm-n56,.mx-sm-n56{margin-left:-56px!important}.m-sm-n58{margin:-58px!important}.mt-sm-n58,.my-sm-n58{margin-top:-58px!important}.mr-sm-n58,.mx-sm-n58{margin-right:-58px!important}.mb-sm-n58,.my-sm-n58{margin-bottom:-58px!important}.ml-sm-n58,.mx-sm-n58{margin-left:-58px!important}.m-sm-n60{margin:-60px!important}.mt-sm-n60,.my-sm-n60{margin-top:-60px!important}.mr-sm-n60,.mx-sm-n60{margin-right:-60px!important}.mb-sm-n60,.my-sm-n60{margin-bottom:-60px!important}.ml-sm-n60,.mx-sm-n60{margin-left:-60px!important}.m-sm-n64{margin:-64px!important}.mt-sm-n64,.my-sm-n64{margin-top:-64px!important}.mr-sm-n64,.mx-sm-n64{margin-right:-64px!important}.mb-sm-n64,.my-sm-n64{margin-bottom:-64px!important}.ml-sm-n64,.mx-sm-n64{margin-left:-64px!important}.m-sm-auto{margin:auto!important}.mt-sm-auto,.my-sm-auto{margin-top:auto!important}.mr-sm-auto,.mx-sm-auto{margin-right:auto!important}.mb-sm-auto,.my-sm-auto{margin-bottom:auto!important}.ml-sm-auto,.mx-sm-auto{margin-left:auto!important}.text-sm-left{text-align:left!important}.text-sm-right{text-align:right!important}.text-sm-center{text-align:center!important}}@media (min-width:768px){.flex-md-row{flex-direction:row!important}.flex-md-column{flex-direction:column!important}.flex-md-row-reverse{flex-direction:row-reverse!important}.flex-md-column-reverse{flex-direction:column-reverse!important}.flex-md-wrap{flex-wrap:wrap!important}.flex-md-nowrap{flex-wrap:nowrap!important}.flex-md-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-md-fill{flex:1 1 auto!important}.flex-md-grow-0{flex-grow:0!important}.flex-md-grow-1{flex-grow:1!important}.flex-md-shrink-0{flex-shrink:0!important}.flex-md-shrink-1{flex-shrink:1!important}.justify-content-md-start{justify-content:flex-start!important}.justify-content-md-end{justify-content:flex-end!important}.justify-content-md-center{justify-content:center!important}.justify-content-md-between{justify-content:space-between!important}.justify-content-md-around{justify-content:space-around!important}.align-items-md-start{align-items:flex-start!important}.align-items-md-end{align-items:flex-end!important}.align-items-md-center{align-items:center!important}.align-items-md-baseline{align-items:baseline!important}.align-items-md-stretch{align-items:stretch!important}.align-content-md-start{align-content:flex-start!important}.align-content-md-end{align-content:flex-end!important}.align-content-md-center{align-content:center!important}.align-content-md-between{align-content:space-between!important}.align-content-md-around{align-content:space-around!important}.align-content-md-stretch{align-content:stretch!important}.align-self-md-auto{align-self:auto!important}.align-self-md-start{align-self:flex-start!important}.align-self-md-end{align-self:flex-end!important}.align-self-md-center{align-self:center!important}.align-self-md-baseline{align-self:baseline!important}.align-self-md-stretch{align-self:stretch!important}.float-md-left{float:left!important}.float-md-right{float:right!important}.float-md-none{float:none!important}.m-md-0{margin:0!important}.mt-md-0,.my-md-0{margin-top:0!important}.mr-md-0,.mx-md-0{margin-right:0!important}.mb-md-0,.my-md-0{margin-bottom:0!important}.ml-md-0,.mx-md-0{margin-left:0!important}.m-md-1{margin:1px!important}.mt-md-1,.my-md-1{margin-top:1px!important}.mr-md-1,.mx-md-1{margin-right:1px!important}.mb-md-1,.my-md-1{margin-bottom:1px!important}.ml-md-1,.mx-md-1{margin-left:1px!important}.m-md-2{margin:2px!important}.mt-md-2,.my-md-2{margin-top:2px!important}.mr-md-2,.mx-md-2{margin-right:2px!important}.mb-md-2,.my-md-2{margin-bottom:2px!important}.ml-md-2,.mx-md-2{margin-left:2px!important}.m-md-3{margin:3px!important}.mt-md-3,.my-md-3{margin-top:3px!important}.mr-md-3,.mx-md-3{margin-right:3px!important}.mb-md-3,.my-md-3{margin-bottom:3px!important}.ml-md-3,.mx-md-3{margin-left:3px!important}.m-md-4{margin:4px!important}.mt-md-4,.my-md-4{margin-top:4px!important}.mr-md-4,.mx-md-4{margin-right:4px!important}.mb-md-4,.my-md-4{margin-bottom:4px!important}.ml-md-4,.mx-md-4{margin-left:4px!important}.m-md-5{margin:5px!important}.mt-md-5,.my-md-5{margin-top:5px!important}.mr-md-5,.mx-md-5{margin-right:5px!important}.mb-md-5,.my-md-5{margin-bottom:5px!important}.ml-md-5,.mx-md-5{margin-left:5px!important}.m-md-6{margin:6px!important}.mt-md-6,.my-md-6{margin-top:6px!important}.mr-md-6,.mx-md-6{margin-right:6px!important}.mb-md-6,.my-md-6{margin-bottom:6px!important}.ml-md-6,.mx-md-6{margin-left:6px!important}.m-md-7{margin:7px!important}.mt-md-7,.my-md-7{margin-top:7px!important}.mr-md-7,.mx-md-7{margin-right:7px!important}.mb-md-7,.my-md-7{margin-bottom:7px!important}.ml-md-7,.mx-md-7{margin-left:7px!important}.m-md-8{margin:8px!important}.mt-md-8,.my-md-8{margin-top:8px!important}.mr-md-8,.mx-md-8{margin-right:8px!important}.mb-md-8,.my-md-8{margin-bottom:8px!important}.ml-md-8,.mx-md-8{margin-left:8px!important}.m-md-9{margin:9px!important}.mt-md-9,.my-md-9{margin-top:9px!important}.mr-md-9,.mx-md-9{margin-right:9px!important}.mb-md-9,.my-md-9{margin-bottom:9px!important}.ml-md-9,.mx-md-9{margin-left:9px!important}.m-md-10{margin:10px!important}.mt-md-10,.my-md-10{margin-top:10px!important}.mr-md-10,.mx-md-10{margin-right:10px!important}.mb-md-10,.my-md-10{margin-bottom:10px!important}.ml-md-10,.mx-md-10{margin-left:10px!important}.m-md-11{margin:11px!important}.mt-md-11,.my-md-11{margin-top:11px!important}.mr-md-11,.mx-md-11{margin-right:11px!important}.mb-md-11,.my-md-11{margin-bottom:11px!important}.ml-md-11,.mx-md-11{margin-left:11px!important}.m-md-12{margin:12px!important}.mt-md-12,.my-md-12{margin-top:12px!important}.mr-md-12,.mx-md-12{margin-right:12px!important}.mb-md-12,.my-md-12{margin-bottom:12px!important}.ml-md-12,.mx-md-12{margin-left:12px!important}.m-md-13{margin:13px!important}.mt-md-13,.my-md-13{margin-top:13px!important}.mr-md-13,.mx-md-13{margin-right:13px!important}.mb-md-13,.my-md-13{margin-bottom:13px!important}.ml-md-13,.mx-md-13{margin-left:13px!important}.m-md-14{margin:14px!important}.mt-md-14,.my-md-14{margin-top:14px!important}.mr-md-14,.mx-md-14{margin-right:14px!important}.mb-md-14,.my-md-14{margin-bottom:14px!important}.ml-md-14,.mx-md-14{margin-left:14px!important}.m-md-15{margin:15px!important}.mt-md-15,.my-md-15{margin-top:15px!important}.mr-md-15,.mx-md-15{margin-right:15px!important}.mb-md-15,.my-md-15{margin-bottom:15px!important}.ml-md-15,.mx-md-15{margin-left:15px!important}.m-md-16{margin:16px!important}.mt-md-16,.my-md-16{margin-top:16px!important}.mr-md-16,.mx-md-16{margin-right:16px!important}.mb-md-16,.my-md-16{margin-bottom:16px!important}.ml-md-16,.mx-md-16{margin-left:16px!important}.m-md-18{margin:18px!important}.mt-md-18,.my-md-18{margin-top:18px!important}.mr-md-18,.mx-md-18{margin-right:18px!important}.mb-md-18,.my-md-18{margin-bottom:18px!important}.ml-md-18,.mx-md-18{margin-left:18px!important}.m-md-20{margin:20px!important}.mt-md-20,.my-md-20{margin-top:20px!important}.mr-md-20,.mx-md-20{margin-right:20px!important}.mb-md-20,.my-md-20{margin-bottom:20px!important}.ml-md-20,.mx-md-20{margin-left:20px!important}.m-md-21{margin:21px!important}.mt-md-21,.my-md-21{margin-top:21px!important}.mr-md-21,.mx-md-21{margin-right:21px!important}.mb-md-21,.my-md-21{margin-bottom:21px!important}.ml-md-21,.mx-md-21{margin-left:21px!important}.m-md-23{margin:23px!important}.mt-md-23,.my-md-23{margin-top:23px!important}.mr-md-23,.mx-md-23{margin-right:23px!important}.mb-md-23,.my-md-23{margin-bottom:23px!important}.ml-md-23,.mx-md-23{margin-left:23px!important}.m-md-24{margin:24px!important}.mt-md-24,.my-md-24{margin-top:24px!important}.mr-md-24,.mx-md-24{margin-right:24px!important}.mb-md-24,.my-md-24{margin-bottom:24px!important}.ml-md-24,.mx-md-24{margin-left:24px!important}.m-md-26{margin:26px!important}.mt-md-26,.my-md-26{margin-top:26px!important}.mr-md-26,.mx-md-26{margin-right:26px!important}.mb-md-26,.my-md-26{margin-bottom:26px!important}.ml-md-26,.mx-md-26{margin-left:26px!important}.m-md-28{margin:28px!important}.mt-md-28,.my-md-28{margin-top:28px!important}.mr-md-28,.mx-md-28{margin-right:28px!important}.mb-md-28,.my-md-28{margin-bottom:28px!important}.ml-md-28,.mx-md-28{margin-left:28px!important}.m-md-29{margin:29px!important}.mt-md-29,.my-md-29{margin-top:29px!important}.mr-md-29,.mx-md-29{margin-right:29px!important}.mb-md-29,.my-md-29{margin-bottom:29px!important}.ml-md-29,.mx-md-29{margin-left:29px!important}.m-md-30{margin:30px!important}.mt-md-30,.my-md-30{margin-top:30px!important}.mr-md-30,.mx-md-30{margin-right:30px!important}.mb-md-30,.my-md-30{margin-bottom:30px!important}.ml-md-30,.mx-md-30{margin-left:30px!important}.m-md-32{margin:32px!important}.mt-md-32,.my-md-32{margin-top:32px!important}.mr-md-32,.mx-md-32{margin-right:32px!important}.mb-md-32,.my-md-32{margin-bottom:32px!important}.ml-md-32,.mx-md-32{margin-left:32px!important}.m-md-38{margin:38px!important}.mt-md-38,.my-md-38{margin-top:38px!important}.mr-md-38,.mx-md-38{margin-right:38px!important}.mb-md-38,.my-md-38{margin-bottom:38px!important}.ml-md-38,.mx-md-38{margin-left:38px!important}.m-md-40{margin:40px!important}.mt-md-40,.my-md-40{margin-top:40px!important}.mr-md-40,.mx-md-40{margin-right:40px!important}.mb-md-40,.my-md-40{margin-bottom:40px!important}.ml-md-40,.mx-md-40{margin-left:40px!important}.m-md-42{margin:42px!important}.mt-md-42,.my-md-42{margin-top:42px!important}.mr-md-42,.mx-md-42{margin-right:42px!important}.mb-md-42,.my-md-42{margin-bottom:42px!important}.ml-md-42,.mx-md-42{margin-left:42px!important}.m-md-48{margin:48px!important}.mt-md-48,.my-md-48{margin-top:48px!important}.mr-md-48,.mx-md-48{margin-right:48px!important}.mb-md-48,.my-md-48{margin-bottom:48px!important}.ml-md-48,.mx-md-48{margin-left:48px!important}.m-md-50{margin:50px!important}.mt-md-50,.my-md-50{margin-top:50px!important}.mr-md-50,.mx-md-50{margin-right:50px!important}.mb-md-50,.my-md-50{margin-bottom:50px!important}.ml-md-50,.mx-md-50{margin-left:50px!important}.m-md-56{margin:56px!important}.mt-md-56,.my-md-56{margin-top:56px!important}.mr-md-56,.mx-md-56{margin-right:56px!important}.mb-md-56,.my-md-56{margin-bottom:56px!important}.ml-md-56,.mx-md-56{margin-left:56px!important}.m-md-58{margin:58px!important}.mt-md-58,.my-md-58{margin-top:58px!important}.mr-md-58,.mx-md-58{margin-right:58px!important}.mb-md-58,.my-md-58{margin-bottom:58px!important}.ml-md-58,.mx-md-58{margin-left:58px!important}.m-md-60{margin:60px!important}.mt-md-60,.my-md-60{margin-top:60px!important}.mr-md-60,.mx-md-60{margin-right:60px!important}.mb-md-60,.my-md-60{margin-bottom:60px!important}.ml-md-60,.mx-md-60{margin-left:60px!important}.m-md-64{margin:64px!important}.mt-md-64,.my-md-64{margin-top:64px!important}.mr-md-64,.mx-md-64{margin-right:64px!important}.mb-md-64,.my-md-64{margin-bottom:64px!important}.ml-md-64,.mx-md-64{margin-left:64px!important}.p-md-0{padding:0!important}.pt-md-0,.py-md-0{padding-top:0!important}.pr-md-0,.px-md-0{padding-right:0!important}.pb-md-0,.py-md-0{padding-bottom:0!important}.pl-md-0,.px-md-0{padding-left:0!important}.p-md-1{padding:1px!important}.pt-md-1,.py-md-1{padding-top:1px!important}.pr-md-1,.px-md-1{padding-right:1px!important}.pb-md-1,.py-md-1{padding-bottom:1px!important}.pl-md-1,.px-md-1{padding-left:1px!important}.p-md-2{padding:2px!important}.pt-md-2,.py-md-2{padding-top:2px!important}.pr-md-2,.px-md-2{padding-right:2px!important}.pb-md-2,.py-md-2{padding-bottom:2px!important}.pl-md-2,.px-md-2{padding-left:2px!important}.p-md-3{padding:3px!important}.pt-md-3,.py-md-3{padding-top:3px!important}.pr-md-3,.px-md-3{padding-right:3px!important}.pb-md-3,.py-md-3{padding-bottom:3px!important}.pl-md-3,.px-md-3{padding-left:3px!important}.p-md-4{padding:4px!important}.pt-md-4,.py-md-4{padding-top:4px!important}.pr-md-4,.px-md-4{padding-right:4px!important}.pb-md-4,.py-md-4{padding-bottom:4px!important}.pl-md-4,.px-md-4{padding-left:4px!important}.p-md-5{padding:5px!important}.pt-md-5,.py-md-5{padding-top:5px!important}.pr-md-5,.px-md-5{padding-right:5px!important}.pb-md-5,.py-md-5{padding-bottom:5px!important}.pl-md-5,.px-md-5{padding-left:5px!important}.p-md-6{padding:6px!important}.pt-md-6,.py-md-6{padding-top:6px!important}.pr-md-6,.px-md-6{padding-right:6px!important}.pb-md-6,.py-md-6{padding-bottom:6px!important}.pl-md-6,.px-md-6{padding-left:6px!important}.p-md-7{padding:7px!important}.pt-md-7,.py-md-7{padding-top:7px!important}.pr-md-7,.px-md-7{padding-right:7px!important}.pb-md-7,.py-md-7{padding-bottom:7px!important}.pl-md-7,.px-md-7{padding-left:7px!important}.p-md-8{padding:8px!important}.pt-md-8,.py-md-8{padding-top:8px!important}.pr-md-8,.px-md-8{padding-right:8px!important}.pb-md-8,.py-md-8{padding-bottom:8px!important}.pl-md-8,.px-md-8{padding-left:8px!important}.p-md-9{padding:9px!important}.pt-md-9,.py-md-9{padding-top:9px!important}.pr-md-9,.px-md-9{padding-right:9px!important}.pb-md-9,.py-md-9{padding-bottom:9px!important}.pl-md-9,.px-md-9{padding-left:9px!important}.p-md-10{padding:10px!important}.pt-md-10,.py-md-10{padding-top:10px!important}.pr-md-10,.px-md-10{padding-right:10px!important}.pb-md-10,.py-md-10{padding-bottom:10px!important}.pl-md-10,.px-md-10{padding-left:10px!important}.p-md-11{padding:11px!important}.pt-md-11,.py-md-11{padding-top:11px!important}.pr-md-11,.px-md-11{padding-right:11px!important}.pb-md-11,.py-md-11{padding-bottom:11px!important}.pl-md-11,.px-md-11{padding-left:11px!important}.p-md-12{padding:12px!important}.pt-md-12,.py-md-12{padding-top:12px!important}.pr-md-12,.px-md-12{padding-right:12px!important}.pb-md-12,.py-md-12{padding-bottom:12px!important}.pl-md-12,.px-md-12{padding-left:12px!important}.p-md-13{padding:13px!important}.pt-md-13,.py-md-13{padding-top:13px!important}.pr-md-13,.px-md-13{padding-right:13px!important}.pb-md-13,.py-md-13{padding-bottom:13px!important}.pl-md-13,.px-md-13{padding-left:13px!important}.p-md-14{padding:14px!important}.pt-md-14,.py-md-14{padding-top:14px!important}.pr-md-14,.px-md-14{padding-right:14px!important}.pb-md-14,.py-md-14{padding-bottom:14px!important}.pl-md-14,.px-md-14{padding-left:14px!important}.p-md-15{padding:15px!important}.pt-md-15,.py-md-15{padding-top:15px!important}.pr-md-15,.px-md-15{padding-right:15px!important}.pb-md-15,.py-md-15{padding-bottom:15px!important}.pl-md-15,.px-md-15{padding-left:15px!important}.p-md-16{padding:16px!important}.pt-md-16,.py-md-16{padding-top:16px!important}.pr-md-16,.px-md-16{padding-right:16px!important}.pb-md-16,.py-md-16{padding-bottom:16px!important}.pl-md-16,.px-md-16{padding-left:16px!important}.p-md-18{padding:18px!important}.pt-md-18,.py-md-18{padding-top:18px!important}.pr-md-18,.px-md-18{padding-right:18px!important}.pb-md-18,.py-md-18{padding-bottom:18px!important}.pl-md-18,.px-md-18{padding-left:18px!important}.p-md-20{padding:20px!important}.pt-md-20,.py-md-20{padding-top:20px!important}.pr-md-20,.px-md-20{padding-right:20px!important}.pb-md-20,.py-md-20{padding-bottom:20px!important}.pl-md-20,.px-md-20{padding-left:20px!important}.p-md-21{padding:21px!important}.pt-md-21,.py-md-21{padding-top:21px!important}.pr-md-21,.px-md-21{padding-right:21px!important}.pb-md-21,.py-md-21{padding-bottom:21px!important}.pl-md-21,.px-md-21{padding-left:21px!important}.p-md-23{padding:23px!important}.pt-md-23,.py-md-23{padding-top:23px!important}.pr-md-23,.px-md-23{padding-right:23px!important}.pb-md-23,.py-md-23{padding-bottom:23px!important}.pl-md-23,.px-md-23{padding-left:23px!important}.p-md-24{padding:24px!important}.pt-md-24,.py-md-24{padding-top:24px!important}.pr-md-24,.px-md-24{padding-right:24px!important}.pb-md-24,.py-md-24{padding-bottom:24px!important}.pl-md-24,.px-md-24{padding-left:24px!important}.p-md-26{padding:26px!important}.pt-md-26,.py-md-26{padding-top:26px!important}.pr-md-26,.px-md-26{padding-right:26px!important}.pb-md-26,.py-md-26{padding-bottom:26px!important}.pl-md-26,.px-md-26{padding-left:26px!important}.p-md-28{padding:28px!important}.pt-md-28,.py-md-28{padding-top:28px!important}.pr-md-28,.px-md-28{padding-right:28px!important}.pb-md-28,.py-md-28{padding-bottom:28px!important}.pl-md-28,.px-md-28{padding-left:28px!important}.p-md-29{padding:29px!important}.pt-md-29,.py-md-29{padding-top:29px!important}.pr-md-29,.px-md-29{padding-right:29px!important}.pb-md-29,.py-md-29{padding-bottom:29px!important}.pl-md-29,.px-md-29{padding-left:29px!important}.p-md-30{padding:30px!important}.pt-md-30,.py-md-30{padding-top:30px!important}.pr-md-30,.px-md-30{padding-right:30px!important}.pb-md-30,.py-md-30{padding-bottom:30px!important}.pl-md-30,.px-md-30{padding-left:30px!important}.p-md-32{padding:32px!important}.pt-md-32,.py-md-32{padding-top:32px!important}.pr-md-32,.px-md-32{padding-right:32px!important}.pb-md-32,.py-md-32{padding-bottom:32px!important}.pl-md-32,.px-md-32{padding-left:32px!important}.p-md-38{padding:38px!important}.pt-md-38,.py-md-38{padding-top:38px!important}.pr-md-38,.px-md-38{padding-right:38px!important}.pb-md-38,.py-md-38{padding-bottom:38px!important}.pl-md-38,.px-md-38{padding-left:38px!important}.p-md-40{padding:40px!important}.pt-md-40,.py-md-40{padding-top:40px!important}.pr-md-40,.px-md-40{padding-right:40px!important}.pb-md-40,.py-md-40{padding-bottom:40px!important}.pl-md-40,.px-md-40{padding-left:40px!important}.p-md-42{padding:42px!important}.pt-md-42,.py-md-42{padding-top:42px!important}.pr-md-42,.px-md-42{padding-right:42px!important}.pb-md-42,.py-md-42{padding-bottom:42px!important}.pl-md-42,.px-md-42{padding-left:42px!important}.p-md-48{padding:48px!important}.pt-md-48,.py-md-48{padding-top:48px!important}.pr-md-48,.px-md-48{padding-right:48px!important}.pb-md-48,.py-md-48{padding-bottom:48px!important}.pl-md-48,.px-md-48{padding-left:48px!important}.p-md-50{padding:50px!important}.pt-md-50,.py-md-50{padding-top:50px!important}.pr-md-50,.px-md-50{padding-right:50px!important}.pb-md-50,.py-md-50{padding-bottom:50px!important}.pl-md-50,.px-md-50{padding-left:50px!important}.p-md-56{padding:56px!important}.pt-md-56,.py-md-56{padding-top:56px!important}.pr-md-56,.px-md-56{padding-right:56px!important}.pb-md-56,.py-md-56{padding-bottom:56px!important}.pl-md-56,.px-md-56{padding-left:56px!important}.p-md-58{padding:58px!important}.pt-md-58,.py-md-58{padding-top:58px!important}.pr-md-58,.px-md-58{padding-right:58px!important}.pb-md-58,.py-md-58{padding-bottom:58px!important}.pl-md-58,.px-md-58{padding-left:58px!important}.p-md-60{padding:60px!important}.pt-md-60,.py-md-60{padding-top:60px!important}.pr-md-60,.px-md-60{padding-right:60px!important}.pb-md-60,.py-md-60{padding-bottom:60px!important}.pl-md-60,.px-md-60{padding-left:60px!important}.p-md-64{padding:64px!important}.pt-md-64,.py-md-64{padding-top:64px!important}.pr-md-64,.px-md-64{padding-right:64px!important}.pb-md-64,.py-md-64{padding-bottom:64px!important}.pl-md-64,.px-md-64{padding-left:64px!important}.m-md-n1{margin:-1px!important}.mt-md-n1,.my-md-n1{margin-top:-1px!important}.mr-md-n1,.mx-md-n1{margin-right:-1px!important}.mb-md-n1,.my-md-n1{margin-bottom:-1px!important}.ml-md-n1,.mx-md-n1{margin-left:-1px!important}.m-md-n2{margin:-2px!important}.mt-md-n2,.my-md-n2{margin-top:-2px!important}.mr-md-n2,.mx-md-n2{margin-right:-2px!important}.mb-md-n2,.my-md-n2{margin-bottom:-2px!important}.ml-md-n2,.mx-md-n2{margin-left:-2px!important}.m-md-n3{margin:-3px!important}.mt-md-n3,.my-md-n3{margin-top:-3px!important}.mr-md-n3,.mx-md-n3{margin-right:-3px!important}.mb-md-n3,.my-md-n3{margin-bottom:-3px!important}.ml-md-n3,.mx-md-n3{margin-left:-3px!important}.m-md-n4{margin:-4px!important}.mt-md-n4,.my-md-n4{margin-top:-4px!important}.mr-md-n4,.mx-md-n4{margin-right:-4px!important}.mb-md-n4,.my-md-n4{margin-bottom:-4px!important}.ml-md-n4,.mx-md-n4{margin-left:-4px!important}.m-md-n5{margin:-5px!important}.mt-md-n5,.my-md-n5{margin-top:-5px!important}.mr-md-n5,.mx-md-n5{margin-right:-5px!important}.mb-md-n5,.my-md-n5{margin-bottom:-5px!important}.ml-md-n5,.mx-md-n5{margin-left:-5px!important}.m-md-n6{margin:-6px!important}.mt-md-n6,.my-md-n6{margin-top:-6px!important}.mr-md-n6,.mx-md-n6{margin-right:-6px!important}.mb-md-n6,.my-md-n6{margin-bottom:-6px!important}.ml-md-n6,.mx-md-n6{margin-left:-6px!important}.m-md-n7{margin:-7px!important}.mt-md-n7,.my-md-n7{margin-top:-7px!important}.mr-md-n7,.mx-md-n7{margin-right:-7px!important}.mb-md-n7,.my-md-n7{margin-bottom:-7px!important}.ml-md-n7,.mx-md-n7{margin-left:-7px!important}.m-md-n8{margin:-8px!important}.mt-md-n8,.my-md-n8{margin-top:-8px!important}.mr-md-n8,.mx-md-n8{margin-right:-8px!important}.mb-md-n8,.my-md-n8{margin-bottom:-8px!important}.ml-md-n8,.mx-md-n8{margin-left:-8px!important}.m-md-n9{margin:-9px!important}.mt-md-n9,.my-md-n9{margin-top:-9px!important}.mr-md-n9,.mx-md-n9{margin-right:-9px!important}.mb-md-n9,.my-md-n9{margin-bottom:-9px!important}.ml-md-n9,.mx-md-n9{margin-left:-9px!important}.m-md-n10{margin:-10px!important}.mt-md-n10,.my-md-n10{margin-top:-10px!important}.mr-md-n10,.mx-md-n10{margin-right:-10px!important}.mb-md-n10,.my-md-n10{margin-bottom:-10px!important}.ml-md-n10,.mx-md-n10{margin-left:-10px!important}.m-md-n11{margin:-11px!important}.mt-md-n11,.my-md-n11{margin-top:-11px!important}.mr-md-n11,.mx-md-n11{margin-right:-11px!important}.mb-md-n11,.my-md-n11{margin-bottom:-11px!important}.ml-md-n11,.mx-md-n11{margin-left:-11px!important}.m-md-n12{margin:-12px!important}.mt-md-n12,.my-md-n12{margin-top:-12px!important}.mr-md-n12,.mx-md-n12{margin-right:-12px!important}.mb-md-n12,.my-md-n12{margin-bottom:-12px!important}.ml-md-n12,.mx-md-n12{margin-left:-12px!important}.m-md-n13{margin:-13px!important}.mt-md-n13,.my-md-n13{margin-top:-13px!important}.mr-md-n13,.mx-md-n13{margin-right:-13px!important}.mb-md-n13,.my-md-n13{margin-bottom:-13px!important}.ml-md-n13,.mx-md-n13{margin-left:-13px!important}.m-md-n14{margin:-14px!important}.mt-md-n14,.my-md-n14{margin-top:-14px!important}.mr-md-n14,.mx-md-n14{margin-right:-14px!important}.mb-md-n14,.my-md-n14{margin-bottom:-14px!important}.ml-md-n14,.mx-md-n14{margin-left:-14px!important}.m-md-n15{margin:-15px!important}.mt-md-n15,.my-md-n15{margin-top:-15px!important}.mr-md-n15,.mx-md-n15{margin-right:-15px!important}.mb-md-n15,.my-md-n15{margin-bottom:-15px!important}.ml-md-n15,.mx-md-n15{margin-left:-15px!important}.m-md-n16{margin:-16px!important}.mt-md-n16,.my-md-n16{margin-top:-16px!important}.mr-md-n16,.mx-md-n16{margin-right:-16px!important}.mb-md-n16,.my-md-n16{margin-bottom:-16px!important}.ml-md-n16,.mx-md-n16{margin-left:-16px!important}.m-md-n18{margin:-18px!important}.mt-md-n18,.my-md-n18{margin-top:-18px!important}.mr-md-n18,.mx-md-n18{margin-right:-18px!important}.mb-md-n18,.my-md-n18{margin-bottom:-18px!important}.ml-md-n18,.mx-md-n18{margin-left:-18px!important}.m-md-n20{margin:-20px!important}.mt-md-n20,.my-md-n20{margin-top:-20px!important}.mr-md-n20,.mx-md-n20{margin-right:-20px!important}.mb-md-n20,.my-md-n20{margin-bottom:-20px!important}.ml-md-n20,.mx-md-n20{margin-left:-20px!important}.m-md-n21{margin:-21px!important}.mt-md-n21,.my-md-n21{margin-top:-21px!important}.mr-md-n21,.mx-md-n21{margin-right:-21px!important}.mb-md-n21,.my-md-n21{margin-bottom:-21px!important}.ml-md-n21,.mx-md-n21{margin-left:-21px!important}.m-md-n23{margin:-23px!important}.mt-md-n23,.my-md-n23{margin-top:-23px!important}.mr-md-n23,.mx-md-n23{margin-right:-23px!important}.mb-md-n23,.my-md-n23{margin-bottom:-23px!important}.ml-md-n23,.mx-md-n23{margin-left:-23px!important}.m-md-n24{margin:-24px!important}.mt-md-n24,.my-md-n24{margin-top:-24px!important}.mr-md-n24,.mx-md-n24{margin-right:-24px!important}.mb-md-n24,.my-md-n24{margin-bottom:-24px!important}.ml-md-n24,.mx-md-n24{margin-left:-24px!important}.m-md-n26{margin:-26px!important}.mt-md-n26,.my-md-n26{margin-top:-26px!important}.mr-md-n26,.mx-md-n26{margin-right:-26px!important}.mb-md-n26,.my-md-n26{margin-bottom:-26px!important}.ml-md-n26,.mx-md-n26{margin-left:-26px!important}.m-md-n28{margin:-28px!important}.mt-md-n28,.my-md-n28{margin-top:-28px!important}.mr-md-n28,.mx-md-n28{margin-right:-28px!important}.mb-md-n28,.my-md-n28{margin-bottom:-28px!important}.ml-md-n28,.mx-md-n28{margin-left:-28px!important}.m-md-n29{margin:-29px!important}.mt-md-n29,.my-md-n29{margin-top:-29px!important}.mr-md-n29,.mx-md-n29{margin-right:-29px!important}.mb-md-n29,.my-md-n29{margin-bottom:-29px!important}.ml-md-n29,.mx-md-n29{margin-left:-29px!important}.m-md-n30{margin:-30px!important}.mt-md-n30,.my-md-n30{margin-top:-30px!important}.mr-md-n30,.mx-md-n30{margin-right:-30px!important}.mb-md-n30,.my-md-n30{margin-bottom:-30px!important}.ml-md-n30,.mx-md-n30{margin-left:-30px!important}.m-md-n32{margin:-32px!important}.mt-md-n32,.my-md-n32{margin-top:-32px!important}.mr-md-n32,.mx-md-n32{margin-right:-32px!important}.mb-md-n32,.my-md-n32{margin-bottom:-32px!important}.ml-md-n32,.mx-md-n32{margin-left:-32px!important}.m-md-n38{margin:-38px!important}.mt-md-n38,.my-md-n38{margin-top:-38px!important}.mr-md-n38,.mx-md-n38{margin-right:-38px!important}.mb-md-n38,.my-md-n38{margin-bottom:-38px!important}.ml-md-n38,.mx-md-n38{margin-left:-38px!important}.m-md-n40{margin:-40px!important}.mt-md-n40,.my-md-n40{margin-top:-40px!important}.mr-md-n40,.mx-md-n40{margin-right:-40px!important}.mb-md-n40,.my-md-n40{margin-bottom:-40px!important}.ml-md-n40,.mx-md-n40{margin-left:-40px!important}.m-md-n42{margin:-42px!important}.mt-md-n42,.my-md-n42{margin-top:-42px!important}.mr-md-n42,.mx-md-n42{margin-right:-42px!important}.mb-md-n42,.my-md-n42{margin-bottom:-42px!important}.ml-md-n42,.mx-md-n42{margin-left:-42px!important}.m-md-n48{margin:-48px!important}.mt-md-n48,.my-md-n48{margin-top:-48px!important}.mr-md-n48,.mx-md-n48{margin-right:-48px!important}.mb-md-n48,.my-md-n48{margin-bottom:-48px!important}.ml-md-n48,.mx-md-n48{margin-left:-48px!important}.m-md-n50{margin:-50px!important}.mt-md-n50,.my-md-n50{margin-top:-50px!important}.mr-md-n50,.mx-md-n50{margin-right:-50px!important}.mb-md-n50,.my-md-n50{margin-bottom:-50px!important}.ml-md-n50,.mx-md-n50{margin-left:-50px!important}.m-md-n56{margin:-56px!important}.mt-md-n56,.my-md-n56{margin-top:-56px!important}.mr-md-n56,.mx-md-n56{margin-right:-56px!important}.mb-md-n56,.my-md-n56{margin-bottom:-56px!important}.ml-md-n56,.mx-md-n56{margin-left:-56px!important}.m-md-n58{margin:-58px!important}.mt-md-n58,.my-md-n58{margin-top:-58px!important}.mr-md-n58,.mx-md-n58{margin-right:-58px!important}.mb-md-n58,.my-md-n58{margin-bottom:-58px!important}.ml-md-n58,.mx-md-n58{margin-left:-58px!important}.m-md-n60{margin:-60px!important}.mt-md-n60,.my-md-n60{margin-top:-60px!important}.mr-md-n60,.mx-md-n60{margin-right:-60px!important}.mb-md-n60,.my-md-n60{margin-bottom:-60px!important}.ml-md-n60,.mx-md-n60{margin-left:-60px!important}.m-md-n64{margin:-64px!important}.mt-md-n64,.my-md-n64{margin-top:-64px!important}.mr-md-n64,.mx-md-n64{margin-right:-64px!important}.mb-md-n64,.my-md-n64{margin-bottom:-64px!important}.ml-md-n64,.mx-md-n64{margin-left:-64px!important}.m-md-auto{margin:auto!important}.mt-md-auto,.my-md-auto{margin-top:auto!important}.mr-md-auto,.mx-md-auto{margin-right:auto!important}.mb-md-auto,.my-md-auto{margin-bottom:auto!important}.ml-md-auto,.mx-md-auto{margin-left:auto!important}.text-md-left{text-align:left!important}.text-md-right{text-align:right!important}.text-md-center{text-align:center!important}}@media (min-width:992px){.flex-lg-row{flex-direction:row!important}.flex-lg-column{flex-direction:column!important}.flex-lg-row-reverse{flex-direction:row-reverse!important}.flex-lg-column-reverse{flex-direction:column-reverse!important}.flex-lg-wrap{flex-wrap:wrap!important}.flex-lg-nowrap{flex-wrap:nowrap!important}.flex-lg-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-lg-fill{flex:1 1 auto!important}.flex-lg-grow-0{flex-grow:0!important}.flex-lg-grow-1{flex-grow:1!important}.flex-lg-shrink-0{flex-shrink:0!important}.flex-lg-shrink-1{flex-shrink:1!important}.justify-content-lg-start{justify-content:flex-start!important}.justify-content-lg-end{justify-content:flex-end!important}.justify-content-lg-center{justify-content:center!important}.justify-content-lg-between{justify-content:space-between!important}.justify-content-lg-around{justify-content:space-around!important}.align-items-lg-start{align-items:flex-start!important}.align-items-lg-end{align-items:flex-end!important}.align-items-lg-center{align-items:center!important}.align-items-lg-baseline{align-items:baseline!important}.align-items-lg-stretch{align-items:stretch!important}.align-content-lg-start{align-content:flex-start!important}.align-content-lg-end{align-content:flex-end!important}.align-content-lg-center{align-content:center!important}.align-content-lg-between{align-content:space-between!important}.align-content-lg-around{align-content:space-around!important}.align-content-lg-stretch{align-content:stretch!important}.align-self-lg-auto{align-self:auto!important}.align-self-lg-start{align-self:flex-start!important}.align-self-lg-end{align-self:flex-end!important}.align-self-lg-center{align-self:center!important}.align-self-lg-baseline{align-self:baseline!important}.align-self-lg-stretch{align-self:stretch!important}.float-lg-left{float:left!important}.float-lg-right{float:right!important}.float-lg-none{float:none!important}.m-lg-0{margin:0!important}.mt-lg-0,.my-lg-0{margin-top:0!important}.mr-lg-0,.mx-lg-0{margin-right:0!important}.mb-lg-0,.my-lg-0{margin-bottom:0!important}.ml-lg-0,.mx-lg-0{margin-left:0!important}.m-lg-1{margin:1px!important}.mt-lg-1,.my-lg-1{margin-top:1px!important}.mr-lg-1,.mx-lg-1{margin-right:1px!important}.mb-lg-1,.my-lg-1{margin-bottom:1px!important}.ml-lg-1,.mx-lg-1{margin-left:1px!important}.m-lg-2{margin:2px!important}.mt-lg-2,.my-lg-2{margin-top:2px!important}.mr-lg-2,.mx-lg-2{margin-right:2px!important}.mb-lg-2,.my-lg-2{margin-bottom:2px!important}.ml-lg-2,.mx-lg-2{margin-left:2px!important}.m-lg-3{margin:3px!important}.mt-lg-3,.my-lg-3{margin-top:3px!important}.mr-lg-3,.mx-lg-3{margin-right:3px!important}.mb-lg-3,.my-lg-3{margin-bottom:3px!important}.ml-lg-3,.mx-lg-3{margin-left:3px!important}.m-lg-4{margin:4px!important}.mt-lg-4,.my-lg-4{margin-top:4px!important}.mr-lg-4,.mx-lg-4{margin-right:4px!important}.mb-lg-4,.my-lg-4{margin-bottom:4px!important}.ml-lg-4,.mx-lg-4{margin-left:4px!important}.m-lg-5{margin:5px!important}.mt-lg-5,.my-lg-5{margin-top:5px!important}.mr-lg-5,.mx-lg-5{margin-right:5px!important}.mb-lg-5,.my-lg-5{margin-bottom:5px!important}.ml-lg-5,.mx-lg-5{margin-left:5px!important}.m-lg-6{margin:6px!important}.mt-lg-6,.my-lg-6{margin-top:6px!important}.mr-lg-6,.mx-lg-6{margin-right:6px!important}.mb-lg-6,.my-lg-6{margin-bottom:6px!important}.ml-lg-6,.mx-lg-6{margin-left:6px!important}.m-lg-7{margin:7px!important}.mt-lg-7,.my-lg-7{margin-top:7px!important}.mr-lg-7,.mx-lg-7{margin-right:7px!important}.mb-lg-7,.my-lg-7{margin-bottom:7px!important}.ml-lg-7,.mx-lg-7{margin-left:7px!important}.m-lg-8{margin:8px!important}.mt-lg-8,.my-lg-8{margin-top:8px!important}.mr-lg-8,.mx-lg-8{margin-right:8px!important}.mb-lg-8,.my-lg-8{margin-bottom:8px!important}.ml-lg-8,.mx-lg-8{margin-left:8px!important}.m-lg-9{margin:9px!important}.mt-lg-9,.my-lg-9{margin-top:9px!important}.mr-lg-9,.mx-lg-9{margin-right:9px!important}.mb-lg-9,.my-lg-9{margin-bottom:9px!important}.ml-lg-9,.mx-lg-9{margin-left:9px!important}.m-lg-10{margin:10px!important}.mt-lg-10,.my-lg-10{margin-top:10px!important}.mr-lg-10,.mx-lg-10{margin-right:10px!important}.mb-lg-10,.my-lg-10{margin-bottom:10px!important}.ml-lg-10,.mx-lg-10{margin-left:10px!important}.m-lg-11{margin:11px!important}.mt-lg-11,.my-lg-11{margin-top:11px!important}.mr-lg-11,.mx-lg-11{margin-right:11px!important}.mb-lg-11,.my-lg-11{margin-bottom:11px!important}.ml-lg-11,.mx-lg-11{margin-left:11px!important}.m-lg-12{margin:12px!important}.mt-lg-12,.my-lg-12{margin-top:12px!important}.mr-lg-12,.mx-lg-12{margin-right:12px!important}.mb-lg-12,.my-lg-12{margin-bottom:12px!important}.ml-lg-12,.mx-lg-12{margin-left:12px!important}.m-lg-13{margin:13px!important}.mt-lg-13,.my-lg-13{margin-top:13px!important}.mr-lg-13,.mx-lg-13{margin-right:13px!important}.mb-lg-13,.my-lg-13{margin-bottom:13px!important}.ml-lg-13,.mx-lg-13{margin-left:13px!important}.m-lg-14{margin:14px!important}.mt-lg-14,.my-lg-14{margin-top:14px!important}.mr-lg-14,.mx-lg-14{margin-right:14px!important}.mb-lg-14,.my-lg-14{margin-bottom:14px!important}.ml-lg-14,.mx-lg-14{margin-left:14px!important}.m-lg-15{margin:15px!important}.mt-lg-15,.my-lg-15{margin-top:15px!important}.mr-lg-15,.mx-lg-15{margin-right:15px!important}.mb-lg-15,.my-lg-15{margin-bottom:15px!important}.ml-lg-15,.mx-lg-15{margin-left:15px!important}.m-lg-16{margin:16px!important}.mt-lg-16,.my-lg-16{margin-top:16px!important}.mr-lg-16,.mx-lg-16{margin-right:16px!important}.mb-lg-16,.my-lg-16{margin-bottom:16px!important}.ml-lg-16,.mx-lg-16{margin-left:16px!important}.m-lg-18{margin:18px!important}.mt-lg-18,.my-lg-18{margin-top:18px!important}.mr-lg-18,.mx-lg-18{margin-right:18px!important}.mb-lg-18,.my-lg-18{margin-bottom:18px!important}.ml-lg-18,.mx-lg-18{margin-left:18px!important}.m-lg-20{margin:20px!important}.mt-lg-20,.my-lg-20{margin-top:20px!important}.mr-lg-20,.mx-lg-20{margin-right:20px!important}.mb-lg-20,.my-lg-20{margin-bottom:20px!important}.ml-lg-20,.mx-lg-20{margin-left:20px!important}.m-lg-21{margin:21px!important}.mt-lg-21,.my-lg-21{margin-top:21px!important}.mr-lg-21,.mx-lg-21{margin-right:21px!important}.mb-lg-21,.my-lg-21{margin-bottom:21px!important}.ml-lg-21,.mx-lg-21{margin-left:21px!important}.m-lg-23{margin:23px!important}.mt-lg-23,.my-lg-23{margin-top:23px!important}.mr-lg-23,.mx-lg-23{margin-right:23px!important}.mb-lg-23,.my-lg-23{margin-bottom:23px!important}.ml-lg-23,.mx-lg-23{margin-left:23px!important}.m-lg-24{margin:24px!important}.mt-lg-24,.my-lg-24{margin-top:24px!important}.mr-lg-24,.mx-lg-24{margin-right:24px!important}.mb-lg-24,.my-lg-24{margin-bottom:24px!important}.ml-lg-24,.mx-lg-24{margin-left:24px!important}.m-lg-26{margin:26px!important}.mt-lg-26,.my-lg-26{margin-top:26px!important}.mr-lg-26,.mx-lg-26{margin-right:26px!important}.mb-lg-26,.my-lg-26{margin-bottom:26px!important}.ml-lg-26,.mx-lg-26{margin-left:26px!important}.m-lg-28{margin:28px!important}.mt-lg-28,.my-lg-28{margin-top:28px!important}.mr-lg-28,.mx-lg-28{margin-right:28px!important}.mb-lg-28,.my-lg-28{margin-bottom:28px!important}.ml-lg-28,.mx-lg-28{margin-left:28px!important}.m-lg-29{margin:29px!important}.mt-lg-29,.my-lg-29{margin-top:29px!important}.mr-lg-29,.mx-lg-29{margin-right:29px!important}.mb-lg-29,.my-lg-29{margin-bottom:29px!important}.ml-lg-29,.mx-lg-29{margin-left:29px!important}.m-lg-30{margin:30px!important}.mt-lg-30,.my-lg-30{margin-top:30px!important}.mr-lg-30,.mx-lg-30{margin-right:30px!important}.mb-lg-30,.my-lg-30{margin-bottom:30px!important}.ml-lg-30,.mx-lg-30{margin-left:30px!important}.m-lg-32{margin:32px!important}.mt-lg-32,.my-lg-32{margin-top:32px!important}.mr-lg-32,.mx-lg-32{margin-right:32px!important}.mb-lg-32,.my-lg-32{margin-bottom:32px!important}.ml-lg-32,.mx-lg-32{margin-left:32px!important}.m-lg-38{margin:38px!important}.mt-lg-38,.my-lg-38{margin-top:38px!important}.mr-lg-38,.mx-lg-38{margin-right:38px!important}.mb-lg-38,.my-lg-38{margin-bottom:38px!important}.ml-lg-38,.mx-lg-38{margin-left:38px!important}.m-lg-40{margin:40px!important}.mt-lg-40,.my-lg-40{margin-top:40px!important}.mr-lg-40,.mx-lg-40{margin-right:40px!important}.mb-lg-40,.my-lg-40{margin-bottom:40px!important}.ml-lg-40,.mx-lg-40{margin-left:40px!important}.m-lg-42{margin:42px!important}.mt-lg-42,.my-lg-42{margin-top:42px!important}.mr-lg-42,.mx-lg-42{margin-right:42px!important}.mb-lg-42,.my-lg-42{margin-bottom:42px!important}.ml-lg-42,.mx-lg-42{margin-left:42px!important}.m-lg-48{margin:48px!important}.mt-lg-48,.my-lg-48{margin-top:48px!important}.mr-lg-48,.mx-lg-48{margin-right:48px!important}.mb-lg-48,.my-lg-48{margin-bottom:48px!important}.ml-lg-48,.mx-lg-48{margin-left:48px!important}.m-lg-50{margin:50px!important}.mt-lg-50,.my-lg-50{margin-top:50px!important}.mr-lg-50,.mx-lg-50{margin-right:50px!important}.mb-lg-50,.my-lg-50{margin-bottom:50px!important}.ml-lg-50,.mx-lg-50{margin-left:50px!important}.m-lg-56{margin:56px!important}.mt-lg-56,.my-lg-56{margin-top:56px!important}.mr-lg-56,.mx-lg-56{margin-right:56px!important}.mb-lg-56,.my-lg-56{margin-bottom:56px!important}.ml-lg-56,.mx-lg-56{margin-left:56px!important}.m-lg-58{margin:58px!important}.mt-lg-58,.my-lg-58{margin-top:58px!important}.mr-lg-58,.mx-lg-58{margin-right:58px!important}.mb-lg-58,.my-lg-58{margin-bottom:58px!important}.ml-lg-58,.mx-lg-58{margin-left:58px!important}.m-lg-60{margin:60px!important}.mt-lg-60,.my-lg-60{margin-top:60px!important}.mr-lg-60,.mx-lg-60{margin-right:60px!important}.mb-lg-60,.my-lg-60{margin-bottom:60px!important}.ml-lg-60,.mx-lg-60{margin-left:60px!important}.m-lg-64{margin:64px!important}.mt-lg-64,.my-lg-64{margin-top:64px!important}.mr-lg-64,.mx-lg-64{margin-right:64px!important}.mb-lg-64,.my-lg-64{margin-bottom:64px!important}.ml-lg-64,.mx-lg-64{margin-left:64px!important}.p-lg-0{padding:0!important}.pt-lg-0,.py-lg-0{padding-top:0!important}.pr-lg-0,.px-lg-0{padding-right:0!important}.pb-lg-0,.py-lg-0{padding-bottom:0!important}.pl-lg-0,.px-lg-0{padding-left:0!important}.p-lg-1{padding:1px!important}.pt-lg-1,.py-lg-1{padding-top:1px!important}.pr-lg-1,.px-lg-1{padding-right:1px!important}.pb-lg-1,.py-lg-1{padding-bottom:1px!important}.pl-lg-1,.px-lg-1{padding-left:1px!important}.p-lg-2{padding:2px!important}.pt-lg-2,.py-lg-2{padding-top:2px!important}.pr-lg-2,.px-lg-2{padding-right:2px!important}.pb-lg-2,.py-lg-2{padding-bottom:2px!important}.pl-lg-2,.px-lg-2{padding-left:2px!important}.p-lg-3{padding:3px!important}.pt-lg-3,.py-lg-3{padding-top:3px!important}.pr-lg-3,.px-lg-3{padding-right:3px!important}.pb-lg-3,.py-lg-3{padding-bottom:3px!important}.pl-lg-3,.px-lg-3{padding-left:3px!important}.p-lg-4{padding:4px!important}.pt-lg-4,.py-lg-4{padding-top:4px!important}.pr-lg-4,.px-lg-4{padding-right:4px!important}.pb-lg-4,.py-lg-4{padding-bottom:4px!important}.pl-lg-4,.px-lg-4{padding-left:4px!important}.p-lg-5{padding:5px!important}.pt-lg-5,.py-lg-5{padding-top:5px!important}.pr-lg-5,.px-lg-5{padding-right:5px!important}.pb-lg-5,.py-lg-5{padding-bottom:5px!important}.pl-lg-5,.px-lg-5{padding-left:5px!important}.p-lg-6{padding:6px!important}.pt-lg-6,.py-lg-6{padding-top:6px!important}.pr-lg-6,.px-lg-6{padding-right:6px!important}.pb-lg-6,.py-lg-6{padding-bottom:6px!important}.pl-lg-6,.px-lg-6{padding-left:6px!important}.p-lg-7{padding:7px!important}.pt-lg-7,.py-lg-7{padding-top:7px!important}.pr-lg-7,.px-lg-7{padding-right:7px!important}.pb-lg-7,.py-lg-7{padding-bottom:7px!important}.pl-lg-7,.px-lg-7{padding-left:7px!important}.p-lg-8{padding:8px!important}.pt-lg-8,.py-lg-8{padding-top:8px!important}.pr-lg-8,.px-lg-8{padding-right:8px!important}.pb-lg-8,.py-lg-8{padding-bottom:8px!important}.pl-lg-8,.px-lg-8{padding-left:8px!important}.p-lg-9{padding:9px!important}.pt-lg-9,.py-lg-9{padding-top:9px!important}.pr-lg-9,.px-lg-9{padding-right:9px!important}.pb-lg-9,.py-lg-9{padding-bottom:9px!important}.pl-lg-9,.px-lg-9{padding-left:9px!important}.p-lg-10{padding:10px!important}.pt-lg-10,.py-lg-10{padding-top:10px!important}.pr-lg-10,.px-lg-10{padding-right:10px!important}.pb-lg-10,.py-lg-10{padding-bottom:10px!important}.pl-lg-10,.px-lg-10{padding-left:10px!important}.p-lg-11{padding:11px!important}.pt-lg-11,.py-lg-11{padding-top:11px!important}.pr-lg-11,.px-lg-11{padding-right:11px!important}.pb-lg-11,.py-lg-11{padding-bottom:11px!important}.pl-lg-11,.px-lg-11{padding-left:11px!important}.p-lg-12{padding:12px!important}.pt-lg-12,.py-lg-12{padding-top:12px!important}.pr-lg-12,.px-lg-12{padding-right:12px!important}.pb-lg-12,.py-lg-12{padding-bottom:12px!important}.pl-lg-12,.px-lg-12{padding-left:12px!important}.p-lg-13{padding:13px!important}.pt-lg-13,.py-lg-13{padding-top:13px!important}.pr-lg-13,.px-lg-13{padding-right:13px!important}.pb-lg-13,.py-lg-13{padding-bottom:13px!important}.pl-lg-13,.px-lg-13{padding-left:13px!important}.p-lg-14{padding:14px!important}.pt-lg-14,.py-lg-14{padding-top:14px!important}.pr-lg-14,.px-lg-14{padding-right:14px!important}.pb-lg-14,.py-lg-14{padding-bottom:14px!important}.pl-lg-14,.px-lg-14{padding-left:14px!important}.p-lg-15{padding:15px!important}.pt-lg-15,.py-lg-15{padding-top:15px!important}.pr-lg-15,.px-lg-15{padding-right:15px!important}.pb-lg-15,.py-lg-15{padding-bottom:15px!important}.pl-lg-15,.px-lg-15{padding-left:15px!important}.p-lg-16{padding:16px!important}.pt-lg-16,.py-lg-16{padding-top:16px!important}.pr-lg-16,.px-lg-16{padding-right:16px!important}.pb-lg-16,.py-lg-16{padding-bottom:16px!important}.pl-lg-16,.px-lg-16{padding-left:16px!important}.p-lg-18{padding:18px!important}.pt-lg-18,.py-lg-18{padding-top:18px!important}.pr-lg-18,.px-lg-18{padding-right:18px!important}.pb-lg-18,.py-lg-18{padding-bottom:18px!important}.pl-lg-18,.px-lg-18{padding-left:18px!important}.p-lg-20{padding:20px!important}.pt-lg-20,.py-lg-20{padding-top:20px!important}.pr-lg-20,.px-lg-20{padding-right:20px!important}.pb-lg-20,.py-lg-20{padding-bottom:20px!important}.pl-lg-20,.px-lg-20{padding-left:20px!important}.p-lg-21{padding:21px!important}.pt-lg-21,.py-lg-21{padding-top:21px!important}.pr-lg-21,.px-lg-21{padding-right:21px!important}.pb-lg-21,.py-lg-21{padding-bottom:21px!important}.pl-lg-21,.px-lg-21{padding-left:21px!important}.p-lg-23{padding:23px!important}.pt-lg-23,.py-lg-23{padding-top:23px!important}.pr-lg-23,.px-lg-23{padding-right:23px!important}.pb-lg-23,.py-lg-23{padding-bottom:23px!important}.pl-lg-23,.px-lg-23{padding-left:23px!important}.p-lg-24{padding:24px!important}.pt-lg-24,.py-lg-24{padding-top:24px!important}.pr-lg-24,.px-lg-24{padding-right:24px!important}.pb-lg-24,.py-lg-24{padding-bottom:24px!important}.pl-lg-24,.px-lg-24{padding-left:24px!important}.p-lg-26{padding:26px!important}.pt-lg-26,.py-lg-26{padding-top:26px!important}.pr-lg-26,.px-lg-26{padding-right:26px!important}.pb-lg-26,.py-lg-26{padding-bottom:26px!important}.pl-lg-26,.px-lg-26{padding-left:26px!important}.p-lg-28{padding:28px!important}.pt-lg-28,.py-lg-28{padding-top:28px!important}.pr-lg-28,.px-lg-28{padding-right:28px!important}.pb-lg-28,.py-lg-28{padding-bottom:28px!important}.pl-lg-28,.px-lg-28{padding-left:28px!important}.p-lg-29{padding:29px!important}.pt-lg-29,.py-lg-29{padding-top:29px!important}.pr-lg-29,.px-lg-29{padding-right:29px!important}.pb-lg-29,.py-lg-29{padding-bottom:29px!important}.pl-lg-29,.px-lg-29{padding-left:29px!important}.p-lg-30{padding:30px!important}.pt-lg-30,.py-lg-30{padding-top:30px!important}.pr-lg-30,.px-lg-30{padding-right:30px!important}.pb-lg-30,.py-lg-30{padding-bottom:30px!important}.pl-lg-30,.px-lg-30{padding-left:30px!important}.p-lg-32{padding:32px!important}.pt-lg-32,.py-lg-32{padding-top:32px!important}.pr-lg-32,.px-lg-32{padding-right:32px!important}.pb-lg-32,.py-lg-32{padding-bottom:32px!important}.pl-lg-32,.px-lg-32{padding-left:32px!important}.p-lg-38{padding:38px!important}.pt-lg-38,.py-lg-38{padding-top:38px!important}.pr-lg-38,.px-lg-38{padding-right:38px!important}.pb-lg-38,.py-lg-38{padding-bottom:38px!important}.pl-lg-38,.px-lg-38{padding-left:38px!important}.p-lg-40{padding:40px!important}.pt-lg-40,.py-lg-40{padding-top:40px!important}.pr-lg-40,.px-lg-40{padding-right:40px!important}.pb-lg-40,.py-lg-40{padding-bottom:40px!important}.pl-lg-40,.px-lg-40{padding-left:40px!important}.p-lg-42{padding:42px!important}.pt-lg-42,.py-lg-42{padding-top:42px!important}.pr-lg-42,.px-lg-42{padding-right:42px!important}.pb-lg-42,.py-lg-42{padding-bottom:42px!important}.pl-lg-42,.px-lg-42{padding-left:42px!important}.p-lg-48{padding:48px!important}.pt-lg-48,.py-lg-48{padding-top:48px!important}.pr-lg-48,.px-lg-48{padding-right:48px!important}.pb-lg-48,.py-lg-48{padding-bottom:48px!important}.pl-lg-48,.px-lg-48{padding-left:48px!important}.p-lg-50{padding:50px!important}.pt-lg-50,.py-lg-50{padding-top:50px!important}.pr-lg-50,.px-lg-50{padding-right:50px!important}.pb-lg-50,.py-lg-50{padding-bottom:50px!important}.pl-lg-50,.px-lg-50{padding-left:50px!important}.p-lg-56{padding:56px!important}.pt-lg-56,.py-lg-56{padding-top:56px!important}.pr-lg-56,.px-lg-56{padding-right:56px!important}.pb-lg-56,.py-lg-56{padding-bottom:56px!important}.pl-lg-56,.px-lg-56{padding-left:56px!important}.p-lg-58{padding:58px!important}.pt-lg-58,.py-lg-58{padding-top:58px!important}.pr-lg-58,.px-lg-58{padding-right:58px!important}.pb-lg-58,.py-lg-58{padding-bottom:58px!important}.pl-lg-58,.px-lg-58{padding-left:58px!important}.p-lg-60{padding:60px!important}.pt-lg-60,.py-lg-60{padding-top:60px!important}.pr-lg-60,.px-lg-60{padding-right:60px!important}.pb-lg-60,.py-lg-60{padding-bottom:60px!important}.pl-lg-60,.px-lg-60{padding-left:60px!important}.p-lg-64{padding:64px!important}.pt-lg-64,.py-lg-64{padding-top:64px!important}.pr-lg-64,.px-lg-64{padding-right:64px!important}.pb-lg-64,.py-lg-64{padding-bottom:64px!important}.pl-lg-64,.px-lg-64{padding-left:64px!important}.m-lg-n1{margin:-1px!important}.mt-lg-n1,.my-lg-n1{margin-top:-1px!important}.mr-lg-n1,.mx-lg-n1{margin-right:-1px!important}.mb-lg-n1,.my-lg-n1{margin-bottom:-1px!important}.ml-lg-n1,.mx-lg-n1{margin-left:-1px!important}.m-lg-n2{margin:-2px!important}.mt-lg-n2,.my-lg-n2{margin-top:-2px!important}.mr-lg-n2,.mx-lg-n2{margin-right:-2px!important}.mb-lg-n2,.my-lg-n2{margin-bottom:-2px!important}.ml-lg-n2,.mx-lg-n2{margin-left:-2px!important}.m-lg-n3{margin:-3px!important}.mt-lg-n3,.my-lg-n3{margin-top:-3px!important}.mr-lg-n3,.mx-lg-n3{margin-right:-3px!important}.mb-lg-n3,.my-lg-n3{margin-bottom:-3px!important}.ml-lg-n3,.mx-lg-n3{margin-left:-3px!important}.m-lg-n4{margin:-4px!important}.mt-lg-n4,.my-lg-n4{margin-top:-4px!important}.mr-lg-n4,.mx-lg-n4{margin-right:-4px!important}.mb-lg-n4,.my-lg-n4{margin-bottom:-4px!important}.ml-lg-n4,.mx-lg-n4{margin-left:-4px!important}.m-lg-n5{margin:-5px!important}.mt-lg-n5,.my-lg-n5{margin-top:-5px!important}.mr-lg-n5,.mx-lg-n5{margin-right:-5px!important}.mb-lg-n5,.my-lg-n5{margin-bottom:-5px!important}.ml-lg-n5,.mx-lg-n5{margin-left:-5px!important}.m-lg-n6{margin:-6px!important}.mt-lg-n6,.my-lg-n6{margin-top:-6px!important}.mr-lg-n6,.mx-lg-n6{margin-right:-6px!important}.mb-lg-n6,.my-lg-n6{margin-bottom:-6px!important}.ml-lg-n6,.mx-lg-n6{margin-left:-6px!important}.m-lg-n7{margin:-7px!important}.mt-lg-n7,.my-lg-n7{margin-top:-7px!important}.mr-lg-n7,.mx-lg-n7{margin-right:-7px!important}.mb-lg-n7,.my-lg-n7{margin-bottom:-7px!important}.ml-lg-n7,.mx-lg-n7{margin-left:-7px!important}.m-lg-n8{margin:-8px!important}.mt-lg-n8,.my-lg-n8{margin-top:-8px!important}.mr-lg-n8,.mx-lg-n8{margin-right:-8px!important}.mb-lg-n8,.my-lg-n8{margin-bottom:-8px!important}.ml-lg-n8,.mx-lg-n8{margin-left:-8px!important}.m-lg-n9{margin:-9px!important}.mt-lg-n9,.my-lg-n9{margin-top:-9px!important}.mr-lg-n9,.mx-lg-n9{margin-right:-9px!important}.mb-lg-n9,.my-lg-n9{margin-bottom:-9px!important}.ml-lg-n9,.mx-lg-n9{margin-left:-9px!important}.m-lg-n10{margin:-10px!important}.mt-lg-n10,.my-lg-n10{margin-top:-10px!important}.mr-lg-n10,.mx-lg-n10{margin-right:-10px!important}.mb-lg-n10,.my-lg-n10{margin-bottom:-10px!important}.ml-lg-n10,.mx-lg-n10{margin-left:-10px!important}.m-lg-n11{margin:-11px!important}.mt-lg-n11,.my-lg-n11{margin-top:-11px!important}.mr-lg-n11,.mx-lg-n11{margin-right:-11px!important}.mb-lg-n11,.my-lg-n11{margin-bottom:-11px!important}.ml-lg-n11,.mx-lg-n11{margin-left:-11px!important}.m-lg-n12{margin:-12px!important}.mt-lg-n12,.my-lg-n12{margin-top:-12px!important}.mr-lg-n12,.mx-lg-n12{margin-right:-12px!important}.mb-lg-n12,.my-lg-n12{margin-bottom:-12px!important}.ml-lg-n12,.mx-lg-n12{margin-left:-12px!important}.m-lg-n13{margin:-13px!important}.mt-lg-n13,.my-lg-n13{margin-top:-13px!important}.mr-lg-n13,.mx-lg-n13{margin-right:-13px!important}.mb-lg-n13,.my-lg-n13{margin-bottom:-13px!important}.ml-lg-n13,.mx-lg-n13{margin-left:-13px!important}.m-lg-n14{margin:-14px!important}.mt-lg-n14,.my-lg-n14{margin-top:-14px!important}.mr-lg-n14,.mx-lg-n14{margin-right:-14px!important}.mb-lg-n14,.my-lg-n14{margin-bottom:-14px!important}.ml-lg-n14,.mx-lg-n14{margin-left:-14px!important}.m-lg-n15{margin:-15px!important}.mt-lg-n15,.my-lg-n15{margin-top:-15px!important}.mr-lg-n15,.mx-lg-n15{margin-right:-15px!important}.mb-lg-n15,.my-lg-n15{margin-bottom:-15px!important}.ml-lg-n15,.mx-lg-n15{margin-left:-15px!important}.m-lg-n16{margin:-16px!important}.mt-lg-n16,.my-lg-n16{margin-top:-16px!important}.mr-lg-n16,.mx-lg-n16{margin-right:-16px!important}.mb-lg-n16,.my-lg-n16{margin-bottom:-16px!important}.ml-lg-n16,.mx-lg-n16{margin-left:-16px!important}.m-lg-n18{margin:-18px!important}.mt-lg-n18,.my-lg-n18{margin-top:-18px!important}.mr-lg-n18,.mx-lg-n18{margin-right:-18px!important}.mb-lg-n18,.my-lg-n18{margin-bottom:-18px!important}.ml-lg-n18,.mx-lg-n18{margin-left:-18px!important}.m-lg-n20{margin:-20px!important}.mt-lg-n20,.my-lg-n20{margin-top:-20px!important}.mr-lg-n20,.mx-lg-n20{margin-right:-20px!important}.mb-lg-n20,.my-lg-n20{margin-bottom:-20px!important}.ml-lg-n20,.mx-lg-n20{margin-left:-20px!important}.m-lg-n21{margin:-21px!important}.mt-lg-n21,.my-lg-n21{margin-top:-21px!important}.mr-lg-n21,.mx-lg-n21{margin-right:-21px!important}.mb-lg-n21,.my-lg-n21{margin-bottom:-21px!important}.ml-lg-n21,.mx-lg-n21{margin-left:-21px!important}.m-lg-n23{margin:-23px!important}.mt-lg-n23,.my-lg-n23{margin-top:-23px!important}.mr-lg-n23,.mx-lg-n23{margin-right:-23px!important}.mb-lg-n23,.my-lg-n23{margin-bottom:-23px!important}.ml-lg-n23,.mx-lg-n23{margin-left:-23px!important}.m-lg-n24{margin:-24px!important}.mt-lg-n24,.my-lg-n24{margin-top:-24px!important}.mr-lg-n24,.mx-lg-n24{margin-right:-24px!important}.mb-lg-n24,.my-lg-n24{margin-bottom:-24px!important}.ml-lg-n24,.mx-lg-n24{margin-left:-24px!important}.m-lg-n26{margin:-26px!important}.mt-lg-n26,.my-lg-n26{margin-top:-26px!important}.mr-lg-n26,.mx-lg-n26{margin-right:-26px!important}.mb-lg-n26,.my-lg-n26{margin-bottom:-26px!important}.ml-lg-n26,.mx-lg-n26{margin-left:-26px!important}.m-lg-n28{margin:-28px!important}.mt-lg-n28,.my-lg-n28{margin-top:-28px!important}.mr-lg-n28,.mx-lg-n28{margin-right:-28px!important}.mb-lg-n28,.my-lg-n28{margin-bottom:-28px!important}.ml-lg-n28,.mx-lg-n28{margin-left:-28px!important}.m-lg-n29{margin:-29px!important}.mt-lg-n29,.my-lg-n29{margin-top:-29px!important}.mr-lg-n29,.mx-lg-n29{margin-right:-29px!important}.mb-lg-n29,.my-lg-n29{margin-bottom:-29px!important}.ml-lg-n29,.mx-lg-n29{margin-left:-29px!important}.m-lg-n30{margin:-30px!important}.mt-lg-n30,.my-lg-n30{margin-top:-30px!important}.mr-lg-n30,.mx-lg-n30{margin-right:-30px!important}.mb-lg-n30,.my-lg-n30{margin-bottom:-30px!important}.ml-lg-n30,.mx-lg-n30{margin-left:-30px!important}.m-lg-n32{margin:-32px!important}.mt-lg-n32,.my-lg-n32{margin-top:-32px!important}.mr-lg-n32,.mx-lg-n32{margin-right:-32px!important}.mb-lg-n32,.my-lg-n32{margin-bottom:-32px!important}.ml-lg-n32,.mx-lg-n32{margin-left:-32px!important}.m-lg-n38{margin:-38px!important}.mt-lg-n38,.my-lg-n38{margin-top:-38px!important}.mr-lg-n38,.mx-lg-n38{margin-right:-38px!important}.mb-lg-n38,.my-lg-n38{margin-bottom:-38px!important}.ml-lg-n38,.mx-lg-n38{margin-left:-38px!important}.m-lg-n40{margin:-40px!important}.mt-lg-n40,.my-lg-n40{margin-top:-40px!important}.mr-lg-n40,.mx-lg-n40{margin-right:-40px!important}.mb-lg-n40,.my-lg-n40{margin-bottom:-40px!important}.ml-lg-n40,.mx-lg-n40{margin-left:-40px!important}.m-lg-n42{margin:-42px!important}.mt-lg-n42,.my-lg-n42{margin-top:-42px!important}.mr-lg-n42,.mx-lg-n42{margin-right:-42px!important}.mb-lg-n42,.my-lg-n42{margin-bottom:-42px!important}.ml-lg-n42,.mx-lg-n42{margin-left:-42px!important}.m-lg-n48{margin:-48px!important}.mt-lg-n48,.my-lg-n48{margin-top:-48px!important}.mr-lg-n48,.mx-lg-n48{margin-right:-48px!important}.mb-lg-n48,.my-lg-n48{margin-bottom:-48px!important}.ml-lg-n48,.mx-lg-n48{margin-left:-48px!important}.m-lg-n50{margin:-50px!important}.mt-lg-n50,.my-lg-n50{margin-top:-50px!important}.mr-lg-n50,.mx-lg-n50{margin-right:-50px!important}.mb-lg-n50,.my-lg-n50{margin-bottom:-50px!important}.ml-lg-n50,.mx-lg-n50{margin-left:-50px!important}.m-lg-n56{margin:-56px!important}.mt-lg-n56,.my-lg-n56{margin-top:-56px!important}.mr-lg-n56,.mx-lg-n56{margin-right:-56px!important}.mb-lg-n56,.my-lg-n56{margin-bottom:-56px!important}.ml-lg-n56,.mx-lg-n56{margin-left:-56px!important}.m-lg-n58{margin:-58px!important}.mt-lg-n58,.my-lg-n58{margin-top:-58px!important}.mr-lg-n58,.mx-lg-n58{margin-right:-58px!important}.mb-lg-n58,.my-lg-n58{margin-bottom:-58px!important}.ml-lg-n58,.mx-lg-n58{margin-left:-58px!important}.m-lg-n60{margin:-60px!important}.mt-lg-n60,.my-lg-n60{margin-top:-60px!important}.mr-lg-n60,.mx-lg-n60{margin-right:-60px!important}.mb-lg-n60,.my-lg-n60{margin-bottom:-60px!important}.ml-lg-n60,.mx-lg-n60{margin-left:-60px!important}.m-lg-n64{margin:-64px!important}.mt-lg-n64,.my-lg-n64{margin-top:-64px!important}.mr-lg-n64,.mx-lg-n64{margin-right:-64px!important}.mb-lg-n64,.my-lg-n64{margin-bottom:-64px!important}.ml-lg-n64,.mx-lg-n64{margin-left:-64px!important}.m-lg-auto{margin:auto!important}.mt-lg-auto,.my-lg-auto{margin-top:auto!important}.mr-lg-auto,.mx-lg-auto{margin-right:auto!important}.mb-lg-auto,.my-lg-auto{margin-bottom:auto!important}.ml-lg-auto,.mx-lg-auto{margin-left:auto!important}.text-lg-left{text-align:left!important}.text-lg-right{text-align:right!important}.text-lg-center{text-align:center!important}}@media (min-width:1200px){.flex-xl-row{flex-direction:row!important}.flex-xl-column{flex-direction:column!important}.flex-xl-row-reverse{flex-direction:row-reverse!important}.flex-xl-column-reverse{flex-direction:column-reverse!important}.flex-xl-wrap{flex-wrap:wrap!important}.flex-xl-nowrap{flex-wrap:nowrap!important}.flex-xl-wrap-reverse{flex-wrap:wrap-reverse!important}.flex-xl-fill{flex:1 1 auto!important}.flex-xl-grow-0{flex-grow:0!important}.flex-xl-grow-1{flex-grow:1!important}.flex-xl-shrink-0{flex-shrink:0!important}.flex-xl-shrink-1{flex-shrink:1!important}.justify-content-xl-start{justify-content:flex-start!important}.justify-content-xl-end{justify-content:flex-end!important}.justify-content-xl-center{justify-content:center!important}.justify-content-xl-between{justify-content:space-between!important}.justify-content-xl-around{justify-content:space-around!important}.align-items-xl-start{align-items:flex-start!important}.align-items-xl-end{align-items:flex-end!important}.align-items-xl-center{align-items:center!important}.align-items-xl-baseline{align-items:baseline!important}.align-items-xl-stretch{align-items:stretch!important}.align-content-xl-start{align-content:flex-start!important}.align-content-xl-end{align-content:flex-end!important}.align-content-xl-center{align-content:center!important}.align-content-xl-between{align-content:space-between!important}.align-content-xl-around{align-content:space-around!important}.align-content-xl-stretch{align-content:stretch!important}.align-self-xl-auto{align-self:auto!important}.align-self-xl-start{align-self:flex-start!important}.align-self-xl-end{align-self:flex-end!important}.align-self-xl-center{align-self:center!important}.align-self-xl-baseline{align-self:baseline!important}.align-self-xl-stretch{align-self:stretch!important}.float-xl-left{float:left!important}.float-xl-right{float:right!important}.float-xl-none{float:none!important}.m-xl-0{margin:0!important}.mt-xl-0,.my-xl-0{margin-top:0!important}.mr-xl-0,.mx-xl-0{margin-right:0!important}.mb-xl-0,.my-xl-0{margin-bottom:0!important}.ml-xl-0,.mx-xl-0{margin-left:0!important}.m-xl-1{margin:1px!important}.mt-xl-1,.my-xl-1{margin-top:1px!important}.mr-xl-1,.mx-xl-1{margin-right:1px!important}.mb-xl-1,.my-xl-1{margin-bottom:1px!important}.ml-xl-1,.mx-xl-1{margin-left:1px!important}.m-xl-2{margin:2px!important}.mt-xl-2,.my-xl-2{margin-top:2px!important}.mr-xl-2,.mx-xl-2{margin-right:2px!important}.mb-xl-2,.my-xl-2{margin-bottom:2px!important}.ml-xl-2,.mx-xl-2{margin-left:2px!important}.m-xl-3{margin:3px!important}.mt-xl-3,.my-xl-3{margin-top:3px!important}.mr-xl-3,.mx-xl-3{margin-right:3px!important}.mb-xl-3,.my-xl-3{margin-bottom:3px!important}.ml-xl-3,.mx-xl-3{margin-left:3px!important}.m-xl-4{margin:4px!important}.mt-xl-4,.my-xl-4{margin-top:4px!important}.mr-xl-4,.mx-xl-4{margin-right:4px!important}.mb-xl-4,.my-xl-4{margin-bottom:4px!important}.ml-xl-4,.mx-xl-4{margin-left:4px!important}.m-xl-5{margin:5px!important}.mt-xl-5,.my-xl-5{margin-top:5px!important}.mr-xl-5,.mx-xl-5{margin-right:5px!important}.mb-xl-5,.my-xl-5{margin-bottom:5px!important}.ml-xl-5,.mx-xl-5{margin-left:5px!important}.m-xl-6{margin:6px!important}.mt-xl-6,.my-xl-6{margin-top:6px!important}.mr-xl-6,.mx-xl-6{margin-right:6px!important}.mb-xl-6,.my-xl-6{margin-bottom:6px!important}.ml-xl-6,.mx-xl-6{margin-left:6px!important}.m-xl-7{margin:7px!important}.mt-xl-7,.my-xl-7{margin-top:7px!important}.mr-xl-7,.mx-xl-7{margin-right:7px!important}.mb-xl-7,.my-xl-7{margin-bottom:7px!important}.ml-xl-7,.mx-xl-7{margin-left:7px!important}.m-xl-8{margin:8px!important}.mt-xl-8,.my-xl-8{margin-top:8px!important}.mr-xl-8,.mx-xl-8{margin-right:8px!important}.mb-xl-8,.my-xl-8{margin-bottom:8px!important}.ml-xl-8,.mx-xl-8{margin-left:8px!important}.m-xl-9{margin:9px!important}.mt-xl-9,.my-xl-9{margin-top:9px!important}.mr-xl-9,.mx-xl-9{margin-right:9px!important}.mb-xl-9,.my-xl-9{margin-bottom:9px!important}.ml-xl-9,.mx-xl-9{margin-left:9px!important}.m-xl-10{margin:10px!important}.mt-xl-10,.my-xl-10{margin-top:10px!important}.mr-xl-10,.mx-xl-10{margin-right:10px!important}.mb-xl-10,.my-xl-10{margin-bottom:10px!important}.ml-xl-10,.mx-xl-10{margin-left:10px!important}.m-xl-11{margin:11px!important}.mt-xl-11,.my-xl-11{margin-top:11px!important}.mr-xl-11,.mx-xl-11{margin-right:11px!important}.mb-xl-11,.my-xl-11{margin-bottom:11px!important}.ml-xl-11,.mx-xl-11{margin-left:11px!important}.m-xl-12{margin:12px!important}.mt-xl-12,.my-xl-12{margin-top:12px!important}.mr-xl-12,.mx-xl-12{margin-right:12px!important}.mb-xl-12,.my-xl-12{margin-bottom:12px!important}.ml-xl-12,.mx-xl-12{margin-left:12px!important}.m-xl-13{margin:13px!important}.mt-xl-13,.my-xl-13{margin-top:13px!important}.mr-xl-13,.mx-xl-13{margin-right:13px!important}.mb-xl-13,.my-xl-13{margin-bottom:13px!important}.ml-xl-13,.mx-xl-13{margin-left:13px!important}.m-xl-14{margin:14px!important}.mt-xl-14,.my-xl-14{margin-top:14px!important}.mr-xl-14,.mx-xl-14{margin-right:14px!important}.mb-xl-14,.my-xl-14{margin-bottom:14px!important}.ml-xl-14,.mx-xl-14{margin-left:14px!important}.m-xl-15{margin:15px!important}.mt-xl-15,.my-xl-15{margin-top:15px!important}.mr-xl-15,.mx-xl-15{margin-right:15px!important}.mb-xl-15,.my-xl-15{margin-bottom:15px!important}.ml-xl-15,.mx-xl-15{margin-left:15px!important}.m-xl-16{margin:16px!important}.mt-xl-16,.my-xl-16{margin-top:16px!important}.mr-xl-16,.mx-xl-16{margin-right:16px!important}.mb-xl-16,.my-xl-16{margin-bottom:16px!important}.ml-xl-16,.mx-xl-16{margin-left:16px!important}.m-xl-18{margin:18px!important}.mt-xl-18,.my-xl-18{margin-top:18px!important}.mr-xl-18,.mx-xl-18{margin-right:18px!important}.mb-xl-18,.my-xl-18{margin-bottom:18px!important}.ml-xl-18,.mx-xl-18{margin-left:18px!important}.m-xl-20{margin:20px!important}.mt-xl-20,.my-xl-20{margin-top:20px!important}.mr-xl-20,.mx-xl-20{margin-right:20px!important}.mb-xl-20,.my-xl-20{margin-bottom:20px!important}.ml-xl-20,.mx-xl-20{margin-left:20px!important}.m-xl-21{margin:21px!important}.mt-xl-21,.my-xl-21{margin-top:21px!important}.mr-xl-21,.mx-xl-21{margin-right:21px!important}.mb-xl-21,.my-xl-21{margin-bottom:21px!important}.ml-xl-21,.mx-xl-21{margin-left:21px!important}.m-xl-23{margin:23px!important}.mt-xl-23,.my-xl-23{margin-top:23px!important}.mr-xl-23,.mx-xl-23{margin-right:23px!important}.mb-xl-23,.my-xl-23{margin-bottom:23px!important}.ml-xl-23,.mx-xl-23{margin-left:23px!important}.m-xl-24{margin:24px!important}.mt-xl-24,.my-xl-24{margin-top:24px!important}.mr-xl-24,.mx-xl-24{margin-right:24px!important}.mb-xl-24,.my-xl-24{margin-bottom:24px!important}.ml-xl-24,.mx-xl-24{margin-left:24px!important}.m-xl-26{margin:26px!important}.mt-xl-26,.my-xl-26{margin-top:26px!important}.mr-xl-26,.mx-xl-26{margin-right:26px!important}.mb-xl-26,.my-xl-26{margin-bottom:26px!important}.ml-xl-26,.mx-xl-26{margin-left:26px!important}.m-xl-28{margin:28px!important}.mt-xl-28,.my-xl-28{margin-top:28px!important}.mr-xl-28,.mx-xl-28{margin-right:28px!important}.mb-xl-28,.my-xl-28{margin-bottom:28px!important}.ml-xl-28,.mx-xl-28{margin-left:28px!important}.m-xl-29{margin:29px!important}.mt-xl-29,.my-xl-29{margin-top:29px!important}.mr-xl-29,.mx-xl-29{margin-right:29px!important}.mb-xl-29,.my-xl-29{margin-bottom:29px!important}.ml-xl-29,.mx-xl-29{margin-left:29px!important}.m-xl-30{margin:30px!important}.mt-xl-30,.my-xl-30{margin-top:30px!important}.mr-xl-30,.mx-xl-30{margin-right:30px!important}.mb-xl-30,.my-xl-30{margin-bottom:30px!important}.ml-xl-30,.mx-xl-30{margin-left:30px!important}.m-xl-32{margin:32px!important}.mt-xl-32,.my-xl-32{margin-top:32px!important}.mr-xl-32,.mx-xl-32{margin-right:32px!important}.mb-xl-32,.my-xl-32{margin-bottom:32px!important}.ml-xl-32,.mx-xl-32{margin-left:32px!important}.m-xl-38{margin:38px!important}.mt-xl-38,.my-xl-38{margin-top:38px!important}.mr-xl-38,.mx-xl-38{margin-right:38px!important}.mb-xl-38,.my-xl-38{margin-bottom:38px!important}.ml-xl-38,.mx-xl-38{margin-left:38px!important}.m-xl-40{margin:40px!important}.mt-xl-40,.my-xl-40{margin-top:40px!important}.mr-xl-40,.mx-xl-40{margin-right:40px!important}.mb-xl-40,.my-xl-40{margin-bottom:40px!important}.ml-xl-40,.mx-xl-40{margin-left:40px!important}.m-xl-42{margin:42px!important}.mt-xl-42,.my-xl-42{margin-top:42px!important}.mr-xl-42,.mx-xl-42{margin-right:42px!important}.mb-xl-42,.my-xl-42{margin-bottom:42px!important}.ml-xl-42,.mx-xl-42{margin-left:42px!important}.m-xl-48{margin:48px!important}.mt-xl-48,.my-xl-48{margin-top:48px!important}.mr-xl-48,.mx-xl-48{margin-right:48px!important}.mb-xl-48,.my-xl-48{margin-bottom:48px!important}.ml-xl-48,.mx-xl-48{margin-left:48px!important}.m-xl-50{margin:50px!important}.mt-xl-50,.my-xl-50{margin-top:50px!important}.mr-xl-50,.mx-xl-50{margin-right:50px!important}.mb-xl-50,.my-xl-50{margin-bottom:50px!important}.ml-xl-50,.mx-xl-50{margin-left:50px!important}.m-xl-56{margin:56px!important}.mt-xl-56,.my-xl-56{margin-top:56px!important}.mr-xl-56,.mx-xl-56{margin-right:56px!important}.mb-xl-56,.my-xl-56{margin-bottom:56px!important}.ml-xl-56,.mx-xl-56{margin-left:56px!important}.m-xl-58{margin:58px!important}.mt-xl-58,.my-xl-58{margin-top:58px!important}.mr-xl-58,.mx-xl-58{margin-right:58px!important}.mb-xl-58,.my-xl-58{margin-bottom:58px!important}.ml-xl-58,.mx-xl-58{margin-left:58px!important}.m-xl-60{margin:60px!important}.mt-xl-60,.my-xl-60{margin-top:60px!important}.mr-xl-60,.mx-xl-60{margin-right:60px!important}.mb-xl-60,.my-xl-60{margin-bottom:60px!important}.ml-xl-60,.mx-xl-60{margin-left:60px!important}.m-xl-64{margin:64px!important}.mt-xl-64,.my-xl-64{margin-top:64px!important}.mr-xl-64,.mx-xl-64{margin-right:64px!important}.mb-xl-64,.my-xl-64{margin-bottom:64px!important}.ml-xl-64,.mx-xl-64{margin-left:64px!important}.p-xl-0{padding:0!important}.pt-xl-0,.py-xl-0{padding-top:0!important}.pr-xl-0,.px-xl-0{padding-right:0!important}.pb-xl-0,.py-xl-0{padding-bottom:0!important}.pl-xl-0,.px-xl-0{padding-left:0!important}.p-xl-1{padding:1px!important}.pt-xl-1,.py-xl-1{padding-top:1px!important}.pr-xl-1,.px-xl-1{padding-right:1px!important}.pb-xl-1,.py-xl-1{padding-bottom:1px!important}.pl-xl-1,.px-xl-1{padding-left:1px!important}.p-xl-2{padding:2px!important}.pt-xl-2,.py-xl-2{padding-top:2px!important}.pr-xl-2,.px-xl-2{padding-right:2px!important}.pb-xl-2,.py-xl-2{padding-bottom:2px!important}.pl-xl-2,.px-xl-2{padding-left:2px!important}.p-xl-3{padding:3px!important}.pt-xl-3,.py-xl-3{padding-top:3px!important}.pr-xl-3,.px-xl-3{padding-right:3px!important}.pb-xl-3,.py-xl-3{padding-bottom:3px!important}.pl-xl-3,.px-xl-3{padding-left:3px!important}.p-xl-4{padding:4px!important}.pt-xl-4,.py-xl-4{padding-top:4px!important}.pr-xl-4,.px-xl-4{padding-right:4px!important}.pb-xl-4,.py-xl-4{padding-bottom:4px!important}.pl-xl-4,.px-xl-4{padding-left:4px!important}.p-xl-5{padding:5px!important}.pt-xl-5,.py-xl-5{padding-top:5px!important}.pr-xl-5,.px-xl-5{padding-right:5px!important}.pb-xl-5,.py-xl-5{padding-bottom:5px!important}.pl-xl-5,.px-xl-5{padding-left:5px!important}.p-xl-6{padding:6px!important}.pt-xl-6,.py-xl-6{padding-top:6px!important}.pr-xl-6,.px-xl-6{padding-right:6px!important}.pb-xl-6,.py-xl-6{padding-bottom:6px!important}.pl-xl-6,.px-xl-6{padding-left:6px!important}.p-xl-7{padding:7px!important}.pt-xl-7,.py-xl-7{padding-top:7px!important}.pr-xl-7,.px-xl-7{padding-right:7px!important}.pb-xl-7,.py-xl-7{padding-bottom:7px!important}.pl-xl-7,.px-xl-7{padding-left:7px!important}.p-xl-8{padding:8px!important}.pt-xl-8,.py-xl-8{padding-top:8px!important}.pr-xl-8,.px-xl-8{padding-right:8px!important}.pb-xl-8,.py-xl-8{padding-bottom:8px!important}.pl-xl-8,.px-xl-8{padding-left:8px!important}.p-xl-9{padding:9px!important}.pt-xl-9,.py-xl-9{padding-top:9px!important}.pr-xl-9,.px-xl-9{padding-right:9px!important}.pb-xl-9,.py-xl-9{padding-bottom:9px!important}.pl-xl-9,.px-xl-9{padding-left:9px!important}.p-xl-10{padding:10px!important}.pt-xl-10,.py-xl-10{padding-top:10px!important}.pr-xl-10,.px-xl-10{padding-right:10px!important}.pb-xl-10,.py-xl-10{padding-bottom:10px!important}.pl-xl-10,.px-xl-10{padding-left:10px!important}.p-xl-11{padding:11px!important}.pt-xl-11,.py-xl-11{padding-top:11px!important}.pr-xl-11,.px-xl-11{padding-right:11px!important}.pb-xl-11,.py-xl-11{padding-bottom:11px!important}.pl-xl-11,.px-xl-11{padding-left:11px!important}.p-xl-12{padding:12px!important}.pt-xl-12,.py-xl-12{padding-top:12px!important}.pr-xl-12,.px-xl-12{padding-right:12px!important}.pb-xl-12,.py-xl-12{padding-bottom:12px!important}.pl-xl-12,.px-xl-12{padding-left:12px!important}.p-xl-13{padding:13px!important}.pt-xl-13,.py-xl-13{padding-top:13px!important}.pr-xl-13,.px-xl-13{padding-right:13px!important}.pb-xl-13,.py-xl-13{padding-bottom:13px!important}.pl-xl-13,.px-xl-13{padding-left:13px!important}.p-xl-14{padding:14px!important}.pt-xl-14,.py-xl-14{padding-top:14px!important}.pr-xl-14,.px-xl-14{padding-right:14px!important}.pb-xl-14,.py-xl-14{padding-bottom:14px!important}.pl-xl-14,.px-xl-14{padding-left:14px!important}.p-xl-15{padding:15px!important}.pt-xl-15,.py-xl-15{padding-top:15px!important}.pr-xl-15,.px-xl-15{padding-right:15px!important}.pb-xl-15,.py-xl-15{padding-bottom:15px!important}.pl-xl-15,.px-xl-15{padding-left:15px!important}.p-xl-16{padding:16px!important}.pt-xl-16,.py-xl-16{padding-top:16px!important}.pr-xl-16,.px-xl-16{padding-right:16px!important}.pb-xl-16,.py-xl-16{padding-bottom:16px!important}.pl-xl-16,.px-xl-16{padding-left:16px!important}.p-xl-18{padding:18px!important}.pt-xl-18,.py-xl-18{padding-top:18px!important}.pr-xl-18,.px-xl-18{padding-right:18px!important}.pb-xl-18,.py-xl-18{padding-bottom:18px!important}.pl-xl-18,.px-xl-18{padding-left:18px!important}.p-xl-20{padding:20px!important}.pt-xl-20,.py-xl-20{padding-top:20px!important}.pr-xl-20,.px-xl-20{padding-right:20px!important}.pb-xl-20,.py-xl-20{padding-bottom:20px!important}.pl-xl-20,.px-xl-20{padding-left:20px!important}.p-xl-21{padding:21px!important}.pt-xl-21,.py-xl-21{padding-top:21px!important}.pr-xl-21,.px-xl-21{padding-right:21px!important}.pb-xl-21,.py-xl-21{padding-bottom:21px!important}.pl-xl-21,.px-xl-21{padding-left:21px!important}.p-xl-23{padding:23px!important}.pt-xl-23,.py-xl-23{padding-top:23px!important}.pr-xl-23,.px-xl-23{padding-right:23px!important}.pb-xl-23,.py-xl-23{padding-bottom:23px!important}.pl-xl-23,.px-xl-23{padding-left:23px!important}.p-xl-24{padding:24px!important}.pt-xl-24,.py-xl-24{padding-top:24px!important}.pr-xl-24,.px-xl-24{padding-right:24px!important}.pb-xl-24,.py-xl-24{padding-bottom:24px!important}.pl-xl-24,.px-xl-24{padding-left:24px!important}.p-xl-26{padding:26px!important}.pt-xl-26,.py-xl-26{padding-top:26px!important}.pr-xl-26,.px-xl-26{padding-right:26px!important}.pb-xl-26,.py-xl-26{padding-bottom:26px!important}.pl-xl-26,.px-xl-26{padding-left:26px!important}.p-xl-28{padding:28px!important}.pt-xl-28,.py-xl-28{padding-top:28px!important}.pr-xl-28,.px-xl-28{padding-right:28px!important}.pb-xl-28,.py-xl-28{padding-bottom:28px!important}.pl-xl-28,.px-xl-28{padding-left:28px!important}.p-xl-29{padding:29px!important}.pt-xl-29,.py-xl-29{padding-top:29px!important}.pr-xl-29,.px-xl-29{padding-right:29px!important}.pb-xl-29,.py-xl-29{padding-bottom:29px!important}.pl-xl-29,.px-xl-29{padding-left:29px!important}.p-xl-30{padding:30px!important}.pt-xl-30,.py-xl-30{padding-top:30px!important}.pr-xl-30,.px-xl-30{padding-right:30px!important}.pb-xl-30,.py-xl-30{padding-bottom:30px!important}.pl-xl-30,.px-xl-30{padding-left:30px!important}.p-xl-32{padding:32px!important}.pt-xl-32,.py-xl-32{padding-top:32px!important}.pr-xl-32,.px-xl-32{padding-right:32px!important}.pb-xl-32,.py-xl-32{padding-bottom:32px!important}.pl-xl-32,.px-xl-32{padding-left:32px!important}.p-xl-38{padding:38px!important}.pt-xl-38,.py-xl-38{padding-top:38px!important}.pr-xl-38,.px-xl-38{padding-right:38px!important}.pb-xl-38,.py-xl-38{padding-bottom:38px!important}.pl-xl-38,.px-xl-38{padding-left:38px!important}.p-xl-40{padding:40px!important}.pt-xl-40,.py-xl-40{padding-top:40px!important}.pr-xl-40,.px-xl-40{padding-right:40px!important}.pb-xl-40,.py-xl-40{padding-bottom:40px!important}.pl-xl-40,.px-xl-40{padding-left:40px!important}.p-xl-42{padding:42px!important}.pt-xl-42,.py-xl-42{padding-top:42px!important}.pr-xl-42,.px-xl-42{padding-right:42px!important}.pb-xl-42,.py-xl-42{padding-bottom:42px!important}.pl-xl-42,.px-xl-42{padding-left:42px!important}.p-xl-48{padding:48px!important}.pt-xl-48,.py-xl-48{padding-top:48px!important}.pr-xl-48,.px-xl-48{padding-right:48px!important}.pb-xl-48,.py-xl-48{padding-bottom:48px!important}.pl-xl-48,.px-xl-48{padding-left:48px!important}.p-xl-50{padding:50px!important}.pt-xl-50,.py-xl-50{padding-top:50px!important}.pr-xl-50,.px-xl-50{padding-right:50px!important}.pb-xl-50,.py-xl-50{padding-bottom:50px!important}.pl-xl-50,.px-xl-50{padding-left:50px!important}.p-xl-56{padding:56px!important}.pt-xl-56,.py-xl-56{padding-top:56px!important}.pr-xl-56,.px-xl-56{padding-right:56px!important}.pb-xl-56,.py-xl-56{padding-bottom:56px!important}.pl-xl-56,.px-xl-56{padding-left:56px!important}.p-xl-58{padding:58px!important}.pt-xl-58,.py-xl-58{padding-top:58px!important}.pr-xl-58,.px-xl-58{padding-right:58px!important}.pb-xl-58,.py-xl-58{padding-bottom:58px!important}.pl-xl-58,.px-xl-58{padding-left:58px!important}.p-xl-60{padding:60px!important}.pt-xl-60,.py-xl-60{padding-top:60px!important}.pr-xl-60,.px-xl-60{padding-right:60px!important}.pb-xl-60,.py-xl-60{padding-bottom:60px!important}.pl-xl-60,.px-xl-60{padding-left:60px!important}.p-xl-64{padding:64px!important}.pt-xl-64,.py-xl-64{padding-top:64px!important}.pr-xl-64,.px-xl-64{padding-right:64px!important}.pb-xl-64,.py-xl-64{padding-bottom:64px!important}.pl-xl-64,.px-xl-64{padding-left:64px!important}.m-xl-n1{margin:-1px!important}.mt-xl-n1,.my-xl-n1{margin-top:-1px!important}.mr-xl-n1,.mx-xl-n1{margin-right:-1px!important}.mb-xl-n1,.my-xl-n1{margin-bottom:-1px!important}.ml-xl-n1,.mx-xl-n1{margin-left:-1px!important}.m-xl-n2{margin:-2px!important}.mt-xl-n2,.my-xl-n2{margin-top:-2px!important}.mr-xl-n2,.mx-xl-n2{margin-right:-2px!important}.mb-xl-n2,.my-xl-n2{margin-bottom:-2px!important}.ml-xl-n2,.mx-xl-n2{margin-left:-2px!important}.m-xl-n3{margin:-3px!important}.mt-xl-n3,.my-xl-n3{margin-top:-3px!important}.mr-xl-n3,.mx-xl-n3{margin-right:-3px!important}.mb-xl-n3,.my-xl-n3{margin-bottom:-3px!important}.ml-xl-n3,.mx-xl-n3{margin-left:-3px!important}.m-xl-n4{margin:-4px!important}.mt-xl-n4,.my-xl-n4{margin-top:-4px!important}.mr-xl-n4,.mx-xl-n4{margin-right:-4px!important}.mb-xl-n4,.my-xl-n4{margin-bottom:-4px!important}.ml-xl-n4,.mx-xl-n4{margin-left:-4px!important}.m-xl-n5{margin:-5px!important}.mt-xl-n5,.my-xl-n5{margin-top:-5px!important}.mr-xl-n5,.mx-xl-n5{margin-right:-5px!important}.mb-xl-n5,.my-xl-n5{margin-bottom:-5px!important}.ml-xl-n5,.mx-xl-n5{margin-left:-5px!important}.m-xl-n6{margin:-6px!important}.mt-xl-n6,.my-xl-n6{margin-top:-6px!important}.mr-xl-n6,.mx-xl-n6{margin-right:-6px!important}.mb-xl-n6,.my-xl-n6{margin-bottom:-6px!important}.ml-xl-n6,.mx-xl-n6{margin-left:-6px!important}.m-xl-n7{margin:-7px!important}.mt-xl-n7,.my-xl-n7{margin-top:-7px!important}.mr-xl-n7,.mx-xl-n7{margin-right:-7px!important}.mb-xl-n7,.my-xl-n7{margin-bottom:-7px!important}.ml-xl-n7,.mx-xl-n7{margin-left:-7px!important}.m-xl-n8{margin:-8px!important}.mt-xl-n8,.my-xl-n8{margin-top:-8px!important}.mr-xl-n8,.mx-xl-n8{margin-right:-8px!important}.mb-xl-n8,.my-xl-n8{margin-bottom:-8px!important}.ml-xl-n8,.mx-xl-n8{margin-left:-8px!important}.m-xl-n9{margin:-9px!important}.mt-xl-n9,.my-xl-n9{margin-top:-9px!important}.mr-xl-n9,.mx-xl-n9{margin-right:-9px!important}.mb-xl-n9,.my-xl-n9{margin-bottom:-9px!important}.ml-xl-n9,.mx-xl-n9{margin-left:-9px!important}.m-xl-n10{margin:-10px!important}.mt-xl-n10,.my-xl-n10{margin-top:-10px!important}.mr-xl-n10,.mx-xl-n10{margin-right:-10px!important}.mb-xl-n10,.my-xl-n10{margin-bottom:-10px!important}.ml-xl-n10,.mx-xl-n10{margin-left:-10px!important}.m-xl-n11{margin:-11px!important}.mt-xl-n11,.my-xl-n11{margin-top:-11px!important}.mr-xl-n11,.mx-xl-n11{margin-right:-11px!important}.mb-xl-n11,.my-xl-n11{margin-bottom:-11px!important}.ml-xl-n11,.mx-xl-n11{margin-left:-11px!important}.m-xl-n12{margin:-12px!important}.mt-xl-n12,.my-xl-n12{margin-top:-12px!important}.mr-xl-n12,.mx-xl-n12{margin-right:-12px!important}.mb-xl-n12,.my-xl-n12{margin-bottom:-12px!important}.ml-xl-n12,.mx-xl-n12{margin-left:-12px!important}.m-xl-n13{margin:-13px!important}.mt-xl-n13,.my-xl-n13{margin-top:-13px!important}.mr-xl-n13,.mx-xl-n13{margin-right:-13px!important}.mb-xl-n13,.my-xl-n13{margin-bottom:-13px!important}.ml-xl-n13,.mx-xl-n13{margin-left:-13px!important}.m-xl-n14{margin:-14px!important}.mt-xl-n14,.my-xl-n14{margin-top:-14px!important}.mr-xl-n14,.mx-xl-n14{margin-right:-14px!important}.mb-xl-n14,.my-xl-n14{margin-bottom:-14px!important}.ml-xl-n14,.mx-xl-n14{margin-left:-14px!important}.m-xl-n15{margin:-15px!important}.mt-xl-n15,.my-xl-n15{margin-top:-15px!important}.mr-xl-n15,.mx-xl-n15{margin-right:-15px!important}.mb-xl-n15,.my-xl-n15{margin-bottom:-15px!important}.ml-xl-n15,.mx-xl-n15{margin-left:-15px!important}.m-xl-n16{margin:-16px!important}.mt-xl-n16,.my-xl-n16{margin-top:-16px!important}.mr-xl-n16,.mx-xl-n16{margin-right:-16px!important}.mb-xl-n16,.my-xl-n16{margin-bottom:-16px!important}.ml-xl-n16,.mx-xl-n16{margin-left:-16px!important}.m-xl-n18{margin:-18px!important}.mt-xl-n18,.my-xl-n18{margin-top:-18px!important}.mr-xl-n18,.mx-xl-n18{margin-right:-18px!important}.mb-xl-n18,.my-xl-n18{margin-bottom:-18px!important}.ml-xl-n18,.mx-xl-n18{margin-left:-18px!important}.m-xl-n20{margin:-20px!important}.mt-xl-n20,.my-xl-n20{margin-top:-20px!important}.mr-xl-n20,.mx-xl-n20{margin-right:-20px!important}.mb-xl-n20,.my-xl-n20{margin-bottom:-20px!important}.ml-xl-n20,.mx-xl-n20{margin-left:-20px!important}.m-xl-n21{margin:-21px!important}.mt-xl-n21,.my-xl-n21{margin-top:-21px!important}.mr-xl-n21,.mx-xl-n21{margin-right:-21px!important}.mb-xl-n21,.my-xl-n21{margin-bottom:-21px!important}.ml-xl-n21,.mx-xl-n21{margin-left:-21px!important}.m-xl-n23{margin:-23px!important}.mt-xl-n23,.my-xl-n23{margin-top:-23px!important}.mr-xl-n23,.mx-xl-n23{margin-right:-23px!important}.mb-xl-n23,.my-xl-n23{margin-bottom:-23px!important}.ml-xl-n23,.mx-xl-n23{margin-left:-23px!important}.m-xl-n24{margin:-24px!important}.mt-xl-n24,.my-xl-n24{margin-top:-24px!important}.mr-xl-n24,.mx-xl-n24{margin-right:-24px!important}.mb-xl-n24,.my-xl-n24{margin-bottom:-24px!important}.ml-xl-n24,.mx-xl-n24{margin-left:-24px!important}.m-xl-n26{margin:-26px!important}.mt-xl-n26,.my-xl-n26{margin-top:-26px!important}.mr-xl-n26,.mx-xl-n26{margin-right:-26px!important}.mb-xl-n26,.my-xl-n26{margin-bottom:-26px!important}.ml-xl-n26,.mx-xl-n26{margin-left:-26px!important}.m-xl-n28{margin:-28px!important}.mt-xl-n28,.my-xl-n28{margin-top:-28px!important}.mr-xl-n28,.mx-xl-n28{margin-right:-28px!important}.mb-xl-n28,.my-xl-n28{margin-bottom:-28px!important}.ml-xl-n28,.mx-xl-n28{margin-left:-28px!important}.m-xl-n29{margin:-29px!important}.mt-xl-n29,.my-xl-n29{margin-top:-29px!important}.mr-xl-n29,.mx-xl-n29{margin-right:-29px!important}.mb-xl-n29,.my-xl-n29{margin-bottom:-29px!important}.ml-xl-n29,.mx-xl-n29{margin-left:-29px!important}.m-xl-n30{margin:-30px!important}.mt-xl-n30,.my-xl-n30{margin-top:-30px!important}.mr-xl-n30,.mx-xl-n30{margin-right:-30px!important}.mb-xl-n30,.my-xl-n30{margin-bottom:-30px!important}.ml-xl-n30,.mx-xl-n30{margin-left:-30px!important}.m-xl-n32{margin:-32px!important}.mt-xl-n32,.my-xl-n32{margin-top:-32px!important}.mr-xl-n32,.mx-xl-n32{margin-right:-32px!important}.mb-xl-n32,.my-xl-n32{margin-bottom:-32px!important}.ml-xl-n32,.mx-xl-n32{margin-left:-32px!important}.m-xl-n38{margin:-38px!important}.mt-xl-n38,.my-xl-n38{margin-top:-38px!important}.mr-xl-n38,.mx-xl-n38{margin-right:-38px!important}.mb-xl-n38,.my-xl-n38{margin-bottom:-38px!important}.ml-xl-n38,.mx-xl-n38{margin-left:-38px!important}.m-xl-n40{margin:-40px!important}.mt-xl-n40,.my-xl-n40{margin-top:-40px!important}.mr-xl-n40,.mx-xl-n40{margin-right:-40px!important}.mb-xl-n40,.my-xl-n40{margin-bottom:-40px!important}.ml-xl-n40,.mx-xl-n40{margin-left:-40px!important}.m-xl-n42{margin:-42px!important}.mt-xl-n42,.my-xl-n42{margin-top:-42px!important}.mr-xl-n42,.mx-xl-n42{margin-right:-42px!important}.mb-xl-n42,.my-xl-n42{margin-bottom:-42px!important}.ml-xl-n42,.mx-xl-n42{margin-left:-42px!important}.m-xl-n48{margin:-48px!important}.mt-xl-n48,.my-xl-n48{margin-top:-48px!important}.mr-xl-n48,.mx-xl-n48{margin-right:-48px!important}.mb-xl-n48,.my-xl-n48{margin-bottom:-48px!important}.ml-xl-n48,.mx-xl-n48{margin-left:-48px!important}.m-xl-n50{margin:-50px!important}.mt-xl-n50,.my-xl-n50{margin-top:-50px!important}.mr-xl-n50,.mx-xl-n50{margin-right:-50px!important}.mb-xl-n50,.my-xl-n50{margin-bottom:-50px!important}.ml-xl-n50,.mx-xl-n50{margin-left:-50px!important}.m-xl-n56{margin:-56px!important}.mt-xl-n56,.my-xl-n56{margin-top:-56px!important}.mr-xl-n56,.mx-xl-n56{margin-right:-56px!important}.mb-xl-n56,.my-xl-n56{margin-bottom:-56px!important}.ml-xl-n56,.mx-xl-n56{margin-left:-56px!important}.m-xl-n58{margin:-58px!important}.mt-xl-n58,.my-xl-n58{margin-top:-58px!important}.mr-xl-n58,.mx-xl-n58{margin-right:-58px!important}.mb-xl-n58,.my-xl-n58{margin-bottom:-58px!important}.ml-xl-n58,.mx-xl-n58{margin-left:-58px!important}.m-xl-n60{margin:-60px!important}.mt-xl-n60,.my-xl-n60{margin-top:-60px!important}.mr-xl-n60,.mx-xl-n60{margin-right:-60px!important}.mb-xl-n60,.my-xl-n60{margin-bottom:-60px!important}.ml-xl-n60,.mx-xl-n60{margin-left:-60px!important}.m-xl-n64{margin:-64px!important}.mt-xl-n64,.my-xl-n64{margin-top:-64px!important}.mr-xl-n64,.mx-xl-n64{margin-right:-64px!important}.mb-xl-n64,.my-xl-n64{margin-bottom:-64px!important}.ml-xl-n64,.mx-xl-n64{margin-left:-64px!important}.m-xl-auto{margin:auto!important}.mt-xl-auto,.my-xl-auto{margin-top:auto!important}.mr-xl-auto,.mx-xl-auto{margin-right:auto!important}.mb-xl-auto,.my-xl-auto{margin-bottom:auto!important}.ml-xl-auto,.mx-xl-auto{margin-left:auto!important}.text-xl-left{text-align:left!important}.text-xl-right{text-align:right!important}.text-xl-center{text-align:center!important}}.text-lowercase{text-transform:lowercase!important}.text-uppercase{text-transform:uppercase!important}.text-capitalize{text-transform:capitalize!important}.font-weight-light{font-weight:300!important}.font-weight-lighter{font-weight:lighter!important}.font-weight-normal{font-weight:400!important}.font-weight-bold{font-weight:700!important}.font-weight-bolder{font-weight:bolder!important}.font-italic{font-style:italic!important}.text-white{color:#fff!important}.text-primary{color:#c82c37!important}a.text-primary:focus,a.text-primary:hover{color:#891e26!important}.text-secondary{color:#919191!important}a.text-secondary:focus,a.text-secondary:hover{color:#6b6b6b!important}.text-success{color:#4caf50!important}a.text-success:focus,a.text-success:hover{color:#357a38!important}.text-info{color:#00bcd4!important}a.text-info:focus,a.text-info:hover{color:#007888!important}.text-warning{color:#ff9800!important}a.text-warning:focus,a.text-warning:hover{color:#b36a00!important}.text-danger{color:#f44336!important}a.text-danger:focus,a.text-danger:hover{color:#d2190b!important}.text-light{color:#f8f9fa!important}a.text-light:focus,a.text-light:hover{color:#cbd3da!important}.text-dark{color:#343a40!important}a.text-dark:focus,a.text-dark:hover{color:#121416!important}.text-body{color:#212529!important}.text-muted{color:#6c757d!important}.text-black-50{color:rgba(0,0,0,.5)!important}.text-white-50{color:rgba(255,255,255,.5)!important}.text-hide{font:0/0 a;color:transparent;text-shadow:none;background-color:transparent;border:0}.text-decoration-none{text-decoration:none!important}.text-break{word-wrap:break-word!important}.text-reset{color:inherit!important}.visible{visibility:visible!important}.invisible{visibility:hidden!important}@media print{*,::after,::before{text-shadow:none!important;box-shadow:none!important}a:not(.btn){text-decoration:underline}abbr[title]::after{content:\" (\" attr(title) \")\"}pre{white-space:pre-wrap!important}blockquote,pre{border:1px solid #adb5bd;page-break-inside:avoid}thead{display:table-header-group}img,tr{page-break-inside:avoid}h2,h3,p{orphans:3;widows:3}h2,h3{page-break-after:avoid}@page{size:a3}.container,body{min-width:992px!important}.navbar{display:none}.badge{border:1px solid #000}.table{border-collapse:collapse!important}.table td,.table th{background-color:#fff!important}.table-bordered td,.table-bordered th{border:1px solid #dee2e6!important}.table-dark{color:inherit}.table-dark tbody+tbody,.table-dark td,.table-dark th,.table-dark thead th{border-color:#f2f3f4}.table .thead-dark th{color:inherit;border-color:#f2f3f4}}.mb-0 label{margin-bottom:0!important}.font-weight-normal .sd-label{font-weight:400!important}.c-fa-icon{font-size:20px;color:gray}"]
    })
], GridPopupFilterComponent);

let ChartControlComponent = class ChartControlComponent {
    constructor(ref, datePipe) {
        this.ref = ref;
        this.datePipe = datePipe;
        this.initialized = false;
        this.visible = true;
        this.height = '300px';
    }
    set chartOption(chartOption) {
        this.pChartOption = chartOption;
        if (this.initialized) {
            this.renderChart();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.renderChart(true);
        this.initialized = true;
        this.ref.detectChanges();
    }
    renderChart(firstRender) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.height = ((_a = this.pChartOption) === null || _a === void 0 ? void 0 : _a.height) || '300px';
            if (!firstRender) {
                this.visible = false;
                yield new Promise(resolve => setTimeout(resolve, 500));
                this.visible = true;
            }
            setTimeout(() => {
                const canvas = this.chartRef.nativeElement;
                this.ctx = canvas.getContext('2d');
                switch (this.pChartOption.type) {
                    case 'pie':
                        this.renderPieChart(this.pChartOption);
                        break;
                    case 'bar':
                        this.renderBarChart(this.pChartOption);
                        break;
                    case 'line':
                        this.renderLineChart(this.pChartOption);
                        break;
                    case 'barline':
                        this.renderBarLineChart(this.pChartOption);
                        break;
                    default: break;
                }
            }, 500);
        });
    }
    renderPieChart(option) {
    }
    renderBarChart(option) {
        var _a, _b;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const newwidth = Math.max(option.labels.length * option.datasets.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
            $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes: [{
                            display: true,
                            ticks: {
                                beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true)),
                            },
                            scaleLabel: {
                                display: !!option.yTitle,
                                labelString: option.yTitle || ''
                            }
                        }]
                }
            },
            type: 'bar',
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        data: e.data
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
    renderLineChart(option) {
        var _a, _b;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const newwidth = Math.max(option.labels.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
            $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes: [{
                            display: true,
                            ticks: {
                                beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true))
                            },
                            scaleLabel: {
                                display: !!option.yTitle,
                                labelString: option.yTitle || ''
                            }
                        }]
                }
            },
            type: 'line',
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        borderColor: e.borderColor,
                        data: e.data,
                        lineTension: 0,
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
    renderBarLineChart(option) {
        var _a, _b, _c;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const numberOfBars = option.datasets.filter(e => e.type === 'bar').length;
            if (numberOfBars <= 1) {
                const newwidth = Math.max(option.labels.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
                $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
            }
            else {
                const newwidth = Math.max(option.labels.length * numberOfBars * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
                $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
            }
        }
        const leftId = `I${v4()}`;
        const rightId = `I${v4()}`;
        const yAxes = [{
                type: 'linear',
                display: true,
                position: 'left',
                id: leftId,
                ticks: {
                    beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true)),
                    suggestedMin: 0
                },
                scaleLabel: {
                    display: !!option.yTitle,
                    labelString: option.yTitle || ''
                }
            }];
        if (option.datasets.some(e => e.yAlign === 'right')) {
            yAxes.push({
                type: 'linear',
                display: true,
                position: 'right',
                id: rightId,
                ticks: {
                    beginAtZero: (_c = option.beginAtZero, (_c !== null && _c !== void 0 ? _c : true)),
                    suggestedMin: 0
                },
                scaleLabel: {
                    display: !!option.yRightTitle,
                    labelString: option.yRightTitle || ''
                }
            });
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                title: {
                    display: true,
                    text: option.title
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes
                }
            },
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        type: e.type,
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        borderColor: e.borderColor,
                        data: e.data,
                        yAxisID: e.yAlign === 'right' ? rightId : leftId
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
};
ChartControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DatePipe }
];
__decorate([
    Input()
], ChartControlComponent.prototype, "chartOption", null);
__decorate([
    ViewChild('chart')
], ChartControlComponent.prototype, "chartRef", void 0);
__decorate([
    ViewChild('chartWrapper')
], ChartControlComponent.prototype, "chartWrapperRef", void 0);
__decorate([
    ViewChild('chartAxis')
], ChartControlComponent.prototype, "chartAxisRef", void 0);
__decorate([
    ViewChild('chartAreaWrapperExtend')
], ChartControlComponent.prototype, "chartAreaWrapperExtendRef", void 0);
ChartControlComponent = __decorate([
    Component({
        selector: 'sd-chart-control',
        template: "<div *ngIf=\"visible\" class=\"c-chart-wrapper mt-2\" >\r\n  <div class=\"c-chart-area-wrapper\" #chartWrapper>\r\n    <div class=\"c-chart-area-wrapper-extend\" [ngStyle]=\"{'height':height}\" #chartAreaWrapperExtend>\r\n      <canvas #chart></canvas>\r\n    </div>\r\n  </div>\r\n</div>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-container{background:#f5f6f7;border-radius:5px}.c-flex{display:flex;margin:15px;border-radius:8px}.c-chart-container{box-shadow:0 0 13px 0 rgba(82,63,105,.1);border-radius:8px;margin:15px;padding:15px;background:#fff}.c-btn-dashboard{height:60%;align-self:center;vertical-align:middle}.c-chart-wrapper{position:relative}.c-chart-wrapper>canvas{position:absolute;left:0;top:0;pointer-events:none}.c-chart-area-wrapper{overflow-x:scroll;position:relative;width:100%}.c-chart-area-wrapper-extend{position:relative}"]
    })
], ChartControlComponent);

let ChipControlComponent = class ChipControlComponent {
    constructor(ref, utilityService, translateService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.translateService = translateService;
        this.initialized = false;
        this.pModel = [];
        this.pItems = [];
        this.name = v4();
        this.separatorKeysCodes = [ENTER, COMMA];
        this.selectable = true;
        this.removable = true;
        // tslint:disable-next-line: variable-name
        this._items = [];
        this.limit = 50;
        this.selectedItems = [];
        // model
        // tslint:disable-next-line: variable-name
        this._model = [];
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: variable-name
        this._minItem = 0;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.chipSelected = new EventEmitter();
        this.onChanges = () => {
            var _a;
            this._model = this.pModel;
            this._items = this.pItems;
            this.selectedItems = this._items.filter(item => this._model.findIndex(value => { var _a; return value === ((_a = item) === null || _a === void 0 ? void 0 : _a[this.valueField]); }) !== -1);
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.items) {
                    return undefined;
                }
                const selectedItem = this.items.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                if (this.items.some(item => item[this.displayField].toLowerCase().indexOf(value.toLowerCase()) !== -1)) {
                    return value;
                }
                else {
                    return undefined;
                }
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.validateMinItem = () => {
            if (!this.chipList) {
                return null;
            }
            if (this.selectedItems.length < this._minItem) {
                this.chipList.errorState = true;
                return `${this.translateService.translate('Please select at least')} ${this._minItem}`;
            }
            this.chipList.errorState = false;
            return null;
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            this.input.nativeElement.value = '';
            this.ipt = '';
            this.formModel.control.setValue(null);
            (_b = this.autocompleteTrigger) === null || _b === void 0 ? void 0 : _b.openPanel();
            this.ref.detectChanges();
        };
    }
    get items() {
        return this._items;
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(values) {
        if (!Array.isArray(values)) {
            values = [];
        }
        this.pModel = values;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set minItem(minItem) {
        var _a;
        minItem = +minItem || 0;
        this._minItem = minItem;
        (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        this.ref.detectChanges();
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => { var _a, _b; return typeof item === 'string' ? item : (_b = (_a = item) === null || _a === void 0 ? void 0 : _a[this.displayField], (_b !== null && _b !== void 0 ? _b : '')); }), map(name => this.filter(name)));
    }
    ngAfterViewInit() {
        var _a, _b;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        (_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    filter(value) {
        return this.items
            .filter(item => {
            if (this.selectedItems.some(e => e[this.valueField] === item[this.valueField])) {
                return false;
            }
            return !value || this.utilityService.changeAliasLowerCase(item[this.displayField])
                .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
        }).filter((item, index) => index < this.limit);
    }
    add(event) {
        // Add item only when MatAutocomplete is not open
        // To make sure this does not conflict with OptionSelected Event
        if (!this.matAutocomplete.isOpen) {
            const input = event.input;
            const value = event.value;
            // Add our item
            if ((value || '').trim()) {
                const item = this.items.find(e => e[this.displayField]
                    && e[this.displayField].toString().toLowerCase() === value.toString().toLowerCase().trim());
                if (item) {
                    this.selectedItems.push(item);
                    this.updateModel();
                }
            }
            // Reset the input value
            if (input) {
                input.value = '';
            }
            this.formModel.control.setValue(null);
        }
    }
    remove(item) {
        const index = this.selectedItems.indexOf(item);
        if (index >= 0) {
            this.selectedItems.splice(index, 1);
            this.updateModel();
            this.formModel.reset();
        }
    }
    select(item) {
        this.chipSelected.emit(item);
    }
    selected(event) {
        const value = event.option.viewValue;
        // Add our fruit
        if ((value || '').trim()) {
            const item = this.items.find(e => e[this.displayField]
                && e[this.displayField].toString().toLowerCase() === value.toString().toLowerCase().trim());
            this.selectedItems.push(item);
            this.input.nativeElement.value = '';
            this.formModel.control.setValue(null);
            this.updateModel();
            setTimeout(() => {
                var _a;
                (_a = this.autocompleteTrigger) === null || _a === void 0 ? void 0 : _a.openPanel();
            });
        }
    }
    updateModel() {
        this._model = this.selectedItems.map(e => e[this.valueField]);
        this.modelChange.emit(this._model);
        this.change.emit(this.selectedItems);
        this.sdChange.emit(this.selectedItems);
        setTimeout(() => {
            var _a, _b;
            (_b = (_a = this.form) === null || _a === void 0 ? void 0 : _a.form) === null || _b === void 0 ? void 0 : _b.markAsDirty();
        }, 0);
    }
};
ChipControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService },
    { type: TranslateService }
];
__decorate([
    Input()
], ChipControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "displayChipField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "items", null);
__decorate([
    Input()
], ChipControlComponent.prototype, "limit", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "model", null);
__decorate([
    Output()
], ChipControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "minItem", null);
__decorate([
    Output()
], ChipControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], ChipControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], ChipControlComponent.prototype, "chipSelected", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], ChipControlComponent.prototype, "formModel", void 0);
__decorate([
    ViewChild('input')
], ChipControlComponent.prototype, "input", void 0);
__decorate([
    ViewChild('auto')
], ChipControlComponent.prototype, "matAutocomplete", void 0);
__decorate([
    ViewChild('chipList', { static: true })
], ChipControlComponent.prototype, "chipList", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], ChipControlComponent.prototype, "autocompleteTrigger", void 0);
ChipControlComponent = __decorate([
    Component({
        selector: 'sd-chip-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <mat-chip-list #chipList>\r\n    <ng-container *ngFor=\"let item of selectedItems\">\r\n      <mat-chip *ngIf=\"item\" [selectable]=\"selectable\" [removable]=\"removable\" (removed)=\"remove(item)\" [selected]=\"item.isSelected\"\r\n        (selectionChange)=\"select(item)\" [disabled]=\"disabled\" (click)=\"item.isSelected = !item.isSelected\">\r\n        {{item[displayChipField] || item[displayField]}}\r\n        <mat-icon matChipRemove *ngIf=\"removable\"><i class=\"fa fa-times text-danger c-chip-remove\"></i></mat-icon>\r\n      </mat-chip>\r\n    </ng-container>\r\n    <input #autocompleteTrigger #formModel=\"ngModel\" [(ngModel)]=\"ipt\" [name]=\"name\" [placeholder]=\"label\"\r\n      [disabled]=\"disabled\" [matAutocomplete]=\"auto\" [matChipInputFor]=\"chipList\"\r\n      [matChipInputSeparatorKeyCodes]=\"separatorKeysCodes\" (matChipInputTokenEnd)=\"add($event)\"\r\n      [sdChipMinItem]=\"validateMinItem\" autocomplete=\"false\" matInput #input>\r\n    <i *ngIf=\"!ipt\" matSuffix class=\"fa fa-search fa-fw\"></i>\r\n    <i *ngIf=\"ipt\" matSuffix class=\"fa fa-times fa-fw text-danger\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i>\r\n  </mat-chip-list>\r\n  <mat-error *ngIf=\"formModel?.errors?.minItem\">\r\n    {{formModel?.errors?.minItem}}\r\n  </mat-error>\r\n  <mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\" (optionSelected)=\"selected($event)\">\r\n    <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-autocomplete>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}", "sd-chip-control .c-chip-remove:hover{color:#f44336!important}"]
    })
], ChipControlComponent);

let GridSubInformationComponent = class GridSubInformationComponent {
    constructor(ref, settingService, notifyService) {
        this.ref = ref;
        this.settingService = settingService;
        this.notifyService = notifyService;
        this.height = 'auto';
        this.columns = [];
        this.commands = [];
        this.subItems = [];
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.filter = {};
        this.onEditorChange = (column, item, value) => {
            var _a;
            if (column.type !== 'children') {
                (_a = column.editor) === null || _a === void 0 ? void 0 : _a.change(item, value);
                this.ref.detectChanges();
            }
        };
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
    }
    updateFilter() {
    }
    trackById(index, item) {
        return item.id;
    }
};
GridSubInformationComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: SettingService },
    { type: NotifyService }
];
__decorate([
    Input()
], GridSubInformationComponent.prototype, "height", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "commands", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "subItems", void 0);
GridSubInformationComponent = __decorate([
    Component({
        selector: 'sd-grid-sub-information',
        template: "<div class=\"clearfix\"></div>\r\n<div *ngIf=\"!isMobile\" class=\"sd-box sd-box-primary\">\r\n  <div class=\"sd-box-body p-0\">\r\n    <div class=\"row mx-0\">\r\n      <div class=\"table-responsive\" style=\"position: relative;\" [ngStyle]=\"{'height': height}\">\r\n        <table class=\"table table-hover table-striped table-bordered\">\r\n          <thead class=\"thead-light\">\r\n            <tr>\r\n              <th class=\"position-sticky c-sticky-all align-middle p-0\" style=\"width:1px\">\r\n                <div class=\"d-flex h-100\">\r\n                  <div style=\"width:4px; min-width: 4px;\"></div>\r\n                  <div *ngIf=\"commands?.length\" class=\"align-middle text-center\"\r\n                    [ngStyle]=\"{'width':commands.length*35 + 'px', 'min-width': commands.length*35 + 'px'}\">\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"c-sticky-spliter\"></div>\r\n                </div>\r\n              </th>\r\n              <th *ngFor=\"let column of columns\" class=\"position-sticky c-sticky-top\"\r\n                [ngStyle]=\"{'width':column.width ? column.width : '','min-width':column.width ? column.width : '300px'}\">\r\n                <span [title]=\"column.title\" class=\"c-header-title cursor-pointer\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : ''}\">\r\n                  {{column.title}}\r\n                </span>\r\n              </th>\r\n            </tr>\r\n          </thead>\r\n          <tbody>\r\n            <ng-container *ngFor=\"let item of subItems; trackBy: trackById\">\r\n              <tr>\r\n                <td class=\"position-sticky c-sticky-left p-0\" style=\"width:1px\">\r\n                  <div class=\"d-inline-flex align-middle h-100\">\r\n                    <div class=\"h-100\" style=\"width:4px;min-width: 4px;left:0\" matTooltipPosition=\"after\">\r\n                    </div>\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"d-inline-flex align-middle\">\r\n                    <div class=\"d-flex align-middle text-center justify-content-center\"\r\n                      [ngStyle]=\"{'width':commands.length*35 + 'px', 'min-width': commands.length*35 + 'px'}\">\r\n                      <ng-container *ngIf=\"item.viewCommands?.length\">\r\n                        <section *ngFor=\"let command of item.viewCommands\">\r\n                          <button (click)=\"command.click(item)\" type=\"button\" class=\"c-btn-icon\"\r\n                            [matTooltip]=\"command.title\" [disabled]=\"command.disabled\">\r\n                            <i class=\"{{command.icon}}\" aria-hidden=\"true\"></i>\r\n                          </button>\r\n                        </section>\r\n                      </ng-container>\r\n                    </div>\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"d-inline-flex align-middle h-100\">\r\n                    <div class=\"c-sticky-spliter h-100\"></div>\r\n                  </div>\r\n                </td>\r\n                <td *ngFor=\"let column of columns\" class=\"align-middle\"\r\n                  [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number', 'text-right': column.type === 'number'}\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '', 'min-width':column.width ? column.width : '300px'}\">\r\n                  <ng-container *ngIf=\"!column.children?.length\">\r\n                    <ng-container *ngIf=\"item[column.field] | editorSubInformationHandler:item:columns\">\r\n                      <ng-container *ngIf=\"item.editorHandler[column.field].visible;else elseDisableEditor\">\r\n                        <div *ngIf=\"column.type === 'string'\">\r\n                          <input class=\"form-control c-input-xs\"\r\n                            [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n                            [(ngModel)]=\"item[column.field]\"\r\n                            (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n                            (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'number'\">\r\n                          <input class=\"form-control c-input-xs\" type=\"number\"\r\n                            [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n                            [(ngModel)]=\"item[column.field]\"\r\n                            (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n                            (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'bool'\">\r\n                          <div class=\"align-middle\">\r\n                            <mat-slide-toggle [(ngModel)]=\"item[column.field]\"\r\n                              (change)=\"onEditorChange(column,item,item[column.field])\" color=\"primary\">\r\n                            </mat-slide-toggle>\r\n                          </div>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #elseDisableEditor>\r\n                        <div *ngIf=\"column.type === 'string'\">\r\n                          <div class=\"c-ellipsis\">\r\n                            <span [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-badge':item.badge && item.badge[column.field], \r\n                            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n                            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n                            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n                            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n                            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n                            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n                            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n                            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n                            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field]}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'color'\">\r\n                          <input [disabled]=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n                            [(ngModel)]=\"item[column.field]\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'number'\">\r\n                          <div class=\"pull-right\">\r\n                            <span\r\n                              [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-badge':item.badge && item.badge[column.field], \r\n                              'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n                              'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n                              'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n                              'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n                              'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n                              'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n                              'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n                              'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n                              'blinker': item.blinker && item.blinker[column.field]}\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'date'\">\r\n                          {{item[column.field] | date:'dd/MM/yyyy'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'datetime'\">\r\n                          {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'time'\">\r\n                          {{item[column.field] | date:'HH:mm'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'bool'\">\r\n                          <div class=\"align-middle\">\r\n                            <span *ngIf=\"item[column.field]\"\r\n                              class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n                            <span *ngIf=\"!item[column.field]\"\r\n                              class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'values'\">\r\n                          <div class=\"status c-ellipsis\"\r\n                            [ngStyle]=\"{'color':column?.dictionary[item[column.field]]?.color}\">\r\n                            {{!!column?.dictionary[item[column.field]] ? column?.dictionary[item[column.field]]?.text : item[column.field]}}\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'radio'\">\r\n                          <div class=\"c-ellipsis\">\r\n                            <span>{{item[column.field]}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'image'\">\r\n                          <div class=\"align-middle\">\r\n                            <img [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n                              [height]=\"column.display?.height\" style=\"margin: 5px 0\">\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </ng-container>\r\n                  </ng-container>\r\n                  <div *ngIf=\"column.children?.length\" class=\"row mx-0\">\r\n                    <div *ngFor=\"let childColumn of column.children | filterMobile:item\"\r\n                      [ngClass]=\"{'col-sm-6': childColumn?.colSpan === 1, 'col-sm-12': !childColumn?.colSpan || childColumn?.colSpan === 2}\">\r\n                      <span class=\"c-mobile-title\">\u2022 {{childColumn.title}}:</span>\r\n                      <span *ngIf=\"childColumn.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n                        'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n                        'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n                        'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n                        'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n                        'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n                        'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n                        'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n                        'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n                        'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field]}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'number'\" class=\"c-mobile-value\"\r\n                        [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n                        'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n                        'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n                        'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n                        'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n                        'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n                        'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n                        'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n                        'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n                        'blinker': item.blinker && item.blinker[childColumn.field]}\">{{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'date'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'time'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'HH:mm'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'bool'\" class=\"c-mobile-value\">\r\n                        <span *ngIf=\"item[childColumn.field]\"\r\n                          class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                        <span *ngIf=\"!item[childColumn.field]\"\r\n                          class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n                      </span>\r\n                      <span *ngIf=\"childColumn.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\"\r\n                          type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[childColumn.field]\"></span>\r\n                      <span *ngIf=\"childColumn.type === 'values'\" class=\"status c-mobile-value\"\r\n                        [ngStyle]=\"{'color':childColumn?.dictionary[item[childColumn.field]]?.color}\">\r\n                        {{!!childColumn?.dictionary[item[childColumn.field]] ? childColumn?.dictionary[item[childColumn.field]]?.text : item[childColumn.field]}}\r\n                      </span>\r\n                      <span *ngIf=\"childColumn.type === 'radio'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n                      <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                        [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\"\r\n                        style=\"margin: 5px 0\">\r\n                    </div>\r\n                  </div>\r\n                </td>\r\n              </tr>\r\n            </ng-container>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n<div *ngIf=\"isMobile\" class=\"sd-box c-mobile-box\">\r\n  <div class=\"sd-box-body c-mobile-body\" [ngStyle]=\"{'height': height}\">\r\n    <ng-container *ngFor=\"let item of subItems\">\r\n      <div class=\"c-mobile-item\">\r\n        <ng-container *ngFor=\"let column of columns | filterMobile:item\">\r\n          <div *ngIf=\"item[column.field]\" class=\"c-mobile-row\">\r\n            <span class=\"c-mobile-title\">\u2022 {{column.title}}:</span>\r\n            <span *ngIf=\"column.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-mobile-badge':item.badge && item.badge[column.field], \r\n            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field]}}</span>\r\n            <span *ngIf=\"column.type === 'number'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-mobile-badge':item.badge && item.badge[column.field], \r\n            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field] | number : '1.0-2'}}</span>\r\n            <span *ngIf=\"column.type === 'datetime'\"\r\n              class=\"c-mobile-value\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n            <span *ngIf=\"column.type === 'date'\"\r\n              class=\"c-mobile-value\">{{item[column.field] | date:'dd/MM/yyyy'}}</span>\r\n            <span *ngIf=\"column.type === 'time'\" class=\"c-mobile-value\">{{item[column.field] | date:'HH:mm'}}</span>\r\n            <span *ngIf=\"column.type === 'bool'\" class=\"c-mobile-value\">\r\n              <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n              <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n            <span *ngIf=\"column.type === 'values'\" class=\"status c-mobile-value\"\r\n              [ngStyle]=\"{'color':column?.dictionary[item[column.field]]?.color}\">\r\n              {{!!column?.dictionary[item[column.field]] ? column?.dictionary[item[column.field]]?.text : item[column.field]}}\r\n            </span>\r\n            <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n            <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n              [height]=\"column.display?.height\" style=\"margin: 5px 0\">\r\n          </div>\r\n          <ng-container *ngIf=\"column.children?.length\">\r\n            <div class=\"c-mobile-row\" *ngFor=\"let childColumn of column.children | filterMobile:item\">\r\n              <span class=\"c-mobile-title\">\u2022 {{childColumn.title}}:</span>\r\n              <span *ngIf=\"childColumn.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n            'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field]}}</span>\r\n              <span *ngIf=\"childColumn.type === 'number'\" class=\"c-mobile-value\"\r\n                [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n            'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field] | number : '1.0-2'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'date'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'time'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'HH:mm'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'bool'\" class=\"c-mobile-value\">\r\n                <span *ngIf=\"item[childColumn.field]\"\r\n                  class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                <span *ngIf=\"!item[childColumn.field]\"\r\n                  class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n              </span>\r\n              <span *ngIf=\"childColumn.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                  class=\"form-control c-input-xs\" [(ngModel)]=\"item[childColumn.field]\"></span>\r\n              <span *ngIf=\"childColumn.type === 'values'\" class=\"status c-mobile-value\"\r\n                [ngStyle]=\"{'color':childColumn?.dictionary[item[childColumn.field]]?.color}\">\r\n                {{!!childColumn?.dictionary[item[childColumn.field]] ? childColumn?.dictionary[item[childColumn.field]]?.text : item[childColumn.field]}}\r\n              </span>\r\n              <span *ngIf=\"childColumn.type === 'radio'\" class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n              <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\" style=\"margin: 5px 0\">\r\n            </div>\r\n          </ng-container>\r\n        </ng-container>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</div>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}", "@charset \"UTF-8\";.grid-header{overflow-x:hidden;overflow-y:hidden}td,th{padding:3px 5px;font-size:13px;min-width:0}.c-cell-padding{padding:3px 5px!important}.c-header-title{text-transform:uppercase;font-weight:500}span.c-header-title{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:0 .3rem}thead th{min-height:50px;height:50px;border-top:none}tbody td{min-height:25px;height:25px}.status{font-weight:500;padding:2px 5px;border-radius:1.5rem;color:#16759b;display:inline-block;text-align:center;text-transform:uppercase}.status-success{color:#43a047}.status-danger{color:#f44336}.sumarize{padding:8px 12px;text-transform:uppercase;font-size:12px;color:#fff;display:inline-block;white-space:normal;font-weight:500;line-height:1;text-align:center;border-radius:10rem;background-color:#00bcd4}.cursor-pointer{cursor:pointer}label.custom-control.custom-checkbox{margin:0}.c-overflow-x-hidden{overflow-x:hidden}.c-overflow-y-hidden{overflow-y:hidden}.c-grid-header{overflow-x:hidden;overflow-y:hidden}.c-th-xs{line-height:1.15;padding:.1rem!important;font-size:.8rem;min-width:0;min-height:49px;height:49px}.c-td-xs{line-height:1.15;padding:.1rem!important;font-size:.8rem;min-width:0;min-height:1.5rem;height:1.5rem}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px!important;height:28px!important}.c-sticky-top{z-index:20;top:0!important}.c-sticky-left{z-index:20;left:0!important;border-left:none!important;border-right:none!important}.c-sticky-all{z-index:30;top:0!important;left:0!important;border-left:none!important;border-right:none!important}.c-sticky-spliter{z-index:40;background-color:#dee2e6;border:none;width:1px;min-width:1px}.table-striped tbody tr:nth-of-type(even) .c-sticky-left{background-color:#fff}.table-striped tbody tr:nth-of-type(odd) .c-sticky-left{background-color:#f2f2f2}.table-responsive>.table-bordered{border:1px solid #dee2e6!important}.c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:.8rem}"]
    })
], GridSubInformationComponent);

var SdMinDateValidator_1;
let SdMinDateValidator = SdMinDateValidator_1 = class SdMinDateValidator {
    validate(c) {
        const date = c.value || null;
        const minDate = this.minDate || null;
        if (!date) {
            return null;
        }
        if (!minDate) {
            return null;
        }
        if (new Date(Date.parseFrom(date, 'dd/MM/yyyy HH:mm')).getTime() < new Date(minDate).getTime()) {
            return {
                minDate: true
            };
        }
        return null;
    }
};
__decorate([
    Input('sdMinDate')
], SdMinDateValidator.prototype, "minDate", void 0);
SdMinDateValidator = SdMinDateValidator_1 = __decorate([
    Directive({
        selector: '[sdMinDate]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdMinDateValidator_1, multi: true }]
    })
], SdMinDateValidator);

var SdMaxDateValidator_1;
let SdMaxDateValidator = SdMaxDateValidator_1 = class SdMaxDateValidator {
    validate(c) {
        const date = c.value || null;
        const maxDate = this.maxDate || null;
        if (!date) {
            return null;
        }
        if (!maxDate) {
            return null;
        }
        if (new Date(Date.parseFrom(date, 'dd/MM/yyyy HH:mm')).getTime() > new Date(maxDate).getTime()) {
            return {
                maxDate: true
            };
        }
        return null;
    }
};
__decorate([
    Input('sdMaxDate')
], SdMaxDateValidator.prototype, "maxDate", void 0);
SdMaxDateValidator = SdMaxDateValidator_1 = __decorate([
    Directive({
        selector: '[sdMaxDate]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdMaxDateValidator_1, multi: true }]
    })
], SdMaxDateValidator);

var SdCustomValidator_1;
let SdCustomValidator = SdCustomValidator_1 = class SdCustomValidator {
    validate(c) {
        return __awaiter(this, void 0, void 0, function* () {
            const value = c.value || null;
            if (this.func && typeof (this.func) === 'function') {
                const result = this.func(value);
                if (result instanceof Promise) {
                    const message = yield result;
                    if (message) {
                        return {
                            customValidator: message
                        };
                    }
                    return null;
                }
                if (result) {
                    return {
                        customValidator: result
                    };
                }
                return null;
            }
            return null;
        });
    }
};
__decorate([
    Input('sdCustomValidator')
], SdCustomValidator.prototype, "func", void 0);
SdCustomValidator = SdCustomValidator_1 = __decorate([
    Directive({
        selector: '[sdCustomValidator]',
        providers: [{ provide: NG_ASYNC_VALIDATORS, useExisting: SdCustomValidator_1, multi: true }]
    })
], SdCustomValidator);

let CommandIconPipe = class CommandIconPipe {
    transform(icon, item) {
        if (!icon) {
            return '';
        }
        if (typeof (icon) === 'string') {
            return icon;
        }
        return icon(item);
    }
};
CommandIconPipe = __decorate([
    Pipe({
        name: 'commandIcon'
    })
], CommandIconPipe);

let CommandTitlePipe = class CommandTitlePipe {
    transform(title, item) {
        if (!title) {
            return '';
        }
        if (typeof (title) === 'string') {
            return title;
        }
        return title(item);
    }
};
CommandTitlePipe = __decorate([
    Pipe({
        name: 'commandTitle'
    })
], CommandTitlePipe);

let CommandDisabledPipe = class CommandDisabledPipe {
    transform(disabled, item) {
        if (!disabled) {
            return false;
        }
        if (typeof (disabled) === 'boolean') {
            return disabled;
        }
        return disabled(item);
    }
};
CommandDisabledPipe = __decorate([
    Pipe({
        name: 'commandDisabled'
    })
], CommandDisabledPipe);

let CommandHiddenByItemPipe = class CommandHiddenByItemPipe {
    transform(item, hiddenByItem) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!hiddenByItem) {
                return false;
            }
            return hiddenByItem(item);
        });
    }
};
CommandHiddenByItemPipe = __decorate([
    Pipe({
        name: 'commandHiddenByItem'
    })
], CommandHiddenByItemPipe);

let MobileCommandFilterPipe = class MobileCommandFilterPipe {
    transform(commands, item) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            if (!commands) {
                return results;
            }
            for (const command of commands) {
                if ('children' in command) {
                    let flag = true;
                    const { hiddenByItem } = command;
                    if (hiddenByItem) {
                        const hidden = hiddenByItem(item);
                        if (hidden instanceof Promise) {
                            if (yield hidden) {
                                flag = false;
                            }
                        }
                        else {
                            if (hidden) {
                                flag = false;
                            }
                        }
                    }
                    if (flag) {
                        for (const childCommand of command.children) {
                            if (!childCommand.hiddenByItem) {
                                results.push(childCommand);
                            }
                            else {
                                const hidden = childCommand.hiddenByItem(item);
                                if (hidden instanceof Promise) {
                                    if (!(yield hidden)) {
                                        results.push(childCommand);
                                    }
                                }
                                else {
                                    if (!hidden) {
                                        results.push(childCommand);
                                    }
                                }
                            }
                        }
                    }
                }
                else {
                    const { hiddenByItem } = command;
                    if (!hiddenByItem) {
                        results.push(command);
                    }
                    else {
                        const hidden = hiddenByItem(item);
                        if (hidden instanceof Promise) {
                            if (!(yield hidden)) {
                                results.push(command);
                            }
                        }
                        else {
                            if (!hidden) {
                                results.push(command);
                            }
                        }
                    }
                }
            }
            return results;
        });
    }
};
MobileCommandFilterPipe = __decorate([
    Pipe({
        name: 'mobileCommandFilter'
    })
], MobileCommandFilterPipe);

let ColumnTitlePipe = class ColumnTitlePipe {
    transform(item, title, dynamicTitle) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!title) {
                return '';
            }
            if (dynamicTitle) {
                const result = dynamicTitle(item);
                if (result instanceof Promise) {
                    return yield result;
                }
                return result;
            }
            return title;
        });
    }
};
ColumnTitlePipe = __decorate([
    Pipe({
        name: 'columnTitle'
    })
], ColumnTitlePipe);

var SdChipMinItemValidator_1;
let SdChipMinItemValidator = SdChipMinItemValidator_1 = class SdChipMinItemValidator {
    validate(c) {
        if (this.func && typeof (this.func) === 'function') {
            const result = this.func();
            if (result) {
                return {
                    minItem: result
                };
            }
            return null;
        }
        return null;
    }
};
__decorate([
    Input('sdChipMinItem')
], SdChipMinItemValidator.prototype, "func", void 0);
SdChipMinItemValidator = SdChipMinItemValidator_1 = __decorate([
    Directive({
        selector: '[sdChipMinItem]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdChipMinItemValidator_1, multi: true }]
    })
], SdChipMinItemValidator);

let EditorValidatePipe = class EditorValidatePipe {
    constructor() {
        this.delay = 1000; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện validate
    }
    transform(value, item, validate) {
        return __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return true;
            }
            item.editorHandler = item.editorHandler || {};
            if (!validate) {
                item.editorHandler.errorMessage = null;
                return true;
            }
            const result = validate(item);
            if (result instanceof Promise) {
                item.editorHandler.errorMessage = yield result;
                return true;
            }
            else {
                item.editorHandler.errorMessage = result;
                return true;
            }
        });
    }
};
EditorValidatePipe = __decorate([
    Pipe({
        name: 'editorValidate'
    })
], EditorValidatePipe);

let EditorDynamicItemPipe = class EditorDynamicItemPipe {
    constructor() {
        this.previousResults = [];
        this.delay = 200; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện gọi hàm
    }
    transform(value, item, editor) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return this.previousResults;
            }
            if (editor.type === 'default') {
                return editor.items;
            }
            else if (editor.type === 'dependent') {
                const results = (_b = (_a = editor).items) === null || _b === void 0 ? void 0 : _b.call(_a, item);
                if (!results) {
                    this.previousResults = [];
                    return this.previousResults;
                }
                if (results instanceof Promise) {
                    this.previousResults = yield results;
                    return this.previousResults;
                }
                this.previousResults = results;
                return results;
            }
            this.previousResults = [];
            return this.previousResults;
        });
    }
};
EditorDynamicItemPipe = __decorate([
    Pipe({
        name: 'editorDynamicItem'
    })
], EditorDynamicItemPipe);

let ColumnHtmlTemplatePipe = class ColumnHtmlTemplatePipe {
    transform(value, rowData, htmlTemplate) {
        if (typeof (htmlTemplate) !== 'function') {
            return value;
        }
        return htmlTemplate(value, rowData, window.innerWidth < MobileMaxWidth);
    }
};
ColumnHtmlTemplatePipe = __decorate([
    Pipe({
        name: 'columnHtmlTemplate'
    })
], ColumnHtmlTemplatePipe);

let ColumnCommandFilterPipe = class ColumnCommandFilterPipe {
    transform(commands, item) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            if (!commands) {
                return results;
            }
            for (const command of commands) {
                const { hiddenByItem } = command;
                if (!hiddenByItem) {
                    results.push(command);
                }
                else {
                    const hidden = hiddenByItem(item);
                    if (hidden instanceof Promise) {
                        if (!(yield hidden)) {
                            results.push(command);
                        }
                    }
                    else {
                        if (!hidden) {
                            results.push(command);
                        }
                    }
                }
            }
            return results;
        });
    }
};
ColumnCommandFilterPipe = __decorate([
    Pipe({
        name: 'columnCommandFilter'
    })
], ColumnCommandFilterPipe);

// https://stackoverflow.com/questions/4459379/preview-an-image-before-it-is-uploaded
let UploadFileControlComponent = class UploadFileControlComponent {
    constructor(ref, notifyService, translateService) {
        this.ref = ref;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.id = `I${v4()}`;
        this.previewFiles = [];
        this.type = 'file';
        this.disabled = false;
        this.extensions = [];
        this.max = 1;
        this.srcs = [];
        this.align = 'center';
        this.sdChange = new EventEmitter();
        this.subscription = new Subscription();
        this.reload = (previewFiles) => {
            if (previewFiles) {
                this.previewFiles = previewFiles;
                return;
            }
            this.previewFiles = this.srcs.map(src => ({
                file: null,
                previewSrc: null,
                src,
                isPreviewImage: this.type === 'image'
            }));
        };
        this.validate = (file) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (this.type === 'image') {
                if (file.type.split('/')[0] !== 'image') {
                    return `[${file.name}] ${this.translateService.translate('Uploaded file is not an image')}`;
                }
            }
            if ((_a = this.extensions) === null || _a === void 0 ? void 0 : _a.length) {
                const lastDot = file.name.lastIndexOf('.');
                const extension = file.name.substring(lastDot + 1);
                if (!this.extensions.some(e => e.toUpperCase() === extension.toUpperCase())) {
                    return `[${file.name}] ${this.translateService.translate('Uploaded file is not match extension')} ${this.extensions.join(', ')}`;
                }
            }
            if (this.maxSize) {
                if (this.maxSize * 1024 * 1024 < file.size) {
                    return `[${file.name}] ${this.translateService.translate('Max file size')} ${this.maxSize} Mbs`;
                }
            }
            if (this.type === 'image' && (this.maxWidth || this.maxHeight)) {
                const message = yield new Promise(resolve => {
                    const URL = window.URL || window.webkitURL;
                    const img = new Image();
                    img.onload = () => {
                        if (this.maxWidth && img.width > this.maxWidth) {
                            resolve(`[${file.name}] ${this.translateService.translate('Max image width')} ${this.maxWidth}px`);
                        }
                        if (this.maxHeight && img.height > this.maxHeight) {
                            resolve(`[${file.name}] ${this.translateService.translate('Max image height')} ${this.maxHeight}px`);
                        }
                        resolve();
                    };
                    img.src = URL.createObjectURL(file);
                });
                if (message) {
                    return message;
                }
            }
            return null;
        });
        this.preview = () => {
            for (const previewFile of this.previewFiles.filter(e => e.file)) {
                const reader = new FileReader();
                reader.onload = (evt) => {
                    var _a;
                    previewFile.previewSrc = evt.target.result;
                    previewFile.isPreviewImage = ((_a = previewFile.file) === null || _a === void 0 ? void 0 : _a.type.split('/')[0]) === 'image';
                    this.ref.detectChanges();
                };
                reader.readAsDataURL(previewFile.file);
            }
        };
        this.uploadFile = (target, previewFile) => __awaiter(this, void 0, void 0, function* () {
            if (!target.files.length) {
                return;
            }
            if (!previewFile) {
                if (target.files.length + this.previewFiles.length > this.max) {
                    this.notifyService.notify.warning(`${this.translateService.translate('Max number of files')} ${this.max}`);
                    return;
                }
                for (let i = 0; i < target.files.length; i++) {
                    const message = yield this.validate(target.files.item(i));
                    if (message) {
                        this.notifyService.notify.warning(message);
                        return;
                    }
                }
                // tslint:disable-next-line: prefer-for-of
                for (let i = 0; i < target.files.length; i++) {
                    const file = target.files.item(i);
                    const lastDot = file.name.lastIndexOf('.');
                    const extension = file.name.substring(lastDot + 1);
                    this.previewFiles.push({
                        file: target.files.item(i),
                        isPreviewImage: false,
                        previewSrc: null,
                        src: null,
                        fileName: file.name,
                        extension
                    });
                }
            }
            else {
                const idx = this.previewFiles.indexOf(previewFile);
                const file = target.files.item(0);
                const lastDot = file.name.lastIndexOf('.');
                const extension = file.name.substring(lastDot + 1);
                this.previewFiles[idx] = {
                    file: target.files.item(0),
                    isPreviewImage: false,
                    previewSrc: null,
                    src: null,
                    fileName: file.name,
                    extension
                };
            }
            this.preview();
            this.sdChange.emit(this.previewFiles);
            this.ref.detectChanges();
        });
    }
    ngOnInit() {
        this.previewFiles = this.srcs.map(src => ({
            file: null,
            previewSrc: null,
            src,
            isPreviewImage: this.type === 'image'
        }));
    }
    ngAfterViewInit() {
        if (this.dropElements.length > 0) {
            const dropContainer = this.dropElements.first.nativeElement;
            this.currentDropContainer = dropContainer;
            dropContainer.addEventListener('dragover', (evt) => {
                evt.preventDefault();
                dropContainer.style.opacity = 0.9;
                dropContainer.style.border = '2px solid grey';
            });
            dropContainer.addEventListener('dragenter', (evt) => {
                evt.preventDefault();
            });
            dropContainer.addEventListener('dragleave', (evt) => {
                dropContainer.style.opacity = 0.6;
                dropContainer.style.border = '2px dashed grey';
            });
            dropContainer.addEventListener('drop', (evt) => __awaiter(this, void 0, void 0, function* () {
                evt.preventDefault();
                dropContainer.style.opacity = 0.6;
                dropContainer.style.border = '2px dashed grey';
                yield this.uploadFile(evt.dataTransfer);
                console.log(this.previewFiles);
            }));
        }
        this.subscription.add(this.dropElements.changes.subscribe(() => {
            if (this.dropElements.length > 0 && this.currentDropContainer !== this.dropElements.first.nativeElement) {
                const dropContainer = this.dropElements.first.nativeElement;
                this.currentDropContainer = dropContainer;
                dropContainer.addEventListener('dragover', (evt) => {
                    evt.preventDefault();
                    dropContainer.style.opacity = 0.9;
                    dropContainer.style.border = '2px solid grey';
                });
                dropContainer.addEventListener('dragenter', (evt) => {
                    evt.preventDefault();
                });
                dropContainer.addEventListener('dragleave', (evt) => {
                    dropContainer.style.opacity = 0.6;
                    dropContainer.style.border = '2px dashed grey';
                });
                dropContainer.addEventListener('drop', (evt) => __awaiter(this, void 0, void 0, function* () {
                    evt.preventDefault();
                    dropContainer.style.opacity = 0.6;
                    dropContainer.style.border = '2px dashed grey';
                    yield this.uploadFile(evt.dataTransfer);
                    console.log(this.previewFiles);
                }));
            }
        }));
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    onUpload(previewFile) {
        if ($$1(`#${this.id}`).length) {
            $$1('body').children(`#${this.id}`).remove();
        }
        if (previewFile || this.max === 1) {
            $$1('body').append(`<input id="${this.id}" style="display: none" type="file" />`);
        }
        else {
            $$1('body').append(`<input id="${this.id}" style="display: none" type="file" multiple />`);
        }
        $$1(`#${this.id}`).on('change', (evt) => __awaiter(this, void 0, void 0, function* () {
            yield this.uploadFile(evt.target, previewFile);
            $$1('body').children(`#${this.id}`).remove();
        }));
        $$1(`#${this.id}`).trigger('click');
    }
    onRemove(previewFile) {
        const idx = this.previewFiles.indexOf(previewFile);
        this.previewFiles.splice(idx, 1);
        this.sdChange.emit(this.previewFiles);
    }
};
UploadFileControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    Input()
], UploadFileControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "extensions", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "max", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxSize", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxWidth", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxHeight", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "srcs", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "previewWidth", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "previewHeight", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "align", void 0);
__decorate([
    Output()
], UploadFileControlComponent.prototype, "sdChange", void 0);
__decorate([
    ViewChildren('dragElement')
], UploadFileControlComponent.prototype, "dropElements", void 0);
UploadFileControlComponent = __decorate([
    Component({
        selector: 'sd-upload-file-control',
        template: "<label *ngIf=\"label\" class=\"sd-label d-block\">{{label}}</label>\r\n<div class=\"row c-upload-file-control\" [ngClass]=\"{'justify-content-center': align === 'center', 'justify-content-start': align === 'left'}\">\r\n  <div *ngFor=\"let file of previewFiles\" class=\"c-area c-view\" [ngStyle]=\"{'width': previewWidth, 'height': previewHeight}\">\r\n    <div class=\"c-preview\">\r\n      <div class=\"c-img-container\">\r\n        <ng-container *ngIf=\"file.previewSrc;else elseOrigin\">\r\n          <img *ngIf=\"file.isPreviewImage\" class=\"c-img\" [src]=\"file.previewSrc\" alt=\"Preview\" />\r\n          <i *ngIf=\"!file.isPreviewImage\" class=\"fa fa-file-text-o fa-fw c-icon-file\"></i>\r\n        </ng-container>\r\n        <ng-template #elseOrigin>\r\n          <img *ngIf=\"type === 'image'\" class=\"c-img\" [src]=\"file.src\" alt=\"Preview\" />\r\n          <i *ngIf=\"type !== 'image'\" class=\"fa fa-file-text-o fa-fw c-icon-file\"></i>\r\n        </ng-template>\r\n      </div>\r\n      <div *ngIf=\"!disabled\" class=\"c-action\">\r\n        <i class=\"fa fa-upload c-icon-upload\" (click)=\"onUpload(file)\"></i>\r\n        <i class=\"fa fa-times c-icon-remove\" (click)=\"onRemove(file)\"></i>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"previewFiles?.length < max && !disabled\" class=\"c-area\" [ngStyle]=\"{'width': previewWidth, 'height': previewHeight}\" #dragElement>\r\n    <i class=\"fa fa-fw c-icon\" [ngClass]=\"{'fa-upload': type === 'file', 'fa-picture-o': type === 'image'}\"\r\n      (click)=\"onUpload()\"></i>\r\n  </div>\r\n</div>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ".c-upload-file-control{width:100%;padding:5px 10px}.c-upload-file-control .c-area{border:2px dashed grey;border-radius:5px;display:table;text-align:center;margin:3px;opacity:.6}.c-upload-file-control .c-area.c-view{border:2px solid grey;opacity:.9}.c-upload-file-control .c-area:hover{opacity:.9}.c-upload-file-control .c-area .c-icon{vertical-align:middle;display:table-cell;margin:16px;font-size:50px;color:grey;cursor:pointer}.c-upload-file-control .c-area .c-preview{vertical-align:middle;display:table-cell}.c-upload-file-control .c-area .c-preview .c-img-container{width:100%;padding:5px 10px 0;height:calc(100% - 20px);display:table}.c-upload-file-control .c-area .c-preview .c-img-container .c-img{max-width:calc(100% - 20px);max-height:calc(100% - 5px)}.c-upload-file-control .c-area .c-preview .c-img-container .c-icon-file{font-size:50px;color:grey;vertical-align:middle;display:table-cell}.c-upload-file-control .c-area .c-preview .c-action{padding:0 5px;width:100%;height:20px}.c-upload-file-control .c-area .c-preview .c-action .c-icon-upload{color:grey;float:left;cursor:pointer}.c-upload-file-control .c-area .c-preview .c-action .c-icon-remove{color:red;float:right;cursor:pointer}"]
    })
], UploadFileControlComponent);

Date.equal = (date1, date2) => {
    if (!Date.isDate(date1) && !Date.isDate(date2)) {
        return true;
    }
    if (!Date.isDate(date1) || !Date.isDate(date2)) {
        return false;
    }
    return new Date(date1).getTime() === new Date(date2).getTime();
};
Date.parseFrom = (value, format) => {
    if (!value) {
        return null;
    }
    if (!format) {
        return null;
    }
    value = value.toString();
    let dd = format.indexOf('dd') > -1 ? value.substr(format.indexOf('dd'), 'dd'.length) : '';
    let MM = format.indexOf('MM') > -1 ? value.substr(format.indexOf('MM'), 'MM'.length) : '';
    let yyyy = format.indexOf('yyyy') > -1 ? value.substr(format.indexOf('yyyy'), 'yyyy'.length) : '';
    const HH = format.indexOf('HH') > -1 ? value.substr(format.indexOf('HH'), 'HH'.length) : '00';
    const mm = format.indexOf('mm') > -1 ? value.substr(format.indexOf('mm'), 'mm'.length) : '00';
    const ss = format.indexOf('ss') > -1 ? value.substr(format.indexOf('ss'), 'ss'.length) : '00';
    const today = new Date();
    let strDate = '';
    if (yyyy && MM && dd) {
        strDate += `${MM}/${dd}/${yyyy}`;
    }
    else {
        yyyy = today.getFullYear().toString();
        MM = (today.getMonth() + 1).toString().padStart(2, '0');
        dd = today.getDate().toString().padStart(2, '0');
        strDate += `${MM}/${dd}/${yyyy}`;
    }
    strDate += ` ${HH}:${mm}:${ss}`;
    return new Date(strDate.trim());
};
Date.isDate = (value) => {
    if (!value) {
        return false;
    }
    const date = new Date(value);
    return !isNaN(date.getTime());
};
Date.toFormat = (value, format) => {
    if (!Date.isDate(value)) {
        return '';
    }
    const date = new Date(value);
    return date.toFormat(format);
};
Date.addMiliseconds = (value, miliseconds) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addMiliseconds(miliseconds);
};
Date.addHours = (value, hours) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addHours(hours);
};
Date.addDays = (value, days) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addDays(days);
};
Date.addMonths = (value, months) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addMonths(months);
};
Date.begin = (value) => {
    if (!Date.isDate(value)) {
        return null;
    }
    return new Date(value.toFormat('MM/dd/yyyy'));
};
Date.end = (value) => {
    if (!Date.isDate(value)) {
        return null;
    }
    return new Date(value).addDays(1).begin().addMiliseconds(-1);
};
Date.prototype.begin = function () {
    const date = this;
    return new Date(date.toFormat('MM/dd/yyyy'));
};
Date.prototype.end = function () {
    const date = this;
    return date.addDays(1).begin().addMiliseconds(-1);
};
Date.prototype.addMiliseconds = function (miliseconds) {
    const date = this;
    date.setMilliseconds(date.getMilliseconds() + miliseconds);
    return date;
};
Date.prototype.addHours = function (hours) {
    const date = this;
    date.setHours(date.getHours() + hours);
    return date;
};
Date.prototype.addDays = function (days) {
    const date = this;
    date.setDate(date.getDate() + days);
    return date;
};
Date.prototype.addMonths = function (months) {
    const date = this;
    date.setMonth(date.getMonth() + months);
    return date;
};
Date.prototype.toFormat = function (format) {
    const date = this;
    let result = format;
    result = result.replace('yyyy', date.getFullYear().toString());
    result = result.replace('MM', (date.getMonth() + 1).toString().padStart(2, '0'));
    result = result.replace('dd', date.getDate().toString().padStart(2, '0'));
    result = result.replace('HH', date.getHours().toString().padStart(2, '0'));
    result = result.replace('mm', date.getMinutes().toString().padStart(2, '0'));
    result = result.replace('ss', date.getSeconds().toString().padStart(2, '0'));
    return result;
};

String.isValidEmail = (value) => {
    if (!value) {
        return false;
    }
    const re = /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i;
    return re.test(value);
};
String.isValidPhone = (value) => {
    if (!value) {
        return false;
    }
    const re = /^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\./0-9]*$/;
    return re.test(value);
};
String.isValidCode = (value) => {
    if (!value) {
        return false;
    }
    const re = /^[a-zA-Z0-9\-\@\_\-]{2,20}$/;
    return re.test(value);
};

let InputTooltipPipe = class InputTooltipPipe {
    transform(value, tooltip) {
        if (typeof (tooltip) === 'string') {
            return tooltip;
        }
        return tooltip(value);
    }
};
InputTooltipPipe = __decorate([
    Pipe({
        name: 'inputTooltipPipe'
    })
], InputTooltipPipe);

let CellClassNamePipe = class CellClassNamePipe {
    transform(value, rowData, column, isChildren) {
        const classNames = [];
        if (column.click) {
            classNames.push('cursor-pointer');
        }
        if (isChildren) {
            classNames.push('c-children');
        }
        if (IsMobile) {
            classNames.push('c-mobile-value');
        }
        if (column.badge) {
            const badge = column.badge(rowData, value);
            if (badge) {
                classNames.push('badge');
                if (IsMobile) {
                    classNames.push('c-mobile-badge');
                }
                else {
                    classNames.push('c-badge');
                }
                if (badge === 'PRIMARY') {
                    classNames.push('badge-primary');
                }
                else if (badge === 'SECONDARY') {
                    classNames.push('badge-secondary');
                }
                else if (badge === 'WARNING') {
                    classNames.push('badge-warning');
                }
                else if (badge === 'SUCCESS') {
                    classNames.push('badge-success');
                }
                else if (badge === 'DANGER') {
                    classNames.push('badge-danger');
                }
                else if (badge === 'LIGHT') {
                    classNames.push('badge-light');
                }
                else if (badge === 'DARK') {
                    classNames.push('badge-dark');
                }
            }
        }
        return classNames.join(' ');
    }
};
CellClassNamePipe = __decorate([
    Pipe({
        name: 'cellClassName'
    })
], CellClassNamePipe);

let ValueTransformPipe = class ValueTransformPipe {
    // tslint:disable-next-line: max-line-length
    transform(value, rowData, column) {
        if (column.transform) {
            return column.transform(value, rowData);
        }
        return value;
    }
};
ValueTransformPipe = __decorate([
    Pipe({
        name: 'valueTransform'
    })
], ValueTransformPipe);

let EditorSubInformationHandlerPipe = class EditorSubInformationHandlerPipe {
    transform(value, item, columns) {
        const visible = (column) => {
            if (column.type === 'children') {
                return false;
            }
            let isDisabled = false;
            // Kiểm tra xem có bị disabled hay không?
            if (column.editor) {
                isDisabled = typeof (column.editor.disabled) === 'function' ? column.editor.disabled(item) : column.editor.disabled;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Hiển thị editor nếu dòng đó:
            // Đang được edit: editingStatus
            return item.editingStatus
                // Được thiết lập alwayDisplay
                || (column.editor && column.editor.alwayDisplay);
        };
        item.editorHandler = item.editorHandler || {};
        for (const column of columns) {
            item.editorHandler.disabled = false;
            item.editorHandler[column.field] = {};
            if (item.editorHandler.disabled) {
                item.editorHandler[column.field].visible = false;
            }
            else {
                item.editorHandler[column.field].visible = visible(column);
            }
        }
        return true;
    }
};
EditorSubInformationHandlerPipe = __decorate([
    Pipe({
        name: 'editorSubInformationHandler'
    })
], EditorSubInformationHandlerPipe);

let SafeHtmlPipe = class SafeHtmlPipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(html) {
        return this.sanitizer.bypassSecurityTrustHtml(html);
    }
};
SafeHtmlPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SafeHtmlPipe = __decorate([
    Pipe({
        name: 'safeHtml',
    })
], SafeHtmlPipe);

let GridDesktopColumnViewComponent = class GridDesktopColumnViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridDesktopColumnViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnViewComponent.prototype, "item", void 0);
GridDesktopColumnViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-view',
        template: "<ng-container *ngIf=\"column && item\">\r\n  <ng-container *ngIf=\"column.htmlTemplate;else useDefaultView\">\r\n    <div [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\">\r\n    </div>\r\n  </ng-container>\r\n  <ng-template #useDefaultView>\r\n    <div *ngIf=\"column.type === 'string'\">\r\n      <span [className]=\"item[column.field] | cellDesktopClassName:item:column\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n        <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n          (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n        <ng-container *ngIf=\"!column.click\">{{item[column.field]}}</ng-container>\r\n      </span>\r\n      <ng-container *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n        <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\" type=\"button\"\r\n          class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n          <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n        </button>\r\n      </ng-container>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'color'\">\r\n      <input disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n        (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n    </div>\r\n    <div *ngIf=\"column.type === 'number'\">\r\n      <span [className]=\"item[column.field] | cellDesktopClassName:item:column\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n        <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n          (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n        <ng-container *ngIf=\"!column.click\">\r\n          {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n      </span>\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'date'\">\r\n      {{item[column.field] | date:'dd/MM/yyyy'}}\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'datetime'\">\r\n      {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'time'\">\r\n      {{item[column.field] | date:'HH:mm'}}\r\n    </div>\r\n    <div class=\"align-middle text-center\" *ngIf=\"column.type === 'bool'\">\r\n      <span *ngIf=\"!item.editorHandler[column.field].visible && item[column.field]\"\r\n        class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n      <span *ngIf=\"!item.editorHandler[column.field].visible && !item[column.field]\"\r\n        class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'values'\">\r\n      <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n        <div *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status\"\r\n          [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n          {{dic.text}}\r\n        </div>\r\n        <ng-template #elseNoStatus>\r\n          <div class=\"text-left\">\r\n            {{dic.text}}\r\n          </div>\r\n        </ng-template>\r\n      </ng-container>\r\n      <ng-template #elseNotInDic>\r\n        <div class=\"text-left\">\r\n          {{item[column.field]}}\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'radio'\">\r\n      {{item[column.field]}}\r\n    </div>\r\n    <div class=\"align-middle text-center\" *ngIf=\"column.type === 'image'\">\r\n      <img *ngIf=\"item[column.field]\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n        [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n        (click)=\"column.click && column.click(item[column.field], item)\" [ngClass]=\"{'c-clickable':column.click}\">\r\n      <i *ngIf=\"!item[column.field]\" class=\"fa fa-picture-o fa-fw c-img\"\r\n        [ngClass]=\"{'c-clickable':column.click}\" (click)=\"column.click && column.click(item[column.field], item)\"></i>\r\n    </div>\r\n  </ng-template>\r\n</ng-container>",
        styles: [".c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge a{color:#fff}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase;width:100%}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridDesktopColumnViewComponent);

let GridDesktopColumnEditComponent = class GridDesktopColumnEditComponent {
    constructor(ref) {
        this.ref = ref;
        this.sdChange = new EventEmitter();
        this.onEditorChange = (column, item, value) => {
            var _a, _b, _c;
            if (column.type !== 'children') {
                (_c = (_a = column.editor) === null || _a === void 0 ? void 0 : (_b = _a).change) === null || _c === void 0 ? void 0 : _c.call(_b, item, value);
                this.ref.detectChanges();
                this.sdChange.emit();
            }
        };
        this.onSearch = (searchValue, item, column) => {
            item[column.field] = searchValue;
        };
    }
};
GridDesktopColumnEditComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], GridDesktopColumnEditComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnEditComponent.prototype, "item", void 0);
__decorate([
    Output()
], GridDesktopColumnEditComponent.prototype, "sdChange", void 0);
GridDesktopColumnEditComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-edit',
        template: "<ng-container *ngIf=\"column && item\">\r\n  <div *ngIf=\"column.type === 'string'\">\r\n    <div *ngIf=\"column.editor?.item;else elseUseInput\">\r\n      <ng-container *ngIf=\"column.editor.autocomplete; else elseUseSelect\">\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'dependent'\"\r\n          [items]=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async\"\r\n          [valueField]=\"column.editor.item.value\" [displayField]=\"column.editor.item.display\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\"\r\n          (search)=\"onSearch($event, item, column)\">\r\n        </sd-grid-autocomplete-control>\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'default'\"\r\n          [items]=\"'' | editorDynamicItem:item:column.editor.item | async\" [valueField]=\"column.editor.item.value\"\r\n          [displayField]=\"column.editor.item.display\" [(model)]=\"item[column.field]\"\r\n          (sdChange)=\"onEditorChange(column,item,$event)\">\r\n        </sd-grid-autocomplete-control>\r\n      </ng-container>\r\n      <ng-template #elseUseSelect>\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <ng-container\r\n            *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <ng-container *ngIf=\"dynamicItems?.subscribe;else elseIsArray\">\r\n              <option *ngFor=\"let data of dynamicItems | async\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-container>\r\n            <ng-template #elseIsArray>\r\n              <option *ngFor=\"let data of (dynamicItems || [])\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-template>\r\n          </ng-container>\r\n        </select>\r\n        <select *ngIf=\"column.editor.item?.type === 'default'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <ng-container *ngIf=\"'' | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <option *ngFor=\"let data of dynamicItems\" [value]=\"data[column.editor.item.value]\">\r\n              {{data[column.editor.item.display]}}\r\n            </option>\r\n          </ng-container>\r\n        </select>\r\n      </ng-template>\r\n    </div>\r\n    <ng-template #elseUseInput>\r\n      <div class=\"input-group\">\r\n        <input class=\"form-control c-input-xs\" [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n          [(ngModel)]=\"item[column.field]\" (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n          (change)=\"onEditorChange(column,item,item[column.field])\">\r\n        <div *ngIf=\"column.editor?.click\" class=\"input-group-append cursor-pointer\">\r\n          <span class=\"input-group-text border-0 py-0 px-1\" style=\"background:#FFF\" (click)=\"column.editor.click(item)\">\r\n            <i class=\"fa fa-search\"></i>\r\n          </span>\r\n        </div>\r\n      </div>\r\n    </ng-template>\r\n  </div>\r\n  <div *ngIf=\"column.type === 'color'\">\r\n    <input type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\">\r\n  </div>\r\n  <div *ngIf=\"column.type === 'number'\">\r\n    <input type=\"number\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n      (keyup.Enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\">\r\n  </div>\r\n  <div *ngIf=\"column.type === 'date'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"date\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"text-center\" *ngIf=\"column.type === 'datetime'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"datetime\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"text-center\" *ngIf=\"column.type === 'time'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"time\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"align-middle text-center\" *ngIf=\"column.type === 'bool'\">\r\n    <sd-switch-control [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,item[column.field])\">\r\n    </sd-switch-control>\r\n    <!-- <mat-slide-toggle [(ngModel)]=\"item[column.field]\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\" color=\"primary\">\r\n    </mat-slide-toggle> -->\r\n  </div>\r\n  <div *ngIf=\"column.type === 'values'\">\r\n    <ng-container *ngIf=\"column.editor?.autocomplete;else elseUseSelect\">\r\n      <ng-container *ngIf=\"column.editor.item;else elseUseValues\">\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'dependent'\"\r\n          [items]=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async\"\r\n          [valueField]=\"column.editor.item.value\" [displayField]=\"column.editor.item.display\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\"\r\n          (search)=\"onSearch($event, item, column)\">\r\n        </sd-grid-autocomplete-control>\r\n        <ng-template #elseDynamicByValue>\r\n          <sd-grid-autocomplete-control [items]=\"column.editor.item.items\" [valueField]=\"column.editor.item.value\"\r\n            [displayField]=\"column.editor.item.display\" [(model)]=\"item[column.field]\"\r\n            (sdChange)=\"onEditorChange(column,item,$event)\">\r\n          </sd-grid-autocomplete-control>\r\n        </ng-template>\r\n      </ng-container>\r\n      <ng-template #elseUseValues>\r\n        <sd-grid-autocomplete-control [items]=\"column.values\" valueField=\"value\" displayField=\"text\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\">\r\n        </sd-grid-autocomplete-control>\r\n      </ng-template>\r\n    </ng-container>\r\n    <ng-template #elseUseSelect>\r\n      <ng-container *ngIf=\"column.editor?.item;else elseUseValues\">\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,$event)\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <ng-container *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item\r\n             | async; let dynamicItems\">\r\n            <ng-container *ngIf=\"dynamicItems?.subscribe;else elseIsArray\">\r\n              <option *ngFor=\"let data of dynamicItems | async\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-container>\r\n            <ng-template #elseIsArray>\r\n              <option *ngFor=\"let data of (dynamicItems || [])\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-template>\r\n          </ng-container>\r\n        </select>\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <ng-container\r\n            *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <option *ngFor=\"let data of dynamicItems\" [value]=\"data[column.editor.item.value]\">\r\n              {{data[column.editor.item.display]}}\r\n            </option>\r\n          </ng-container>\r\n        </select>\r\n      </ng-container>\r\n      <ng-template #elseUseValues>\r\n        <select class=\"form-control form-control-xs\" [(ngModel)]=\"item[column.field]\"\r\n          (change)=\"column.editor?.change && column.editor.change(item)\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}\r\n          </option>\r\n        </select>\r\n      </ng-template>\r\n    </ng-template>\r\n  </div>\r\n  <div *ngIf=\"column.type === 'radio'\">\r\n    <section class=\"mt-2 ml-3\" style=\"align-content: center; align-items: center;\">\r\n      <mat-radio-group style=\"display: flex\" [(ngModel)]=\"item[column.field]\"\r\n        (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n        <mat-radio-button *ngIf=\"!column.editor?.required\" color=\"warn\" class=\"mr-2\" value=\"\">\r\n          {{'Please select' | sdTranslate}}\r\n        </mat-radio-button>\r\n        <mat-radio-button color=\"primary\" class=\"mr-2\" *ngFor=\"let data of column.values\"\r\n          [value]=\"data[column.valueField]\">\r\n          {{data[column.displayField]}}\r\n        </mat-radio-button>\r\n      </mat-radio-group>\r\n    </section>\r\n  </div>\r\n  <div class=\"align-middle text-center\" *ngIf=\"column.type === 'image'\">\r\n    <img [src]=\"item[column.field]\" [width]=\"column.display?.width\" [height]=\"column.display?.height\"\r\n      style=\"margin: 5px 0\" (click)=\"column.click && column.click(item[column.field], item)\">\r\n  </div>\r\n</ng-container>",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}", ".c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px!important;height:28px!important}"]
    })
], GridDesktopColumnEditComponent);

let GridDesktopInlineFilterComponent = class GridDesktopInlineFilterComponent {
    constructor(deviceService) {
        this.deviceService = deviceService;
        this.externalFilters = [];
        this.columns = [];
        this.externalFilter = {};
        this.filter = {};
        this.showInlineFilter = false;
        this.showColumnInlineFilter = false;
        this.sdChange = new EventEmitter();
        this.displayKey = 'SDCUSTOM';
        this.onUpdateFilter = () => {
            this.sdChange.emit();
        };
        this.isDesktop = this.deviceService.isDesktop();
    }
};
GridDesktopInlineFilterComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "externalFilters", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "externalFilter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "filter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "showInlineFilter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "showColumnInlineFilter", void 0);
__decorate([
    Output()
], GridDesktopInlineFilterComponent.prototype, "sdChange", void 0);
GridDesktopInlineFilterComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-inline-filter',
        template: "<ng-container *ngIf=\"isDesktop && showInlineFilter\">\r\n  <div *ngIf=\"externalFilters?.length\" class=\"row\">\r\n    <ng-container *ngFor=\"let item of externalFilters\">\r\n      <div *ngIf=\"item.type !=='daterange' && item.type !=='numberrange';else elseFilterRange\"\r\n        class=\"col-lg-2 col-md-3 col-sm-6\">\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\"\r\n          [(model)]=\"externalFilter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n          [(model)]=\"externalFilter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\"[{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n          [(model)]=\"externalFilter[item.field]\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-radio-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'custom'\"\r\n          [(model)]=\"externalFilter[displayKey + item.field]\"\r\n          (sdClick)=\"item?.onClick(externalFilter, item.field, displayKey + item.field)\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <ng-container *ngIf=\"item.type === 'values'\">\r\n          <sd-select-control *ngIf=\"item.selection === 'MULTIPLE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\" multiple=\"true\">\r\n          </sd-select-control>\r\n          <sd-autocomplete-control *ngIf=\"item.selection === 'AUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-autocomplete-control>\r\n          <sd-chip-control *ngIf=\"item.selection === 'MULTIPLEAUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-chip-control>\r\n          <sd-select-control *ngIf=\"!item.selection\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-select-control>\r\n        </ng-container>\r\n        <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n          type=\"date\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-picker-control>\r\n        <sd-date-range-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='daterangefull'\"\r\n          [(fromDate)]=\"externalFilter[item.field].from\" [(toDate)]=\"externalFilter[item.field].to\"\r\n          [minDate]=\"item.minDate\" [maxDate]=\"item.maxDate\" type=\"date\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-range-picker-control>\r\n      </div>\r\n      <ng-template #elseFilterRange>\r\n        <ng-container *ngIf=\"item.type ==='daterange' && externalFilter[item.field]\">\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-date-picker-control [label]=\"item.fromTitle\" [(model)]=\"externalFilter[item.field].from\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate\"\r\n              [maxDate]=\"externalFilter[item.field].to || item.maxDate\" (sdChange)=\"onUpdateFilter()\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-date-picker-control [label]=\"item.toTitle\" [(model)]=\"externalFilter[item.field].to\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate || externalFilter[item.field].from\"\r\n              [maxDate]=\"item.maxDate\" (sdChange)=\"onUpdateFilter()\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"item.type ==='numberrange' && externalFilter[item.field]\">\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-input-control [label]=\"item.fromTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].from\"\r\n              (sdChange)=\"onUpdateFilter()\">\r\n            </sd-input-control>\r\n          </div>\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-input-control [label]=\"item.toTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].to\"\r\n              (sdChange)=\"onUpdateFilter()\">\r\n            </sd-input-control>\r\n          </div>\r\n        </ng-container>\r\n      </ng-template>\r\n    </ng-container>\r\n  </div>\r\n\r\n  <div *ngIf=\"columns?.length && showColumnInlineFilter\" class=\"row\">\r\n    <ng-container *ngFor=\"let item of columns\">\r\n      <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\" [(model)]=\"filter[item.field]\"\r\n          (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n          [(model)]=\"filter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\"[{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n          [(model)]=\"filter[item.field]\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-radio-control>\r\n        <sd-select-control *ngIf=\"item.type === 'values'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n          type=\"date\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-picker-control>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>",
        styles: [""]
    })
], GridDesktopInlineFilterComponent);

let CellDesktopClassNamePipe = class CellDesktopClassNamePipe {
    transform(value, rowData, column, isChildren) {
        const classNames = [];
        if (column.click) {
            classNames.push('cursor-pointer');
        }
        if (isChildren) {
            classNames.push('c-children');
        }
        if (column.badge) {
            const badge = column.badge(rowData, value);
            if (badge) {
                classNames.push('c-badge');
                classNames.push('badge');
                if (badge === 'PRIMARY') {
                    classNames.push('badge-primary');
                }
                else if (badge === 'SECONDARY') {
                    classNames.push('badge-secondary');
                }
                else if (badge === 'WARNING') {
                    classNames.push('badge-warning');
                }
                else if (badge === 'SUCCESS') {
                    classNames.push('badge-success');
                }
                else if (badge === 'DANGER') {
                    classNames.push('badge-danger');
                }
                else if (badge === 'LIGHT') {
                    classNames.push('badge-light');
                }
                else if (badge === 'DARK') {
                    classNames.push('badge-dark');
                }
            }
        }
        return classNames.join(' ');
    }
};
CellDesktopClassNamePipe = __decorate([
    Pipe({
        name: 'cellDesktopClassName'
    })
], CellDesktopClassNamePipe);

let GridDesktopColumnChildrenViewComponent = class GridDesktopColumnChildrenViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridDesktopColumnChildrenViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnChildrenViewComponent.prototype, "item", void 0);
GridDesktopColumnChildrenViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-children-view',
        template: "<ng-container *ngIf=\"column.children?.length\">\r\n  <div class=\"row mx-n2 c-cell-padding\">\r\n    <div *ngFor=\"let childColumn of column.children | filterMobile:item\" class=\"px-2\"\r\n      [ngClass]=\"{'col-sm-6': childColumn?.colSpan === 1, 'col-sm-12': !childColumn?.colSpan || childColumn?.colSpan === 2}\">\r\n      <span class=\"c-title\">\r\n        {{item | columnTitle:childColumn.title:childColumn.dynamicTitle | async}}:\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'string'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field]}}</ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'number'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{(item[childColumn.field]  | valueTransform:item:childColumn) | number : '1.0-2'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{(item[childColumn.field]  | valueTransform:item:childColumn) | number : '1.0-2'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'datetime'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'date'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'dd/MM/yyyy'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'time'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'HH:mm'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'HH:mm'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'bool'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n        <span *ngIf=\"item[childColumn.field]\"\r\n          class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n        <span *ngIf=\"!item[childColumn.field]\"\r\n          class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'color'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\"><input\r\n          disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n          [(ngModel)]=\"item[childColumn.field]\"></span>\r\n      <ng-container *ngIf=\"childColumn.type === 'values'\">\r\n        <ng-container\r\n          *ngIf=\"childColumn?.dictionary[item[childColumn.field]] as dic; else elseNotInDic\">\r\n          <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\"\r\n            class=\"status c-children\"\r\n            [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n            {{dic.text}}\r\n          </span>\r\n          <ng-template #elseNoStatus>\r\n            <span [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n              (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n              {{dic.text}}\r\n            </span>\r\n          </ng-template>\r\n        </ng-container>\r\n        <ng-template #elseNotInDic>\r\n          <span [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n            [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n            (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n            {{item[childColumn.field]}}\r\n          </span>\r\n        </ng-template>\r\n      </ng-container>\r\n      <span *ngIf=\"childColumn.type === 'radio'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</span>\r\n      <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n        [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\"\r\n        style=\"margin: 5px 0\" (click)=\"column.click && column.click(item[column.field], item)\">\r\n    </div>\r\n  </div>\r\n</ng-container>",
        styles: [".c-title{font-size:13px;margin-right:3px;font-weight:700;color:#212529;line-height:1.7}.c-badge{display:block!important;border-radius:10rem;font-weight:500;max-width:80%;margin:0 auto;padding:5px!important;font-size:14px;color:#212529}.c-badge a{color:#fff}.c-children{font-size:14px;overflow-wrap:break-word;color:#212529}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:left!important;text-transform:uppercase}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridDesktopColumnChildrenViewComponent);

let GridMobileColumnViewComponent = class GridMobileColumnViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridMobileColumnViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridMobileColumnViewComponent.prototype, "item", void 0);
GridMobileColumnViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-mobile-view',
        template: "<!-- <ng-container *ngIf=\"column && item\">\r\n  <div class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n    <div class=\"col-5\">\r\n      <span class=\"c-mobile-title\">\r\n        {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n      </span>\r\n    </div>\r\n    <div class=\"col-7\">\r\n      <ng-container *ngIf=\"column.htmlTemplate;else useDefaultView\">\r\n        <span class=\"c-mobile-value\"\r\n          [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n      </ng-container>\r\n      <ng-template #useDefaultView>\r\n        <div class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n          <div class=\"col-5\">\r\n            <span class=\"c-mobile-title\">\r\n              {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n            </span>\r\n          </div>\r\n          <div class=\"col-7\">\r\n            <ng-container *ngIf=\"column.type === 'string'\">\r\n              <span *ngIf=\"!column.htmlTemplate; else elseUseTemplate\"\r\n                [className]=\"item[column.field] | cellClassName:item:column\"\r\n                [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                  (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n                <ng-container *ngIf=\"!column.click\">\r\n                  {{item[column.field]}}</ng-container>\r\n              </span>\r\n              <ng-template #elseUseTemplate>\r\n                <span class=\"c-mobile-value\"\r\n                  [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n              </ng-template>\r\n              <ng-container\r\n                *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\"\r\n                  type=\"button\" class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n                  <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\" style=\"font-size: 14px;\"></i>\r\n                </button>\r\n              </ng-container>\r\n            </ng-container>\r\n            <span *ngIf=\"column.type === 'number'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'datetime'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'date'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'time'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'HH:mm'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'HH:mm'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'bool'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\"\r\n              (click)=\"column.click && column.click(item[column.field], item)\">\r\n              <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n              <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n            <ng-container *ngIf=\"column.type === 'values'\">\r\n              <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n                <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                  [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                  {{dic.text}}\r\n                </span>\r\n                <ng-template #elseNoStatus>\r\n                  <span class=\"c-mobile-value\">\r\n                    {{dic.text}}\r\n                  </span>\r\n                </ng-template>\r\n              </ng-container>\r\n              <ng-template #elseNotInDic>\r\n                <span class=\"c-mobile-value\">\r\n                  {{item[column.field]}}\r\n                </span>\r\n              </ng-template>\r\n            </ng-container>\r\n            <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n            <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n              [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n              (click)=\"column.click && column.click(item[column.field], item)\">\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n  </div>\r\n</ng-container> -->",
        styles: [".c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge a{color:#fff}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase;width:100%}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridMobileColumnViewComponent);

// Document: http://www.daterangepicker.com/
let DateRangePickerControlComponent = class DateRangePickerControlComponent {
    constructor(ref, deviceService, translateService) {
        this.ref = ref;
        this.translateService = translateService;
        this.isMobileOrTablet = false;
        this.initialized = false;
        this.pMinDate = null;
        this.pMaxDate = null;
        this.name = v4();
        this.model = '';
        this.type = 'datetime';
        this.disabled = false;
        this.required = false;
        this.sdChange = new EventEmitter();
        this.fromDateChange = new EventEmitter();
        this.toDateChange = new EventEmitter();
        this.onFocus = () => {
            $$1(this.control.nativeElement).trigger('blur');
        };
        this.onChanges = () => {
        };
        this.clear = () => {
            // ($(this.control.nativeElement) as any).val('');
            this.model = '';
            const fromDate = null;
            const toDate = null;
            this.pFromDate = fromDate;
            this.pToDate = toDate;
            this.fromDateChange.emit(this.pFromDate);
            this.toDateChange.emit(this.pToDate);
            this.sdChange.emit({ fromDate, toDate });
            this.ref.detectChanges();
        };
        this.reload = (startDate, endDate) => {
            this.model = startDate + ' - ' + endDate;
            // ($(this.control.nativeElement) as any).val(startDate + ' - ' + endDate);
            this.ref.detectChanges();
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    get format() {
        let format = 'DD/MM/YYYY';
        if (this.type === 'datetime') {
            format = 'DD/MM/YYYY hh:mm';
        }
        else if (this.type === 'time') {
            format = 'hh:mm';
        }
        return format;
    }
    set minDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        this.pMinDate = val;
        if (this.initialized) {
            this.setOption();
        }
    }
    set maxDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        this.pMaxDate = val;
        if (this.initialized) {
            this.setOption();
        }
    }
    set fromDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        else {
            val = Date.toFormat(val, 'MM/dd/yyyy HH:mm');
        }
        if (this.initialized) {
            if (this.pFromDate !== val) {
                if (val) {
                    $$1(this.control.nativeElement)
                        .data('daterangepicker').setStartDate(moment(val, 'MM/DD/YYYY hh:mm').format(this.format));
                    this.reload(val, this.pToDate);
                }
            }
        }
        this.pFromDate = val;
        this.ref.detectChanges();
    }
    set toDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        else {
            val = Date.toFormat(val, 'MM/dd/yyyy HH:mm');
        }
        if (this.initialized) {
            if (this.pToDate !== val) {
                if (val) {
                    $$1(this.control.nativeElement)
                        .data('daterangepicker').setEndDate(moment(val, 'MM/DD/YYYY hh:mm').format(this.format));
                    this.reload(this.pFromDate, val);
                }
            }
        }
        this.pToDate = val;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.setOption();
        this.ref.detectChanges();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).daterangepicker({
                autoUpdateInput: false,
                timePicker: this.type === 'datetime' || this.type === 'time',
                timePicker24Hour: true,
                locale: {
                    // format: this.format,
                    // separator: ' - ',
                    applyLabel: this.translateService.translate('Apply'),
                    cancelLabel: this.translateService.translate('Clear'),
                    fromLabel: this.translateService.translate('From'),
                    toLabel: this.translateService.translate('To'),
                    customRangeLabel: this.translateService.translate('Custom'),
                    weekLabel: 'W',
                    daysOfWeek: [
                        this.translateService.translate('Su'),
                        this.translateService.translate('Mo'),
                        this.translateService.translate('Tu'),
                        this.translateService.translate('We'),
                        this.translateService.translate('Th'),
                        this.translateService.translate('Fr'),
                        this.translateService.translate('Sa')
                    ],
                    monthNames: [
                        this.translateService.translate('January'),
                        this.translateService.translate('February'),
                        this.translateService.translate('March'),
                        this.translateService.translate('April'),
                        this.translateService.translate('May'),
                        this.translateService.translate('June'),
                        this.translateService.translate('July'),
                        this.translateService.translate('August'),
                        this.translateService.translate('September'),
                        this.translateService.translate('October'),
                        this.translateService.translate('November'),
                        this.translateService.translate('December')
                    ],
                    firstDay: 1
                },
                startDate: Date.isDate(this.pFromDate) ? moment(this.pFromDate).format(this.format) : undefined,
                endDate: Date.isDate(this.pToDate) ? moment(this.pToDate).format(this.format) : undefined,
                minDate: Date.isDate(this.pMinDate) ? moment(this.pMinDate).format(this.format) : undefined,
                maxDate: Date.isDate(this.pMaxDate) ? moment(this.pMaxDate).format(this.format) : undefined,
            }, (fDate, tDate, label) => {
                const fromDate = fDate.format('MM/DD/YYYY HH:mm');
                const toDate = tDate.format('MM/DD/YYYY HH:mm');
                this.pFromDate = fromDate;
                this.pToDate = toDate;
                this.fromDateChange.emit(this.pFromDate);
                this.toDateChange.emit(this.pToDate);
                this.sdChange.emit({ fromDate, toDate });
                this.ref.detectChanges();
            });
            $$1(this.control.nativeElement).on('apply.daterangepicker', (ev, picker) => {
                if (picker.startDate && picker.endDate) {
                    const startDate = picker.startDate.format(this.format);
                    const endDate = picker.endDate.format(this.format);
                    this.reload(startDate, endDate);
                }
            });
            $$1(this.control.nativeElement).on('cancel.daterangepicker', this.clear);
        }
    }
};
DateRangePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: TranslateService }
];
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "minDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "maxDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "fromDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "toDate", null);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "fromDateChange", void 0);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "toDateChange", void 0);
__decorate([
    ViewChild('control')
], DateRangePickerControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], DateRangePickerControlComponent.prototype, "formModel", void 0);
DateRangePickerControlComponent = __decorate([
    Component({
        selector: 'sd-date-range-picker-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input #formModel=\"ngModel\" [ngModel]=\"model\" class=\"sd-input\" [name]=\"name\" autocomplete=\"false\" #control matInput\r\n    placeholder=\"{{label}}\" (focus)=\"onFocus()\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"off\">\r\n  <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}"]
    })
], DateRangePickerControlComponent);

let BottomSheetComponent = class BottomSheetComponent {
    constructor(bottomSheet) {
        this.bottomSheet = bottomSheet;
        this.isOpened = false;
        this.open = () => {
            this.isOpened = true;
            this.bottomSheet.open(this.templateRef);
        };
        this.close = () => {
            this.bottomSheet.dismiss();
        };
    }
};
BottomSheetComponent.ctorParameters = () => [
    { type: MatBottomSheet }
];
__decorate([
    ViewChild('templateRef')
], BottomSheetComponent.prototype, "templateRef", void 0);
__decorate([
    Input()
], BottomSheetComponent.prototype, "title", void 0);
BottomSheetComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet',
        template: "<ng-template #templateRef>\r\n  <ng-container *ngIf=\"isOpened\">\r\n    <sd-bottom-sheet-header *ngIf=\"title\">{{title}}</sd-bottom-sheet-header>\r\n    <ng-content></ng-content>\r\n  </ng-container>\r\n</ng-template>"
    })
], BottomSheetComponent);

let BottomSheetBodyComponent = class BottomSheetBodyComponent {
    constructor() {
        this.height = 'auto';
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], BottomSheetBodyComponent.prototype, "height", void 0);
BottomSheetBodyComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-body',
        template: "<div class=\"c-body\" [ngStyle]=\"{'height': height}\">\r\n  <ng-content></ng-content>\r\n<div>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-body{display:block;margin:0 -16px;padding:0 16px;max-height:80vh;overflow:auto}"]
    })
], BottomSheetBodyComponent);

let BottomSheetFooterComponent = class BottomSheetFooterComponent {
    constructor() { }
    ngOnInit() {
    }
};
BottomSheetFooterComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-footer',
        template: "<!-- <div class=\"modal-footer\" style=\"padding:5px\"><ng-content></ng-content></div> -->\r\n<div class=\"c-footer\">\r\n  <ng-content></ng-content>\r\n</div>",
        styles: [".c-footer{padding-top:5px;flex:auto;display:flex}"]
    })
], BottomSheetFooterComponent);

let BottomSheetHeaderComponent = class BottomSheetHeaderComponent {
    constructor() { }
    ngOnInit() {
    }
};
BottomSheetHeaderComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-header',
        template: "<h3 mat-dialog-title><ng-content></ng-content></h3>"
    })
], BottomSheetHeaderComponent);

let ButtonComponent = class ButtonComponent {
    constructor(ref) {
        this.ref = ref;
        this.pDisabled = false;
        this.initialized = false;
        this.isDisabled = false;
        this.color = undefined;
        // tslint:disable-next-line: max-line-length
        this.fontSet = 'material-icons';
        this.loading = false;
        this.action = new EventEmitter();
        this.onClick = ($event) => {
            if (this.loading) {
                return;
            }
            this.action.emit($event);
        };
    }
    set disabled(value) {
        this.pDisabled = value || false;
        if (this.initialized) {
            this.onChanges();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.initialized = true;
        this.onChanges();
    }
    onChanges() {
        this.isDisabled = this.pDisabled;
        this.ref.detectChanges();
    }
};
ButtonComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], ButtonComponent.prototype, "color", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "title", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "icon", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "width", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "size", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "tooltip", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "fontSet", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "disabled", null);
__decorate([
    Input()
], ButtonComponent.prototype, "loading", void 0);
__decorate([
    Output()
], ButtonComponent.prototype, "action", void 0);
ButtonComponent = __decorate([
    Component({
        selector: 'sd-button',
        template: "<button *ngIf=\"title\" [ngStyle]=\"{'width':width}\" class=\"c-button\" [ngClass]=\"{'c-sm': size === 'sm'}\" type=\"button\" \r\n  (click)=\"onClick($event)\" [color]=\"color\" [disabled]=\"isDisabled\" matTooltipPosition=\"above\"\r\n  [matTooltip]=\"tooltip\" mat-raised-button>\r\n  <mat-icon [fontSet]=\"fontSet\">{{icon}}</mat-icon>\r\n  {{title}}\r\n</button>\r\n<button *ngIf=\"!title\" [ngStyle]=\"{'width':width}\" class=\"c-button\" [ngClass]=\"{'c-sm': size === 'sm'}\" type=\"button\" \r\n  (click)=\"onClick($event)\" [color]=\"color\" [disabled]=\"isDisabled\" matTooltipPosition=\"above\"\r\n  [matTooltip]=\"tooltip\" mat-icon-button>\r\n  <mat-icon [fontSet]=\"fontSet\">{{icon}}</mat-icon>\r\n</button>",
        styles: ["button.c-button.c-sm{font-size:12px!important;line-height:24px!important;padding:2px 8px!important}button.c-button.c-sm mat-icon{height:20px!important;width:20px!important;font-size:20px!important}button.c-button:focus{outline:0}"]
    })
], ButtonComponent);

let DesktopDirective = class DesktopDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isDesktop()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
DesktopDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
DesktopDirective = __decorate([
    Directive({
        selector: '[sdDesktop]'
    })
], DesktopDirective);

let MobileDirective = class MobileDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isMobile()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
MobileDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
MobileDirective = __decorate([
    Directive({
        selector: '[sdMobile]'
    })
], MobileDirective);

let TabletDirective = class TabletDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isTablet()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
TabletDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
TabletDirective = __decorate([
    Directive({
        selector: '[sdTablet]'
    })
], TabletDirective);

let MobileTabletDirective = class MobileTabletDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isMobile() || deviceService.isTablet()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
MobileTabletDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
MobileTabletDirective = __decorate([
    Directive({
        selector: '[sdMobileTablet]'
    })
], MobileTabletDirective);

let GridPopupQuickFilterDetailComponent = class GridPopupQuickFilterDetailComponent {
    constructor(ref, deviceService, settingService, notifyService, translateService) {
        this.ref = ref;
        this.settingService = settingService;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.displayKey = 'SDCUSTOM';
        this.isMobileOrTablet = false;
        this.accept = new EventEmitter();
        this.fields = [];
        this.selectableFields = [];
        this.columns = [];
        this.externalFilters = [];
        this.filter = {};
        this.externalFilter = {};
        this.selectedFields = [];
        this.page = 1;
        this.onAccept = () => {
            const execute = () => {
                const filter = {};
                const externalFilter = {};
                Object.keys(this.filter).forEach(key => {
                    if (this.filter[key] === undefined || this.filter[key] === null || this.filter[key] === '') {
                        return;
                    }
                    if (!this.fields.some(e => e.group === 'column' && e.code === key)) {
                        return;
                    }
                    filter[key] = this.filter[key];
                });
                Object.keys(this.externalFilter).forEach(key => {
                    if (this.externalFilter[key] === undefined || this.externalFilter[key] === null || this.externalFilter[key] === '') {
                        return;
                    }
                    if (!this.fields.some(e => e.group === 'external' && e.code === key)) {
                        return;
                    }
                    externalFilter[key] = this.externalFilter[key];
                });
                this.accept.emit({
                    code: this.code,
                    filter,
                    externalFilter
                });
                this.modal.close();
            };
            if (!this.code) {
                this.notifyService.confirmWithInput('Enter your quick filter name').then((value) => {
                    if (value) {
                        this.code = value;
                        execute();
                    }
                });
            }
            else {
                execute();
            }
        };
        this.onCancel = () => {
            this.modal.close();
        };
        this.onSelectField = (values) => {
            this.fields = this.selectableFields.filter(e => values.some(v => e.code === v));
            for (const field of this.fields) {
                if (field.group === 'external' && field.type.includes('range')) {
                    this.externalFilter[field.code] = this.externalFilter[field.code] || {};
                }
            }
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
    }
    open(columns, externalFilters, filter, externalFilter, code) {
        var _a, _b;
        this.fields = [];
        this.filter = {};
        this.externalFilter = {};
        this.columns = columns;
        this.externalFilters = externalFilters;
        this.code = code;
        if (filter) {
            Object.keys(filter).forEach(key => {
                if (filter[key] === undefined || filter[key] === null || filter[key] === '') {
                    return;
                }
                const column = columns.find(e => e.field === key);
                if (!column) {
                    return;
                }
                this.filter[key] = filter[key];
                this.fields.push(Object.assign(Object.assign({}, column), { group: 'column', type: column.type, code: column.field, title: column.title }));
            });
        }
        if (externalFilter) {
            Object.keys(externalFilter).forEach(key => {
                var _a, _b, _c, _d;
                if (externalFilter[key] === undefined || externalFilter[key] === null || externalFilter[key] === '') {
                    return;
                }
                const item = externalFilters.find(e => e.field === key);
                if (!item) {
                    return;
                }
                if (item.type === 'daterange' || item.type === 'numberrange') {
                    this.externalFilter[key] = Object.assign({}, externalFilter[key]);
                    if (!((_a = externalFilter[key]) === null || _a === void 0 ? void 0 : _a.from) && !((_b = externalFilter[key]) === null || _b === void 0 ? void 0 : _b.to)) {
                        return;
                    }
                    this.fields.push(Object.assign(Object.assign({}, item), { group: 'external', type: item.type, code: item.field, title: item.title, fromTitle: item.fromTitle, toTitle: item.toTitle }));
                }
                else if (item.type === 'daterangefull') {
                    this.externalFilter[key] = Object.assign({}, externalFilter[key]);
                    if (!((_c = externalFilter[key]) === null || _c === void 0 ? void 0 : _c.from) && !((_d = externalFilter[key]) === null || _d === void 0 ? void 0 : _d.to)) {
                        return;
                    }
                    this.fields.push(Object.assign(Object.assign({}, item), { group: 'external', type: item.type, code: item.field, title: item.title }));
                }
                else {
                    this.externalFilter[key] = externalFilter[key];
                    this.fields.push(Object.assign(Object.assign({}, item), { group: 'external', type: item.type, code: item.field, title: item.title }));
                }
            });
        }
        const externalFields = ((_a = externalFilters) === null || _a === void 0 ? void 0 : _a.map(e => (Object.assign(Object.assign({}, e), { group: 'external', code: e.field, type: e.type, title: e.title })))) || [];
        const columnFields = ((_b = columns) === null || _b === void 0 ? void 0 : _b.map(e => (Object.assign(Object.assign({}, e), { group: 'column', code: e.field, type: e.type, title: e.title })))) || [];
        this.selectableFields = [...externalFields, ...columnFields];
        this.selectedFields = this.fields.map(e => e.code);
        this.modal.open();
    }
};
GridPopupQuickFilterDetailComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: SettingService },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridPopupQuickFilterDetailComponent.prototype, "modal", void 0);
__decorate([
    Output()
], GridPopupQuickFilterDetailComponent.prototype, "accept", void 0);
GridPopupQuickFilterDetailComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-quick-filter-detail',
        template: "<sd-modal-control width=\"sm\" [title]=\"(code ? 'Update quick filter':'Create quick filter') | sdTranslate\" #modal>\r\n  <sd-modal-body>\r\n    <div class=\"row\">\r\n      <div class=\"col-12\">\r\n        <sd-select-control [label]=\"'Filterable fields' | sdTranslate\" multiple=\"true\" [(model)]=\"selectedFields\"\r\n          [items]=\"selectableFields\" (sdChange)=\"onSelectField($event)\" valueField=\"code\" displayField=\"title\">\r\n        </sd-select-control>\r\n      </div>\r\n      <div class=\"col-12\" *ngFor=\"let item of fields\">\r\n        <ng-container *ngIf=\"item.group === 'external'\">\r\n          <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\"\r\n            [(model)]=\"externalFilter[item.code]\">\r\n          </sd-input-control>\r\n          <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n            [(model)]=\"externalFilter[item.code]\">\r\n          </sd-input-control>\r\n          <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\" [{value:'1',display:item.trueValue || 'True' },\r\n            {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n            [(model)]=\"externalFilter[item.code]\">\r\n          </sd-select-control>\r\n          <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.code]\">\r\n          </sd-radio-control>\r\n          <ng-container *ngIf=\"item.type === 'values'\">\r\n            <sd-select-control *ngIf=\"item.selection === 'MULTIPLE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n              [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.code]\"\r\n              multiple=\"true\">\r\n            </sd-select-control>\r\n            <sd-autocomplete-control *ngIf=\"item.selection === 'AUTOCOMPLETE'\" [label]=\"item.title\"\r\n              [items]=\"item.values\" [valueField]=\"item.valueField\" [displayField]=\"item.displayField\"\r\n              [(model)]=\"externalFilter[item.code]\">\r\n            </sd-autocomplete-control>\r\n            <sd-chip-control *ngIf=\"item.selection === 'MULTIPLEAUTOCOMPLETE'\" [label]=\"item.title\"\r\n              [items]=\"item.values\" [valueField]=\"item.valueField\" [displayField]=\"item.displayField\"\r\n              [(model)]=\"externalFilter[item.code]\">\r\n            </sd-chip-control>\r\n            <sd-select-control *ngIf=\"!item.selection\" [label]=\"item.title\" [items]=\"item.values\"\r\n              [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.code]\">\r\n            </sd-select-control>\r\n          </ng-container>\r\n          <sd-input-control *ngIf=\"item.type === 'custom'\" [label]=\"item.title\"\r\n            [(model)]=\"externalFilter[displayKey + item.code]\"\r\n            (sdClick)=\"item?.onClick(externalFilter, item.code, displayKey + item.code)\">\r\n          </sd-input-control>\r\n          <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.code]\"\r\n            type=\"date\">\r\n          </sd-date-picker-control>\r\n          <sd-date-range-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='daterangefull'\"\r\n            [(fromDate)]=\"externalFilter[item.code].from\" [(toDate)]=\"externalFilter[item.code].to\"\r\n            [minDate]=\"item.minDate\" [maxDate]=\"item.maxDate\" type=\"date\">\r\n          </sd-date-range-picker-control>\r\n          <ng-container *ngIf=\"item.type ==='daterange'\">\r\n            <div class=\"row\">\r\n              <div class=\"col-6\">\r\n                <sd-date-picker-control [label]=\"item.fromTitle\" [(model)]=\"externalFilter[item.code].from\"\r\n                  [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate\"\r\n                  [maxDate]=\"externalFilter[item.code].to || item.maxDate\">\r\n                </sd-date-picker-control>\r\n              </div>\r\n              <div class=\"col-6\">\r\n                <sd-date-picker-control [label]=\"item.toTitle\" [(model)]=\"externalFilter[item.code].to\"\r\n                  [type]=\"item.enableTime ? 'datetime' : 'date'\"\r\n                  [minDate]=\"item.minDate || externalFilter[item.code].from\" [maxDate]=\"item.maxDate\">\r\n                </sd-date-picker-control>\r\n              </div>\r\n            </div>\r\n          </ng-container>\r\n          <div class=\"row\" *ngIf=\"item.type ==='numberrange'\">\r\n            <div class=\"col-6\">\r\n              <sd-input-control [label]=\"item.fromTitle\" type=\" number\" [(model)]=\"externalFilter[item.code].from\">\r\n              </sd-input-control>\r\n            </div>\r\n            <div class=\"col-6\">\r\n              <sd-input-control [label]=\"item.toTitle\" type=\" number\" [(model)]=\"externalFilter[item.code].to\">\r\n              </sd-input-control>\r\n            </div>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"item.group === 'column'\">\r\n          <sd-input-control *ngIf=\"item.type === 'string'\" [label]=\"item.title\" type=\"text\"\r\n            [(model)]=\"filter[item.code]\">\r\n          </sd-input-control>\r\n          <sd-input-control *ngIf=\"item.type === 'number'\" [label]=\"item.title\" type=\" number\"\r\n            [(model)]=\"filter[item.code]\">\r\n          </sd-input-control>\r\n          <sd-radio-control *ngIf=\"item.type === 'bool'\" [label]=\"item.title\" [items]=\"[{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" [(model)]=\"filter[item.code]\">\r\n          </sd-radio-control>\r\n          <sd-radio-control *ngIf=\"item.type === 'radio'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"filter[item.code]\">\r\n          </sd-radio-control>\r\n          <sd-autocomplete-control *ngIf=\"item.type === 'values'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            valueField=\"value\" displayField=\"text\" [(model)]=\"filter[item.code]\">\r\n          </sd-autocomplete-control>\r\n          <sd-date-picker-control *ngIf=\"item.type ==='date' || item.type==='datetime' ||\r\n          item.type==='time'\" [label]=\"item.title\" [(model)]=\" filter[item.code]\" type=\"date\">\r\n          </sd-date-picker-control>\r\n        </ng-container>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <sd-button class=\"mr-auto\" (action)=\"onCancel()\" icon=\"clear\" [title]=\"'Cancel' | sdTranslate\"></sd-button>\r\n    <sd-button (action)=\"onAccept()\" icon=\"done\" [title]=\"'Accept' | sdTranslate\" color=\"primary\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button style=\"flex: 1; padding-right: 5px;\" (action)=\"onCancel()\" icon=\"clear\" [title]=\"'Cancel' | sdTranslate\"\r\n      width=\"100%\"></sd-button>\r\n    <sd-button style=\"flex: 1; padding-left: 5px;\" (action)=\"onAccept()\" icon=\"done\" [title]=\"'Accept' | sdTranslate\"\r\n      color=\"primary\" width=\"100%\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}.daterangepicker{z-index:99999}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", "fieldset.c-fieldset{border-radius:5px;border:1px solid #919191}legend.c-legend{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:20px}.c-quick-filter{display:inline-block;margin-right:5px;margin-bottom:10px;border:1px solid #919191;border-radius:20px;padding:2px 10px;cursor:pointer}.c-quick-filter.c-selected{border:1px solid #00bcd4;background-color:#00bcd4;color:#fff}.c-quick-filter span{font-size:16px}.c-quick-filter i{font-size:16px;margin-left:12px;cursor:pointer;opacity:.7}.c-quick-filter i:hover{opacity:1}"]
    })
], GridPopupQuickFilterDetailComponent);

var SuperdevAngularCoreModule_1;
let SuperdevAngularCoreModule = SuperdevAngularCoreModule_1 = class SuperdevAngularCoreModule {
    static forRoot() {
        return {
            ngModule: SuperdevAngularCoreModule_1,
            providers: [
                DatePipe,
                HandlerLocal,
                HandlerDotnet,
                ApiService,
                ConfigurationService,
                NotifyService,
                UtilityService,
                EditorHandlerPipe,
                TranslateService,
                CacheService,
                ExcelService,
                LoadingService,
                SettingService
            ]
        };
    }
    static forChild() {
        return {
            ngModule: SuperdevAngularCoreModule_1,
            providers: []
        };
    }
};
SuperdevAngularCoreModule = SuperdevAngularCoreModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            ReactiveFormsModule,
            HttpClientModule,
            MaterialModule,
            CKEditorModule,
            DeviceDetectorModule.forRoot()
        ],
        declarations: [
            GridControlComponent,
            GridConfigComponent,
            GridPopupExportExcelComponent,
            GridImportExcelComponent,
            GridPopupEditorComponent,
            GridSubInformationComponent,
            GridDesktopColumnViewComponent,
            GridDesktopColumnEditComponent,
            GridDesktopColumnChildrenViewComponent,
            GridDesktopInlineFilterComponent,
            GridMobileColumnViewComponent,
            UploadExcelConfigComponent,
            UploadExcelControlComponent,
            InputControlComponent,
            SelectControlComponent,
            ModalControl,
            DatePickerControlComponent,
            DateRangePickerControlComponent,
            ModalHeaderComponent,
            ModalBodyComponent,
            ModalFooterComponent,
            TextareaControlComponent,
            AutocompleteControlComponent,
            GridDatePickerControlComponent,
            GridAutocompleteControl,
            GridPopupFilterComponent,
            GridPopupQuickFilterDetailComponent,
            DesktopDirective,
            MobileDirective,
            TabletDirective,
            MobileTabletDirective,
            CheckboxControlComponent,
            SwitchControlComponent,
            RadioControlComponent,
            CkeditorControlComponent,
            ChartControlComponent,
            ChipControlComponent,
            UploadFileControlComponent,
            BottomSheetComponent,
            BottomSheetBodyComponent,
            BottomSheetFooterComponent,
            BottomSheetHeaderComponent,
            ButtonComponent,
            // Login Form
            Login01Component,
            // Pipes
            TranslatePipe,
            EditorHandlerPipe,
            EditorValidatePipe,
            EditorDynamicItemPipe,
            FilterMobilePipe,
            MobileCommandFilterPipe,
            ColumnHtmlTemplatePipe,
            ColumnTitlePipe,
            CommandIconPipe,
            CommandTitlePipe,
            CommandDisabledPipe,
            CommandHiddenByItemPipe,
            ColumnCommandFilterPipe,
            CellClassNamePipe,
            CellDesktopClassNamePipe,
            InputTooltipPipe,
            ValueTransformPipe,
            EditorSubInformationHandlerPipe,
            SafeHtmlPipe,
            // Validators
            SdMinDateValidator,
            SdMaxDateValidator,
            SdCustomValidator,
            SdChipMinItemValidator,
            // Components,
            DialogConfirmComponent
        ],
        exports: [
            MaterialModule,
            // Controls
            InputControlComponent,
            SelectControlComponent,
            DatePickerControlComponent,
            DateRangePickerControlComponent,
            GridControlComponent,
            UploadExcelControlComponent,
            TextareaControlComponent,
            AutocompleteControlComponent,
            ModalControl,
            ModalHeaderComponent,
            ModalBodyComponent,
            ModalFooterComponent,
            CheckboxControlComponent,
            SwitchControlComponent,
            RadioControlComponent,
            CkeditorControlComponent,
            ChartControlComponent,
            ChipControlComponent,
            UploadFileControlComponent,
            BottomSheetComponent,
            BottomSheetBodyComponent,
            BottomSheetFooterComponent,
            BottomSheetHeaderComponent,
            ButtonComponent,
            // Directives
            DesktopDirective,
            MobileDirective,
            TabletDirective,
            MobileTabletDirective,
            // Pipes
            TranslatePipe,
            // Components
            Login01Component
        ]
    })
], SuperdevAngularCoreModule);

/*
 * Public API Surface of superdev-angular-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ApiService, AutocompleteControlComponent, BottomSheetBodyComponent, BottomSheetComponent, BottomSheetFooterComponent, BottomSheetHeaderComponent, ButtonComponent, CacheService, ChartControlComponent, CheckboxControlComponent, CkeditorControlComponent, ConfigurationService, DatePickerControlComponent, DateRangePickerControlComponent, DesktopDirective, ExcelService, GridControlComponent, HandlerDotnet, HandlerLocal, InputControlComponent, LoadingService, MobileDirective, MobileTabletDirective, ModalBodyComponent, ModalControl, ModalFooterComponent, ModalHeaderComponent, NotifyService, RadioControlComponent, SelectControlComponent, SettingService, SuperdevAngularCoreModule, SwitchControlComponent, TabletDirective, TextareaControlComponent, TranslatePipe, TranslateService, UploadExcelControlComponent, UploadFileControlComponent, UtilityService, defaultGridOption, MaterialModule as ɵa, GridControlComponent as ɵb, SelectControlComponent as ɵba, ModalControl as ɵbb, DatePickerControlComponent as ɵbc, DateRangePickerControlComponent as ɵbd, ModalHeaderComponent as ɵbe, ModalBodyComponent as ɵbf, ModalFooterComponent as ɵbg, TextareaControlComponent as ɵbh, AutocompleteControlComponent as ɵbi, GridDatePickerControlComponent as ɵbj, GridAutocompleteControl as ɵbk, GridPopupFilterComponent as ɵbl, GridPopupQuickFilterDetailComponent as ɵbm, DesktopDirective as ɵbn, MobileDirective as ɵbo, TabletDirective as ɵbp, MobileTabletDirective as ɵbq, CheckboxControlComponent as ɵbr, SwitchControlComponent as ɵbs, RadioControlComponent as ɵbt, CkeditorControlComponent as ɵbu, ChartControlComponent as ɵbv, ChipControlComponent as ɵbw, UploadFileControlComponent as ɵbx, BottomSheetComponent as ɵby, BottomSheetBodyComponent as ɵbz, GridImportExcelComponent as ɵc, BottomSheetFooterComponent as ɵca, BottomSheetHeaderComponent as ɵcb, ButtonComponent as ɵcc, Login01Component as ɵcd, TranslatePipe as ɵce, EditorValidatePipe as ɵcf, EditorDynamicItemPipe as ɵcg, FilterMobilePipe as ɵch, MobileCommandFilterPipe as ɵci, ColumnHtmlTemplatePipe as ɵcj, ColumnTitlePipe as ɵck, CommandIconPipe as ɵcl, CommandTitlePipe as ɵcm, CommandDisabledPipe as ɵcn, CommandHiddenByItemPipe as ɵco, ColumnCommandFilterPipe as ɵcp, CellClassNamePipe as ɵcq, CellDesktopClassNamePipe as ɵcr, InputTooltipPipe as ɵcs, ValueTransformPipe as ɵct, EditorSubInformationHandlerPipe as ɵcu, SafeHtmlPipe as ɵcv, SdMinDateValidator as ɵcw, SdMaxDateValidator as ɵcx, SdCustomValidator as ɵcy, SdChipMinItemValidator as ɵcz, GridPopupExportExcelComponent as ɵd, DialogConfirmComponent as ɵda, CacheService as ɵdb, LoadingService as ɵe, ExcelService as ɵf, ConfigurationService as ɵg, NotifyService as ɵh, TranslateService as ɵi, HandlerLocal as ɵj, HandlerDotnet as ɵk, UtilityService as ɵl, ApiService as ɵm, EditorHandlerPipe as ɵn, GridConfigComponent as ɵo, SettingService as ɵp, GridPopupEditorComponent as ɵq, GridSubInformationComponent as ɵr, GridDesktopColumnViewComponent as ɵs, GridDesktopColumnEditComponent as ɵt, GridDesktopColumnChildrenViewComponent as ɵu, GridDesktopInlineFilterComponent as ɵv, GridMobileColumnViewComponent as ɵw, UploadExcelConfigComponent as ɵx, UploadExcelControlComponent as ɵy, InputControlComponent as ɵz };
//# sourceMappingURL=superdev-angular-core.js.map
